#!/usr/bin/perl

use strict;
use lib 't/lib';
use utf8;

use Test::More;
use Test::Deep qw(cmp_deeply);

use FusionInventory::Agent::SNMP::Mock;
use FusionInventory::Agent::Tools::Hardware;

my %tests = (
    'juniper/ex2200.01.walk' => [
        {
            TYPE         => 'NETWORKING',
            MANUFACTURER => 'Juniper',
            MODEL        => 'EX2200',
            DESCRIPTION  => 'Juniper Networks, Inc. ex2200-c-12p-2g internet router, kernel JUNOS 11.3R1.7 #0: 2011-08-30 11:49:21 UTC     builder@dagmath.juniper.net:/volume/build/junos/11.3/release/11.3R1.7/obj-arm/bsd/kernels/JUNIPER-EX-2200/kernel Build date: 2011-08-30 11:32:01',

            SNMPHOSTNAME => 'AB-B404-23-ex2200',
            UPTIME       => '(1896073543) 219 days, 10:52:15.43',
            IPS          => {
                IP => [
                    '128.0.0.1',
                    '128.0.0.127',
                    '128.0.0.16',
                    '128.0.0.32',
                    '192.168.1.23',
                ],
            },
        },
        {
            INFO => {
                ID           => undef,
                TYPE         => 'NETWORKING',
                MANUFACTURER => 'Juniper',
                MODEL        => 'EX2200',
                COMMENTS     => 'Juniper Networks, Inc. ex2200-c-12p-2g internet router, kernel JUNOS 11.3R1.7 #0: 2011-08-30 11:49:21 UTC     builder@dagmath.juniper.net:/volume/build/junos/11.3/release/11.3R1.7/obj-arm/bsd/kernels/JUNIPER-EX-2200/kernel Build date: 2011-08-30 11:32:01',
                NAME         => 'AB-B404-23-ex2200',
                UPTIME       => '(1896073543) 219 days, 10:52:15.43',
                IPS          => {
                    IP => [
                        '128.0.0.1',
                        '128.0.0.127',
                        '128.0.0.16',
                        '128.0.0.32',
                        '192.168.1.23',
                    ],
                },
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '4',
                        IFNAME           => 'lsi',
                        IFDESCR          => 'lsi',
                        IFTYPE           => '150',
                        IFSPEED          => '0',
                        IFMTU            => '1496',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(210618496) 24 days, 9:03:04.96',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5',
                        IFNAME           => 'dsc',
                        IFDESCR          => 'dsc',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(210651137) 24 days, 9:08:31.37',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '6',
                        IFNAME           => 'lo0',
                        IFDESCR          => 'lo0',
                        IFTYPE           => '24',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(210651144) 24 days, 9:08:31.44',
                        IFINOCTETS       => '3847149791',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3847149791',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '7',
                        IFNAME           => 'tap',
                        IFDESCR          => 'tap',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(210651150) 24 days, 9:08:31.50',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '8',
                        IFNAME           => 'gre',
                        IFDESCR          => 'gre',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(210651140) 24 days, 9:08:31.40',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '9',
                        IFNAME           => 'ipip',
                        IFDESCR          => 'ipip',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(210651143) 24 days, 9:08:31.43',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10',
                        IFNAME           => 'pime',
                        IFDESCR          => 'pime',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(210651130) 24 days, 9:08:31.30',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '11',
                        IFNAME           => 'pimd',
                        IFDESCR          => 'pimd',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(210651132) 24 days, 9:08:31.32',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '12',
                        IFNAME           => 'mtun',
                        IFDESCR          => 'mtun',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(210651149) 24 days, 9:08:31.49',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '33',
                        IFNAME           => 'me0',
                        IFDESCR          => 'me0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:df:20:3f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(210651147) 24 days, 9:08:31.47',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '37',
                        IFNAME           => 'bme0',
                        IFDESCR          => 'bme0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1576',
                        MAC              => '00:0b:ca:fe:00:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(210651124) 24 days, 9:08:31.24',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1660461977',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '38',
                        IFNAME           => 'bme0.32768',
                        IFDESCR          => 'bme0.32768',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1562',
                        IP               => '128.0.0.32',
                        MAC              => '00:0b:ca:fe:00:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(210651153) 24 days, 9:08:31.53',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '501',
                        IFNAME           => 'jsrv',
                        IFDESCR          => 'jsrv',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '78:fe:3d:df:20:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(795719864) 92 days, 2:19:58.64',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '502',
                        IFNAME           => 'jsrv.1',
                        IFDESCR          => 'jsrv.1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '128.0.0.127',
                        MAC              => '78:fe:3d:df:20:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(795719864) 92 days, 2:19:58.64',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '42',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '503',
                        IFNAME           => 'vlan',
                        IFDESCR          => 'vlan',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '78:fe:3d:df:20:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(210651161) 24 days, 9:08:31.61',
                        IFINOCTETS       => '2169597684',
                        IFINERRORS       => '22',
                        IFOUTOCTETS      => '378679611',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '504',
                        IFNAME           => 'ge-0/0/0',
                        IFDESCR          => 'ge-0/0/0',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:df:20:03',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2080979263) 240 days, 20:29:52.63',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '54996177',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3775595507',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '505',
                        IFNAME           => 'ge-0/0/1',
                        IFDESCR          => 'ge-0/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:df:20:04',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2081029863) 240 days, 20:38:18.63',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '42701777',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '8617260',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '506',
                        IFNAME           => 'ge-0/0/2',
                        IFDESCR          => 'ge-0/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:df:20:05',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2080957353) 240 days, 20:26:13.53',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '276103333',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1776301481',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '507',
                        IFNAME           => 'ge-0/0/3',
                        IFDESCR          => 'ge-0/0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:df:20:06',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2081042643) 240 days, 20:40:26.43',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '743174854',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1617417859',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '508',
                        IFNAME           => 'ge-0/0/4',
                        IFDESCR          => 'ge-0/0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:df:20:07',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2081034223) 240 days, 20:39:02.23',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '65424546',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '729029155',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '509',
                        IFNAME           => 'ge-0/0/5',
                        IFDESCR          => 'ge-0/0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:df:20:08',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2081071652) 240 days, 20:45:16.52',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '121426929',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '786124744',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '510',
                        IFNAME           => 'ge-0/0/6',
                        IFDESCR          => 'ge-0/0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:df:20:09',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2081053722) 240 days, 20:42:17.22',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '310326639',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1458885492',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '511',
                        IFNAME           => 'ge-0/0/7',
                        IFDESCR          => 'ge-0/0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:df:20:0a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(210651201) 24 days, 9:08:32.01',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '512',
                        IFNAME           => 'ge-0/0/8',
                        IFDESCR          => 'ge-0/0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:df:20:0b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(210651203) 24 days, 9:08:32.03',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '513',
                        IFNAME           => 'ge-0/0/0.0',
                        IFDESCR          => 'ge-0/0/0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:df:20:03',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2080979263) 240 days, 20:29:52.63',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '12422938',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '5825457',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '514',
                        IFNAME           => 'ge-0/0/9',
                        IFDESCR          => 'ge-0/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:df:20:0c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2080931282) 240 days, 20:21:52.82',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '703703523',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1577399105',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '515',
                        IFNAME           => 'ge-0/0/10',
                        IFDESCR          => 'ge-0/0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:df:20:0d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(210651209) 24 days, 9:08:32.09',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '516',
                        IFNAME           => 'ge-0/0/1.0',
                        IFDESCR          => 'ge-0/0/1.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:df:20:04',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2081029863) 240 days, 20:38:18.63',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '12416987',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '5824725',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '517',
                        IFNAME           => 'ge-0/0/11',
                        IFDESCR          => 'ge-0/0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:df:20:0e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2080999052) 240 days, 20:33:10.52',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '242475284',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1017324509',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '518',
                        IFNAME           => 'ge-0/0/2.0',
                        IFDESCR          => 'ge-0/0/2.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:df:20:05',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2080957353) 240 days, 20:26:13.53',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '37828621',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '127953081',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '519',
                        IFNAME           => 'ge-0/0/3.0',
                        IFDESCR          => 'ge-0/0/3.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:df:20:06',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2081042643) 240 days, 20:40:26.43',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '37862757',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '128037429',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '520',
                        IFNAME           => 'ge-0/0/4.0',
                        IFDESCR          => 'ge-0/0/4.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:df:20:07',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2081034223) 240 days, 20:39:02.23',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '18172757',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '33823397',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '521',
                        IFNAME           => 'ge-0/0/5.0',
                        IFDESCR          => 'ge-0/0/5.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:df:20:08',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2081071652) 240 days, 20:45:16.52',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '35637120',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '117501872',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '522',
                        IFNAME           => 'ge-0/0/6.0',
                        IFDESCR          => 'ge-0/0/6.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:df:20:09',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2081053722) 240 days, 20:42:17.22',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '38298814',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '130188996',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '523',
                        IFNAME           => 'ge-0/0/7.0',
                        IFDESCR          => 'ge-0/0/7.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:df:20:0a',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(210651217) 24 days, 9:08:32.17',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '524',
                        IFNAME           => 'ge-0/0/8.0',
                        IFDESCR          => 'ge-0/0/8.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:df:20:0b',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(210651220) 24 days, 9:08:32.20',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '525',
                        IFNAME           => 'ge-0/0/9.0',
                        IFDESCR          => 'ge-0/0/9.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:df:20:0c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2080931282) 240 days, 20:21:52.82',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '37907646',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '128195994',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '526',
                        IFNAME           => 'ge-0/0/10.0',
                        IFDESCR          => 'ge-0/0/10.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:df:20:0d',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(210651225) 24 days, 9:08:32.25',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '527',
                        IFNAME           => 'ge-0/0/11.0',
                        IFDESCR          => 'ge-0/0/11.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:df:20:0e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2080999052) 240 days, 20:33:10.52',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '33695673',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '108809558',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '528',
                        IFNAME           => 'ge-0/1/0',
                        IFDESCR          => 'ge-0/1/0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:df:20:0f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(210651230) 24 days, 9:08:32.30',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '529',
                        IFNAME           => 'ge-0/1/0.0',
                        IFDESCR          => 'ge-0/1/0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:df:20:0f',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(210651234) 24 days, 9:08:32.34',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '530',
                        IFNAME           => 'ge-0/1/1',
                        IFDESCR          => 'ge-0/1/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:df:20:10',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(210651853) 24 days, 9:08:38.53',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1984754089',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2897992952',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '531',
                        IFNAME           => 'ge-0/1/1.0',
                        IFDESCR          => 'ge-0/1/1.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:df:20:10',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(210651853) 24 days, 9:08:38.53',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3925538024',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '515351797',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '532',
                        IFNAME           => 'vlan.0',
                        IFDESCR          => 'vlan.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '192.168.1.23',
                        MAC              => '78:fe:3d:df:20:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(210651853) 24 days, 9:08:38.53',
                        IFINOCTETS       => '2169600207',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '344650884',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        },
    ],
    'juniper/ex2200.02.walk' => [
        {
            TYPE         => 'NETWORKING',
            MANUFACTURER => 'Juniper',
            MODEL        => 'EX2200',
            DESCRIPTION  => 'Juniper Networks, Inc. ex2200-c-12p-2g internet router, kernel JUNOS 11.4R1.6 #0: 2011-11-15 10:11:59 UTC     builder@evenath.juniper.net:/volume/build/junos/11.4/release/11.4R1.6/obj-arm/bsd/kernels/JUNIPER-EX-2200/kernel Build date: 2011-11-15 09:57:14',

            SNMPHOSTNAME => 'C005-236b-ex2200',
            UPTIME       => '(1539344336) 178 days, 3:57:23.36',
            IPS          => {
                IP => [
                    '128.0.0.1',
                    '128.0.0.127',
                    '128.0.0.16',
                    '128.0.0.32',
                    '192.168.1.236',
                ],
            },
        },
        {
            INFO => {
                ID           => undef,
                TYPE         => 'NETWORKING',
                MANUFACTURER => 'Juniper',
                MODEL        => 'EX2200',
                COMMENTS     => 'Juniper Networks, Inc. ex2200-c-12p-2g internet router, kernel JUNOS 11.4R1.6 #0: 2011-11-15 10:11:59 UTC     builder@evenath.juniper.net:/volume/build/junos/11.4/release/11.4R1.6/obj-arm/bsd/kernels/JUNIPER-EX-2200/kernel Build date: 2011-11-15 09:57:14',
                NAME         => 'C005-236b-ex2200',
                UPTIME       => '(1539344336) 178 days, 3:57:23.36',
                IPS          => {
                    IP => [
                        '128.0.0.1',
                        '128.0.0.127',
                        '128.0.0.16',
                        '128.0.0.32',
                        '192.168.1.236',
                    ],
                },
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '4',
                        IFNAME           => 'lsi',
                        IFDESCR          => 'lsi',
                        IFTYPE           => '150',
                        IFSPEED          => '0',
                        IFMTU            => '1496',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5',
                        IFNAME           => 'dsc',
                        IFDESCR          => 'dsc',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1328) 0:00:13.28',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '6',
                        IFNAME           => 'lo0',
                        IFDESCR          => 'lo0',
                        IFTYPE           => '24',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1356) 0:00:13.56',
                        IFINOCTETS       => '1205099385',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1205099385',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '7',
                        IFNAME           => 'tap',
                        IFDESCR          => 'tap',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1371) 0:00:13.71',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '8',
                        IFNAME           => 'gre',
                        IFDESCR          => 'gre',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1336) 0:00:13.36',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '9',
                        IFNAME           => 'ipip',
                        IFDESCR          => 'ipip',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1352) 0:00:13.52',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10',
                        IFNAME           => 'pime',
                        IFDESCR          => 'pime',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1271) 0:00:12.71',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '11',
                        IFNAME           => 'pimd',
                        IFDESCR          => 'pimd',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1274) 0:00:12.74',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '12',
                        IFNAME           => 'mtun',
                        IFDESCR          => 'mtun',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1363) 0:00:13.63',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '33',
                        IFNAME           => 'me0',
                        IFDESCR          => 'me0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '64:87:88:b0:39:ff',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1358) 0:00:13.58',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '37',
                        IFNAME           => 'bme0',
                        IFDESCR          => 'bme0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1576',
                        MAC              => '00:0b:ca:fe:00:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1268) 0:00:12.68',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '534363148',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '38',
                        IFNAME           => 'bme0.32768',
                        IFDESCR          => 'bme0.32768',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1562',
                        IP               => '128.0.0.32',
                        MAC              => '00:0b:ca:fe:00:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1377) 0:00:13.77',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '501',
                        IFNAME           => 'jsrv',
                        IFDESCR          => 'jsrv',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '64:87:88:b0:39:c0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1288) 0:00:12.88',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '502',
                        IFNAME           => 'jsrv.1',
                        IFDESCR          => 'jsrv.1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '128.0.0.127',
                        MAC              => '64:87:88:b0:39:c0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1292) 0:00:12.92',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '42',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '503',
                        IFNAME           => 'vlan',
                        IFDESCR          => 'vlan',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '64:87:88:b0:39:c1',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1391) 0:00:13.91',
                        IFINOCTETS       => '1895692302',
                        IFINERRORS       => '18',
                        IFOUTOCTETS      => '350482164',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '504',
                        IFNAME           => 'ge-0/0/0',
                        IFDESCR          => 'ge-0/0/0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '64:87:88:b0:39:c3',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1404) 0:00:14.04',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '505',
                        IFNAME           => 'ge-0/0/0.0',
                        IFDESCR          => 'ge-0/0/0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '64:87:88:b0:39:c3',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1407) 0:00:14.07',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '506',
                        IFNAME           => 'ge-0/0/1',
                        IFDESCR          => 'ge-0/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '64:87:88:b0:39:c4',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1519198217) 175 days, 19:59:42.17',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '671285559',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1344808667',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '507',
                        IFNAME           => 'ge-0/0/1.0',
                        IFDESCR          => 'ge-0/0/1.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '64:87:88:b0:39:c4',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1519198217) 175 days, 19:59:42.17',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '19465116',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '5704',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '508',
                        IFNAME           => 'ge-0/0/2',
                        IFDESCR          => 'ge-0/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '64:87:88:b0:39:c5',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1428) 0:00:14.28',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '509',
                        IFNAME           => 'ge-0/0/2.0',
                        IFDESCR          => 'ge-0/0/2.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '64:87:88:b0:39:c5',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1441) 0:00:14.41',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '510',
                        IFNAME           => 'ge-0/0/3',
                        IFDESCR          => 'ge-0/0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '64:87:88:b0:39:c6',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1519237117) 175 days, 20:06:11.17',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1801889333',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2786297666',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '511',
                        IFNAME           => 'ge-0/0/3.0',
                        IFDESCR          => 'ge-0/0/3.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '64:87:88:b0:39:c6',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1519237117) 175 days, 20:06:11.17',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '30642324',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6670',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '512',
                        IFNAME           => 'ge-0/0/4',
                        IFDESCR          => 'ge-0/0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '64:87:88:b0:39:c7',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1519160047) 175 days, 19:53:20.47',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '749044509',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1606606341',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '513',
                        IFNAME           => 'ge-0/0/4.0',
                        IFDESCR          => 'ge-0/0/4.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '64:87:88:b0:39:c7',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1519160047) 175 days, 19:53:20.47',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '24091394',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6578',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '514',
                        IFNAME           => 'ge-0/0/5',
                        IFDESCR          => 'ge-0/0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '64:87:88:b0:39:c8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1520147727) 175 days, 22:37:57.27',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1460221696',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2680801766',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '515',
                        IFNAME           => 'ge-0/0/5.0',
                        IFDESCR          => 'ge-0/0/5.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '64:87:88:b0:39:c8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1520147727) 175 days, 22:37:57.27',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '24573648',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '7636',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '516',
                        IFNAME           => 'ge-0/0/6',
                        IFDESCR          => 'ge-0/0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '64:87:88:b0:39:c9',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1519144687) 175 days, 19:50:46.87',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1204472549',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2280812113',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '517',
                        IFNAME           => 'ge-0/0/6.0',
                        IFDESCR          => 'ge-0/0/6.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '64:87:88:b0:39:c9',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1519144687) 175 days, 19:50:46.87',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '25579766',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4784',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '518',
                        IFNAME           => 'ge-0/0/7',
                        IFDESCR          => 'ge-0/0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '64:87:88:b0:39:ca',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(276784128) 32 days, 0:50:41.28',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1884',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '538',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '519',
                        IFNAME           => 'ge-0/0/7.0',
                        IFDESCR          => 'ge-0/0/7.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '64:87:88:b0:39:ca',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(276784128) 32 days, 0:50:41.28',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '826',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '92',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '520',
                        IFNAME           => 'ge-0/0/8',
                        IFDESCR          => 'ge-0/0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '64:87:88:b0:39:cb',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1519114587) 175 days, 19:45:45.87',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1293235433',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2255802556',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '521',
                        IFNAME           => 'ge-0/0/9',
                        IFDESCR          => 'ge-0/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '64:87:88:b0:39:cc',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(276799604) 32 days, 0:53:16.04',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1998',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '576',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '522',
                        IFNAME           => 'ge-0/0/10',
                        IFDESCR          => 'ge-0/0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '64:87:88:b0:39:cd',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1507) 0:00:15.07',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '523',
                        IFNAME           => 'ge-0/0/8.0',
                        IFDESCR          => 'ge-0/0/8.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '64:87:88:b0:39:cb',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1519114587) 175 days, 19:45:45.87',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '31177451',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6532',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '524',
                        IFNAME           => 'ge-0/0/11',
                        IFDESCR          => 'ge-0/0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '64:87:88:b0:39:ce',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1512) 0:00:15.12',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '525',
                        IFNAME           => 'ge-0/0/9.0',
                        IFDESCR          => 'ge-0/0/9.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '64:87:88:b0:39:cc',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(276799604) 32 days, 0:53:16.04',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1420',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '92',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '526',
                        IFNAME           => 'ge-0/0/10.0',
                        IFDESCR          => 'ge-0/0/10.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '64:87:88:b0:39:cd',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1541) 0:00:15.41',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '527',
                        IFNAME           => 'ge-0/0/11.0',
                        IFDESCR          => 'ge-0/0/11.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '64:87:88:b0:39:ce',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1554) 0:00:15.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '528',
                        IFNAME           => 'ge-0/1/0',
                        IFDESCR          => 'ge-0/1/0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '64:87:88:b0:39:cf',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1550) 0:00:15.50',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '529',
                        IFNAME           => 'ge-0/1/0.0',
                        IFDESCR          => 'ge-0/1/0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '64:87:88:b0:39:cf',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1572) 0:00:15.72',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '530',
                        IFNAME           => 'ge-0/1/1',
                        IFDESCR          => 'ge-0/1/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '64:87:88:b0:39:d0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(28667) 0:04:46.67',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3750278254',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3165078235',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '531',
                        IFNAME           => 'ge-0/1/1.0',
                        IFDESCR          => 'ge-0/1/1.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '64:87:88:b0:39:d0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(28667) 0:04:46.67',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2510254288',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '361557089',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '532',
                        IFNAME           => 'vlan.0',
                        IFDESCR          => 'vlan.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '192.168.1.236',
                        MAC              => '64:87:88:b0:39:c1',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(28671) 0:04:46.71',
                        IFINOCTETS       => '1895694825',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '315971005',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        },
    ],
    'juniper/ex2200.03.walk' => [
        {
            TYPE         => 'NETWORKING',
            MANUFACTURER => 'Juniper',
            MODEL        => 'EX2200',
            DESCRIPTION  => 'Juniper Networks, Inc. ex2200-24t-4g internet router, kernel JUNOS 11.1R3.5 #0: 2011-06-25 00:35:00 UTC     builder@briath.juniper.net:/volume/build/junos/11.1/release/11.1R3.5/obj-arm/bsd/kernels/JUNIPER-EX/kernel Build date: 2011-06-25 00:31:37 UTC Cop',

            SNMPHOSTNAME => 'INTERUFR-219-ex2200-24',
            LOCATION     => 'CB',
            CONTACT      => 'cricesr@dauphine.fr',
            SERIAL       => 'CW0211513175',
            UPTIME       => '(9174471) 1 day, 1:29:04.71',
            MEMORY       => '0',
            MAC          => '78:fe:3d:d5:0e:c0',
            IPS          => {
                IP => [
                    '128.0.0.1',
                    '128.0.0.127',
                    '128.0.0.16',
                    '128.0.0.32',
                    '192.168.1.219',
                ],
            },
        },
        {
            INFO => {
                ID           => undef,
                TYPE         => 'NETWORKING',
                MANUFACTURER => 'Juniper',
                MODEL        => 'EX2200',
                COMMENTS     => 'Juniper Networks, Inc. ex2200-24t-4g internet router, kernel JUNOS 11.1R3.5 #0: 2011-06-25 00:35:00 UTC     builder@briath.juniper.net:/volume/build/junos/11.1/release/11.1R3.5/obj-arm/bsd/kernels/JUNIPER-EX/kernel Build date: 2011-06-25 00:31:37 UTC Cop',
                NAME         => 'INTERUFR-219-ex2200-24',
                LOCATION     => 'CB',
                CONTACT      => 'cricesr@dauphine.fr',
                SERIAL       => 'CW0211513175',
                UPTIME       => '(9174471) 1 day, 1:29:04.71',
                MEMORY       => '0',
                MAC          => '78:fe:3d:d5:0e:c0',
                IPS          => {
                    IP => [
                        '128.0.0.1',
                        '128.0.0.127',
                        '128.0.0.16',
                        '128.0.0.32',
                        '192.168.1.219',
                    ],
                },
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '4',
                        IFNAME           => 'lsi',
                        IFDESCR          => 'lsi',
                        IFTYPE           => '150',
                        IFSPEED          => '0',
                        IFMTU            => '1496',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4298) 0:00:42.98',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5',
                        IFNAME           => 'dsc',
                        IFDESCR          => 'dsc',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4128) 0:00:41.28',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '6',
                        IFNAME           => 'lo0',
                        IFDESCR          => 'lo0',
                        IFTYPE           => '24',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4295) 0:00:42.95',
                        IFINOCTETS       => '131885047',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '131885047',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '7',
                        IFNAME           => 'tap',
                        IFDESCR          => 'tap',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4311) 0:00:43.11',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '8',
                        IFNAME           => 'gre',
                        IFDESCR          => 'gre',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4282) 0:00:42.82',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '9',
                        IFNAME           => 'ipip',
                        IFDESCR          => 'ipip',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4288) 0:00:42.88',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10',
                        IFNAME           => 'pime',
                        IFDESCR          => 'pime',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4309) 0:00:43.09',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '11',
                        IFNAME           => 'pimd',
                        IFDESCR          => 'pimd',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4307) 0:00:43.07',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '12',
                        IFNAME           => 'mtun',
                        IFDESCR          => 'mtun',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4304) 0:00:43.04',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '33',
                        IFNAME           => 'me0',
                        IFDESCR          => 'me0',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:ff',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4300) 0:00:43.00',
                        IFINOCTETS       => '14638812',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '34',
                        IFNAME           => 'me0.0',
                        IFDESCR          => 'me0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        IP               => '192.168.1.219',
                        MAC              => '78:fe:3d:d5:0e:ff',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4302) 0:00:43.02',
                        IFINOCTETS       => '14638898',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3954144',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '37',
                        IFNAME           => 'bme0',
                        IFDESCR          => 'bme0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1576',
                        MAC              => '00:0b:ca:fe:00:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4123) 0:00:41.23',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '13256588',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '38',
                        IFNAME           => 'bme0.32768',
                        IFDESCR          => 'bme0.32768',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1562',
                        IP               => '128.0.0.32',
                        MAC              => '00:0b:ca:fe:00:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4125) 0:00:41.25',
                        IFINOCTETS       => '3337783',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '126',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '501',
                        IFNAME           => 'ge-0/0/0',
                        IFDESCR          => 'ge-0/0/0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:c0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4130) 0:00:41.30',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '502',
                        IFNAME           => 'ge-0/0/0.0',
                        IFDESCR          => 'ge-0/0/0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:c0',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4131) 0:00:41.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '503',
                        IFNAME           => 'ge-0/0/1',
                        IFDESCR          => 'ge-0/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:c1',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4134) 0:00:41.34',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '504',
                        IFNAME           => 'ge-0/0/1.0',
                        IFDESCR          => 'ge-0/0/1.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:c1',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4136) 0:00:41.36',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '505',
                        IFNAME           => 'ge-0/0/10',
                        IFDESCR          => 'ge-0/0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:ca',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4172) 0:00:41.72',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '506',
                        IFNAME           => 'ge-0/0/10.0',
                        IFDESCR          => 'ge-0/0/10.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:ca',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4172) 0:00:41.72',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '507',
                        IFNAME           => 'ge-0/0/11',
                        IFDESCR          => 'ge-0/0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:cb',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4264) 0:00:42.64',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '508',
                        IFNAME           => 'ge-0/0/11.0',
                        IFDESCR          => 'ge-0/0/11.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:cb',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4264) 0:00:42.64',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '509',
                        IFNAME           => 'ge-0/0/12',
                        IFDESCR          => 'ge-0/0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:cc',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4332) 0:00:43.32',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '510',
                        IFNAME           => 'ge-0/0/12.0',
                        IFDESCR          => 'ge-0/0/12.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:cc',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4332) 0:00:43.32',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '511',
                        IFNAME           => 'ge-0/0/13',
                        IFDESCR          => 'ge-0/0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:cd',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4357) 0:00:43.57',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '512',
                        IFNAME           => 'ge-0/0/13.0',
                        IFDESCR          => 'ge-0/0/13.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:cd',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4357) 0:00:43.57',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '513',
                        IFNAME           => 'ge-0/0/14',
                        IFDESCR          => 'ge-0/0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:ce',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4383) 0:00:43.83',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '514',
                        IFNAME           => 'ge-0/0/14.0',
                        IFDESCR          => 'ge-0/0/14.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:ce',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4383) 0:00:43.83',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '515',
                        IFNAME           => 'ge-0/0/15',
                        IFDESCR          => 'ge-0/0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:cf',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4418) 0:00:44.18',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '516',
                        IFNAME           => 'ge-0/0/15.0',
                        IFDESCR          => 'ge-0/0/15.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:cf',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4418) 0:00:44.18',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '517',
                        IFNAME           => 'ge-0/0/16',
                        IFDESCR          => 'ge-0/0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:d0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4450) 0:00:44.50',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '518',
                        IFNAME           => 'ge-0/0/16.0',
                        IFDESCR          => 'ge-0/0/16.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:d0',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4450) 0:00:44.50',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '519',
                        IFNAME           => 'ge-0/0/17',
                        IFDESCR          => 'ge-0/0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:d1',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4479) 0:00:44.79',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '520',
                        IFNAME           => 'ge-0/0/17.0',
                        IFDESCR          => 'ge-0/0/17.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:d1',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4479) 0:00:44.79',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '521',
                        IFNAME           => 'ge-0/0/18',
                        IFDESCR          => 'ge-0/0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:d2',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4511) 0:00:45.11',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '522',
                        IFNAME           => 'ge-0/0/18.0',
                        IFDESCR          => 'ge-0/0/18.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:d2',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4511) 0:00:45.11',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '523',
                        IFNAME           => 'ge-0/0/19',
                        IFDESCR          => 'ge-0/0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:d3',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4536) 0:00:45.36',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '524',
                        IFNAME           => 'ge-0/0/19.0',
                        IFDESCR          => 'ge-0/0/19.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:d3',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4536) 0:00:45.36',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '525',
                        IFNAME           => 'ge-0/0/2',
                        IFDESCR          => 'ge-0/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:c2',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4211) 0:00:42.11',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '526',
                        IFNAME           => 'ge-0/0/2.0',
                        IFDESCR          => 'ge-0/0/2.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:c2',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4213) 0:00:42.13',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '527',
                        IFNAME           => 'ge-0/0/20',
                        IFDESCR          => 'ge-0/0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:d4',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4557) 0:00:45.57',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '528',
                        IFNAME           => 'ge-0/0/20.0',
                        IFDESCR          => 'ge-0/0/20.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:d4',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4557) 0:00:45.57',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '529',
                        IFNAME           => 'ge-0/0/21',
                        IFDESCR          => 'ge-0/0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:d5',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4567) 0:00:45.67',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '530',
                        IFNAME           => 'ge-0/0/21.0',
                        IFDESCR          => 'ge-0/0/21.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:d5',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4567) 0:00:45.67',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '531',
                        IFNAME           => 'ge-0/0/22',
                        IFDESCR          => 'ge-0/0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:d6',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4587) 0:00:45.87',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '532',
                        IFNAME           => 'ge-0/0/22.0',
                        IFDESCR          => 'ge-0/0/22.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:d6',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4587) 0:00:45.87',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '533',
                        IFNAME           => 'ge-0/0/23',
                        IFDESCR          => 'ge-0/0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:d7',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4618) 0:00:46.18',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '534',
                        IFNAME           => 'ge-0/0/23.0',
                        IFDESCR          => 'ge-0/0/23.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:d7',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4618) 0:00:46.18',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '535',
                        IFNAME           => 'ge-0/0/3',
                        IFDESCR          => 'ge-0/0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:c3',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4236) 0:00:42.36',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '536',
                        IFNAME           => 'ge-0/0/3.0',
                        IFDESCR          => 'ge-0/0/3.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:c3',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4238) 0:00:42.38',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '537',
                        IFNAME           => 'ge-0/0/4',
                        IFDESCR          => 'ge-0/0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:c4',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4239) 0:00:42.39',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '538',
                        IFNAME           => 'ge-0/0/4.0',
                        IFDESCR          => 'ge-0/0/4.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:c4',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4240) 0:00:42.40',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '539',
                        IFNAME           => 'ge-0/0/5',
                        IFDESCR          => 'ge-0/0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:c5',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4242) 0:00:42.42',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '540',
                        IFNAME           => 'ge-0/0/5.0',
                        IFDESCR          => 'ge-0/0/5.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:c5',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4245) 0:00:42.45',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '541',
                        IFNAME           => 'ge-0/0/6',
                        IFDESCR          => 'ge-0/0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:c6',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4247) 0:00:42.47',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '542',
                        IFNAME           => 'ge-0/0/6.0',
                        IFDESCR          => 'ge-0/0/6.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:c6',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4250) 0:00:42.50',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '543',
                        IFNAME           => 'ge-0/0/7',
                        IFDESCR          => 'ge-0/0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:c7',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4254) 0:00:42.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '544',
                        IFNAME           => 'ge-0/0/7.0',
                        IFDESCR          => 'ge-0/0/7.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:c7',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4257) 0:00:42.57',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '545',
                        IFNAME           => 'ge-0/0/8',
                        IFDESCR          => 'ge-0/0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:c8',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4260) 0:00:42.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '546',
                        IFNAME           => 'ge-0/0/8.0',
                        IFDESCR          => 'ge-0/0/8.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:c8',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4266) 0:00:42.66',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '547',
                        IFNAME           => 'ge-0/0/9',
                        IFDESCR          => 'ge-0/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:c9',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4269) 0:00:42.69',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '548',
                        IFNAME           => 'ge-0/0/9.0',
                        IFDESCR          => 'ge-0/0/9.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:c9',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4271) 0:00:42.71',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '549',
                        IFNAME           => 'ge-0/1/0',
                        IFDESCR          => 'ge-0/1/0',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:d8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4627) 0:00:46.27',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2760591156',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '742321097',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '550',
                        IFNAME           => 'ge-0/1/0.0',
                        IFDESCR          => 'ge-0/1/0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:d8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4627) 0:00:46.27',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1518484',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6487435',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:10:5a:13:a5:47',
                                    '00:10:5a:1b:c5:be',
                                    '00:d0:b7:45:80:30',
                                    '00:18:f3:f0:0c:0e',
                                    '00:19:d1:82:ab:f6',
                                    '00:1b:2f:b3:c0:d5',
                                    '00:1b:2f:b3:c0:d7',
                                    '00:1c:c0:bd:d2:82',
                                    '00:1c:c0:bd:d7:79',
                                    '00:1c:c0:bd:d7:54',
                                    '00:1c:c0:bd:d9:1b',
                                    '00:1c:c0:bd:d9:3f',
                                    '00:1c:c0:dc:69:5a',
                                    '00:1c:c0:dc:6b:fa',
                                    '00:1c:c0:dc:6d:47',
                                    '00:1c:c0:dc:7a:ea',
                                    '00:1c:c0:dc:7b:17',
                                    '00:1c:c0:dc:7d:7f',
                                    '00:1c:c0:df:39:ee',
                                    '00:1c:c0:df:39:f6',
                                    '00:1c:c0:df:3a:8a',
                                    '00:1c:c0:df:3a:8b',
                                    '00:1c:c0:df:3a:1f',
                                    '00:1c:c0:df:3a:55',
                                    '00:03:22:01:9b:19',
                                    '00:27:0e:2d:f8:64',
                                    '00:27:0e:2d:f9:60',
                                    '00:40:0d:8a:8b:47',
                                    '00:50:da:7c:51:52',
                                    '00:50:da:7c:63:4c',
                                    '00:50:da:d8:4e:47',
                                    '00:50:04:82:ce:89',
                                    '00:50:04:a9:60:39',
                                    '00:50:04:50:54:e8',
                                    '00:60:08:64:12:81',
                                    '00:60:08:64:15:f0',
                                    '00:60:08:64:16:8c',
                                    '00:60:08:64:16:11',
                                    '00:60:08:64:16:3f',
                                    '00:60:08:64:16:46',
                                    '00:60:08:64:16:4c',
                                    '00:60:08:64:23:e5',
                                    '00:60:08:72:78:cb',
                                    '00:60:08:0c:01:7d',
                                    '00:60:08:9f:35:83',
                                    '00:60:08:63:fa:63',
                                    '78:e7:d1:a9:3c:2b',
                                    '8c:89:a5:3a:ba:20',
                                    'b4:b5:2f:54:c9:30',
                                    'bc:ae:c5:43:da:70',
                                    'c8:9c:dc:f3:e7:71',
                                    'f8:0f:41:36:13:75',
                                    'f8:0f:41:36:13:63',
                                    'f8:0f:41:36:49:6b',
                                    'f8:0f:41:36:49:03',
                                    'f8:0f:41:3b:13:6f',
                                    'f8:0f:41:3d:1e:e6',
                                    'f8:0f:41:3d:38:66',
                                    'f8:0f:41:3d:38:a0',
                                    'f8:0f:41:3d:38:d7',
                                    'f8:0f:41:3d:38:da',
                                    'f8:0f:41:3d:38:26',
                                    'f8:0f:41:3d:39:85',
                                    'f8:0f:41:3d:39:32',
                                    'f8:0f:41:3d:39:35',
                                    'f8:0f:41:3d:43:64',
                                    'f8:0f:41:3d:43:69',
                                    'f8:0f:41:3d:43:8b',
                                    'f8:0f:41:3d:47:00',
                                    'f8:0f:41:3d:48:95',
                                    'f8:0f:41:3d:48:c4',
                                    'f8:0f:41:3d:48:ca',
                                    'f8:0f:41:3d:48:59',
                                    'f8:0f:41:3e:0a:d1',
                                    'f8:0f:41:3e:0a:29',
                                    'f8:0f:41:3e:0b:c5',
                                    'f8:0f:41:3e:0b:d2',
                                    'f8:0f:41:3e:0c:bd',
                                    'f8:0f:41:3e:0c:33',
                                    'f8:0f:41:3e:07:37',
                                    'f8:0f:41:3e:09:2e',
                                    '20:cf:30:f0:82:d8',
                                    '20:cf:30:f0:82:e6',
                                    'f8:0f:41:3d:49:2a',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '555',
                        IFNAME           => 'ge-0/1/3',
                        IFDESCR          => 'ge-0/1/3',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:db',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4674) 0:00:46.74',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '738384759',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2761755337',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '556',
                        IFNAME           => 'jsrv',
                        IFDESCR          => 'jsrv',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '78:fe:3d:d5:0e:c0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4290) 0:00:42.90',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '557',
                        IFNAME           => 'jsrv.1',
                        IFDESCR          => 'jsrv.1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '128.0.0.127',
                        MAC              => '78:fe:3d:d5:0e:c0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4293) 0:00:42.93',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '42',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '558',
                        IFNAME           => 'vlan',
                        IFDESCR          => 'vlan',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '78:fe:3d:d5:0e:c0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4316) 0:00:43.16',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '559',
                        IFNAME           => 'ge-0/1/3.0',
                        IFDESCR          => 'ge-0/1/3.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:d5:0e:db',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4674) 0:00:46.74',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '796377',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6009138',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:11:85:69:2f:08',
                                    '00:11:85:69:2f:09',
                                    '00:12:79:39:3c:6e',
                                    '00:12:79:39:3c:30',
                                    '00:15:60:a8:9a:31',
                                    '00:15:60:a8:9a:32',
                                    '00:15:60:a8:c8:a5',
                                    '00:15:60:a8:c8:a6',
                                    '00:24:81:a5:8c:99',
                                    '00:24:81:a5:8c:9a',
                                    '00:24:81:a5:ad:82',
                                    '00:24:81:a5:ad:84',
                                    '00:25:b3:aa:d6:b6',
                                    '00:50:56:b7:0b:86',
                                    '00:50:56:b7:20:69',
                                    '78:e3:b5:12:97:d8',
                                    '78:e3:b5:12:97:da',
                                    '78:e3:b5:12:a7:0a',
                                    '78:e3:b5:12:a7:08',
                                    '9c:8e:99:14:8a:9c',
                                    '9c:8e:99:14:8a:9e',
                                    '9c:8e:99:14:8a:a4',
                                    '9c:8e:99:14:8a:a6',
                                    'b4:99:ba:c0:eb:a4',
                                    'b4:99:ba:c0:eb:a6',
                                    'b4:99:ba:c0:eb:a8',
                                    'b4:99:ba:c0:eb:aa',
                                    'e4:11:5b:b0:29:fe',
                                    'e4:11:5b:b0:2a:02',
                                    'e4:11:5b:b0:2a:04',
                                    '18:33:9d:e7:15:1a',
                                ],
                            }
                        }
                    },
                ]
            },
        },
    ],
    'juniper/ex2200.04.walk' => [
        {
            TYPE         => 'NETWORKING',
            MANUFACTURER => 'Juniper',
            MODEL        => 'EX2200',
            DESCRIPTION  => 'Juniper Networks, Inc. ex2200-48t-4g internet router, kernel JUNOS 11.1R3.5 #0: 2011-06-25 00:35:00 UTC     builder@briath.juniper.net:/volume/build/junos/11.1/release/11.1R3.5/obj-arm/bsd/kernels/JUNIPER-EX/kernel Build date: 2011-06-25 00:31:37 UTC Cop',

            SNMPHOSTNAME => 'AB-BU6-132-ex2200-48',
            LOCATION     => 'AB-BU6',
            CONTACT      => 'cricesr@dauphine.fr',
            SERIAL       => 'CU0211450517',
            UPTIME       => '(1514669572) 175 days, 7:24:55.72',
            MEMORY       => '0',
            MAC          => '78:fe:3d:37:5e:c0',
            IPS          => {
                IP => [
                    '128.0.0.1',
                    '128.0.0.127',
                    '128.0.0.16',
                    '128.0.0.32',
                    '192.168.1.132',
                ],
            },
        },
        {
            INFO => {
                ID           => undef,
                TYPE         => 'NETWORKING',
                MANUFACTURER => 'Juniper',
                MODEL        => 'EX2200',
                COMMENTS     => 'Juniper Networks, Inc. ex2200-48t-4g internet router, kernel JUNOS 11.1R3.5 #0: 2011-06-25 00:35:00 UTC     builder@briath.juniper.net:/volume/build/junos/11.1/release/11.1R3.5/obj-arm/bsd/kernels/JUNIPER-EX/kernel Build date: 2011-06-25 00:31:37 UTC Cop',
                NAME         => 'AB-BU6-132-ex2200-48',
                LOCATION     => 'AB-BU6',
                CONTACT      => 'cricesr@dauphine.fr',
                SERIAL       => 'CU0211450517',
                UPTIME       => '(1514669572) 175 days, 7:24:55.72',
                MEMORY       => '0',
                MAC          => '78:fe:3d:37:5e:c0',
                IPS          => {
                    IP => [
                        '128.0.0.1',
                        '128.0.0.127',
                        '128.0.0.16',
                        '128.0.0.32',
                        '192.168.1.132',
                    ],
                },
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '4',
                        IFNAME           => 'lsi',
                        IFDESCR          => 'lsi',
                        IFTYPE           => '150',
                        IFSPEED          => '0',
                        IFMTU            => '1496',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3055) 0:00:30.55',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5',
                        IFNAME           => 'dsc',
                        IFDESCR          => 'dsc',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3012) 0:00:30.12',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '6',
                        IFNAME           => 'lo0',
                        IFDESCR          => 'lo0',
                        IFTYPE           => '24',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3019) 0:00:30.19',
                        IFINOCTETS       => '4148021786',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4148591022',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '7',
                        IFNAME           => 'tap',
                        IFDESCR          => 'tap',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3066) 0:00:30.66',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '8',
                        IFNAME           => 'gre',
                        IFDESCR          => 'gre',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3014) 0:00:30.14',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '9',
                        IFNAME           => 'ipip',
                        IFDESCR          => 'ipip',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3015) 0:00:30.15',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10',
                        IFNAME           => 'pime',
                        IFDESCR          => 'pime',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3065) 0:00:30.65',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '11',
                        IFNAME           => 'pimd',
                        IFDESCR          => 'pimd',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3063) 0:00:30.63',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '12',
                        IFNAME           => 'mtun',
                        IFDESCR          => 'mtun',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3060) 0:00:30.60',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '33',
                        IFNAME           => 'me0',
                        IFDESCR          => 'me0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:ff',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3058) 0:00:30.58',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '37',
                        IFNAME           => 'bme0',
                        IFDESCR          => 'bme0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1576',
                        MAC              => '00:0b:ca:fe:00:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3010) 0:00:30.10',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '901896814',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '38',
                        IFNAME           => 'bme0.32768',
                        IFDESCR          => 'bme0.32768',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1562',
                        IP               => '128.0.0.32',
                        MAC              => '00:0b:ca:fe:00:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3011) 0:00:30.11',
                        IFINOCTETS       => '2267152155',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '126',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '501',
                        IFNAME           => 'ge-0/0/0',
                        IFDESCR          => 'ge-0/0/0',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:c0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1513913595) 175 days, 5:18:55.95',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '62430575',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2121260600',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '502',
                        IFNAME           => 'ge-0/0/0.0',
                        IFDESCR          => 'ge-0/0/0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:c0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1513913595) 175 days, 5:18:55.95',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '614461',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '323610',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:24:be:b6:4c:20',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '503',
                        IFNAME           => 'ge-0/0/1',
                        IFDESCR          => 'ge-0/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:c1',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1507307600) 174 days, 10:57:56.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '147698220',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '886946729',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '504',
                        IFNAME           => 'ge-0/0/1.0',
                        IFDESCR          => 'ge-0/0/1.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:c1',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1507307600) 174 days, 10:57:56.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1758171',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '754660',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '505',
                        IFNAME           => 'ge-0/0/10',
                        IFDESCR          => 'ge-0/0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:ca',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1202418760) 139 days, 4:03:07.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '33040562',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '919887004',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '506',
                        IFNAME           => 'ge-0/0/10.0',
                        IFDESCR          => 'ge-0/0/10.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:ca',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1202418760) 139 days, 4:03:07.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '260404',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '113845',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '507',
                        IFNAME           => 'ge-0/0/11',
                        IFDESCR          => 'ge-0/0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:cb',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1204402388) 139 days, 9:33:43.88',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '23866591',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '573739283',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '508',
                        IFNAME           => 'ge-0/0/11.0',
                        IFDESCR          => 'ge-0/0/11.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:cb',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1204402388) 139 days, 9:33:43.88',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '687393',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '75969',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '509',
                        IFNAME           => 'ge-0/0/12',
                        IFDESCR          => 'ge-0/0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:cc',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1454505788) 168 days, 8:17:37.88',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '65490962',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3128608219',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '510',
                        IFNAME           => 'ge-0/0/12.0',
                        IFDESCR          => 'ge-0/0/12.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:cc',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1454505788) 168 days, 8:17:37.88',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1205122',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '668789',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '511',
                        IFNAME           => 'ge-0/0/13',
                        IFDESCR          => 'ge-0/0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:cd',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1383988034) 160 days, 4:24:40.34',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '50434211',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2070139092',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '512',
                        IFNAME           => 'ge-0/0/13.0',
                        IFDESCR          => 'ge-0/0/13.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:cd',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1383988034) 160 days, 4:24:40.34',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '390894',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '131871',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '513',
                        IFNAME           => 'ge-0/0/14',
                        IFDESCR          => 'ge-0/0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:ce',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1392608516) 161 days, 4:21:25.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '73541065',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2042948528',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '514',
                        IFNAME           => 'ge-0/0/14.0',
                        IFDESCR          => 'ge-0/0/14.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:ce',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1392608516) 161 days, 4:21:25.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '247639',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '142940',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '515',
                        IFNAME           => 'ge-0/0/15',
                        IFDESCR          => 'ge-0/0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:cf',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1383987392) 160 days, 4:24:33.92',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '10291556',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '920149549',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '516',
                        IFNAME           => 'ge-0/0/15.0',
                        IFDESCR          => 'ge-0/0/15.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:cf',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1383987392) 160 days, 4:24:33.92',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '624396',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '193755',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '517',
                        IFNAME           => 'ge-0/0/16',
                        IFDESCR          => 'ge-0/0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:d0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1402988034) 162 days, 9:11:20.34',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '144694897',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '373175314',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '518',
                        IFNAME           => 'ge-0/0/16.0',
                        IFDESCR          => 'ge-0/0/16.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:d0',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1402988034) 162 days, 9:11:20.34',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '4168655',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '800961',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '519',
                        IFNAME           => 'ge-0/0/17',
                        IFDESCR          => 'ge-0/0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:d1',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1505111362) 174 days, 4:51:53.62',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '112282597',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3622860141',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '520',
                        IFNAME           => 'ge-0/0/17.0',
                        IFDESCR          => 'ge-0/0/17.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:d1',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1505111362) 174 days, 4:51:53.62',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3263756',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '388748',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '521',
                        IFNAME           => 'ge-0/0/18',
                        IFDESCR          => 'ge-0/0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:d2',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1143701810) 132 days, 8:56:58.10',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '69571870',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2110991844',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '522',
                        IFNAME           => 'ge-0/0/18.0',
                        IFDESCR          => 'ge-0/0/18.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:d2',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1143701810) 132 days, 8:56:58.10',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2358039',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '498770',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '523',
                        IFNAME           => 'ge-0/0/19',
                        IFDESCR          => 'ge-0/0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:d3',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1143887182) 132 days, 9:27:51.82',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '54665076',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1198628365',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '524',
                        IFNAME           => 'ge-0/0/19.0',
                        IFDESCR          => 'ge-0/0/19.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:d3',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1143887182) 132 days, 9:27:51.82',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '844445',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '84168',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '525',
                        IFNAME           => 'ge-0/0/2',
                        IFDESCR          => 'ge-0/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:c2',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1514274855) 175 days, 6:19:08.55',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '71549018',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2214237751',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '526',
                        IFNAME           => 'ge-0/0/2.0',
                        IFDESCR          => 'ge-0/0/2.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:c2',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1514274855) 175 days, 6:19:08.55',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1344926',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '216986',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:26:b0:f1:25:3e',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '527',
                        IFNAME           => 'ge-0/0/20',
                        IFDESCR          => 'ge-0/0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:d4',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1031918668) 119 days, 10:26:26.68',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '101162940',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3191603905',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '528',
                        IFNAME           => 'ge-0/0/20.0',
                        IFDESCR          => 'ge-0/0/20.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:d4',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1031918668) 119 days, 10:26:26.68',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '287186',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '331734',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '529',
                        IFNAME           => 'ge-0/0/21',
                        IFDESCR          => 'ge-0/0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:d5',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1452971670) 168 days, 4:01:56.70',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '45333984',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1112146726',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '530',
                        IFNAME           => 'ge-0/0/21.0',
                        IFDESCR          => 'ge-0/0/21.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:d5',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1452971670) 168 days, 4:01:56.70',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2170170',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '118187',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '531',
                        IFNAME           => 'ge-0/0/22',
                        IFDESCR          => 'ge-0/0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:d6',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1507744280) 174 days, 12:10:42.80',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '349227121',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2349516312',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '532',
                        IFNAME           => 'ge-0/0/22.0',
                        IFDESCR          => 'ge-0/0/22.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:d6',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1507744280) 174 days, 12:10:42.80',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '7875686',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '837854',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '533',
                        IFNAME           => 'ge-0/0/23',
                        IFDESCR          => 'ge-0/0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:d7',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1384857878) 160 days, 6:49:38.78',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '63700153',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3770626360',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '534',
                        IFNAME           => 'ge-0/0/23.0',
                        IFDESCR          => 'ge-0/0/23.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:d7',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1384857878) 160 days, 6:49:38.78',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1953525',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '505220',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '535',
                        IFNAME           => 'ge-0/0/24',
                        IFDESCR          => 'ge-0/0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:d8',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1506337000) 174 days, 8:16:10.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '24341650',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1675279409',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '536',
                        IFNAME           => 'ge-0/0/24.0',
                        IFDESCR          => 'ge-0/0/24.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:d8',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1506337000) 174 days, 8:16:10.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '299238',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '215960',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '537',
                        IFNAME           => 'ge-0/0/25',
                        IFDESCR          => 'ge-0/0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:d9',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1506965500) 174 days, 10:00:55.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '149804990',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '958374164',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '538',
                        IFNAME           => 'ge-0/0/25.0',
                        IFDESCR          => 'ge-0/0/25.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:d9',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1506965500) 174 days, 10:00:55.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3824745',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '429062',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '539',
                        IFNAME           => 'ge-0/0/26',
                        IFDESCR          => 'ge-0/0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:da',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1030566650) 119 days, 6:41:06.50',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '8707382',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '314497846',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '540',
                        IFNAME           => 'ge-0/0/26.0',
                        IFDESCR          => 'ge-0/0/26.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:da',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1030566650) 119 days, 6:41:06.50',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '250977',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6710',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '541',
                        IFNAME           => 'ge-0/0/27',
                        IFDESCR          => 'ge-0/0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:db',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1507221140) 174 days, 10:43:31.40',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '59953469',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2945748283',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '542',
                        IFNAME           => 'ge-0/0/27.0',
                        IFDESCR          => 'ge-0/0/27.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:db',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1507221140) 174 days, 10:43:31.40',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '424630',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '118141',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '543',
                        IFNAME           => 'ge-0/0/28',
                        IFDESCR          => 'ge-0/0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:dc',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(850490968) 98 days, 10:28:29.68',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '35974557',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '801954910',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '544',
                        IFNAME           => 'ge-0/0/28.0',
                        IFDESCR          => 'ge-0/0/28.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:dc',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(850490968) 98 days, 10:28:29.68',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1732098',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '460',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '545',
                        IFNAME           => 'ge-0/0/29',
                        IFDESCR          => 'ge-0/0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:dd',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1470728810) 170 days, 5:21:28.10',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '62331862',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2935236434',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '546',
                        IFNAME           => 'ge-0/0/29.0',
                        IFDESCR          => 'ge-0/0/29.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:dd',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1470728810) 170 days, 5:21:28.10',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1758447',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '265039',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '547',
                        IFNAME           => 'ge-0/0/3',
                        IFDESCR          => 'ge-0/0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:c3',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1092023384) 126 days, 9:23:53.84',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '63492350',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3428946165',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '548',
                        IFNAME           => 'ge-0/0/3.0',
                        IFDESCR          => 'ge-0/0/3.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:c3',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1092023384) 126 days, 9:23:53.84',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '671676',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '309544',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '549',
                        IFNAME           => 'ge-0/0/30',
                        IFDESCR          => 'ge-0/0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:de',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1470404984) 170 days, 4:27:29.84',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '7460415',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '490225744',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '550',
                        IFNAME           => 'ge-0/0/30.0',
                        IFDESCR          => 'ge-0/0/30.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:de',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1470404984) 170 days, 4:27:29.84',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '350036',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '115652',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '551',
                        IFNAME           => 'ge-0/0/31',
                        IFDESCR          => 'ge-0/0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:df',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1110357572) 128 days, 12:19:35.72',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '125852225',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1174250796',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '552',
                        IFNAME           => 'ge-0/0/31.0',
                        IFDESCR          => 'ge-0/0/31.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:df',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1110357572) 128 days, 12:19:35.72',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3504165',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '647546',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '553',
                        IFNAME           => 'ge-0/0/32',
                        IFDESCR          => 'ge-0/0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:e0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1384810132) 160 days, 6:41:41.32',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '124837521',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3504587939',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '554',
                        IFNAME           => 'ge-0/0/32.0',
                        IFDESCR          => 'ge-0/0/32.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:e0',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1384810132) 160 days, 6:41:41.32',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3993337',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '566590',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '555',
                        IFNAME           => 'ge-0/0/33',
                        IFDESCR          => 'ge-0/0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:e1',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1143565972) 132 days, 8:34:19.72',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '96592127',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2598548649',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '556',
                        IFNAME           => 'ge-0/0/33.0',
                        IFDESCR          => 'ge-0/0/33.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:e1',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1143565972) 132 days, 8:34:19.72',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2466593',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '356779',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '557',
                        IFNAME           => 'ge-0/0/34',
                        IFDESCR          => 'ge-0/0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:e2',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1384542134) 160 days, 5:57:01.34',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '16553538',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '550813130',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '558',
                        IFNAME           => 'ge-0/0/35',
                        IFDESCR          => 'ge-0/0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:e3',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1118850195) 129 days, 11:55:01.95',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '33379366',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1447930462',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '559',
                        IFNAME           => 'ge-0/0/36',
                        IFDESCR          => 'ge-0/0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:e4',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1410733362) 163 days, 6:42:13.62',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '23981022',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '713660693',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '560',
                        IFNAME           => 'ge-0/0/37',
                        IFDESCR          => 'ge-0/0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:e5',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1211950856) 140 days, 6:31:48.56',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '152170123',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3016135548',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '561',
                        IFNAME           => 'ge-0/0/38',
                        IFDESCR          => 'ge-0/0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:e6',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1455360768) 168 days, 10:40:07.68',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '76749283',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3017918010',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '562',
                        IFNAME           => 'ge-0/0/39',
                        IFDESCR          => 'ge-0/0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:e7',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1505307478) 174 days, 5:24:34.78',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '203771803',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2659142896',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '563',
                        IFNAME           => 'ge-0/0/4',
                        IFDESCR          => 'ge-0/0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:c4',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1099914508) 127 days, 7:19:05.08',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '38057500',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1007329801',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '564',
                        IFNAME           => 'ge-0/0/4.0',
                        IFDESCR          => 'ge-0/0/4.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:c4',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1099914508) 127 days, 7:19:05.08',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3524662',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '145026',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '565',
                        IFNAME           => 'ge-0/0/40',
                        IFDESCR          => 'ge-0/0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:e8',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5428) 0:00:54.28',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '566',
                        IFNAME           => 'ge-0/0/41',
                        IFDESCR          => 'ge-0/0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:e9',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5434) 0:00:54.34',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '567',
                        IFNAME           => 'ge-0/0/42',
                        IFDESCR          => 'ge-0/0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:ea',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5441) 0:00:54.41',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '568',
                        IFNAME           => 'ge-0/0/43',
                        IFDESCR          => 'ge-0/0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:eb',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5448) 0:00:54.48',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '569',
                        IFNAME           => 'ge-0/0/44',
                        IFDESCR          => 'ge-0/0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:ec',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5458) 0:00:54.58',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '570',
                        IFNAME           => 'ge-0/0/45',
                        IFDESCR          => 'ge-0/0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:ed',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5466) 0:00:54.66',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '571',
                        IFNAME           => 'ge-0/0/46',
                        IFDESCR          => 'ge-0/0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:ee',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5473) 0:00:54.73',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '572',
                        IFNAME           => 'ge-0/0/47',
                        IFDESCR          => 'ge-0/0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:ef',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6575) 0:01:05.75',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3459942395',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '759695086',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '573',
                        IFNAME           => 'ge-0/0/5',
                        IFDESCR          => 'ge-0/0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:c5',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(848117844) 98 days, 3:52:58.44',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '13515708',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '817163343',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '574',
                        IFNAME           => 'ge-0/0/5.0',
                        IFDESCR          => 'ge-0/0/5.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:c5',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(848117844) 98 days, 3:52:58.44',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '74580',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '460',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '575',
                        IFNAME           => 'ge-0/0/6',
                        IFDESCR          => 'ge-0/0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:c6',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1401432020) 162 days, 4:52:00.20',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '19677539',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '560323704',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '576',
                        IFNAME           => 'ge-0/0/6.0',
                        IFDESCR          => 'ge-0/0/6.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:c6',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1401432020) 162 days, 4:52:00.20',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1654420',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '85644',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '577',
                        IFNAME           => 'ge-0/0/7',
                        IFDESCR          => 'ge-0/0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:c7',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1098601452) 127 days, 3:40:14.52',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '28825938',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1046046635',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '578',
                        IFNAME           => 'ge-0/0/7.0',
                        IFDESCR          => 'ge-0/0/7.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:c7',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1098601452) 127 days, 3:40:14.52',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '149457',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '75874',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '579',
                        IFNAME           => 'ge-0/0/8',
                        IFDESCR          => 'ge-0/0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:c8',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1030139372) 119 days, 5:29:53.72',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '69584990',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4092848179',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '580',
                        IFNAME           => 'ge-0/0/8.0',
                        IFDESCR          => 'ge-0/0/8.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:c8',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1030139372) 119 days, 5:29:53.72',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '644434',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '656200',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '581',
                        IFNAME           => 'ge-0/0/9',
                        IFDESCR          => 'ge-0/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:c9',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1453646644) 168 days, 5:54:26.44',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1575617312',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3989857445',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '582',
                        IFNAME           => 'ge-0/0/9.0',
                        IFDESCR          => 'ge-0/0/9.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:c9',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1453646644) 168 days, 5:54:26.44',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1953950',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '601344',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '583',
                        IFNAME           => 'jsrv',
                        IFDESCR          => 'jsrv',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '78:fe:3d:37:5e:c0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3017) 0:00:30.17',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '584',
                        IFNAME           => 'jsrv.1',
                        IFDESCR          => 'jsrv.1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '128.0.0.127',
                        MAC              => '78:fe:3d:37:5e:c0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3839) 0:00:38.39',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '42',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '585',
                        IFNAME           => 'vlan',
                        IFDESCR          => 'vlan',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '78:fe:3d:37:5e:c0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4134) 0:00:41.34',
                        IFINOCTETS       => '1771188614',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '507220467',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '586',
                        IFNAME           => 'ge-0/0/34.0',
                        IFDESCR          => 'ge-0/0/34.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:e2',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1384542134) 160 days, 5:57:01.34',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1127322',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '154281',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '587',
                        IFNAME           => 'ge-0/0/35.0',
                        IFDESCR          => 'ge-0/0/35.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:e3',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1118850195) 129 days, 11:55:01.95',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '223310',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '225632',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '588',
                        IFNAME           => 'ge-0/0/36.0',
                        IFDESCR          => 'ge-0/0/36.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:e4',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1410733362) 163 days, 6:42:13.62',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '503203',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '48493',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '589',
                        IFNAME           => 'ge-0/0/37.0',
                        IFDESCR          => 'ge-0/0/37.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:e5',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1211950856) 140 days, 6:31:48.56',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '376559',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '165325',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '590',
                        IFNAME           => 'ge-0/0/38.0',
                        IFDESCR          => 'ge-0/0/38.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:e6',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1455360768) 168 days, 10:40:07.68',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1999894',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '393988',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '591',
                        IFNAME           => 'ge-0/0/39.0',
                        IFDESCR          => 'ge-0/0/39.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:e7',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1505307478) 174 days, 5:24:34.78',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3498450',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '810980',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '592',
                        IFNAME           => 'ge-0/0/40.0',
                        IFDESCR          => 'ge-0/0/40.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:e8',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5431) 0:00:54.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '593',
                        IFNAME           => 'ge-0/0/41.0',
                        IFDESCR          => 'ge-0/0/41.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:e9',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5438) 0:00:54.38',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '594',
                        IFNAME           => 'ge-0/0/42.0',
                        IFDESCR          => 'ge-0/0/42.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:ea',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5445) 0:00:54.45',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '595',
                        IFNAME           => 'ge-0/0/43.0',
                        IFDESCR          => 'ge-0/0/43.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:eb',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5453) 0:00:54.53',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '596',
                        IFNAME           => 'ge-0/0/44.0',
                        IFDESCR          => 'ge-0/0/44.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:ec',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5462) 0:00:54.62',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '597',
                        IFNAME           => 'ge-0/0/45.0',
                        IFDESCR          => 'ge-0/0/45.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:ed',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5470) 0:00:54.70',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '598',
                        IFNAME           => 'ge-0/0/46.0',
                        IFDESCR          => 'ge-0/0/46.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:ee',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5477) 0:00:54.77',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '599',
                        IFNAME           => 'ge-0/0/47.0',
                        IFDESCR          => 'ge-0/0/47.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:37:5e:ef',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6575) 0:01:05.75',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '85681745',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '593871581',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:0b:fd:15:bb:ee',
                                    '00:0b:5f:cc:d8:80',
                                    '00:19:d1:92:0c:4c',
                                    '00:09:43:09:04:18',
                                    'e8:e7:32:27:63:f4',
                                    'e8:e7:32:2a:e0:9e',
                                    'e8:e7:32:2a:e8:a4',
                                    'e8:e7:32:2b:c1:e2',
                                    'e8:e7:32:4b:7b:b4',
                                    'e8:e7:32:4b:8a:cc',
                                    '00:01:2e:2b:c1:82',
                                    '00:80:91:6c:d0:58',
                                    '00:19:d1:8b:25:86',
                                    '00:1c:c0:86:c3:a9',
                                    '00:1c:c0:a5:07:6a',
                                    '00:1c:c0:a5:07:4a',
                                    '00:1c:c0:a5:07:4b',
                                    '00:1c:c0:2c:d4:c5',
                                    '00:1c:c0:2c:d4:2e',
                                    '00:22:68:64:59:b9',
                                    '00:22:19:ba:3a:9f',
                                    '00:22:4d:47:f3:d1',
                                    '8c:89:a5:3b:2f:bb',
                                    '8c:89:a5:3b:32:79',
                                    '8c:89:a5:3b:32:7f',
                                    '8c:89:a5:3b:32:8d',
                                    '8c:89:a5:3b:32:e4',
                                    '8c:89:a5:3b:32:f2',
                                    '8c:89:a5:3b:32:4b',
                                    '8c:89:a5:3b:32:4c',
                                    'd0:27:88:54:76:6a',
                                    'f8:0f:41:35:e4:b5',
                                    '52:54:00:fe:d5:26',
                                    '00:50:ba:23:24:63',
                                    '1c:c1:de:c9:3d:6d',
                                    '00:14:6a:d6:b1:b8',
                                    '00:14:6a:d6:b1:d8',
                                    '00:14:6a:d6:b2:b8',
                                    '00:14:6a:d6:b2:ba',
                                    '00:14:6a:d6:b2:c0',
                                    '00:14:6a:d6:b2:f4',
                                    '00:14:6a:d6:b3:14',
                                    '00:15:f2:d5:b3:f6',
                                    '00:17:c4:ae:c8:b8',
                                    '00:18:de:e1:43:bf',
                                    '00:1b:77:df:5d:e1',
                                    '00:1b:a9:a2:a8:8e',
                                    '00:1b:b1:4c:10:34',
                                    '00:1b:63:cb:45:98',
                                    '00:1c:b3:bc:b5:f0',
                                    '00:1e:64:0a:41:ae',
                                    '00:1e:64:8e:40:0e',
                                    '00:1e:64:35:1c:38',
                                    '00:1e:64:3c:e3:80',
                                    '00:1e:64:53:d8:c4',
                                    '00:1e:65:2c:6c:aa',
                                    '00:1e:c2:ae:f4:c5',
                                    '00:1e:4c:13:ce:44',
                                    '00:1e:52:6f:aa:33',
                                    '00:1e:52:c8:8f:81',
                                    '00:1f:3c:a5:cc:ef',
                                    '00:1f:3c:e1:9a:87',
                                    '00:1f:5b:b4:0c:1f',
                                    '00:1f:5b:d7:41:1f',
                                    '00:21:00:30:65:1c',
                                    '00:21:6a:0f:10:68',
                                    '00:21:6a:b6:86:96',
                                    '00:21:6b:c7:95:50',
                                    '00:21:6b:31:e5:88',
                                    '00:21:e9:db:c8:5c',
                                    '00:21:5d:08:76:58',
                                    '00:22:fa:31:cd:40',
                                    '00:22:41:f6:e1:0f',
                                    '00:22:43:70:ac:5f',
                                    '00:22:43:25:f8:02',
                                    '00:22:4d:47:f6:65',
                                    '00:22:5f:b4:e2:c8',
                                    '00:23:6c:7a:2d:67',
                                    '00:23:6c:82:7a:e6',
                                    '00:23:6c:89:6f:5e',
                                    '00:23:6c:8a:00:b0',
                                    '00:23:6c:8b:88:6c',
                                    '00:23:6c:94:c6:40',
                                    '00:23:6c:99:48:86',
                                    '00:23:6c:09:bb:50',
                                    '00:23:12:0d:33:dc',
                                    '00:23:12:c3:d9:f5',
                                    '00:23:12:54:7f:d7',
                                    '00:23:12:57:99:6e',
                                    '00:23:14:1b:a7:d0',
                                    '00:23:14:3e:a1:2c',
                                    '00:23:14:56:47:d8',
                                    '00:23:4d:4f:93:97',
                                    '00:24:d2:bf:78:ed',
                                    '00:24:d6:0a:d1:94',
                                    '00:24:d6:98:03:5a',
                                    '00:24:d6:06:e2:64',
                                    '00:25:00:3d:c4:72',
                                    '00:25:00:3f:7c:c5',
                                    '00:25:00:3f:1d:f0',
                                    '00:25:00:4f:12:88',
                                    '00:25:d3:79:55:24',
                                    '00:25:d3:d4:3e:20',
                                    '00:25:d3:d4:52:d1',
                                    '00:25:d3:3f:65:6b',
                                    '00:25:d3:45:a7:ec',
                                    '00:25:4b:71:76:ec',
                                    '00:25:4b:85:a6:4f',
                                    '00:25:4b:8f:61:cb',
                                    '00:26:82:73:62:85',
                                    '00:26:82:86:b0:c7',
                                    '00:26:82:a0:97:b6',
                                    '00:26:82:f7:38:b8',
                                    '00:26:b0:be:84:a0',
                                    '00:26:b6:c3:a6:c5',
                                    '00:26:b6:53:ad:c3',
                                    '00:26:bb:0e:ad:6e',
                                    '00:26:bb:15:dd:9f',
                                    '00:26:bb:18:80:63',
                                    '00:26:bb:18:b3:2b',
                                    '00:26:bb:1b:ad:65',
                                    '00:26:bb:03:a5:36',
                                    '00:26:c7:a7:38:9a',
                                    '00:26:c7:c1:70:1e',
                                    '00:26:4d:43:92:01',
                                    '00:26:08:e6:73:9a',
                                    '00:26:08:e7:21:bf',
                                    '00:26:08:ec:e3:96',
                                    '00:26:08:f5:87:fb',
                                    '00:27:10:f2:a3:18',
                                    '00:27:10:42:50:14',
                                    '00:08:ca:e6:b3:26',
                                    '00:08:ca:e7:7e:29',
                                    '00:08:ca:e7:2f:6b',
                                    '00:08:ca:21:42:9d',
                                    '00:08:ca:46:9b:a1',
                                    '00:50:56:b7:2c:4e',
                                    '68:a3:c4:85:93:fc',
                                    '68:a3:c4:85:97:53',
                                    '68:a3:c4:db:f2:5e',
                                    '68:a3:c4:dd:e6:21',
                                    '68:a3:c4:dd:e9:2d',
                                    '68:a3:c4:e2:5e:03',
                                    '68:a3:c4:25:2f:4d',
                                    '68:a3:c4:37:e4:6a',
                                    '68:a3:c4:4c:b1:89',
                                    '68:a8:6d:10:ea:2e',
                                    '68:a8:6d:25:c9:0c',
                                    '68:a8:6d:04:a4:5e',
                                    '68:a8:6d:2a:55:cc',
                                    '68:a8:6d:37:37:f2',
                                    '68:a8:6d:42:5e:84',
                                    '68:a8:6d:45:c1:1e',
                                    '68:a8:6d:45:1f:2a',
                                    '68:a8:6d:4a:f8:a0',
                                    '68:a8:6d:4a:63:3c',
                                    '68:a8:6d:56:12:22',
                                    '68:ed:43:df:f7:9d',
                                    '68:09:27:f1:c9:b9',
                                    '70:f1:a1:89:2a:2b',
                                    '70:f1:a1:da:a6:9e',
                                    '70:f1:a1:ed:42:b7',
                                    '70:f3:95:36:76:93',
                                    '70:1a:04:34:27:90',
                                    '70:1a:04:36:f0:b2',
                                    '70:56:81:88:75:19',
                                    '70:56:81:89:b9:17',
                                    '70:56:81:8d:ca:91',
                                    '70:56:81:8f:79:69',
                                    '70:56:81:92:9e:31',
                                    '70:56:81:9c:e7:d9',
                                    '70:56:81:9c:ef:ef',
                                    '70:56:81:aa:68:11',
                                    '70:56:81:aa:bf:85',
                                    '70:56:81:ac:22:8b',
                                    '70:56:81:ac:33:81',
                                    '70:56:81:b6:2e:8d',
                                    '70:56:81:b8:55:93',
                                    '74:de:2b:9d:1c:45',
                                    '74:de:2b:c4:ea:49',
                                    '74:de:2b:f3:5c:74',
                                    '74:de:2b:25:dd:18',
                                    '74:e5:43:a4:1a:43',
                                    '74:e5:43:bb:6b:70',
                                    '74:f0:6d:30:05:d2',
                                    '74:f0:6d:07:97:5e',
                                    '74:f0:6d:50:ce:ce',
                                    '74:f0:6d:53:3f:c2',
                                    '74:f0:6d:09:69:1b',
                                    '74:2f:68:cd:75:49',
                                    '74:2f:68:29:fd:9c',
                                    '74:2f:68:30:de:80',
                                    '74:2f:68:31:5a:c5',
                                    '74:2f:68:32:a3:59',
                                    '74:2f:68:33:dd:f7',
                                    '74:2f:68:33:eb:50',
                                    '0c:74:c2:4f:7c:34',
                                    '0c:74:c2:61:bd:fe',
                                    '0c:d2:92:03:0d:7c',
                                    '0c:60:76:44:92:09',
                                    '0c:60:76:59:62:d0',
                                    '78:92:9c:29:8f:62',
                                    '78:92:9c:06:fd:a2',
                                    '78:ca:39:ae:65:df',
                                    '78:ca:39:ae:9e:d0',
                                    '78:ca:39:b0:1f:f1',
                                    '78:ca:39:b1:19:54',
                                    '78:ca:39:b1:34:d9',
                                    '78:ca:39:b3:f3:79',
                                    '78:ca:39:b4:59:1a',
                                    '78:ca:39:b8:3d:cb',
                                    '78:ca:39:b8:5c:e1',
                                    '78:ca:39:ba:57:d3',
                                    '78:ca:39:bb:24:e3',
                                    '78:ca:39:bc:d1:44',
                                    '78:ca:39:bd:55:20',
                                    '78:ca:39:19:6f:a4',
                                    '78:ca:39:34:b2:b6',
                                    '78:ca:39:35:8c:56',
                                    '78:ca:39:5b:db:36',
                                    '78:dd:08:d4:b1:d2',
                                    '78:dd:08:e1:36:9d',
                                    '78:dd:08:f6:36:47',
                                    '78:e4:00:9f:7f:56',
                                    '78:e4:00:04:a9:7f',
                                    '7c:d1:c3:70:ef:8e',
                                    '7c:d1:c3:72:e3:ea',
                                    '7c:d1:c3:75:a7:84',
                                    '7c:d1:c3:83:52:6c',
                                    '7c:d1:c3:88:a2:d6',
                                    '7c:d1:c3:88:df:76',
                                    '7c:d1:c3:89:ae:f2',
                                    '7c:d1:c3:95:46:b6',
                                    '7c:d1:c3:98:70:e2',
                                    '7c:d1:c3:9a:80:60',
                                    '7c:d1:c3:9a:84:7a',
                                    '7c:d1:c3:9c:3f:24',
                                    '7c:d1:c3:ec:1a:cb',
                                    '7c:d1:c3:ec:09:ff',
                                    '7c:d1:c3:f1:bc:35',
                                    '7c:d1:c3:f1:f4:79',
                                    '7c:d1:c3:f5:17:51',
                                    '7c:d1:c3:f6:dc:15',
                                    '7c:d1:c3:f7:d7:c3',
                                    '7c:e9:d3:6d:8c:d2',
                                    '7c:61:93:f5:37:96',
                                    '84:a6:c8:0d:d4:f5',
                                    '84:a6:c8:5d:b1:e1',
                                    '84:4b:f5:b6:73:09',
                                    '84:4b:f5:c2:6e:59',
                                    '84:4b:f5:ca:b4:7d',
                                    '84:4b:f5:cf:d0:eb',
                                    '84:4b:f5:26:b7:86',
                                    '84:4b:f5:4c:34:8b',
                                    '84:4b:f5:54:9f:03',
                                    '88:9f:fa:69:d8:51',
                                    '88:9f:fa:03:fa:4c',
                                    '88:53:2e:b2:e0:6c',
                                    '8c:7b:9d:d5:c5:82',
                                    '8c:7b:9d:d5:e8:55',
                                    '8c:a9:82:14:56:c6',
                                    '8c:2d:aa:65:ef:51',
                                    '90:00:4e:61:24:43',
                                    '90:84:0d:78:95:d2',
                                    '90:a4:de:c1:fe:0e',
                                    '90:a4:de:28:75:16',
                                    '90:fb:a6:9e:ac:91',
                                    '90:27:e4:eb:6f:dc',
                                    '90:27:e4:ed:4a:3a',
                                    '90:27:e4:f2:2d:90',
                                    '90:27:e4:f3:97:2f',
                                    '90:27:e4:f5:4d:6b',
                                    '90:27:e4:f7:31:30',
                                    '90:27:e4:fd:40:fc',
                                    '94:db:c9:44:d6:ff',
                                    '94:39:e5:b0:54:4f',
                                    '98:0c:82:cc:01:2c',
                                    '98:fe:94:3f:c8:94',
                                    '98:fe:94:41:65:d4',
                                    '98:fe:94:47:36:3e',
                                    '98:fe:94:4a:bf:8e',
                                    '9c:b7:0d:7b:2f:a3',
                                    '9c:b7:0d:d2:c1:a9',
                                    '9c:4e:36:53:76:74',
                                    '9c:4e:36:58:d0:94',
                                    '10:93:e9:00:c7:94',
                                    '10:93:e9:04:e0:c6',
                                    '10:93:e9:5d:4a:43',
                                    '10:93:e9:5e:37:5e',
                                    '10:9a:dd:a7:e0:92',
                                    '10:9a:dd:b2:fb:61',
                                    '10:9a:dd:c2:42:39',
                                    '10:9a:dd:c5:9e:76',
                                    '10:40:f3:7b:bc:78',
                                    '10:40:f3:80:06:34',
                                    '10:40:f3:86:39:6e',
                                    '10:40:f3:8d:83:0c',
                                    '10:40:f3:8d:85:32',
                                    '10:40:f3:8f:25:38',
                                    '10:40:f3:93:99:7c',
                                    '10:40:f3:99:50:8e',
                                    '10:40:f3:9c:35:ac',
                                    '10:40:f3:a5:45:30',
                                    '10:40:f3:a7:42:56',
                                    '10:40:f3:ef:ba:be',
                                    'a4:d1:d2:82:1a:a7',
                                    'a4:d1:d2:ac:32:1b',
                                    'a8:16:b2:67:31:2a',
                                    'a8:26:d9:e9:d6:63',
                                    'ac:81:12:8c:a2:10',
                                    'ac:81:12:47:d1:a5',
                                    'b0:65:bd:01:f6:c9',
                                    'b0:65:bd:60:60:17',
                                    '12:41:9b:00:62:fa',
                                    'b4:74:9f:7c:55:ec',
                                    'b8:8d:12:0c:3f:3a',
                                    'b8:8d:12:0d:49:64',
                                    'b8:8d:12:10:4b:3a',
                                    'b8:8d:12:12:f6:e8',
                                    'b8:8d:12:16:e3:7c',
                                    'b8:8d:12:1a:e9:6a',
                                    'b8:8d:12:1b:dc:1a',
                                    'b8:8d:12:1c:58:a6',
                                    'b8:8d:12:1e:21:1e',
                                    'b8:8d:12:20:04:78',
                                    'b8:8d:12:22:fc:e2',
                                    'b8:8d:12:22:37:3a',
                                    'b8:8d:12:22:5c:76',
                                    'b8:8d:12:24:35:c2',
                                    'b8:8d:12:05:12:56',
                                    'b8:8d:12:34:99:32',
                                    'b8:8d:12:34:b1:84',
                                    'b8:8d:12:38:fa:6a',
                                    'b8:8d:12:39:d7:e4',
                                    'b8:8d:12:39:f9:e4',
                                    'b8:8d:12:06:d5:74',
                                    'b8:8d:12:40:21:ae',
                                    'b8:8d:12:07:fc:32',
                                    'bc:67:78:9a:d9:82',
                                    'bc:67:78:17:6c:ec',
                                    'c0:9f:42:52:9a:5e',
                                    'c0:cb:38:01:35:18',
                                    'c0:f8:da:a7:e9:fe',
                                    'c4:85:08:69:9c:18',
                                    'c4:85:08:6a:0b:c6',
                                    'c4:85:08:22:d6:93',
                                    'c4:85:08:22:ff:74',
                                    'c4:85:08:34:39:74',
                                    'c4:85:08:37:c7:38',
                                    'c4:85:08:41:97:e5',
                                    'c4:85:08:56:d8:d5',
                                    'c4:85:08:57:0c:c4',
                                    'c4:17:fe:b5:48:8a',
                                    'c4:17:fe:55:91:75',
                                    'c4:17:fe:5c:24:68',
                                    'c4:2c:03:00:e7:8c',
                                    'c4:46:19:5f:74:ef',
                                    '14:74:11:ec:5e:a2',
                                    '14:8f:c6:5b:80:fe',
                                    '14:10:9f:f1:0e:a2',
                                    '14:10:9f:f1:99:a6',
                                    '14:10:9f:f1:9b:5a',
                                    'c8:bc:c8:bc:e7:28',
                                    'c8:bc:c8:cc:9a:b6',
                                    'c8:bc:c8:ce:3e:88',
                                    'c8:bc:c8:d5:ff:25',
                                    'c8:bc:c8:d9:92:35',
                                    'c8:bc:c8:dd:b7:01',
                                    'c8:bc:c8:dd:e5:56',
                                    'c8:bc:c8:ea:0c:60',
                                    'c8:f7:33:20:a6:89',
                                    'cc:af:78:73:a6:a0',
                                    'cc:af:78:15:18:89',
                                    'cc:af:78:2a:02:7c',
                                    'cc:af:78:08:7b:7c',
                                    'd0:df:9a:81:09:37',
                                    'd0:df:9a:e3:3d:ee',
                                    'd0:df:9a:21:f2:97',
                                    'd0:df:9a:04:4e:4a',
                                    'd4:9a:20:65:3a:98',
                                    'd4:9a:20:66:51:4d',
                                    'd4:9a:20:68:04:29',
                                    'd4:9a:20:6e:1c:23',
                                    'd4:9a:20:71:d6:db',
                                    'd4:9a:20:71:2d:a5',
                                    'd4:9a:20:72:81:66',
                                    'd4:9a:20:72:b8:1e',
                                    'd4:9a:20:72:ba:28',
                                    'd4:9a:20:72:d6:83',
                                    'd4:9a:20:72:e4:7e',
                                    'd8:a2:5e:8c:88:79',
                                    'd8:a2:5e:8e:ff:28',
                                    'd8:a2:5e:8e:48:c4',
                                    'd8:a2:5e:91:93:0e',
                                    'd8:a2:5e:91:9e:e5',
                                    'd8:a2:5e:91:a1:34',
                                    'd8:a2:5e:91:36:12',
                                    'd8:a2:5e:97:f7:91',
                                    'd8:30:62:81:6e:9f',
                                    'dc:85:de:69:44:24',
                                    'dc:85:de:13:b1:7a',
                                    'dc:85:de:15:d1:21',
                                    'e0:b9:a5:80:12:73',
                                    'e0:b9:a5:83:1b:d5',
                                    'e0:b9:a5:9d:00:f8',
                                    'e0:b9:a5:ae:01:43',
                                    'e0:b9:a5:c5:e8:12',
                                    'e0:b9:ba:87:f0:31',
                                    'e0:b9:ba:2b:eb:f0',
                                    'e0:ca:94:77:e2:76',
                                    'e0:ca:94:1d:15:ae',
                                    'e0:ca:94:24:ec:6f',
                                    'e0:f8:47:12:76:ea',
                                    'e0:f8:47:13:02:b4',
                                    'e0:f8:47:1b:f9:00',
                                    'e0:f8:47:03:e0:e8',
                                    'e0:f8:47:2b:8b:44',
                                    'e0:f8:47:35:7b:f6',
                                    'e0:f8:47:39:8f:2c',
                                    'e0:f8:47:39:c4:9c',
                                    'e0:f8:47:39:e3:0e',
                                    'e0:f8:47:43:cc:74',
                                    'e0:f8:47:09:95:0a',
                                    'e0:06:e6:6a:6c:0e',
                                    'e0:06:e6:93:5b:21',
                                    'e0:06:e6:96:d4:a1',
                                    'e0:06:e6:11:70:b7',
                                    'e0:06:e6:41:d7:d7',
                                    'e0:06:e6:43:24:17',
                                    'e4:ce:8f:0f:1c:64',
                                    'e4:ce:8f:0f:04:58',
                                    'e4:ce:8f:2d:07:f4',
                                    'e4:ce:8f:35:bb:f2',
                                    'e4:ce:8f:36:00:ee',
                                    'e4:ce:8f:4a:bd:8e',
                                    'e4:ce:8f:4b:21:16',
                                    'e4:ce:8f:50:71:0c',
                                    'e8:03:9a:8b:6d:12',
                                    'e8:39:df:6c:b3:07',
                                    'e8:39:df:84:76:cc',
                                    'e8:39:df:3f:05:c5',
                                    '18:a9:05:e3:0c:f5',
                                    '18:34:51:17:ff:78',
                                    'f0:7b:cb:01:a5:2c',
                                    'f0:7b:cb:18:ce:2a',
                                    'f0:b4:79:13:51:14',
                                    'f0:b4:79:14:aa:e7',
                                    'f0:b4:79:14:af:78',
                                    'f0:b4:79:14:b2:c6',
                                    'f0:b4:79:14:d5:04',
                                    'f0:b4:79:18:e4:4f',
                                    'f0:b4:79:19:71:e2',
                                    'f0:b4:79:1b:e4:5b',
                                    'f0:b4:79:1c:00:c4',
                                    'f0:b4:79:1c:12:90',
                                    'f0:b4:79:1c:4f:99',
                                    'f0:b4:79:1f:5b:76',
                                    'f0:b4:79:23:a1:ee',
                                    'f0:cb:a1:ca:da:f7',
                                    'f0:dc:e2:6b:35:48',
                                    'f0:e7:7e:51:28:f4',
                                    'f8:1e:df:d9:9f:79',
                                    'f8:1e:df:e9:69:37',
                                    'f8:1e:df:eb:11:47',
                                    'f8:1e:df:ed:3e:da',
                                    'f8:1e:df:f2:63:c8',
                                    'f8:1e:df:26:b4:55',
                                    '1c:4b:d6:80:6c:00',
                                    '1c:4b:d6:b9:19:c3',
                                    '1c:4b:d6:f2:d2:b8',
                                    '1c:4b:d6:1f:d4:05',
                                    '20:68:9d:bb:fd:17',
                                    '20:7c:8f:6b:79:0f',
                                    '20:02:af:55:ba:56',
                                    '20:c9:d0:7c:fc:3d',
                                    '20:c9:d0:80:c8:f5',
                                    '20:c9:d0:c3:10:f9',
                                    '20:c9:d0:c9:25:37',
                                    '20:c9:d0:d0:42:e9',
                                    '20:c9:d0:d1:45:05',
                                    '20:c9:d0:d1:56:0d',
                                    '20:c9:d0:d4:c8:ad',
                                    '20:c9:d0:d6:75:03',
                                    '20:c9:d0:da:82:61',
                                    '20:c9:d0:da:b2:81',
                                    '20:c9:d0:dd:c0:bd',
                                    '20:c9:d0:dd:d1:fb',
                                    '20:c9:d0:e0:83:db',
                                    '20:c9:d0:e4:2f:85',
                                    '20:c9:d0:44:8c:cb',
                                    '24:77:03:e2:30:74',
                                    '24:ab:81:06:f4:d4',
                                    '24:ec:99:23:1c:c6',
                                    '04:0c:ce:d0:a6:d2',
                                    '04:0c:ce:d3:ed:18',
                                    '04:0c:ce:d5:9f:a8',
                                    '04:0c:ce:d5:19:da',
                                    '04:0c:ce:d5:1c:4e',
                                    '04:0c:ce:dc:82:50',
                                    '04:0c:ce:dc:c3:40',
                                    '04:0c:ce:de:70:90',
                                    '04:0c:ce:e4:62:42',
                                    '04:0c:ce:20:b9:aa',
                                    '04:f7:e4:39:b1:57',
                                    '04:fe:31:99:65:bf',
                                    '04:1e:64:73:d2:b3',
                                    '04:1e:64:f8:5a:bd',
                                    '04:46:65:60:b2:7f',
                                    '04:54:53:06:bc:95',
                                    '28:94:0f:c1:1d:90',
                                    '28:cf:da:d6:81:fc',
                                    '28:cf:da:df:c4:50',
                                    '28:cf:da:e0:f1:1e',
                                    '28:cf:da:e7:68:26',
                                    '28:cf:da:e7:16:84',
                                    '28:cf:da:ec:03:d2',
                                    '28:e7:cf:08:ab:76',
                                    '28:37:37:24:94:1a',
                                    '28:37:37:25:c1:52',
                                    '28:37:37:25:dd:1e',
                                    '2c:81:58:fd:18:17',
                                    '2c:44:01:b4:87:f2',
                                    '30:39:26:e5:84:84',
                                    '34:c0:59:5f:ca:0f',
                                    '34:15:9e:8d:d4:71',
                                    '34:15:9e:91:f8:f0',
                                    '34:15:9e:94:10:71',
                                    '34:15:9e:95:e1:1a',
                                    '38:59:f9:44:5f:b2',
                                    '3c:07:54:11:e3:0f',
                                    '40:30:04:21:bc:bb',
                                    '44:6d:57:0d:03:2a',
                                    '44:6d:57:87:be:af',
                                    '44:6d:57:03:11:09',
                                    '44:2a:60:f2:f1:10',
                                    '48:5d:60:10:5a:39',
                                    '48:5d:60:b0:8c:ac',
                                    '48:5d:60:f5:96:80',
                                    '48:5d:60:5a:24:f8',
                                    '4c:0f:6e:e1:0d:bf',
                                    '4c:0f:6e:fa:2b:fd',
                                    '4c:0f:6e:fe:e9:78',
                                    '4c:bc:a5:ad:bf:6c',
                                    '4c:eb:42:98:9a:81',
                                    '4c:ed:de:65:5e:8e',
                                    '4c:ed:de:1c:60:a6',
                                    '08:ed:b9:9c:4e:2f',
                                    '08:ed:b9:f8:57:07',
                                    '08:ed:b9:34:c2:f4',
                                    '08:ed:b9:06:23:a2',
                                    '08:3e:8e:b2:c5:e1',
                                    '50:cc:f8:21:c2:58',
                                    '50:46:5d:29:77:c3',
                                    '54:04:a6:96:01:e1',
                                    '54:04:a6:07:54:9d',
                                    '58:94:6b:d2:d4:e4',
                                    '58:b0:35:66:11:6e',
                                    '58:b0:35:6c:f7:e4',
                                    '58:b0:35:75:f3:93',
                                    '58:b0:35:7e:cf:d3',
                                    '58:b0:35:80:a8:93',
                                    '58:b0:35:fc:6b:30',
                                    '58:b0:35:5c:95:64',
                                    '58:1f:aa:c8:62:d9',
                                    '58:55:ca:f6:86:6f',
                                    '58:55:ca:f8:15:4d',
                                    '5c:96:9d:76:2a:7f',
                                    '5c:96:9d:7a:9c:fb',
                                    '5c:96:9d:7c:71:c9',
                                    '5c:96:9d:7c:5a:15',
                                    '5c:96:9d:7d:1b:63',
                                    '5c:96:9d:8a:96:2f',
                                    '5c:96:9d:8b:05:db',
                                    '5c:59:48:a9:f0:37',
                                    '60:c5:47:0a:cb:34',
                                    '60:c5:47:8c:75:e0',
                                    '60:c5:47:8d:a6:7e',
                                    '60:c5:47:8d:b3:00',
                                    '60:c5:47:96:c3:26',
                                    '60:c5:47:07:6d:90',
                                    '60:d8:19:65:c4:df',
                                    '60:d8:19:08:a2:92',
                                    '60:33:4b:01:c7:d8',
                                    '60:33:4b:01:dd:f5',
                                    '60:33:4b:23:62:e2',
                                    '60:33:4b:26:8b:b7',
                                    '60:33:4b:26:bc:8f',
                                    '60:45:bd:24:de:76',
                                    '00:00:5e:00:01:02',
                                    '00:80:9f:ba:8d:d5',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '600',
                        IFNAME           => 'vlan.0',
                        IFDESCR          => 'vlan.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '192.168.1.132',
                        MAC              => '78:fe:3d:37:5e:c0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6577) 0:01:05.77',
                        IFINOCTETS       => '1771189919',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '447506369',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        },
    ],
    'juniper/ex2200.05.walk' => [
        {
            TYPE         => 'NETWORKING',
            MANUFACTURER => 'Juniper',
            MODEL        => 'EX2200',
            DESCRIPTION  => 'Juniper Networks, Inc. ex2200-48t-4g internet router, kernel JUNOS 11.4R5.5 #0: 2012-08-25 05:21:13 UTC     builder@evenath.juniper.net:/volume/build/junos/11.4/release/11.4R5.5/obj-arm/bsd/kernels/JUNIPER-EX-2200/kernel Build date: 2012-08-25 04:48:47 U',

            SNMPHOSTNAME => 'jtc407-01',
            LOCATION     => 'PMF 4 n° 407',
            UPTIME       => '(690838738) 79 days, 22:59:47.38',
            IPS          => {
                IP => [
                    '128.0.0.1',
                    '128.0.0.16',
                    '128.0.0.32',
                    '192.168.100.65',
                ],
            },
        },
        {
            INFO => {
                ID           => undef,
                TYPE         => 'NETWORKING',
                MANUFACTURER => 'Juniper',
                MODEL        => 'EX2200',
                COMMENTS     => 'Juniper Networks, Inc. ex2200-48t-4g internet router, kernel JUNOS 11.4R5.5 #0: 2012-08-25 05:21:13 UTC     builder@evenath.juniper.net:/volume/build/junos/11.4/release/11.4R5.5/obj-arm/bsd/kernels/JUNIPER-EX-2200/kernel Build date: 2012-08-25 04:48:47 U',
                NAME         => 'jtc407-01',
                LOCATION     => 'PMF 4 n° 407',
                UPTIME       => '(690838738) 79 days, 22:59:47.38',
                IPS          => {
                    IP => [
                        '128.0.0.1',
                        '128.0.0.16',
                        '128.0.0.32',
                        '192.168.100.65',
                    ],
                },
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '4',
                        IFNAME           => 'lsi',
                        IFDESCR          => 'lsi',
                        IFTYPE           => '150',
                        IFSPEED          => '0',
                        IFMTU            => '1496',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5',
                        IFNAME           => 'dsc',
                        IFDESCR          => 'dsc',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3199) 0:00:31.99',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '6',
                        IFNAME           => 'lo0',
                        IFDESCR          => 'lo0',
                        IFTYPE           => '24',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3203) 0:00:32.03',
                        IFINOCTETS       => '3299710309',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3300277085',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '7',
                        IFNAME           => 'tap',
                        IFDESCR          => 'tap',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3204) 0:00:32.04',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '8',
                        IFNAME           => 'gre',
                        IFDESCR          => 'gre',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3201) 0:00:32.01',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '9',
                        IFNAME           => 'ipip',
                        IFDESCR          => 'ipip',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3202) 0:00:32.02',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10',
                        IFNAME           => 'pime',
                        IFDESCR          => 'pime',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3208) 0:00:32.08',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '11',
                        IFNAME           => 'pimd',
                        IFDESCR          => 'pimd',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3209) 0:00:32.09',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '12',
                        IFNAME           => 'mtun',
                        IFDESCR          => 'mtun',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3211) 0:00:32.11',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '33',
                        IFNAME           => 'me0',
                        IFDESCR          => 'me0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:3f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3210) 0:00:32.10',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '37',
                        IFNAME           => 'bme0',
                        IFDESCR          => 'bme0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1576',
                        MAC              => '00:0b:ca:fe:00:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3198) 0:00:31.98',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2715463516',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '38',
                        IFNAME           => 'bme0.32768',
                        IFDESCR          => 'bme0.32768',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1562',
                        IP               => '128.0.0.32',
                        MAC              => '00:0b:ca:fe:00:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3213) 0:00:32.13',
                        IFINOCTETS       => '901244274',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '126',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '501',
                        IFNAME           => 'ge-0/0/0',
                        IFDESCR          => 'ge-0/0/0',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:03',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7247) 0:01:12.47',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3654820112',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1776131026',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '502',
                        IFNAME           => 'ge-0/0/46.0',
                        IFDESCR          => 'ge-0/0/46.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:03',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3891) 0:00:38.91',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '503',
                        IFNAME           => 'ge-0/0/1',
                        IFDESCR          => 'ge-0/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:04',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7247) 0:01:12.47',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '99911270',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3838463887',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '504',
                        IFNAME           => 'ge-0/0/1.0',
                        IFDESCR          => 'ge-0/0/1.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:04',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7247) 0:01:12.47',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '188602',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '465720827',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '505',
                        IFNAME           => 'ge-0/0/10',
                        IFDESCR          => 'ge-0/0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:0d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3345) 0:00:33.45',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '506',
                        IFNAME           => 'ge-0/0/10.0',
                        IFDESCR          => 'ge-0/0/10.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:0d',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3347) 0:00:33.47',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '507',
                        IFNAME           => 'ge-0/0/11',
                        IFDESCR          => 'ge-0/0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:0e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3356) 0:00:33.56',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '508',
                        IFNAME           => 'ge-0/0/11.0',
                        IFDESCR          => 'ge-0/0/11.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:0e',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3359) 0:00:33.59',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '509',
                        IFNAME           => 'ge-0/0/12',
                        IFDESCR          => 'ge-0/0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:0f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3367) 0:00:33.67',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '510',
                        IFNAME           => 'ge-0/0/12.0',
                        IFDESCR          => 'ge-0/0/12.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:0f',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3371) 0:00:33.71',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '511',
                        IFNAME           => 'ge-0/0/13',
                        IFDESCR          => 'ge-0/0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:10',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(577843267) 66 days, 21:07:12.67',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3030652257',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3013626698',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '512',
                        IFNAME           => 'ge-0/0/13.0',
                        IFDESCR          => 'ge-0/0/13.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:10',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(577843267) 66 days, 21:07:12.67',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '33585640',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '465476805',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '513',
                        IFNAME           => 'ge-0/0/14',
                        IFDESCR          => 'ge-0/0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:11',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(654577277) 75 days, 18:16:12.77',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3319962578',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1283149072',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '514',
                        IFNAME           => 'ge-0/0/14.0',
                        IFDESCR          => 'ge-0/0/14.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:11',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(654577277) 75 days, 18:16:12.77',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '8379249',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '465486252',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '515',
                        IFNAME           => 'ge-0/0/15',
                        IFDESCR          => 'ge-0/0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:12',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3405) 0:00:34.05',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '516',
                        IFNAME           => 'ge-0/0/15.0',
                        IFDESCR          => 'ge-0/0/15.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:12',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3407) 0:00:34.07',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '517',
                        IFNAME           => 'ge-0/0/16',
                        IFDESCR          => 'ge-0/0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:13',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3414) 0:00:34.14',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '518',
                        IFNAME           => 'ge-0/0/16.0',
                        IFDESCR          => 'ge-0/0/16.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:13',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3418) 0:00:34.18',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '519',
                        IFNAME           => 'ge-0/0/17',
                        IFDESCR          => 'ge-0/0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:14',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3424) 0:00:34.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '520',
                        IFNAME           => 'ge-0/0/17.0',
                        IFDESCR          => 'ge-0/0/17.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:14',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3435) 0:00:34.35',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '521',
                        IFNAME           => 'ge-0/0/18',
                        IFDESCR          => 'ge-0/0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:15',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3426) 0:00:34.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '522',
                        IFNAME           => 'ge-0/0/18.0',
                        IFDESCR          => 'ge-0/0/18.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:15',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3446) 0:00:34.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '523',
                        IFNAME           => 'ge-0/0/19',
                        IFDESCR          => 'ge-0/0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:16',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3442) 0:00:34.42',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '524',
                        IFNAME           => 'ge-0/0/19.0',
                        IFDESCR          => 'ge-0/0/19.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:16',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3454) 0:00:34.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '525',
                        IFNAME           => 'ge-0/0/2',
                        IFDESCR          => 'ge-0/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:05',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3248) 0:00:32.48',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '526',
                        IFNAME           => 'ge-0/0/2.0',
                        IFDESCR          => 'ge-0/0/2.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:05',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3250) 0:00:32.50',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '527',
                        IFNAME           => 'ge-0/0/20',
                        IFDESCR          => 'ge-0/0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:17',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3449) 0:00:34.49',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '528',
                        IFNAME           => 'ge-0/0/20.0',
                        IFDESCR          => 'ge-0/0/20.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:17',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3460) 0:00:34.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '529',
                        IFNAME           => 'ge-0/0/21',
                        IFDESCR          => 'ge-0/0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:18',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3456) 0:00:34.56',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '530',
                        IFNAME           => 'ge-0/0/21.0',
                        IFDESCR          => 'ge-0/0/21.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:18',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3474) 0:00:34.74',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '531',
                        IFNAME           => 'ge-0/0/22',
                        IFDESCR          => 'ge-0/0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:19',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3462) 0:00:34.62',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '532',
                        IFNAME           => 'ge-0/0/22.0',
                        IFDESCR          => 'ge-0/0/22.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:19',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3501) 0:00:35.01',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '533',
                        IFNAME           => 'ge-0/0/23',
                        IFDESCR          => 'ge-0/0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:1a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3467) 0:00:34.67',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '534',
                        IFNAME           => 'ge-0/0/23.0',
                        IFDESCR          => 'ge-0/0/23.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:1a',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3519) 0:00:35.19',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '535',
                        IFNAME           => 'ge-0/0/24',
                        IFDESCR          => 'ge-0/0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:1b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3471) 0:00:34.71',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '536',
                        IFNAME           => 'ge-0/0/24.0',
                        IFDESCR          => 'ge-0/0/24.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:1b',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3532) 0:00:35.32',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '537',
                        IFNAME           => 'ge-0/0/25',
                        IFDESCR          => 'ge-0/0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:1c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7370) 0:01:13.70',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '995965943',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3951591485',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '538',
                        IFNAME           => 'ge-0/0/25.0',
                        IFDESCR          => 'ge-0/0/25.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:1c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7370) 0:01:13.70',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '5187440',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '466471737',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '539',
                        IFNAME           => 'ge-0/0/26',
                        IFDESCR          => 'ge-0/0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:1d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3487) 0:00:34.87',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '540',
                        IFNAME           => 'ge-0/0/26.0',
                        IFDESCR          => 'ge-0/0/26.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:1d',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3589) 0:00:35.89',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '541',
                        IFNAME           => 'ge-0/0/27',
                        IFDESCR          => 'ge-0/0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:1e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3493) 0:00:34.93',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '542',
                        IFNAME           => 'ge-0/0/27.0',
                        IFDESCR          => 'ge-0/0/27.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:1e',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3605) 0:00:36.05',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '543',
                        IFNAME           => 'ge-0/0/28',
                        IFDESCR          => 'ge-0/0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:1f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3496) 0:00:34.96',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '544',
                        IFNAME           => 'ge-0/0/28.0',
                        IFDESCR          => 'ge-0/0/28.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:1f',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3630) 0:00:36.30',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '545',
                        IFNAME           => 'ge-0/0/29',
                        IFDESCR          => 'ge-0/0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:20',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3505) 0:00:35.05',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '546',
                        IFNAME           => 'ge-0/0/29.0',
                        IFDESCR          => 'ge-0/0/29.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:20',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3641) 0:00:36.41',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '547',
                        IFNAME           => 'ge-0/0/3',
                        IFDESCR          => 'ge-0/0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:06',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3252) 0:00:32.52',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '548',
                        IFNAME           => 'ge-0/0/3.0',
                        IFDESCR          => 'ge-0/0/3.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:06',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3253) 0:00:32.53',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '549',
                        IFNAME           => 'ge-0/0/30',
                        IFDESCR          => 'ge-0/0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:21',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3508) 0:00:35.08',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '550',
                        IFNAME           => 'ge-0/0/30.0',
                        IFDESCR          => 'ge-0/0/30.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:21',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3645) 0:00:36.45',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '551',
                        IFNAME           => 'ge-0/0/31',
                        IFDESCR          => 'ge-0/0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:22',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(688688737) 79 days, 17:01:27.37',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '141635944',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3460900081',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '552',
                        IFNAME           => 'ge-0/0/31.0',
                        IFDESCR          => 'ge-0/0/31.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:22',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(688688737) 79 days, 17:01:27.37',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '500773',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '421381483',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '553',
                        IFNAME           => 'ge-0/0/32',
                        IFDESCR          => 'ge-0/0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:23',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(689602367) 79 days, 19:33:43.67',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '86562173',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1295216410',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '554',
                        IFNAME           => 'ge-0/0/32.0',
                        IFDESCR          => 'ge-0/0/32.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:23',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(689602367) 79 days, 19:33:43.67',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '694827',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '61338038',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '555',
                        IFNAME           => 'ge-0/0/33',
                        IFDESCR          => 'ge-0/0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:24',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7371) 0:01:13.71',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '4011077581',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3301180591',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '556',
                        IFNAME           => 'ge-0/0/33.0',
                        IFDESCR          => 'ge-0/0/33.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:24',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7371) 0:01:13.71',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '7570937',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '449527190',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '557',
                        IFNAME           => 'ge-0/0/34',
                        IFDESCR          => 'ge-0/0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:25',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(605122587) 70 days, 0:53:45.87',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1188771734',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3796981610',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '558',
                        IFNAME           => 'ge-0/0/34.0',
                        IFDESCR          => 'ge-0/0/34.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:25',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(605122587) 70 days, 0:53:45.87',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '5660368',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '464675284',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '559',
                        IFNAME           => 'ge-0/0/35',
                        IFDESCR          => 'ge-0/0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:26',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(603753039) 69 days, 21:05:30.39',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '717085133',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1859341136',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '560',
                        IFNAME           => 'ge-0/0/35.0',
                        IFDESCR          => 'ge-0/0/35.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:26',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(603753039) 69 days, 21:05:30.39',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '6150747',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '407661671',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '561',
                        IFNAME           => 'ge-0/0/36',
                        IFDESCR          => 'ge-0/0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:27',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(630152097) 72 days, 22:25:20.97',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2150647287',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3123063969',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '562',
                        IFNAME           => 'ge-0/0/36.0',
                        IFDESCR          => 'ge-0/0/36.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:27',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(630152097) 72 days, 22:25:20.97',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '210659779',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '76952215',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '563',
                        IFNAME           => 'ge-0/0/37',
                        IFDESCR          => 'ge-0/0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:28',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(672589657) 77 days, 20:18:16.57',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2139115923',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '713610076',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '564',
                        IFNAME           => 'ge-0/0/37.0',
                        IFDESCR          => 'ge-0/0/37.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:28',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(672589657) 77 days, 20:18:16.57',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2007812',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '449518210',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '565',
                        IFNAME           => 'ge-0/0/38',
                        IFDESCR          => 'ge-0/0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:29',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(671864217) 77 days, 18:17:22.17',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2276628107',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3562479292',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '566',
                        IFNAME           => 'ge-0/0/38.0',
                        IFDESCR          => 'ge-0/0/38.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:29',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(671864217) 77 days, 18:17:22.17',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3779632',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '449506711',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '567',
                        IFNAME           => 'ge-0/0/39',
                        IFDESCR          => 'ge-0/0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:2a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3579) 0:00:35.79',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '568',
                        IFNAME           => 'ge-0/0/39.0',
                        IFDESCR          => 'ge-0/0/39.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:2a',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3785) 0:00:37.85',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '569',
                        IFNAME           => 'ge-0/0/4',
                        IFDESCR          => 'ge-0/0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:07',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3256) 0:00:32.56',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '570',
                        IFNAME           => 'ge-0/0/4.0',
                        IFDESCR          => 'ge-0/0/4.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:07',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3258) 0:00:32.58',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '571',
                        IFNAME           => 'ge-0/0/40',
                        IFDESCR          => 'ge-0/0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:2b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(623010977) 72 days, 2:35:09.77',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3533234512',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2633122441',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '572',
                        IFNAME           => 'ge-0/0/40.0',
                        IFDESCR          => 'ge-0/0/40.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:2b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(623010977) 72 days, 2:35:09.77',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3134933',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '449446120',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '573',
                        IFNAME           => 'ge-0/0/41',
                        IFDESCR          => 'ge-0/0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:2c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(380811077) 44 days, 1:48:30.77',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3363359789',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1143757502',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '574',
                        IFNAME           => 'ge-0/0/41.0',
                        IFDESCR          => 'ge-0/0/41.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:2c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(380811077) 44 days, 1:48:30.77',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '6930628',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '449497792',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '575',
                        IFNAME           => 'ge-0/0/42',
                        IFDESCR          => 'ge-0/0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:2d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(626710427) 72 days, 12:51:44.27',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '360348982',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1936465493',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '576',
                        IFNAME           => 'ge-0/0/42.0',
                        IFDESCR          => 'ge-0/0/42.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:2d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(626710427) 72 days, 12:51:44.27',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '928054',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '93754257',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '577',
                        IFNAME           => 'ge-0/0/43',
                        IFDESCR          => 'ge-0/0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:2e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3616) 0:00:36.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '578',
                        IFNAME           => 'ge-0/0/43.0',
                        IFDESCR          => 'ge-0/0/43.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:2e',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3833) 0:00:38.33',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '579',
                        IFNAME           => 'ge-0/0/44',
                        IFDESCR          => 'ge-0/0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:2f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(654832517) 75 days, 18:58:45.17',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3158408642',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4246970219',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '580',
                        IFNAME           => 'ge-0/0/44.0',
                        IFDESCR          => 'ge-0/0/44.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:2f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(654832517) 75 days, 18:58:45.17',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '41406521',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '449536917',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFNUMBER => '0x001A1ECDBB02',
                                IFDESCR  => 'eth0',
                                SYSNAME  => 'PMF-sap-c407',
                                SYSDESCR => 'ArubaOS (MODEL: 125), Version 6.2.1.2 (38711)',
                                SYSMAC   => '00:1a:1e:cd:bb:02',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '581',
                        IFNAME           => 'ge-0/0/45',
                        IFDESCR          => 'ge-0/0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:30',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(561606847) 65 days, 0:01:08.47',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3458219972',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '244487005',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '582',
                        IFNAME           => 'ge-0/0/45.0',
                        IFDESCR          => 'ge-0/0/45.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:30',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(561606847) 65 days, 0:01:08.47',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '16584800',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '465451921',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '583',
                        IFNAME           => 'ge-0/0/46',
                        IFDESCR          => 'ge-0/0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:03',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3635) 0:00:36.35',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '584',
                        IFNAME           => 'ge-0/0/47.0',
                        IFDESCR          => 'ge-0/0/47.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:03',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3903) 0:00:39.03',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '585',
                        IFNAME           => 'ge-0/0/47',
                        IFDESCR          => 'ge-0/0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:03',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3638) 0:00:36.38',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '586',
                        IFNAME           => 'ge-0/0/0.0',
                        IFDESCR          => 'ge-0/0/0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:03',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7247) 0:01:12.47',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3030702800',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '171078177',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '587',
                        IFNAME           => 'ge-0/0/5',
                        IFDESCR          => 'ge-0/0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:08',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3259) 0:00:32.59',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '588',
                        IFNAME           => 'ge-0/0/5.0',
                        IFDESCR          => 'ge-0/0/5.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:08',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3261) 0:00:32.61',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '589',
                        IFNAME           => 'ge-0/0/6',
                        IFDESCR          => 'ge-0/0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:09',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3301) 0:00:33.01',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '590',
                        IFNAME           => 'ge-0/0/6.0',
                        IFDESCR          => 'ge-0/0/6.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:09',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3304) 0:00:33.04',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '591',
                        IFNAME           => 'ge-0/0/7',
                        IFDESCR          => 'ge-0/0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:0a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3311) 0:00:33.11',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '592',
                        IFNAME           => 'ge-0/0/7.0',
                        IFDESCR          => 'ge-0/0/7.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:0a',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3314) 0:00:33.14',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '593',
                        IFNAME           => 'ge-0/0/8',
                        IFDESCR          => 'ge-0/0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:0b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3328) 0:00:33.28',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '594',
                        IFNAME           => 'ge-0/0/8.0',
                        IFDESCR          => 'ge-0/0/8.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:0b',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3333) 0:00:33.33',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '595',
                        IFNAME           => 'ge-0/0/9',
                        IFDESCR          => 'ge-0/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:0c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3338) 0:00:33.38',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '596',
                        IFNAME           => 'ge-0/0/9.0',
                        IFDESCR          => 'ge-0/0/9.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:0c',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3340) 0:00:33.40',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '599',
                        IFNAME           => 'vlan',
                        IFDESCR          => 'vlan',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '78:fe:3d:36:f7:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3224) 0:00:32.24',
                        IFINOCTETS       => '1782820774',
                        IFINERRORS       => '18',
                        IFOUTOCTETS      => '68750026',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '600',
                        IFNAME           => 'vlan.0',
                        IFDESCR          => 'vlan.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '192.168.100.65',
                        MAC              => '78:fe:3d:36:f7:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7309) 0:01:13.09',
                        IFINOCTETS       => '1782820862',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '64824825',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '609',
                        IFNAME           => 'ae0',
                        IFDESCR          => 'ae0',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:03',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3215) 0:00:32.15',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '610',
                        IFNAME           => 'ae1',
                        IFDESCR          => 'ae1',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:04',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3216) 0:00:32.16',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '611',
                        IFNAME           => 'ae2',
                        IFDESCR          => 'ae2',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:05',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3218) 0:00:32.18',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '612',
                        IFNAME           => 'ae3',
                        IFDESCR          => 'ae3',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:06',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3219) 0:00:32.19',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '613',
                        IFNAME           => 'ae4',
                        IFDESCR          => 'ae4',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:07',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3221) 0:00:32.21',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '614',
                        IFNAME           => 'ae0.0',
                        IFDESCR          => 'ae0.0',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:36:f7:03',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3222) 0:00:32.22',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        },
    ],
    'juniper/ex2200.06.walk' => [
        {
            TYPE         => 'NETWORKING',
            MANUFACTURER => 'Juniper',
            MODEL        => 'EX2200',
            DESCRIPTION  => 'Juniper Networks, Inc. ex2200-48t-4g internet router, kernel JUNOS 11.4R5.5 #0: 2012-08-25 05:21:13 UTC     builder@evenath.juniper.net:/volume/build/junos/11.4/release/11.4R5.5/obj-arm/bsd/kernels/JUNIPER-EX-2200/kernel Build date: 2012-08-25 04:48:47 U',

            SNMPHOSTNAME => 'jtc407-01',
            LOCATION     => 'PMF 4 n° 407',
            UPTIME       => '(690835636) 79 days, 22:59:16.36',
        },
        {
            INFO => {
                ID           => undef,
                TYPE         => 'NETWORKING',
                MANUFACTURER => 'Juniper',
                MODEL        => 'EX2200',
                COMMENTS     => 'Juniper Networks, Inc. ex2200-48t-4g internet router, kernel JUNOS 11.4R5.5 #0: 2012-08-25 05:21:13 UTC     builder@evenath.juniper.net:/volume/build/junos/11.4/release/11.4R5.5/obj-arm/bsd/kernels/JUNIPER-EX-2200/kernel Build date: 2012-08-25 04:48:47 U',
                NAME         => 'jtc407-01',
                LOCATION     => 'PMF 4 n° 407',
                UPTIME       => '(690835636) 79 days, 22:59:16.36',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '4',
                        IFNAME           => 'lsi',
                        IFDESCR          => 'lsi',
                        IFTYPE           => '150',
                        IFSPEED          => '0',
                        IFMTU            => '1496',
                    },
                    {
                        IFNUMBER         => '5',
                        IFNAME           => 'dsc',
                        IFDESCR          => 'dsc',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                    },
                    {
                        IFNUMBER         => '6',
                        IFNAME           => 'lo0',
                        IFDESCR          => 'lo0',
                        IFTYPE           => '24',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                    },
                    {
                        IFNUMBER         => '7',
                        IFNAME           => 'tap',
                        IFDESCR          => 'tap',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                    },
                    {
                        IFNUMBER         => '8',
                        IFNAME           => 'gre',
                        IFDESCR          => 'gre',
                        IFTYPE           => '131',
                        IFMTU            => '2147483647',
                    },
                    {
                        IFNUMBER         => '9',
                        IFNAME           => 'ipip',
                        IFDESCR          => 'ipip',
                        IFTYPE           => '131',
                        IFMTU            => '2147483647',
                    },
                    {
                        IFNUMBER         => '10',
                        IFNAME           => 'pime',
                        IFDESCR          => 'pime',
                        IFTYPE           => '131',
                        IFMTU            => '2147483647',
                    },
                    {
                        IFNUMBER         => '11',
                        IFNAME           => 'pimd',
                        IFDESCR          => 'pimd',
                        IFTYPE           => '131',
                        IFMTU            => '2147483647',
                    },
                    {
                        IFNUMBER         => '12',
                        IFNAME           => 'mtun',
                        IFDESCR          => 'mtun',
                        IFTYPE           => '131',
                        IFMTU            => '2147483647',
                    },
                    {
                        IFNUMBER         => '33',
                        IFNAME           => 'me0',
                        IFDESCR          => 'me0',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '37',
                        IFNAME           => 'bme0',
                        IFDESCR          => 'bme0',
                        IFTYPE           => '6',
                        IFMTU            => '1576',
                    },
                    {
                        IFNUMBER         => '38',
                        IFNAME           => 'bme0.32768',
                        IFDESCR          => 'bme0.32768',
                        IFTYPE           => '53',
                        IFMTU            => '1562',
                    },
                    {
                        IFNUMBER         => '501',
                        IFNAME           => 'ge-0/0/0',
                        IFDESCR          => 'ge-0/0/0',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '502',
                        IFNAME           => 'ge-0/0/46.0',
                        IFDESCR          => 'ge-0/0/46.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '503',
                        IFNAME           => 'ge-0/0/1',
                        IFDESCR          => 'ge-0/0/1',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '504',
                        IFNAME           => 'ge-0/0/1.0',
                        IFDESCR          => 'ge-0/0/1.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '505',
                        IFNAME           => 'ge-0/0/10',
                        IFDESCR          => 'ge-0/0/10',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '506',
                        IFNAME           => 'ge-0/0/10.0',
                        IFDESCR          => 'ge-0/0/10.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '507',
                        IFNAME           => 'ge-0/0/11',
                        IFDESCR          => 'ge-0/0/11',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '508',
                        IFNAME           => 'ge-0/0/11.0',
                        IFDESCR          => 'ge-0/0/11.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '509',
                        IFNAME           => 'ge-0/0/12',
                        IFDESCR          => 'ge-0/0/12',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '510',
                        IFNAME           => 'ge-0/0/12.0',
                        IFDESCR          => 'ge-0/0/12.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '511',
                        IFNAME           => 'ge-0/0/13',
                        IFDESCR          => 'ge-0/0/13',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '512',
                        IFNAME           => 'ge-0/0/13.0',
                        IFDESCR          => 'ge-0/0/13.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '513',
                        IFNAME           => 'ge-0/0/14',
                        IFDESCR          => 'ge-0/0/14',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '514',
                        IFNAME           => 'ge-0/0/14.0',
                        IFDESCR          => 'ge-0/0/14.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '515',
                        IFNAME           => 'ge-0/0/15',
                        IFDESCR          => 'ge-0/0/15',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '516',
                        IFNAME           => 'ge-0/0/15.0',
                        IFDESCR          => 'ge-0/0/15.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '517',
                        IFNAME           => 'ge-0/0/16',
                        IFDESCR          => 'ge-0/0/16',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '518',
                        IFNAME           => 'ge-0/0/16.0',
                        IFDESCR          => 'ge-0/0/16.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '519',
                        IFNAME           => 'ge-0/0/17',
                        IFDESCR          => 'ge-0/0/17',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '520',
                        IFNAME           => 'ge-0/0/17.0',
                        IFDESCR          => 'ge-0/0/17.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '521',
                        IFNAME           => 'ge-0/0/18',
                        IFDESCR          => 'ge-0/0/18',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '522',
                        IFNAME           => 'ge-0/0/18.0',
                        IFDESCR          => 'ge-0/0/18.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '523',
                        IFNAME           => 'ge-0/0/19',
                        IFDESCR          => 'ge-0/0/19',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '524',
                        IFNAME           => 'ge-0/0/19.0',
                        IFDESCR          => 'ge-0/0/19.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '525',
                        IFNAME           => 'ge-0/0/2',
                        IFDESCR          => 'ge-0/0/2',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '526',
                        IFNAME           => 'ge-0/0/2.0',
                        IFDESCR          => 'ge-0/0/2.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '527',
                        IFNAME           => 'ge-0/0/20',
                        IFDESCR          => 'ge-0/0/20',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '528',
                        IFNAME           => 'ge-0/0/20.0',
                        IFDESCR          => 'ge-0/0/20.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '529',
                        IFNAME           => 'ge-0/0/21',
                        IFDESCR          => 'ge-0/0/21',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '530',
                        IFNAME           => 'ge-0/0/21.0',
                        IFDESCR          => 'ge-0/0/21.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '531',
                        IFNAME           => 'ge-0/0/22',
                        IFDESCR          => 'ge-0/0/22',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '532',
                        IFNAME           => 'ge-0/0/22.0',
                        IFDESCR          => 'ge-0/0/22.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '533',
                        IFNAME           => 'ge-0/0/23',
                        IFDESCR          => 'ge-0/0/23',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '534',
                        IFNAME           => 'ge-0/0/23.0',
                        IFDESCR          => 'ge-0/0/23.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '535',
                        IFNAME           => 'ge-0/0/24',
                        IFDESCR          => 'ge-0/0/24',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '536',
                        IFNAME           => 'ge-0/0/24.0',
                        IFDESCR          => 'ge-0/0/24.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '537',
                        IFNAME           => 'ge-0/0/25',
                        IFDESCR          => 'ge-0/0/25',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '538',
                        IFNAME           => 'ge-0/0/25.0',
                        IFDESCR          => 'ge-0/0/25.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '539',
                        IFNAME           => 'ge-0/0/26',
                        IFDESCR          => 'ge-0/0/26',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '540',
                        IFNAME           => 'ge-0/0/26.0',
                        IFDESCR          => 'ge-0/0/26.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '541',
                        IFNAME           => 'ge-0/0/27',
                        IFDESCR          => 'ge-0/0/27',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '542',
                        IFNAME           => 'ge-0/0/27.0',
                        IFDESCR          => 'ge-0/0/27.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '543',
                        IFNAME           => 'ge-0/0/28',
                        IFDESCR          => 'ge-0/0/28',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '544',
                        IFNAME           => 'ge-0/0/28.0',
                        IFDESCR          => 'ge-0/0/28.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '545',
                        IFNAME           => 'ge-0/0/29',
                        IFDESCR          => 'ge-0/0/29',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '546',
                        IFNAME           => 'ge-0/0/29.0',
                        IFDESCR          => 'ge-0/0/29.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '547',
                        IFNAME           => 'ge-0/0/3',
                        IFDESCR          => 'ge-0/0/3',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '548',
                        IFNAME           => 'ge-0/0/3.0',
                        IFDESCR          => 'ge-0/0/3.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '549',
                        IFNAME           => 'ge-0/0/30',
                        IFDESCR          => 'ge-0/0/30',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '550',
                        IFNAME           => 'ge-0/0/30.0',
                        IFDESCR          => 'ge-0/0/30.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '551',
                        IFNAME           => 'ge-0/0/31',
                        IFDESCR          => 'ge-0/0/31',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '552',
                        IFNAME           => 'ge-0/0/31.0',
                        IFDESCR          => 'ge-0/0/31.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '553',
                        IFNAME           => 'ge-0/0/32',
                        IFDESCR          => 'ge-0/0/32',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '554',
                        IFNAME           => 'ge-0/0/32.0',
                        IFDESCR          => 'ge-0/0/32.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '555',
                        IFNAME           => 'ge-0/0/33',
                        IFDESCR          => 'ge-0/0/33',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '556',
                        IFNAME           => 'ge-0/0/33.0',
                        IFDESCR          => 'ge-0/0/33.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '557',
                        IFNAME           => 'ge-0/0/34',
                        IFDESCR          => 'ge-0/0/34',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '558',
                        IFNAME           => 'ge-0/0/34.0',
                        IFDESCR          => 'ge-0/0/34.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '559',
                        IFNAME           => 'ge-0/0/35',
                        IFDESCR          => 'ge-0/0/35',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '560',
                        IFNAME           => 'ge-0/0/35.0',
                        IFDESCR          => 'ge-0/0/35.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '561',
                        IFNAME           => 'ge-0/0/36',
                        IFDESCR          => 'ge-0/0/36',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '562',
                        IFNAME           => 'ge-0/0/36.0',
                        IFDESCR          => 'ge-0/0/36.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '563',
                        IFNAME           => 'ge-0/0/37',
                        IFDESCR          => 'ge-0/0/37',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '564',
                        IFNAME           => 'ge-0/0/37.0',
                        IFDESCR          => 'ge-0/0/37.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '565',
                        IFNAME           => 'ge-0/0/38',
                        IFDESCR          => 'ge-0/0/38',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '566',
                        IFNAME           => 'ge-0/0/38.0',
                        IFDESCR          => 'ge-0/0/38.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '567',
                        IFNAME           => 'ge-0/0/39',
                        IFDESCR          => 'ge-0/0/39',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '568',
                        IFNAME           => 'ge-0/0/39.0',
                        IFDESCR          => 'ge-0/0/39.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '569',
                        IFNAME           => 'ge-0/0/4',
                        IFDESCR          => 'ge-0/0/4',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '570',
                        IFNAME           => 'ge-0/0/4.0',
                        IFDESCR          => 'ge-0/0/4.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '571',
                        IFNAME           => 'ge-0/0/40',
                        IFDESCR          => 'ge-0/0/40',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '572',
                        IFNAME           => 'ge-0/0/40.0',
                        IFDESCR          => 'ge-0/0/40.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '573',
                        IFNAME           => 'ge-0/0/41',
                        IFDESCR          => 'ge-0/0/41',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '574',
                        IFNAME           => 'ge-0/0/41.0',
                        IFDESCR          => 'ge-0/0/41.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '575',
                        IFNAME           => 'ge-0/0/42',
                        IFDESCR          => 'ge-0/0/42',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '576',
                        IFNAME           => 'ge-0/0/42.0',
                        IFDESCR          => 'ge-0/0/42.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '577',
                        IFNAME           => 'ge-0/0/43',
                        IFDESCR          => 'ge-0/0/43',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '578',
                        IFNAME           => 'ge-0/0/43.0',
                        IFDESCR          => 'ge-0/0/43.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '579',
                        IFNAME           => 'ge-0/0/44',
                        IFDESCR          => 'ge-0/0/44',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '580',
                        IFNAME           => 'ge-0/0/44.0',
                        IFDESCR          => 'ge-0/0/44.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFNUMBER => '0x001A1ECDBB02',
                                IFDESCR  => 'eth0',
                                SYSNAME  => 'PMF-sap-c407',
                                SYSDESCR => 'ArubaOS (MODEL: 125), Version 6.2.1.2 (38711)',
                                SYSMAC   => '00:1a:1e:cd:bb:02',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '581',
                        IFNAME           => 'ge-0/0/45',
                        IFDESCR          => 'ge-0/0/45',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '582',
                        IFNAME           => 'ge-0/0/45.0',
                        IFDESCR          => 'ge-0/0/45.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '583',
                        IFNAME           => 'ge-0/0/46',
                        IFDESCR          => 'ge-0/0/46',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '584',
                        IFNAME           => 'ge-0/0/47.0',
                        IFDESCR          => 'ge-0/0/47.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '585',
                        IFNAME           => 'ge-0/0/47',
                        IFDESCR          => 'ge-0/0/47',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '586',
                        IFNAME           => 'ge-0/0/0.0',
                        IFDESCR          => 'ge-0/0/0.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '587',
                        IFNAME           => 'ge-0/0/5',
                        IFDESCR          => 'ge-0/0/5',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '588',
                        IFNAME           => 'ge-0/0/5.0',
                        IFDESCR          => 'ge-0/0/5.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '589',
                        IFNAME           => 'ge-0/0/6',
                        IFDESCR          => 'ge-0/0/6',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '590',
                        IFNAME           => 'ge-0/0/6.0',
                        IFDESCR          => 'ge-0/0/6.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '591',
                        IFNAME           => 'ge-0/0/7',
                        IFDESCR          => 'ge-0/0/7',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '592',
                        IFNAME           => 'ge-0/0/7.0',
                        IFDESCR          => 'ge-0/0/7.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '593',
                        IFNAME           => 'ge-0/0/8',
                        IFDESCR          => 'ge-0/0/8',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '594',
                        IFNAME           => 'ge-0/0/8.0',
                        IFDESCR          => 'ge-0/0/8.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '595',
                        IFNAME           => 'ge-0/0/9',
                        IFDESCR          => 'ge-0/0/9',
                        IFTYPE           => '6',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '596',
                        IFNAME           => 'ge-0/0/9.0',
                        IFDESCR          => 'ge-0/0/9.0',
                        IFTYPE           => '53',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '599',
                        IFNAME           => 'vlan',
                        IFDESCR          => 'vlan',
                        IFTYPE           => '6',
                        IFMTU            => '1518',
                    },
                    {
                        IFNUMBER         => '600',
                        IFNAME           => 'vlan.0',
                        IFDESCR          => 'vlan.0',
                        IFTYPE           => '53',
                        IFMTU            => '1500',
                    },
                    {
                        IFNUMBER         => '609',
                        IFNAME           => 'ae0',
                        IFDESCR          => 'ae0',
                        IFTYPE           => '161',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '610',
                        IFNAME           => 'ae1',
                        IFDESCR          => 'ae1',
                        IFTYPE           => '161',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '611',
                        IFNAME           => 'ae2',
                        IFDESCR          => 'ae2',
                        IFTYPE           => '161',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '612',
                        IFNAME           => 'ae3',
                        IFDESCR          => 'ae3',
                        IFTYPE           => '161',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '613',
                        IFNAME           => 'ae4',
                        IFDESCR          => 'ae4',
                        IFTYPE           => '161',
                        IFMTU            => '1514',
                    },
                    {
                        IFNUMBER         => '614',
                        IFNAME           => 'ae0.0',
                        IFDESCR          => 'ae0.0',
                        IFTYPE           => '161',
                        IFMTU            => '1514',
                    },
                ]
            },
        },
    ],
    'juniper/ex2200.07.walk' => [
        {
            TYPE         => 'NETWORKING',
            MANUFACTURER => 'Juniper',
            MODEL        => 'EX2200',
            DESCRIPTION  => 'Juniper Networks, Inc. ex2200-48p-4g internet router, kernel JUNOS 11.4R5.5 #0: 2012-08-25 05:21:13 UTC     builder@evenath.juniper.net:/volume/build/junos/11.4/release/11.4R5.5/obj-arm/bsd/kernels/JUNIPER-EX-2200/kernel Build date: 2012-08-25 04:48:47 U',

            SNMPHOSTNAME => 'jtc13-03',
            LOCATION     => 'PMF 13eme',
            SERIAL       => 'CT0211454290',
            UPTIME       => '(499476755) 57 days, 19:26:07.55',
            MEMORY       => '0',
            MAC          => '78:fe:3d:35:14:41',
            IPS          => {
                IP => [
                    '128.0.0.1',
                    '128.0.0.16',
                    '128.0.0.32',
                    '192.168.100.140',
                ],
            },
        },
        {
            INFO => {
                ID           => undef,
                TYPE         => 'NETWORKING',
                MANUFACTURER => 'Juniper',
                MODEL        => 'EX2200',
                COMMENTS     => 'Juniper Networks, Inc. ex2200-48p-4g internet router, kernel JUNOS 11.4R5.5 #0: 2012-08-25 05:21:13 UTC     builder@evenath.juniper.net:/volume/build/junos/11.4/release/11.4R5.5/obj-arm/bsd/kernels/JUNIPER-EX-2200/kernel Build date: 2012-08-25 04:48:47 U',
                NAME         => 'jtc13-03',
                LOCATION     => 'PMF 13eme',
                SERIAL       => 'CT0211454290',
                UPTIME       => '(499476755) 57 days, 19:26:07.55',
                MEMORY       => '0',
                MAC          => '78:fe:3d:35:14:41',
                IPS          => {
                    IP => [
                        '128.0.0.1',
                        '128.0.0.16',
                        '128.0.0.32',
                        '192.168.100.140',
                    ],
                },
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '4',
                        IFNAME           => 'lsi',
                        IFDESCR          => 'lsi',
                        IFTYPE           => '150',
                        IFSPEED          => '0',
                        IFMTU            => '1496',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5',
                        IFNAME           => 'dsc',
                        IFDESCR          => 'dsc',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2310) 0:00:23.10',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '6',
                        IFNAME           => 'lo0',
                        IFDESCR          => 'lo0',
                        IFTYPE           => '24',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2330) 0:00:23.30',
                        IFINOCTETS       => '2891947405',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2892532185',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '7',
                        IFNAME           => 'tap',
                        IFDESCR          => 'tap',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2337) 0:00:23.37',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '8',
                        IFNAME           => 'gre',
                        IFDESCR          => 'gre',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2317) 0:00:23.17',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '9',
                        IFNAME           => 'ipip',
                        IFDESCR          => 'ipip',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2324) 0:00:23.24',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10',
                        IFNAME           => 'pime',
                        IFDESCR          => 'pime',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2343) 0:00:23.43',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '11',
                        IFNAME           => 'pimd',
                        IFDESCR          => 'pimd',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2346) 0:00:23.46',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '12',
                        IFNAME           => 'mtun',
                        IFDESCR          => 'mtun',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2391) 0:00:23.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '33',
                        IFNAME           => 'me0',
                        IFDESCR          => 'me0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:7f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2357) 0:00:23.57',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '34',
                        IFNAME           => 'me0.0',
                        IFDESCR          => 'me0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '78:fe:3d:35:14:7f',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2373) 0:00:23.73',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '37',
                        IFNAME           => 'bme0',
                        IFDESCR          => 'bme0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1576',
                        MAC              => '00:0b:ca:fe:00:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2302) 0:00:23.02',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2324005029',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '38',
                        IFNAME           => 'bme0.32768',
                        IFDESCR          => 'bme0.32768',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1562',
                        IP               => '128.0.0.32',
                        MAC              => '00:0b:ca:fe:00:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2394) 0:00:23.94',
                        IFINOCTETS       => '112538765',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '126',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '501',
                        IFNAME           => 'ge-0/0/0',
                        IFDESCR          => 'ge-0/0/0',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:43',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(83323040) 9 days, 15:27:10.40',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1744384224',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '338781511',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '502',
                        IFNAME           => 'ge-0/0/0.0',
                        IFDESCR          => 'ge-0/0/0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:43',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(83323040) 9 days, 15:27:10.40',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2557466',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '56896598',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '20:3a:07:ee:e1:60',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '503',
                        IFNAME           => 'ge-0/0/1',
                        IFDESCR          => 'ge-0/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:44',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(490874463) 56 days, 19:32:24.63',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '81139766',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '650360168',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '504',
                        IFNAME           => 'ge-0/0/1.0',
                        IFDESCR          => 'ge-0/0/1.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:44',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(490874463) 56 days, 19:32:24.63',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '212731',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '287926476',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '505',
                        IFNAME           => 'ge-0/0/10',
                        IFDESCR          => 'ge-0/0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:4d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(472291924) 54 days, 15:55:19.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '35529',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '39114',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '506',
                        IFNAME           => 'ge-0/0/10.0',
                        IFDESCR          => 'ge-0/0/10.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:4d',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(472291924) 54 days, 15:55:19.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '6838',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '22750',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '507',
                        IFNAME           => 'ge-0/0/11',
                        IFDESCR          => 'ge-0/0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:4e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(492159839) 56 days, 23:06:38.39',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '674968419',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1597370852',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '508',
                        IFNAME           => 'ge-0/0/11.0',
                        IFDESCR          => 'ge-0/0/11.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:4e',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(492159839) 56 days, 23:06:38.39',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2239067',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '12578934',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '509',
                        IFNAME           => 'ge-0/0/12',
                        IFDESCR          => 'ge-0/0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:4f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2728) 0:00:27.28',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '510',
                        IFNAME           => 'ge-0/0/12.0',
                        IFDESCR          => 'ge-0/0/12.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:4f',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2733) 0:00:27.33',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '511',
                        IFNAME           => 'ge-0/0/13',
                        IFDESCR          => 'ge-0/0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:50',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(474504079) 54 days, 22:04:00.79',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '305790865',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '335531496',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '512',
                        IFNAME           => 'ge-0/0/13.0',
                        IFDESCR          => 'ge-0/0/13.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:50',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(474504079) 54 days, 22:04:00.79',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '814511',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6868262',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '513',
                        IFNAME           => 'ge-0/0/14',
                        IFDESCR          => 'ge-0/0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:51',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(472607150) 54 days, 16:47:51.50',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '706240582',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1981564306',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '514',
                        IFNAME           => 'ge-0/0/14.0',
                        IFDESCR          => 'ge-0/0/14.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:51',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(472607150) 54 days, 16:47:51.50',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2684663',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '305745401',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '88:ae:1d:ce:12:4e',
                                    'b8:8d:12:53:6a:7f',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '515',
                        IFNAME           => 'ge-0/0/15',
                        IFDESCR          => 'ge-0/0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:52',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(58579375) 6 days, 18:43:13.75',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '7474192',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '28526957',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '516',
                        IFNAME           => 'ge-0/0/15.0',
                        IFDESCR          => 'ge-0/0/15.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:52',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(58579375) 6 days, 18:43:13.75',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '58650',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '296261',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '517',
                        IFNAME           => 'ge-0/0/16',
                        IFDESCR          => 'ge-0/0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:53',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(58586022) 6 days, 18:44:20.22',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2444780',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '50242056',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '518',
                        IFNAME           => 'ge-0/0/16.0',
                        IFDESCR          => 'ge-0/0/16.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:53',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(58586022) 6 days, 18:44:20.22',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '9576',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '38422452',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '519',
                        IFNAME           => 'ge-0/0/17',
                        IFDESCR          => 'ge-0/0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:54',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2776) 0:00:27.76',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '520',
                        IFNAME           => 'ge-0/0/17.0',
                        IFDESCR          => 'ge-0/0/17.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:54',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2780) 0:00:27.80',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '521',
                        IFNAME           => 'ge-0/0/18',
                        IFDESCR          => 'ge-0/0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:55',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(491424998) 56 days, 21:04:09.98',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '738137413',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '34484781',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '522',
                        IFNAME           => 'ge-0/0/18.0',
                        IFDESCR          => 'ge-0/0/18.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:55',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(491424998) 56 days, 21:04:09.98',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '227863',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '17397782',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '523',
                        IFNAME           => 'ge-0/0/19',
                        IFDESCR          => 'ge-0/0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:56',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(474866627) 54 days, 23:04:26.27',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1235150564',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '854199719',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '524',
                        IFNAME           => 'ge-0/0/19.0',
                        IFDESCR          => 'ge-0/0/19.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:56',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(474866627) 54 days, 23:04:26.27',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1689222',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '40410472',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '525',
                        IFNAME           => 'ge-0/0/2',
                        IFDESCR          => 'ge-0/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:45',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5910) 0:00:59.10',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1286810852',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '625722619',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '526',
                        IFNAME           => 'ge-0/0/2.0',
                        IFDESCR          => 'ge-0/0/2.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:45',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5910) 0:00:59.10',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2927955',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '327508850',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '527',
                        IFNAME           => 'ge-0/0/20',
                        IFDESCR          => 'ge-0/0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:57',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2803) 0:00:28.03',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '528',
                        IFNAME           => 'ge-0/0/20.0',
                        IFDESCR          => 'ge-0/0/20.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:57',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2814) 0:00:28.14',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '529',
                        IFNAME           => 'ge-0/0/21',
                        IFDESCR          => 'ge-0/0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:58',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2810) 0:00:28.10',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '530',
                        IFNAME           => 'ge-0/0/21.0',
                        IFDESCR          => 'ge-0/0/21.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:58',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2819) 0:00:28.19',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '531',
                        IFNAME           => 'ge-0/0/22',
                        IFDESCR          => 'ge-0/0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:59',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(482826811) 55 days, 21:11:08.11',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '931159501',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2326041633',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '532',
                        IFNAME           => 'ge-0/0/22.0',
                        IFDESCR          => 'ge-0/0/22.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:59',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(482826811) 55 days, 21:11:08.11',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1428463',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6920069',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '533',
                        IFNAME           => 'ge-0/0/23',
                        IFDESCR          => 'ge-0/0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:5a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2825) 0:00:28.25',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '534',
                        IFNAME           => 'ge-0/0/23.0',
                        IFDESCR          => 'ge-0/0/23.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:5a',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2849) 0:00:28.49',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '535',
                        IFNAME           => 'ge-0/0/24',
                        IFDESCR          => 'ge-0/0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:5b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(410512310) 47 days, 12:18:43.10',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3299641',
                        IFINERRORS       => '21',
                        IFOUTOCTETS      => '558181286',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '536',
                        IFNAME           => 'ge-0/0/24.0',
                        IFDESCR          => 'ge-0/0/24.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:5b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(410512310) 47 days, 12:18:43.10',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2047',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '327656344',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '537',
                        IFNAME           => 'ge-0/0/25',
                        IFDESCR          => 'ge-0/0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:5c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(482930025) 55 days, 21:28:20.25',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '282999027',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3232568305',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '538',
                        IFNAME           => 'ge-0/0/25.0',
                        IFDESCR          => 'ge-0/0/25.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:5c',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(482930025) 55 days, 21:28:20.25',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '421384',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '19049883',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '539',
                        IFNAME           => 'ge-0/0/26',
                        IFDESCR          => 'ge-0/0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:5d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(480571640) 55 days, 14:55:16.40',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '433766676',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1449823136',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '540',
                        IFNAME           => 'ge-0/0/26.0',
                        IFDESCR          => 'ge-0/0/26.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:5d',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(480571640) 55 days, 14:55:16.40',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '553601',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '12043513',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '541',
                        IFNAME           => 'ge-0/0/27',
                        IFDESCR          => 'ge-0/0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:5e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(498384383) 57 days, 16:24:03.83',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '709592546',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2039323682',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '542',
                        IFNAME           => 'ge-0/0/27.0',
                        IFDESCR          => 'ge-0/0/27.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:5e',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(498384383) 57 days, 16:24:03.83',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '536134',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '284310206',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '543',
                        IFNAME           => 'ge-0/0/28',
                        IFDESCR          => 'ge-0/0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:5f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2853) 0:00:28.53',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '544',
                        IFNAME           => 'ge-0/0/28.0',
                        IFDESCR          => 'ge-0/0/28.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:5f',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2926) 0:00:29.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '545',
                        IFNAME           => 'ge-0/0/29',
                        IFDESCR          => 'ge-0/0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:60',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(481571980) 55 days, 17:41:59.80',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '5303509',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '476264161',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '546',
                        IFNAME           => 'ge-0/0/29.0',
                        IFDESCR          => 'ge-0/0/29.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:60',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(481571980) 55 days, 17:41:59.80',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '5400',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '327586683',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '547',
                        IFNAME           => 'ge-0/0/3',
                        IFDESCR          => 'ge-0/0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:46',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2560) 0:00:25.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '548',
                        IFNAME           => 'ge-0/0/3.0',
                        IFDESCR          => 'ge-0/0/3.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:46',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2574) 0:00:25.74',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '549',
                        IFNAME           => 'ge-0/0/30',
                        IFDESCR          => 'ge-0/0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:61',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(498168960) 57 days, 15:48:09.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3168553434',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1575972079',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '550',
                        IFNAME           => 'ge-0/0/30.0',
                        IFDESCR          => 'ge-0/0/30.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:61',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(498168960) 57 days, 15:48:09.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '357238',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '330356904',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '54:53:ed:7f:cc:fb',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '551',
                        IFNAME           => 'ge-0/0/31',
                        IFDESCR          => 'ge-0/0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:62',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5820) 0:00:58.20',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2168289414',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2998024565',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '552',
                        IFNAME           => 'ge-0/0/31.0',
                        IFDESCR          => 'ge-0/0/31.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:62',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5820) 0:00:58.20',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '276480',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '328409671',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '54:53:ed:7f:cc:13',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '553',
                        IFNAME           => 'ge-0/0/32',
                        IFDESCR          => 'ge-0/0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:63',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(498885870) 57 days, 17:47:38.70',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '227158483',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1931125831',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '554',
                        IFNAME           => 'ge-0/0/32.0',
                        IFDESCR          => 'ge-0/0/32.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:63',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(498885870) 57 days, 17:47:38.70',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '827296',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '13180849',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '84:8f:69:d0:ab:90',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '555',
                        IFNAME           => 'ge-0/0/33',
                        IFDESCR          => 'ge-0/0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:64',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(496811760) 57 days, 12:01:57.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1446896777',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '135042718',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '556',
                        IFNAME           => 'ge-0/0/33.0',
                        IFDESCR          => 'ge-0/0/33.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:64',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(496811760) 57 days, 12:01:57.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '5714913',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '32163624',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '3c:07:54:38:e0:33',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '557',
                        IFNAME           => 'ge-0/0/34',
                        IFDESCR          => 'ge-0/0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:65',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(482370940) 55 days, 19:55:09.40',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '26151636',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1568180907',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '558',
                        IFNAME           => 'ge-0/0/34.0',
                        IFDESCR          => 'ge-0/0/34.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:65',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(482370940) 55 days, 19:55:09.40',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '177506',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1151895',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '559',
                        IFNAME           => 'ge-0/0/35',
                        IFDESCR          => 'ge-0/0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:66',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(497161860) 57 days, 13:00:18.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '197802341',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1067397285',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '560',
                        IFNAME           => 'ge-0/0/35.0',
                        IFDESCR          => 'ge-0/0/35.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:66',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(497161860) 57 days, 13:00:18.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '55838',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '260824305',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '561',
                        IFNAME           => 'ge-0/0/36',
                        IFDESCR          => 'ge-0/0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:67',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(472444770) 54 days, 16:20:47.70',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '58569',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '322841413',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '562',
                        IFNAME           => 'ge-0/0/36.0',
                        IFDESCR          => 'ge-0/0/36.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:67',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(472444770) 54 days, 16:20:47.70',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '4369',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '226777070',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '563',
                        IFNAME           => 'ge-0/0/37',
                        IFDESCR          => 'ge-0/0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:68',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(483202680) 55 days, 22:13:46.80',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '664',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '57194403',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '564',
                        IFNAME           => 'ge-0/0/37.0',
                        IFDESCR          => 'ge-0/0/37.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:68',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(483202680) 55 days, 22:13:46.80',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '42744530',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '565',
                        IFNAME           => 'ge-0/0/38',
                        IFDESCR          => 'ge-0/0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:69',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(481989430) 55 days, 18:51:34.30',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '37857253',
                        IFINERRORS       => '16',
                        IFOUTOCTETS      => '1175000865',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '566',
                        IFNAME           => 'ge-0/0/38.0',
                        IFDESCR          => 'ge-0/0/38.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:69',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(481989430) 55 days, 18:51:34.30',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '107050',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '327690167',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '567',
                        IFNAME           => 'ge-0/0/39',
                        IFDESCR          => 'ge-0/0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:6a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(83675374) 9 days, 16:25:53.74',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '52422417',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '568',
                        IFNAME           => 'ge-0/0/39.0',
                        IFDESCR          => 'ge-0/0/39.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:6a',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(83675374) 9 days, 16:25:53.74',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '54789340',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '569',
                        IFNAME           => 'ge-0/0/4',
                        IFDESCR          => 'ge-0/0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:47',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(185623970) 21 days, 11:37:19.70',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '429906244',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '570',
                        IFNAME           => 'ge-0/0/4.0',
                        IFDESCR          => 'ge-0/0/4.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:47',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(185623970) 21 days, 11:37:19.70',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '327367176',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '571',
                        IFNAME           => 'ge-0/0/40',
                        IFDESCR          => 'ge-0/0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:6b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(488988670) 56 days, 14:18:06.70',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '56742623',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '675050738',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '572',
                        IFNAME           => 'ge-0/0/40.0',
                        IFDESCR          => 'ge-0/0/40.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:6b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(488988670) 56 days, 14:18:06.70',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '59814',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '15085956',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '84:2b:2b:ad:58:65',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '573',
                        IFNAME           => 'ge-0/0/41',
                        IFDESCR          => 'ge-0/0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:6c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5873) 0:00:58.73',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2126678145',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2508127997',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '574',
                        IFNAME           => 'ge-0/0/41.0',
                        IFDESCR          => 'ge-0/0/41.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:6c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5873) 0:00:58.73',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '343650',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '329796027',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '54:53:ed:7f:cc:ff',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '575',
                        IFNAME           => 'ge-0/0/42',
                        IFDESCR          => 'ge-0/0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:6d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(496841100) 57 days, 12:06:51.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '136854405',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2940766281',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '576',
                        IFNAME           => 'ge-0/0/42.0',
                        IFDESCR          => 'ge-0/0/42.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:6d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(496841100) 57 days, 12:06:51.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '438278',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '327882746',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '1c:6f:65:0e:51:dd',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '577',
                        IFNAME           => 'ge-0/0/43',
                        IFDESCR          => 'ge-0/0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:6e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2937) 0:00:29.37',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '578',
                        IFNAME           => 'ge-0/0/43.0',
                        IFDESCR          => 'ge-0/0/43.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:6e',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3054) 0:00:30.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '579',
                        IFNAME           => 'ge-0/0/44',
                        IFDESCR          => 'ge-0/0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:6f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(249013790) 28 days, 19:42:17.90',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '424387114',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '651547347',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '580',
                        IFNAME           => 'ge-0/0/44.0',
                        IFDESCR          => 'ge-0/0/44.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:6f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(249013790) 28 days, 19:42:17.90',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '318728',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '328402257',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '54:53:ed:7f:cc:fd',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '581',
                        IFNAME           => 'ge-0/0/45',
                        IFDESCR          => 'ge-0/0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:70',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(430521590) 49 days, 19:53:35.90',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '140623101',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '383297325',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '582',
                        IFNAME           => 'ge-0/0/45.0',
                        IFDESCR          => 'ge-0/0/45.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:70',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(430521590) 49 days, 19:53:35.90',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '379324',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '328414005',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '54:53:ed:7f:cc:fe',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '583',
                        IFNAME           => 'ge-0/0/46',
                        IFDESCR          => 'ge-0/0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:71',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(481266820) 55 days, 16:51:08.20',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '88355',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '56337',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '584',
                        IFNAME           => 'ge-0/0/46.0',
                        IFDESCR          => 'ge-0/0/46.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:71',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(481266820) 55 days, 16:51:08.20',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '21424',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '29827',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '585',
                        IFNAME           => 'ge-0/0/47',
                        IFDESCR          => 'ge-0/0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:72',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(482462235) 55 days, 20:10:22.35',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '522060',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '338107',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '586',
                        IFNAME           => 'ge-0/0/47.0',
                        IFDESCR          => 'ge-0/0/47.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:72',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(482462235) 55 days, 20:10:22.35',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '90347',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '142213',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '587',
                        IFNAME           => 'ge-0/0/5',
                        IFDESCR          => 'ge-0/0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:48',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2623) 0:00:26.23',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '588',
                        IFNAME           => 'ge-0/0/5.0',
                        IFDESCR          => 'ge-0/0/5.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:48',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2629) 0:00:26.29',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '589',
                        IFNAME           => 'ge-0/0/6',
                        IFDESCR          => 'ge-0/0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:49',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(481761753) 55 days, 18:13:37.53',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '486790886',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '362600196',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '590',
                        IFNAME           => 'ge-0/0/6.0',
                        IFDESCR          => 'ge-0/0/6.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:49',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(481761753) 55 days, 18:13:37.53',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '144582',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '208995379',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '591',
                        IFNAME           => 'ge-0/0/7',
                        IFDESCR          => 'ge-0/0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:4a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(489621221) 56 days, 16:03:32.21',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '719813169',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1043360413',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '592',
                        IFNAME           => 'ge-0/0/7.0',
                        IFDESCR          => 'ge-0/0/7.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:4a',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(489621221) 56 days, 16:03:32.21',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '488108',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '14646662',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '593',
                        IFNAME           => 'ge-0/0/8',
                        IFDESCR          => 'ge-0/0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:4b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2663) 0:00:26.63',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '594',
                        IFNAME           => 'ge-0/0/8.0',
                        IFDESCR          => 'ge-0/0/8.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:4b',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2671) 0:00:26.71',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '595',
                        IFNAME           => 'ge-0/0/9',
                        IFDESCR          => 'ge-0/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:4c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(488302009) 56 days, 12:23:40.09',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3268629629',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1002264684',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '596',
                        IFNAME           => 'ge-0/0/9.0',
                        IFDESCR          => 'ge-0/0/9.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:4c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(488302009) 56 days, 12:23:40.09',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3844613',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '338671560',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '2c:36:f8:4b:66:00',
                                    '00:19:d1:17:ae:6a',
                                    '44:37:e6:bb:a3:bf',
                                    '44:37:e6:bb:a3:ca',
                                    '44:37:e6:bb:a3:d0',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '599',
                        IFNAME           => 'vlan',
                        IFDESCR          => 'vlan',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '78:fe:3d:35:14:41',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2443) 0:00:24.43',
                        IFINOCTETS       => '1417841504',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '60361330',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '600',
                        IFNAME           => 'ge-0/1/0',
                        IFDESCR          => 'ge-0/1/0',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:73',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5680) 0:00:56.80',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3462021619',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '763621010',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '601',
                        IFNAME           => 'ge-0/1/1',
                        IFDESCR          => 'ge-0/1/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:74',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5981) 0:00:59.81',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1756608694',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '188016786',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '604',
                        IFNAME           => 'vlan.0',
                        IFDESCR          => 'vlan.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '78:fe:3d:35:14:41',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2451) 0:00:24.51',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '605',
                        IFNAME           => 'ge-0/1/0.0',
                        IFDESCR          => 'ge-0/1/0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:73',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5680) 0:00:56.80',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2462905321',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '117830992',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFNUMBER => '651',
                                IFDESCR  => 'ge-1/0/6.0',
                                SYSNAME  => 'jte4-00',
                                SYSDESCR => 'Juniper Networks, Inc. ex4500-40f , version 11.4R2.14 Build date: 2012-03-17 17:46:53 UTC ',
                                SYSMAC   => '78:fe:3d:df:c1:80',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '606',
                        IFNAME           => 'ge-0/1/1.0',
                        IFDESCR          => 'ge-0/1/1.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:74',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5981) 0:00:59.81',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '152003984',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '335449643',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFNUMBER => '602',
                                IFDESCR  => 'ge-0/1/0.0',
                                SYSNAME  => 'jtc13-04',
                                SYSDESCR => 'Juniper Networks, Inc. ex2200-48p-4g , version 11.4R5.7 Build date: 2013-01-05 12:28:58 UTC ',
                                SYSMAC   => 'b0:a8:6e:9a:55:c0',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '609',
                        IFNAME           => 'vlan.1',
                        IFDESCR          => 'vlan.1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '192.168.100.140',
                        MAC              => '78:fe:3d:35:14:41',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5696) 0:00:56.96',
                        IFINOCTETS       => '1417842056',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '55958584',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '610',
                        IFNAME           => 'ae0',
                        IFDESCR          => 'ae0',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:43',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2417) 0:00:24.17',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '611',
                        IFNAME           => 'ae1',
                        IFDESCR          => 'ae1',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:44',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2421) 0:00:24.21',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '612',
                        IFNAME           => 'ae2',
                        IFDESCR          => 'ae2',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:45',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2425) 0:00:24.25',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '613',
                        IFNAME           => 'ae3',
                        IFDESCR          => 'ae3',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:46',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2430) 0:00:24.30',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '614',
                        IFNAME           => 'ae4',
                        IFDESCR          => 'ae4',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:fe:3d:35:14:47',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2438) 0:00:24.38',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        },
    ],
    'juniper/ex3200.01.walk' => [
        {
            TYPE         => 'NETWORKING',
            MANUFACTURER => 'Juniper',
            MODEL        => 'EX3200-24t',
            DESCRIPTION  => 'Juniper Networks, Inc. ex3200-48p internet router, kernel JUNOS 11.4R5.7 #0: 2013-01-05 14:23:01 UTC     builder@queth.juniper.net:/volume/build/junos/11.4/release/11.4R5.7/obj-powerpc/bsd/kernels/JUNIPER-EX/kernel Build date: 2013-01-05 14:01:19 UTC Cop',

            SNMPHOSTNAME => 'jmsea3-10',
            LOCATION     => 'MSE Bat.A 3eme',
            SERIAL       => 'BL0211085719',
            UPTIME       => '(502367524) 58 days, 3:27:55.24',
            MEMORY       => '0',
            MAC          => '5c:5e:ab:6a:3b:81',
            IPS          => {
                IP => [
                    '128.0.0.1',
                    '128.0.0.16',
                    '128.0.0.32',
                    '172.21.10.250',
                    '172.21.10.251',
                    '172.21.12.251',
                    '192.168.100.55',
                ],
            },
        },
        {
            INFO => {
                ID           => undef,
                TYPE         => 'NETWORKING',
                MANUFACTURER => 'Juniper',
                MODEL        => 'EX3200-24t',
                COMMENTS     => 'Juniper Networks, Inc. ex3200-48p internet router, kernel JUNOS 11.4R5.7 #0: 2013-01-05 14:23:01 UTC     builder@queth.juniper.net:/volume/build/junos/11.4/release/11.4R5.7/obj-powerpc/bsd/kernels/JUNIPER-EX/kernel Build date: 2013-01-05 14:01:19 UTC Cop',
                NAME         => 'jmsea3-10',
                LOCATION     => 'MSE Bat.A 3eme',
                SERIAL       => 'BL0211085719',
                UPTIME       => '(502367524) 58 days, 3:27:55.24',
                MEMORY       => '0',
                MAC          => '5c:5e:ab:6a:3b:81',
                IPS          => {
                    IP => [
                        '128.0.0.1',
                        '128.0.0.16',
                        '128.0.0.32',
                        '172.21.10.250',
                        '172.21.10.251',
                        '172.21.12.251',
                        '192.168.100.55',
                    ],
                },
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '4',
                        IFNAME           => 'lsi',
                        IFDESCR          => 'lsi',
                        IFTYPE           => '150',
                        IFSPEED          => '0',
                        IFMTU            => '1496',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5',
                        IFNAME           => 'dsc',
                        IFDESCR          => 'dsc',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(727) 0:00:07.27',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '6',
                        IFNAME           => 'lo0',
                        IFDESCR          => 'lo0',
                        IFTYPE           => '24',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(734) 0:00:07.34',
                        IFINOCTETS       => '1670941135',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1671236103',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '7',
                        IFNAME           => 'tap',
                        IFDESCR          => 'tap',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(751) 0:00:07.51',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '8',
                        IFNAME           => 'gre',
                        IFDESCR          => 'gre',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(729) 0:00:07.29',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '9',
                        IFNAME           => 'ipip',
                        IFDESCR          => 'ipip',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(733) 0:00:07.33',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10',
                        IFNAME           => 'pime',
                        IFDESCR          => 'pime',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(697) 0:00:06.97',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '11',
                        IFNAME           => 'pimd',
                        IFDESCR          => 'pimd',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(703) 0:00:07.03',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '12',
                        IFNAME           => 'mtun',
                        IFDESCR          => 'mtun',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(744) 0:00:07.44',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '33',
                        IFNAME           => 'me0',
                        IFDESCR          => 'me0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:ff',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(712) 0:00:07.12',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '34',
                        IFNAME           => 'me0.0',
                        IFDESCR          => 'me0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '5c:5e:ab:6a:3b:ff',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(719) 0:00:07.19',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '37',
                        IFNAME           => 'bme0',
                        IFDESCR          => 'bme0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1576',
                        MAC              => '00:0b:ca:fe:00:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(696) 0:00:06.96',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '184063134',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '38',
                        IFNAME           => 'bme0.32768',
                        IFDESCR          => 'bme0.32768',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1562',
                        IP               => '128.0.0.32',
                        MAC              => '00:0b:ca:fe:00:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(721) 0:00:07.21',
                        IFINOCTETS       => '1790026646',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '126',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '501',
                        IFNAME           => 'ge-0/0/0',
                        IFDESCR          => 'ge-0/0/0',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:83',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(492827293) 57 days, 0:57:52.93',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '246519',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '10138622',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '502',
                        IFNAME           => 'ge-0/0/0.0',
                        IFDESCR          => 'ge-0/0/0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:83',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(492827293) 57 days, 0:57:52.93',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '10320',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '282201',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '503',
                        IFNAME           => 'ge-0/0/1',
                        IFDESCR          => 'ge-0/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:84',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(477688824) 55 days, 6:54:48.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '45971733',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '203486701',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '504',
                        IFNAME           => 'ge-0/0/1.0',
                        IFDESCR          => 'ge-0/0/1.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:84',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(477688824) 55 days, 6:54:48.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '33128',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2126195',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '505',
                        IFNAME           => 'ge-0/0/10',
                        IFDESCR          => 'ge-0/0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:8d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(501368552) 58 days, 0:41:25.52',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '270172930',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1844438574',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '506',
                        IFNAME           => 'ge-0/0/10.0',
                        IFDESCR          => 'ge-0/0/10.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:8d',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(501368552) 58 days, 0:41:25.52',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '800120',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '13952517',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '507',
                        IFNAME           => 'ge-0/0/11',
                        IFDESCR          => 'ge-0/0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:8e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(449694202) 52 days, 1:09:02.02',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2307654152',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1421090198',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '508',
                        IFNAME           => 'ge-0/0/11.0',
                        IFDESCR          => 'ge-0/0/11.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:8e',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(449694202) 52 days, 1:09:02.02',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1170082',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '37154679',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '509',
                        IFNAME           => 'ge-0/0/12',
                        IFDESCR          => 'ge-0/0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:8f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(501585675) 58 days, 1:17:36.75',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '151307165',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '500897188',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '510',
                        IFNAME           => 'ge-0/0/12.0',
                        IFDESCR          => 'ge-0/0/12.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:8f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(501585675) 58 days, 1:17:36.75',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '246231',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '306919010',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'd4:be:d9:6f:c8:b0',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '511',
                        IFNAME           => 'ge-0/0/13',
                        IFDESCR          => 'ge-0/0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:90',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(972) 0:00:09.72',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '512',
                        IFNAME           => 'ge-0/0/13.0',
                        IFDESCR          => 'ge-0/0/13.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:90',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(980) 0:00:09.80',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '513',
                        IFNAME           => 'ge-0/0/14',
                        IFDESCR          => 'ge-0/0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:91',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(985) 0:00:09.85',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '514',
                        IFNAME           => 'ge-0/0/14.0',
                        IFDESCR          => 'ge-0/0/14.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:91',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(991) 0:00:09.91',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '515',
                        IFNAME           => 'ge-0/0/15',
                        IFDESCR          => 'ge-0/0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:92',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(998) 0:00:09.98',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '516',
                        IFNAME           => 'ge-0/0/15.0',
                        IFDESCR          => 'ge-0/0/15.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:92',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1002) 0:00:10.02',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '517',
                        IFNAME           => 'ge-0/0/16',
                        IFDESCR          => 'ge-0/0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:93',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(243406802) 28 days, 4:07:48.02',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '273492030',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '907272775',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '518',
                        IFNAME           => 'ge-0/0/16.0',
                        IFDESCR          => 'ge-0/0/16.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:93',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(243406802) 28 days, 4:07:48.02',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1303739',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '11482948',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '519',
                        IFNAME           => 'ge-0/0/17',
                        IFDESCR          => 'ge-0/0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:94',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(501393666) 58 days, 0:45:36.66',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '26470611',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '161931299',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '520',
                        IFNAME           => 'ge-0/0/17.0',
                        IFDESCR          => 'ge-0/0/17.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:94',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(501393666) 58 days, 0:45:36.66',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '147245',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1976217',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '521',
                        IFNAME           => 'ge-0/0/18',
                        IFDESCR          => 'ge-0/0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:95',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(502094365) 58 days, 2:42:23.65',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2934604904',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '712190856',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '522',
                        IFNAME           => 'ge-0/0/18.0',
                        IFDESCR          => 'ge-0/0/18.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:95',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(502094365) 58 days, 2:42:23.65',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '663672',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '325217408',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:0f:fe:f7:46:37',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '523',
                        IFNAME           => 'ge-0/0/19',
                        IFDESCR          => 'ge-0/0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:96',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(501262435) 58 days, 0:23:44.35',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3942071796',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2239896034',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '524',
                        IFNAME           => 'ge-0/0/19.0',
                        IFDESCR          => 'ge-0/0/19.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:96',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(501262435) 58 days, 0:23:44.35',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '975321',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '329159030',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'd4:85:64:b3:5d:f2',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '525',
                        IFNAME           => 'ge-0/0/2',
                        IFDESCR          => 'ge-0/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:85',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(847) 0:00:08.47',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '526',
                        IFNAME           => 'ge-0/0/2.0',
                        IFDESCR          => 'ge-0/0/2.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:85',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(850) 0:00:08.50',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '527',
                        IFNAME           => 'ge-0/0/20',
                        IFDESCR          => 'ge-0/0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:97',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1985) 0:00:19.85',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '528',
                        IFNAME           => 'ge-0/0/21',
                        IFDESCR          => 'ge-0/0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:98',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(489642565) 56 days, 16:07:05.65',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '920709452',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '654099821',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '529',
                        IFNAME           => 'ge-0/0/22',
                        IFDESCR          => 'ge-0/0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:99',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(485155235) 56 days, 3:39:12.35',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '173454217',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2084960452',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '530',
                        IFNAME           => 'ge-0/0/23',
                        IFDESCR          => 'ge-0/0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:9a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(502360558) 58 days, 3:26:45.58',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1839646193',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '873849043',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '531',
                        IFNAME           => 'ge-0/0/24',
                        IFDESCR          => 'ge-0/0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:9b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(502132988) 58 days, 2:48:49.88',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '197941728',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '664274824',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '532',
                        IFNAME           => 'ge-0/0/25',
                        IFDESCR          => 'ge-0/0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:9c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(476374946) 55 days, 3:15:49.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '39438945',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '874573435',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '533',
                        IFNAME           => 'ge-0/0/26',
                        IFDESCR          => 'ge-0/0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:9d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(88742086) 10 days, 6:30:20.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '19433754',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '102855597',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '534',
                        IFNAME           => 'ge-0/0/27',
                        IFDESCR          => 'ge-0/0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:9e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(293675818) 33 days, 23:45:58.18',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '5344',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '20131',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '535',
                        IFNAME           => 'ge-0/0/28',
                        IFDESCR          => 'ge-0/0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:9f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2002) 0:00:20.02',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '536',
                        IFNAME           => 'ge-0/0/29',
                        IFDESCR          => 'ge-0/0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:a0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(434401888) 50 days, 6:40:18.88',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '45038439',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '506215047',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '537',
                        IFNAME           => 'ge-0/0/3',
                        IFDESCR          => 'ge-0/0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:86',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(852) 0:00:08.52',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '538',
                        IFNAME           => 'ge-0/0/3.0',
                        IFDESCR          => 'ge-0/0/3.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:86',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(854) 0:00:08.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '539',
                        IFNAME           => 'ge-0/0/30',
                        IFDESCR          => 'ge-0/0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:a1',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(486281260) 56 days, 6:46:52.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '39832006',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1266427988',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '540',
                        IFNAME           => 'ge-0/0/31',
                        IFDESCR          => 'ge-0/0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:a2',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(502211469) 58 days, 3:01:54.69',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '705976519',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2903037237',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '541',
                        IFNAME           => 'ge-0/0/32',
                        IFDESCR          => 'ge-0/0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:a3',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(303327646) 35 days, 2:34:36.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '33953382',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '66708891',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '542',
                        IFNAME           => 'ge-0/0/33',
                        IFDESCR          => 'ge-0/0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:a4',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2015) 0:00:20.15',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '543',
                        IFNAME           => 'ge-0/0/34',
                        IFDESCR          => 'ge-0/0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:a5',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(500473278) 57 days, 22:12:12.78',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '618719067',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '158394497',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '544',
                        IFNAME           => 'ge-0/0/35',
                        IFDESCR          => 'ge-0/0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:a6',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2021) 0:00:20.21',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '545',
                        IFNAME           => 'ge-0/0/36',
                        IFDESCR          => 'ge-0/0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:a7',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2023) 0:00:20.23',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '546',
                        IFNAME           => 'ge-0/0/37',
                        IFDESCR          => 'ge-0/0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:a8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(502359755) 58 days, 3:26:37.55',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1960930767',
                        IFINERRORS       => '90',
                        IFOUTOCTETS      => '2041708704',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '547',
                        IFNAME           => 'ge-0/0/38',
                        IFDESCR          => 'ge-0/0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:a9',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(501869385) 58 days, 2:04:53.85',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1529884146',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2194553032',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '548',
                        IFNAME           => 'ge-0/0/39',
                        IFDESCR          => 'ge-0/0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:aa',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(501850865) 58 days, 2:01:48.65',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '890508579',
                        IFINERRORS       => '2320',
                        IFOUTOCTETS      => '3540729963',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '549',
                        IFNAME           => 'ge-0/0/4',
                        IFDESCR          => 'ge-0/0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:87',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(500131365) 57 days, 21:15:13.65',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3924273711',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '336951765',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '550',
                        IFNAME           => 'ge-0/0/4.0',
                        IFDESCR          => 'ge-0/0/4.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:87',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(500131365) 57 days, 21:15:13.65',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1846346',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '126729274',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:1b:63:a1:b7:3f',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '551',
                        IFNAME           => 'ge-0/0/40',
                        IFDESCR          => 'ge-0/0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:ab',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(450298295) 52 days, 2:49:42.95',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '355808091',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3187920484',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '552',
                        IFNAME           => 'ge-0/0/41',
                        IFDESCR          => 'ge-0/0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:ac',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(494573682) 57 days, 5:48:56.82',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '64013107',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '385956305',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '553',
                        IFNAME           => 'ge-0/0/42',
                        IFDESCR          => 'ge-0/0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:ad',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2033) 0:00:20.33',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '554',
                        IFNAME           => 'ge-0/0/43',
                        IFDESCR          => 'ge-0/0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:ae',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(475141828) 54 days, 23:50:18.28',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '756337312',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '180066856',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '555',
                        IFNAME           => 'ge-0/0/44',
                        IFDESCR          => 'ge-0/0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:af',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3485) 0:00:34.85',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '299556285',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3378018137',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '556',
                        IFNAME           => 'ge-0/0/45',
                        IFDESCR          => 'ge-0/0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:b0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(494262375) 57 days, 4:57:03.75',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2793185087',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1047954877',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '557',
                        IFNAME           => 'ge-0/0/46',
                        IFDESCR          => 'ge-0/0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:83',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(27545575) 3 days, 4:30:55.75',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1784328962',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2576332072',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '558',
                        IFNAME           => 'ge-0/0/47',
                        IFDESCR          => 'ge-0/0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:83',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(27545935) 3 days, 4:30:59.35',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '4163400289',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1949303753',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '559',
                        IFNAME           => 'ge-0/0/5',
                        IFDESCR          => 'ge-0/0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:88',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(441301615) 51 days, 1:50:16.15',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '19775821',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1054882336',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '560',
                        IFNAME           => 'ge-0/0/5.0',
                        IFDESCR          => 'ge-0/0/5.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:88',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(441301615) 51 days, 1:50:16.15',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '15742',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '57698310',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '561',
                        IFNAME           => 'ge-0/0/6',
                        IFDESCR          => 'ge-0/0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:89',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(500084615) 57 days, 21:07:26.15',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '932913942',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3045558475',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '562',
                        IFNAME           => 'ge-0/0/6.0',
                        IFDESCR          => 'ge-0/0/6.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:89',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(500084615) 57 days, 21:07:26.15',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1923937',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '35968159',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:11:11:63:36:6d',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '563',
                        IFNAME           => 'ge-0/0/7',
                        IFDESCR          => 'ge-0/0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:8a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(450567846) 52 days, 3:34:38.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '33928625',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '123229715',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '564',
                        IFNAME           => 'ge-0/0/7.0',
                        IFDESCR          => 'ge-0/0/7.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:8a',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(450567846) 52 days, 3:34:38.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '80048',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1615054',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '565',
                        IFNAME           => 'ge-0/0/8',
                        IFDESCR          => 'ge-0/0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:8b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(502183765) 58 days, 2:57:17.65',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '240667725',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2007003312',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '566',
                        IFNAME           => 'ge-0/0/8.0',
                        IFDESCR          => 'ge-0/0/8.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:8b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(502183765) 58 days, 2:57:17.65',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '423086',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '28885020',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'c8:0a:a9:3a:a5:43',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '567',
                        IFNAME           => 'ge-0/0/9',
                        IFDESCR          => 'ge-0/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:8c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(947) 0:00:09.47',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '568',
                        IFNAME           => 'ge-0/0/9.0',
                        IFDESCR          => 'ge-0/0/9.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:8c',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(950) 0:00:09.50',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '571',
                        IFNAME           => 'vlan',
                        IFDESCR          => 'vlan',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '5c:5e:ab:6a:3b:81',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(787) 0:00:07.87',
                        IFINOCTETS       => '2065441240',
                        IFINERRORS       => '242',
                        IFOUTOCTETS      => '376754111',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '574',
                        IFNAME           => 'ge-0/0/20.0',
                        IFDESCR          => 'ge-0/0/20.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:97',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1986) 0:00:19.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '575',
                        IFNAME           => 'ge-0/0/21.0',
                        IFDESCR          => 'ge-0/0/21.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:98',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(489642565) 56 days, 16:07:05.65',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1157859',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '155347400',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:1e:c9:2c:7d:c3',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '576',
                        IFNAME           => 'ge-0/0/22.0',
                        IFDESCR          => 'ge-0/0/22.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:99',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(485155235) 56 days, 3:39:12.35',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '326462',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '91836193',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '577',
                        IFNAME           => 'ge-0/0/23.0',
                        IFDESCR          => 'ge-0/0/23.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:9a',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(502360558) 58 days, 3:26:45.58',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '606818',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '28092285',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '578',
                        IFNAME           => 'ge-0/0/24.0',
                        IFDESCR          => 'ge-0/0/24.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:9b',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(502132988) 58 days, 2:48:49.88',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '880723',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '13708517',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '579',
                        IFNAME           => 'ge-0/0/25.0',
                        IFDESCR          => 'ge-0/0/25.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:9c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(476374946) 55 days, 3:15:49.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '25626',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '51497346',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '580',
                        IFNAME           => 'ge-0/0/26.0',
                        IFDESCR          => 'ge-0/0/26.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:9d',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(88742086) 10 days, 6:30:20.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '427395',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '611054',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '581',
                        IFNAME           => 'ge-0/0/27.0',
                        IFDESCR          => 'ge-0/0/27.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:9e',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(293675818) 33 days, 23:45:58.18',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2105',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2198',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '582',
                        IFNAME           => 'ge-0/0/38.0',
                        IFDESCR          => 'ge-0/0/38.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:a9',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(501869385) 58 days, 2:04:53.85',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '201546',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '30932570',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:24:e8:d0:be:86',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '583',
                        IFNAME           => 'ge-0/0/39.0',
                        IFDESCR          => 'ge-0/0/39.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:aa',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(501850865) 58 days, 2:01:48.65',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '6659780',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '117016530',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '1c:6f:65:0f:e2:08',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '584',
                        IFNAME           => 'ge-0/0/28.0',
                        IFDESCR          => 'ge-0/0/28.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:9f',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2005) 0:00:20.05',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '585',
                        IFNAME           => 'ge-0/0/29.0',
                        IFDESCR          => 'ge-0/0/29.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:a0',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(434401888) 50 days, 6:40:18.88',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '731957',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1829027',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '586',
                        IFNAME           => 'ge-0/0/30.0',
                        IFDESCR          => 'ge-0/0/30.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:a1',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(486281260) 56 days, 6:46:52.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '161370',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '75889201',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '587',
                        IFNAME           => 'ge-0/0/31.0',
                        IFDESCR          => 'ge-0/0/31.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:a2',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(502211469) 58 days, 3:01:54.69',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '314104',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '32640988',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '588',
                        IFNAME           => 'ge-0/0/32.0',
                        IFDESCR          => 'ge-0/0/32.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:a3',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(303327646) 35 days, 2:34:36.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1360813',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1388364',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '589',
                        IFNAME           => 'ge-0/0/33.0',
                        IFDESCR          => 'ge-0/0/33.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:a4',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2020) 0:00:20.20',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '590',
                        IFNAME           => 'ge-0/0/34.0',
                        IFDESCR          => 'ge-0/0/34.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:a5',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(500473278) 57 days, 22:12:12.78',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '393628',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3559823',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '591',
                        IFNAME           => 'ge-0/0/35.0',
                        IFDESCR          => 'ge-0/0/35.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:a6',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2030) 0:00:20.30',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '592',
                        IFNAME           => 'ge-0/0/36.0',
                        IFDESCR          => 'ge-0/0/36.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:a7',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2036) 0:00:20.36',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '593',
                        IFNAME           => 'ge-0/0/37.0',
                        IFDESCR          => 'ge-0/0/37.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:a8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(502359755) 58 days, 3:26:37.55',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '601714',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '329345598',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '78:ac:c0:b8:69:80',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '594',
                        IFNAME           => 'ge-0/0/40.0',
                        IFDESCR          => 'ge-0/0/40.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:ab',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(450298295) 52 days, 2:49:42.95',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '63393',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '301234445',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '595',
                        IFNAME           => 'ge-0/0/41.0',
                        IFDESCR          => 'ge-0/0/41.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:ac',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(494573682) 57 days, 5:48:56.82',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '170600',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2929897',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '596',
                        IFNAME           => 'ge-0/0/42.0',
                        IFDESCR          => 'ge-0/0/42.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:ad',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2050) 0:00:20.50',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '597',
                        IFNAME           => 'ge-0/0/43.0',
                        IFDESCR          => 'ge-0/0/43.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:ae',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(475141828) 54 days, 23:50:18.28',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '253289',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '287202426',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '598',
                        IFNAME           => 'ge-0/0/44.0',
                        IFDESCR          => 'ge-0/0/44.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:af',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(3485) 0:00:34.85',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '185515',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '329365567',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'f0:92:1c:5a:5b:23',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '599',
                        IFNAME           => 'ge-0/0/45.0',
                        IFDESCR          => 'ge-0/0/45.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:b0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(494262375) 57 days, 4:57:03.75',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '35361721',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '329362919',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'a0:b3:cc:f7:26:3d',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '600',
                        IFNAME           => 'ge-0/0/46.0',
                        IFDESCR          => 'ge-0/0/46.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:83',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(27545575) 3 days, 4:30:55.75',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '55258732',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '458540929',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFNUMBER => '1048',
                                IFDESCR  => 'ge-2/0/0.0',
                                SYSNAME  => 'jmse-01',
                                SYSDESCR => 'Juniper Networks, Inc. ex4200-48p , version 10.4R3.4 Build date: 2011-03-19 22:17:08 UTC ',
                                SYSMAC   => '5c:5e:ab:66:60:80',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '601',
                        IFNAME           => 'ge-0/0/47.0',
                        IFDESCR          => 'ge-0/0/47.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:83',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(27545935) 3 days, 4:30:59.35',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '55091283',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '58718811',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFNUMBER => '952',
                                IFDESCR  => 'ge-3/0/0.0',
                                SYSNAME  => 'jmse-01',
                                SYSDESCR => 'Juniper Networks, Inc. ex4200-48p , version 10.4R3.4 Build date: 2011-03-19 22:17:08 UTC ',
                                SYSMAC   => '5c:5e:ab:66:60:80',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '604',
                        IFNAME           => 'vlan.0',
                        IFDESCR          => 'vlan.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '192.168.100.55',
                        MAC              => '5c:5e:ab:6a:3b:81',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(27545806) 3 days, 4:30:58.06',
                        IFINOCTETS       => '3540839640',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '29780586',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '605',
                        IFNAME           => 'ae0',
                        IFDESCR          => 'ae0',
                        IFTYPE           => '161',
                        IFSPEED          => '2000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:83',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(27545802) 3 days, 4:30:58.02',
                        IFINOCTETS       => '1652781314',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '230681227',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '606',
                        IFNAME           => 'ae1',
                        IFDESCR          => 'ae1',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:84',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(761) 0:00:07.61',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '607',
                        IFNAME           => 'ae2',
                        IFDESCR          => 'ae2',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:85',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(768) 0:00:07.68',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '608',
                        IFNAME           => 'ae3',
                        IFDESCR          => 'ae3',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:86',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(774) 0:00:07.74',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '609',
                        IFNAME           => 'ae4',
                        IFDESCR          => 'ae4',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:87',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(780) 0:00:07.80',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '610',
                        IFNAME           => 'ae0.0',
                        IFDESCR          => 'ae0.0',
                        IFTYPE           => '161',
                        IFSPEED          => '2000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:3b:83',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(27545802) 3 days, 4:30:58.02',
                        IFINOCTETS       => '1493589753',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '399817511',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:01:30:12:80:80',
                                    '00:01:30:12:91:80',
                                    '00:01:30:12:a6:c0',
                                    '00:01:30:12:a6:d0',
                                    '00:01:30:12:a8:30',
                                    '00:0b:60:b0:b0:1b',
                                    '00:0f:34:aa:ee:1b',
                                    '00:10:db:ff:10:02',
                                    '00:02:b3:31:fa:f9',
                                    '00:e0:86:12:d9:6f',
                                    '00:e0:2b:00:00:01',
                                    '00:19:d1:17:e7:3e',
                                    '00:1b:ec:00:04:09',
                                    '00:1e:c9:da:3b:fc',
                                    '00:1e:c9:f2:ca:8d',
                                    '00:1e:4f:1f:3c:44',
                                    '00:1e:4f:1f:57:4b',
                                    '00:1e:4f:31:a9:a0',
                                    '00:1e:4f:31:ab:88',
                                    '00:1e:4f:31:ab:ab',
                                    '00:1e:4f:32:e1:d3',
                                    '00:1e:4f:32:e4:69',
                                    '00:1e:4f:33:07:e1',
                                    '00:1e:4f:41:d0:a4',
                                    '00:1e:4f:41:dc:7e',
                                    '00:1e:4f:41:dd:53',
                                    '00:20:4a:0b:24:06',
                                    '00:20:4a:08:72:d2',
                                    '00:20:4a:08:ac:f6',
                                    '00:20:4a:08:ac:56',
                                    '00:20:4a:08:e1:6d',
                                    '00:20:4a:08:60:c6',
                                    '00:22:19:7b:be:11',
                                    '00:22:19:7b:be:da',
                                    '00:22:19:7b:bf:e6',
                                    '00:22:19:85:d9:70',
                                    '00:23:ae:fb:fd:89',
                                    '00:23:ae:fb:fd:b0',
                                    '00:23:ae:fc:00:cd',
                                    '00:23:ae:fc:00:d3',
                                    '00:23:ae:fc:00:d8',
                                    '00:04:96:18:6e:93',
                                    '00:04:96:18:5b:61',
                                    '00:04:96:1c:6f:f0',
                                    '00:04:96:1c:71:00',
                                    '00:04:96:1f:8f:0f',
                                    '00:04:96:1f:91:50',
                                    '00:04:96:27:93:f9',
                                    '00:04:96:04:58:20',
                                    '00:04:96:34:69:ab',
                                    '00:04:96:34:69:b1',
                                    '00:04:96:34:69:40',
                                    '00:04:96:34:89:5c',
                                    '00:04:96:34:8b:82',
                                    '00:04:96:34:8b:f8',
                                    '00:04:96:34:8c:10',
                                    '00:04:96:34:8c:11',
                                    '00:04:96:34:92:82',
                                    '00:04:96:34:92:31',
                                    '00:04:96:34:92:47',
                                    '00:04:96:35:77:14',
                                    '00:04:96:35:90:4d',
                                    '00:04:96:35:93:b9',
                                    '00:04:96:35:ad:e4',
                                    '00:04:96:35:c8:14',
                                    '00:04:96:35:c8:1f',
                                    '00:04:96:35:fa:ae',
                                    '00:04:96:35:fa:b1',
                                    '00:04:96:08:1e:70',
                                    '00:04:96:09:07:00',
                                    '00:05:1e:08:f8:20',
                                    '00:05:1e:08:f9:12',
                                    '00:05:33:54:16:aa',
                                    '00:50:56:bc:31:8a',
                                    '00:50:56:50:38:30',
                                    '00:50:56:50:38:32',
                                    '00:50:56:51:4d:58',
                                    '00:50:56:51:4d:5a',
                                    '00:60:16:1e:68:23',
                                    '78:fe:3d:df:c1:82',
                                    '78:fe:3d:df:cc:41',
                                    '78:fe:3d:3f:7f:c0',
                                    '84:18:88:ae:73:00',
                                    '84:18:88:ae:83:00',
                                    '84:18:88:ae:be:00',
                                    '84:2b:2b:71:30:f3',
                                    '10:8c:cf:cb:9b:5f',
                                    'ac:4b:c8:23:3d:41',
                                    'b0:a8:6e:85:f8:81',
                                    'b0:a8:6e:9a:2d:41',
                                    'b0:a8:6e:9a:2f:81',
                                    'b0:a8:6e:9a:52:01',
                                    '02:04:96:35:f9:24',
                                    'd0:d0:fd:b2:ad:35',
                                    'd0:d0:fd:45:e8:b5',
                                    'e4:1f:13:76:ca:35',
                                    'e4:1f:13:76:cd:e9',
                                    '18:03:73:0a:29:c2',
                                    '18:03:73:09:ae:8c',
                                    'f0:4d:a2:6e:cf:89',
                                    'f0:4d:a2:6e:d3:e6',
                                    'f0:4d:a2:6e:d4:96',
                                    'f0:4d:a2:6e:d4:1c',
                                    'f0:4d:a2:6f:03:39',
                                    'f0:4d:a2:6f:03:5b',
                                    'f0:4d:a2:d9:bc:3f',
                                    '20:3a:07:ee:e1:4a',
                                    '20:3a:07:ee:e1:54',
                                    '20:3a:07:ee:e2:40',
                                    '2c:6b:f5:9a:7e:80',
                                    '2c:36:f8:4b:66:00',
                                    '2c:36:f8:4b:6a:4a',
                                    '2c:36:f8:4b:6e:e6',
                                    '3c:4a:92:b4:f5:0d',
                                    '58:35:d9:94:e2:8d',
                                    '5c:5e:ab:65:4a:81',
                                    '5c:5e:ab:66:60:80',
                                    '5c:5e:ab:66:60:84',
                                    '5c:5e:ab:6b:ec:01',
                                    '5c:5e:ab:78:1c:80',
                                    '5c:5e:ab:78:25:00',
                                    '00:00:5e:00:01:01',
                                    '00:0c:29:0d:55:85',
                                    '00:0f:fe:ce:b0:6c',
                                    '00:0f:fe:fc:8d:a2',
                                    '00:11:11:ee:ae:b7',
                                    '00:11:43:7d:c6:da',
                                    '00:13:72:1a:72:ba',
                                    '00:13:72:2a:02:8f',
                                    '00:13:72:39:f1:22',
                                    '00:13:20:2d:75:b4',
                                    '00:d0:b8:0c:f4:e8',
                                    '00:15:17:2b:0f:64',
                                    '00:19:b9:19:31:36',
                                    '00:19:d1:aa:78:42',
                                    '00:1a:a0:c1:8c:36',
                                    '00:1a:a0:ea:93:d8',
                                    '00:1a:a0:ea:94:19',
                                    '00:1a:a0:28:3a:7d',
                                    '00:1c:c0:c0:a5:bb',
                                    '00:1c:c0:ed:8f:6a',
                                    '00:1c:c0:f1:f6:4c',
                                    '00:1c:c0:f8:19:e0',
                                    '00:1c:c0:fc:49:8e',
                                    '00:1f:f3:8b:18:39',
                                    '00:21:9b:7a:75:78',
                                    '00:22:19:16:a7:73',
                                    '00:22:19:16:a8:fe',
                                    '00:22:19:16:53:ec',
                                    '00:22:19:dc:cd:34',
                                    '00:22:19:1c:1c:c0',
                                    '00:22:19:1d:53:bc',
                                    '00:22:19:1e:18:84',
                                    '00:22:19:07:23:a2',
                                    '00:26:b9:e5:05:e5',
                                    '00:08:9b:d2:5f:2e',
                                    '00:50:b6:57:59:74',
                                    '64:31:50:3a:8f:84',
                                    '68:5b:35:7d:5b:88',
                                    '6c:3b:e5:2b:0e:9a',
                                    '6c:3b:e5:2c:08:b8',
                                    '6c:3b:e5:36:09:92',
                                    '70:5a:b6:3c:93:fe',
                                    '78:ac:c0:a0:ab:63',
                                    '78:ac:c0:a0:bb:bb',
                                    '78:ac:c0:a1:ad:14',
                                    '78:e3:b5:6f:04:3d',
                                    '78:e7:d1:c2:31:ff',
                                    '80:c1:6e:e6:bc:2f',
                                    '80:c1:6e:ec:96:4e',
                                    '80:c1:6e:fd:13:e1',
                                    '80:ee:73:41:a4:2d',
                                    '84:2b:2b:9e:f4:fb',
                                    '9c:eb:e8:00:96:2e',
                                    '10:60:4b:68:0a:ce',
                                    '10:60:4b:85:4e:d8',
                                    'ac:16:2d:46:3a:b5',
                                    'b4:b5:2f:af:86:46',
                                    'b4:b5:2f:bd:b2:bd',
                                    'b4:b5:2f:cc:91:17',
                                    'b4:b5:2f:cc:91:19',
                                    'b8:8d:12:53:3c:06',
                                    'b8:ca:3a:a0:1b:e3',
                                    'b8:ca:3a:a0:1c:0e',
                                    'b8:ca:3a:a2:95:bd',
                                    'c4:2c:03:28:c1:b3',
                                    '14:da:e9:ce:36:4b',
                                    'c8:2a:14:0f:96:16',
                                    'cc:52:af:4a:5c:4a',
                                    'cc:52:af:4c:27:57',
                                    'd4:85:64:b8:c1:c6',
                                    'd4:85:64:b8:c5:b2',
                                    'd4:85:64:b8:c5:e2',
                                    'd4:85:64:b8:c5:53',
                                    'd4:3d:7e:1f:c3:0e',
                                    'd4:3d:7e:1f:c4:d3',
                                    'e0:18:77:01:9a:74',
                                    'e8:03:9a:f7:f2:b6',
                                    'e8:39:35:3e:af:88',
                                    'f0:4d:a2:28:50:ae',
                                    'f0:4d:a2:28:51:a4',
                                    'f0:4d:a2:28:51:d2',
                                    'f0:4d:a2:38:21:8d',
                                    'f0:4d:a2:38:25:63',
                                    'f8:b1:56:9b:b0:fc',
                                    'fc:4d:d4:3d:6a:a5',
                                    '1c:6f:65:0e:51:e2',
                                    '1c:6f:65:09:58:9a',
                                    '24:be:05:0f:65:97',
                                    '24:be:05:0f:65:9d',
                                    '24:be:05:27:32:86',
                                    '24:be:05:27:3b:a6',
                                    '28:d2:44:14:03:53',
                                    '2c:27:d7:35:cf:01',
                                    '2c:27:d7:35:d2:de',
                                    '2c:27:d7:35:d3:26',
                                    '2c:41:38:93:aa:d3',
                                    '2c:41:38:ab:f9:76',
                                    '2c:41:38:b5:c0:8c',
                                    '2c:44:fd:66:1c:98',
                                    '34:15:9e:21:45:fa',
                                    '3c:d9:2b:79:8b:3a',
                                    '3c:d9:2b:5a:ec:d6',
                                    '3c:07:54:2d:a8:95',
                                    '40:6c:8f:53:e7:26',
                                    '08:2e:5f:29:26:88',
                                    '08:2e:5f:31:e7:d7',
                                    '50:46:5d:3a:0c:ed',
                                    '54:53:ed:1b:f9:d8',
                                    '5c:26:0a:74:26:30',
                                    '5c:26:0a:19:dd:8a',
                                    '5c:26:0a:2e:06:ef',
                                    '00:0c:29:86:0c:c0',
                                    '00:0c:29:94:f8:bc',
                                    '00:0c:29:b9:6d:7d',
                                    '00:0c:29:ca:32:91',
                                    '00:0c:29:2b:12:ce',
                                    '00:0c:29:56:6b:7a',
                                    '00:13:20:e4:0a:53',
                                    '00:19:d1:7a:5d:7b',
                                    '00:19:d1:ae:27:a6',
                                    '00:19:d1:17:af:cc',
                                    '00:19:d1:17:b0:2c',
                                    '00:1a:a0:65:6c:c0',
                                    '00:1c:c0:7f:3c:dd',
                                    '00:1c:c0:7f:3d:0e',
                                    '00:1c:c0:7f:3d:03',
                                    '00:1c:c0:8f:2b:f1',
                                    '00:1c:c0:8f:45:0c',
                                    '00:1c:c0:8f:46:69',
                                    '00:1c:c0:8f:46:72',
                                    '00:1c:c0:8f:46:75',
                                    '00:1c:c0:8f:46:14',
                                    '00:1c:c0:9b:30:f6',
                                    '00:1c:c0:ed:15:8c',
                                    '00:1c:c0:f1:f7:ae',
                                    '00:1c:c0:f8:1d:a7',
                                    '00:1c:c0:f8:1d:c6',
                                    '00:1c:c0:1b:04:a3',
                                    '00:1e:4f:bf:c8:8b',
                                    '00:1e:4f:32:ea:9a',
                                    '00:23:ae:92:f7:90',
                                    '00:23:ae:93:2d:e6',
                                    '00:25:64:94:49:b1',
                                    '00:25:64:a0:39:0b',
                                    '00:25:64:bd:f1:a0',
                                    '00:27:0e:00:9a:d2',
                                    '00:27:0e:01:25:64',
                                    '00:27:0e:01:25:67',
                                    '00:27:0e:01:25:6e',
                                    '00:27:0e:01:28:fc',
                                    '00:27:0e:01:28:57',
                                    '00:27:0e:01:28:5e',
                                    '00:27:0e:02:64:91',
                                    '00:27:0e:02:56:22',
                                    '00:27:0e:02:56:57',
                                    '00:50:56:bc:00:48',
                                    '00:50:56:50:30:a0',
                                    '00:50:56:50:30:a2',
                                    '00:50:56:50:30:b8',
                                    '00:50:56:50:30:ba',
                                    '70:f3:95:13:d5:a2',
                                    '70:f3:95:13:d6:54',
                                    '70:f3:95:19:1c:47',
                                    '70:f3:95:19:2a:3a',
                                    '78:2b:cb:7e:63:a7',
                                    '84:2b:2b:9d:79:cc',
                                    '84:2b:2b:9d:8a:df',
                                    '10:78:d2:c3:db:b7',
                                    '10:78:d2:c3:df:fc',
                                    '10:78:d2:c3:e1:c0',
                                    'f0:4d:a2:0e:2c:5f',
                                    '1c:6f:65:0a:68:d1',
                                    '1c:6f:65:0b:cf:c8',
                                    '1c:6f:65:0d:e0:b3',
                                    '1c:6f:65:0d:ed:6c',
                                    '1c:6f:65:0f:e1:2e',
                                    '1c:6f:65:0f:fd:21',
                                    '44:37:e6:87:65:ed',
                                    '44:37:e6:62:26:f7',
                                    '44:37:e6:63:4c:e1',
                                    '00:0c:f1:e2:78:ed',
                                    '00:0c:f1:e2:79:3f',
                                    '00:0c:f1:e2:7a:aa',
                                    '00:0c:f1:e2:7a:4a',
                                    '00:0c:f1:e8:b9:65',
                                    '00:0c:f1:e8:b9:80',
                                    '00:0c:f1:e8:bc:31',
                                    '00:13:20:4a:d7:3f',
                                    '00:13:20:4a:d7:44',
                                    '00:16:76:86:6a:24',
                                    '00:11:43:a2:83:c1',
                                    'c8:cb:b8:2b:47:63',
                                    'c8:cb:b8:2b:4c:38',
                                    '00:60:ef:04:7b:a9',
                                    '00:1c:c0:7f:3f:46',
                                    '00:1c:c0:fc:f8:fb',
                                    '00:1c:c0:fc:f9:93',
                                    '00:1c:c0:fc:fa:09',
                                    '84:2b:2b:b2:74:db',
                                    '84:2b:2b:b9:3d:90',
                                    '00:60:16:1e:57:3d',
                                    '00:0c:29:ca:32:9b',
                                    '00:50:56:50:30:a0',
                                    '00:50:56:50:30:a2',
                                    '00:0c:29:ca:32:af',
                                    '00:19:d1:b1:fa:10',
                                    '00:19:d1:04:c2:29',
                                    '00:21:9b:60:d0:4e',
                                    '00:25:64:a0:3c:09',
                                    '00:50:56:bc:02:49',
                                    '00:50:56:bc:1c:83',
                                    '00:50:56:bc:29:c6',
                                    '00:50:56:50:30:a0',
                                    '00:50:56:50:30:a2',
                                    '00:50:56:50:30:b8',
                                    '00:50:56:50:30:ba',
                                    '70:f3:95:19:28:a7',
                                    '70:f3:95:19:29:7f',
                                    '70:f3:95:19:32:39',
                                    '70:f3:95:19:36:1e',
                                    '70:f3:95:1b:84:bc',
                                    '70:f3:95:1b:87:3d',
                                    '70:f3:95:1b:87:45',
                                    '70:f3:95:1b:87:50',
                                    '70:f3:95:1b:87:54',
                                    '88:f0:77:59:d9:ae',
                                    '14:fe:b5:b8:c2:03',
                                    'c8:2a:14:42:4b:e0',
                                    'cc:52:af:4a:4b:98',
                                    'cc:52:af:4c:23:23',
                                    'e8:9a:8f:6d:c9:80',
                                    'e8:11:32:61:38:ef',
                                    'f0:de:f1:b0:72:97',
                                    '1c:6f:65:0b:cf:67',
                                    '40:6c:8f:51:ac:bd',
                                    '40:2c:f4:eb:d1:2d',
                                    '40:2c:f4:eb:d8:6c',
                                    '40:2c:f4:eb:d8:97',
                                    '40:2c:f4:ec:01:8a',
                                    '44:37:e6:92:3a:ae',
                                    '44:37:e6:bb:a3:c9',
                                    '08:00:27:2d:5d:16',
                                    '08:00:27:41:88:d9',
                                    '5c:f9:dd:41:55:a1',
                                    '14:da:e9:0d:7e:d9',
                                    '50:46:5d:ea:cb:91',
                                    '00:13:20:32:81:47',
                                    '00:16:76:0d:37:22',
                                    '00:16:cb:aa:6d:75',
                                    '00:16:cb:ae:3d:f1',
                                    '00:e0:db:0c:ef:43',
                                    '00:e0:db:08:14:ef',
                                    '00:18:51:c7:ad:5f',
                                    '00:19:b9:fe:c1:52',
                                    '00:1a:a0:ba:e2:a6',
                                    '00:1a:a0:36:6d:b3',
                                    '00:1a:a0:36:ac:4d',
                                    '00:1c:c0:9b:30:e9',
                                    '00:1c:c0:9b:31:e2',
                                    '00:1c:c0:9b:58:fd',
                                    '00:1d:09:ff:83:c0',
                                    '00:1e:4f:f4:2d:4a',
                                    '00:1e:4f:f4:31:2d',
                                    '00:22:19:63:0f:4d',
                                    '00:25:64:92:7d:88',
                                    '00:25:64:bd:e6:e7',
                                    '00:25:64:bd:f1:fb',
                                    '00:25:64:bd:f1:5f',
                                    '00:25:64:be:2b:6d',
                                    '00:04:00:c3:15:26',
                                    '64:b9:e8:bc:71:c2',
                                    '64:b9:e8:c0:af:d8',
                                    '68:a8:6d:57:2f:5e',
                                    '70:cd:60:f1:fb:d0',
                                    '78:92:9c:12:3f:1c',
                                    '78:2b:cb:7e:62:9e',
                                    '7c:6d:62:8c:ed:22',
                                    '84:2b:2b:ab:ee:ad',
                                    '84:2b:2b:ab:ef:b4',
                                    'a8:20:66:03:64:2c',
                                    'bc:30:5b:ab:ff:5e',
                                    'c4:2c:03:21:ca:b2',
                                    '14:10:9f:dc:8d:dd',
                                    'cc:52:af:41:38:5e',
                                    'cc:52:af:4c:27:44',
                                    'd4:9a:20:07:10:be',
                                    'f0:4d:a2:0e:2c:38',
                                    '1c:6f:65:0d:ed:2a',
                                    '1c:6f:65:0d:f0:52',
                                    '1c:6f:65:0d:f1:e8',
                                    '1c:6f:65:0d:f2:9f',
                                    '1c:6f:65:0e:4f:b9',
                                    '1c:6f:65:0e:4f:de',
                                    '1c:6f:65:0e:4f:e2',
                                    '1c:6f:65:0e:50:e5',
                                    '1c:6f:65:0e:51:02',
                                    '1c:6f:65:0e:51:06',
                                    '20:c9:d0:29:d8:47',
                                    '3c:97:0e:70:0b:73',
                                    '3c:97:0e:7b:e8:4a',
                                    '3c:97:0e:48:cd:86',
                                    '3c:d0:f8:af:22:93',
                                    '3c:07:54:35:11:7a',
                                    '3c:07:54:35:22:51',
                                    '40:6c:8f:bb:dc:e2',
                                    '44:37:e6:6f:30:d8',
                                    '44:37:e6:6f:34:68',
                                    '44:37:e6:79:b2:84',
                                    '44:37:e6:79:b9:61',
                                    '44:37:e6:87:65:d2',
                                    '44:37:e6:87:65:d7',
                                    '44:37:e6:87:65:36',
                                    '44:37:e6:87:65:55',
                                    '44:37:e6:87:60:7f',
                                    '44:37:e6:63:4c:f7',
                                    '5c:26:0a:12:2e:62',
                                    '5c:26:0a:63:7c:f2',
                                    '00:0c:29:cf:f4:09',
                                    '00:0c:29:d4:b1:ab',
                                    '00:0c:29:f1:eb:69',
                                    '00:18:51:72:8e:eb',
                                    '00:18:51:7d:14:84',
                                    '00:18:51:91:7b:7c',
                                    '00:18:51:1c:b8:09',
                                    '00:1e:c9:f2:c0:81',
                                    '00:1e:4f:32:f7:9e',
                                    '00:1e:4f:33:14:d1',
                                    '00:1e:4f:41:d8:69',
                                    '00:1e:4f:41:e2:8c',
                                    '00:22:19:85:d5:3d',
                                    '00:22:19:63:0f:4d',
                                    '00:23:ae:fe:9c:e0',
                                    '00:23:ae:fe:9d:7c',
                                    '00:23:ae:fe:a9:c8',
                                    '00:23:ae:fe:a9:e0',
                                    '00:30:8c:1a:4b:4c',
                                    '00:50:56:bc:00:27',
                                    '00:50:56:bc:00:2f',
                                    '00:50:56:bc:57:2f',
                                    '00:50:56:bc:5d:6b',
                                    '00:50:56:50:30:a0',
                                    '00:50:56:50:30:a2',
                                    '00:50:56:50:30:b8',
                                    '00:50:56:50:30:ba',
                                    '00:1e:c9:f2:c0:81',
                                    '00:1e:4f:32:f7:9e',
                                    '00:1e:4f:33:14:d1',
                                    '00:1e:4f:41:d8:69',
                                    '00:1e:4f:41:e2:84',
                                    '00:1e:4f:41:e2:8c',
                                    '00:22:19:85:d5:3d',
                                    '00:23:ae:fe:9c:e0',
                                    '00:23:ae:fe:9d:7c',
                                    '00:23:ae:fe:a9:c8',
                                    '00:23:ae:fe:a9:e0',
                                    '00:50:56:bc:03:4b',
                                    '00:50:56:bc:57:30',
                                    '00:50:56:50:30:a0',
                                    '00:50:56:50:30:a2',
                                    '00:50:56:50:30:b8',
                                    '00:50:56:50:30:ba',
                                    '00:80:9f:53:3d:f7',
                                    '00:10:5a:c7:8d:62',
                                    '00:50:04:54:86:6f',
                                    '0c:77:1a:21:98:47',
                                    '84:a6:c8:ab:d3:c1',
                                    '88:53:2e:d7:07:85',
                                    'c4:85:08:7d:77:c9',
                                    'c4:85:08:05:2b:e3',
                                    'c8:f7:33:89:ba:61',
                                    '24:77:03:d2:eb:18',
                                    '4c:80:93:68:01:41',
                                    '4c:eb:42:95:f5:88',
                                    '58:91:cf:07:bd:9a',
                                    '00:0b:86:0a:f8:a0',
                                    '00:0c:29:27:f8:57',
                                    '00:11:11:3a:83:e7',
                                    '00:16:76:ce:7c:0a',
                                    '00:17:f2:94:41:c4',
                                    '00:18:51:00:00:54',
                                    '00:18:51:00:41:ec',
                                    '00:18:51:6a:b1:c9',
                                    '00:18:51:6b:ef:ef',
                                    '00:18:51:91:62:38',
                                    '00:18:51:94:15:c6',
                                    '00:18:51:99:f9:a1',
                                    '00:18:51:a6:4b:5c',
                                    '00:18:51:a9:ad:1b',
                                    '00:18:51:11:12:86',
                                    '00:18:51:b7:73:e0',
                                    '00:18:51:bd:01:02',
                                    '00:18:51:c7:06:38',
                                    '00:18:51:ec:1e:3b',
                                    '00:18:51:18:85:31',
                                    '00:18:51:fb:8c:ef',
                                    '00:18:51:1d:af:93',
                                    '00:18:51:24:40:88',
                                    '00:18:51:04:2d:18',
                                    '00:18:51:37:05:fa',
                                    '00:18:51:44:08:78',
                                    '00:18:51:47:8c:c5',
                                    '00:18:51:4b:1a:a2',
                                    '00:18:51:51:f1:8d',
                                    '00:18:51:5c:d2:3b',
                                    '00:18:51:5e:18:6c',
                                    '00:18:51:5e:25:c8',
                                    '00:1c:c0:22:f4:d4',
                                    '00:20:4a:d7:39:5a',
                                    '00:22:19:63:0f:4d',
                                    '00:24:36:f4:02:3e',
                                    '00:26:b9:77:17:f6',
                                    '00:30:48:76:ab:88',
                                    '00:30:48:82:e7:72',
                                    '00:50:56:bc:00:00',
                                    '00:50:56:bc:00:01',
                                    '00:50:56:bc:00:09',
                                    '00:50:56:bc:28:f1',
                                    '00:50:56:bc:29:c3',
                                    '00:50:56:bc:31:94',
                                    '00:50:56:bc:35:da',
                                    '00:50:56:50:30:a0',
                                    '00:50:56:50:30:a2',
                                    '00:50:56:50:30:b8',
                                    '00:50:56:50:30:ba',
                                    '00:1c:c0:9b:31:d1',
                                    '00:27:0e:01:25:fa',
                                    '70:f3:95:1b:85:4c',
                                    '00:0c:29:ca:32:a5',
                                    '00:13:20:6c:ab:be',
                                    '00:19:d1:17:af:ad',
                                    '00:19:d1:17:b0:7e',
                                    '00:19:d1:17:b0:93',
                                    '00:19:d1:17:b0:99',
                                    '00:19:d1:17:b0:14',
                                    '00:19:d1:17:b0:1b',
                                    '00:19:d1:17:b0:1c',
                                    '00:19:d1:17:b0:27',
                                    '00:19:d1:17:b0:35',
                                    '00:19:d1:05:a6:73',
                                    '00:1c:c0:7f:3c:d6',
                                    '00:1c:c0:8f:30:26',
                                    '00:23:7d:1d:d7:de',
                                    '00:23:7d:1d:fe:cb',
                                    '00:26:b9:ed:20:53',
                                    '00:27:0e:01:25:4a',
                                    '00:50:56:50:30:a0',
                                    '00:50:56:50:30:a2',
                                    '70:f3:95:1b:84:96',
                                    '70:f3:95:1b:85:37',
                                    '84:2b:2b:9d:8a:f9',
                                    '84:2b:2b:9d:8c:20',
                                    '84:2b:2b:9d:8c:32',
                                    '84:2b:2b:a0:44:4e',
                                    '1c:6f:65:0d:f7:3d',
                                    '44:37:e6:bb:a3:cc',
                                    '00:80:91:74:98:a2',
                                    '00:80:91:74:98:c8',
                                    '00:80:91:74:98:3f',
                                    '00:80:91:74:a3:4c',
                                    '00:20:4a:b1:3d:da',
                                    '00:23:24:60:6d:11',
                                    '00:22:19:1c:53:77',
                                    '00:22:19:1c:53:b3',
                                    '00:22:19:1c:55:8d',
                                    '00:22:19:1c:55:b9',
                                    '00:22:19:1c:56:01',
                                    '00:22:19:1d:d5:d8',
                                    '00:0d:7c:00:73:ae',
                                    '00:1e:67:03:93:04',
                                    '00:50:56:bc:00:24',
                                    '00:50:60:05:61:43',
                                    '00:12:3f:76:69:ab',
                                    '00:12:3f:76:b6:91',
                                    '00:12:3f:76:b6:ae',
                                    '00:13:20:38:f6:3e',
                                    '00:16:cb:99:5a:94',
                                    '00:19:d1:b1:ce:50',
                                    '00:24:e8:46:17:8e',
                                    '68:b5:99:90:64:4d',
                                    '70:f3:95:13:af:0d',
                                    '70:f3:95:1b:84:fc',
                                    '70:f3:95:1b:85:ac',
                                    'b8:ac:6f:2e:cb:13',
                                    'c8:bc:c8:92:76:53',
                                    'd4:85:64:a9:96:94',
                                    'd4:85:64:b8:c5:af',
                                    '1c:6f:65:0e:90:39',
                                    '24:be:05:0d:a0:96',
                                    '24:be:05:0d:b3:28',
                                    '24:be:05:0f:58:2f',
                                    '2c:27:d7:2d:9f:7c',
                                    '00:24:e8:46:17:aa',
                                    '00:24:e8:46:17:b8',
                                    '00:24:e8:46:25:ba',
                                    '00:24:e8:46:26:10',
                                    '00:24:e8:46:27:5b',
                                    '00:14:38:a2:c7:95',
                                    '00:21:5a:7b:0b:c9',
                                    '00:21:5a:81:95:36',
                                    '00:23:7d:77:5c:42',
                                    '6c:3b:e5:02:c1:a4',
                                    '78:ac:c0:91:d0:b5',
                                    '98:4b:e1:3b:ea:d4',
                                    '10:60:4b:14:9c:07',
                                    '10:60:4b:14:ac:23',
                                    '10:60:4b:14:17:ac',
                                    'b4:b5:2f:f5:d6:73',
                                    'd4:85:64:3c:0b:56',
                                    'd4:85:64:3c:2b:af',
                                    '3c:d9:2b:9f:e2:64',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '611',
                        IFNAME           => 'vlan.1114',
                        IFDESCR          => 'vlan.1114',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '172.21.10.251',
                        MAC              => '5c:5e:ab:6a:3b:81',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(27545808) 3 days, 4:30:58.08',
                        IFINOCTETS       => '1070904092',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '343849980',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '612',
                        IFNAME           => 'vlan.1116',
                        IFDESCR          => 'vlan.1116',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '172.21.12.251',
                        MAC              => '5c:5e:ab:6a:3b:81',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(27545809) 3 days, 4:30:58.09',
                        IFINOCTETS       => '936738386',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '21522',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        },
    ],
    'juniper/ex3200.02.walk' => [
        {
            TYPE         => 'NETWORKING',
            MANUFACTURER => 'Juniper',
            MODEL        => 'EX3200-24t',
            DESCRIPTION  => 'Juniper Networks, Inc. ex3200-48p internet router, kernel JUNOS 10.4R3.4 #0: 2011-03-19 22:06:32 UTC     builder@warth.juniper.net:/volume/build/junos/10.4/release/10.4R3.4/obj-powerpc/bsd/sys/compile/JUNIPER-EX Build date: 2011-03-19 21:51:24 UTC Copyri',
            SNMPHOSTNAME => 'jmsea3-11',
            LOCATION     => 'MSE Bat.A 3eme',
            SERIAL       => 'BL0211118777',
            UPTIME       => '(474858650) 54 days, 23:03:06.50',
            MEMORY       => '0',
            IPS          => {
                IP => [
                    '128.0.0.1',
                    '128.0.0.127',
                    '128.0.0.16',
                    '128.0.0.32',
                    '172.21.10.252',
                    '172.21.12.250',
                    '172.21.12.252',
                    '192.168.100.56',
                ],
            },
        },
        {
            INFO => {
                ID           => undef,
                TYPE         => 'NETWORKING',
                MANUFACTURER => 'Juniper',
                MODEL        => 'EX3200-24t',
                COMMENTS     => 'Juniper Networks, Inc. ex3200-48p internet router, kernel JUNOS 10.4R3.4 #0: 2011-03-19 22:06:32 UTC     builder@warth.juniper.net:/volume/build/junos/10.4/release/10.4R3.4/obj-powerpc/bsd/sys/compile/JUNIPER-EX Build date: 2011-03-19 21:51:24 UTC Copyri',
                NAME         => 'jmsea3-11',
                LOCATION     => 'MSE Bat.A 3eme',
                SERIAL       => 'BL0211118777',
                UPTIME       => '(474858650) 54 days, 23:03:06.50',
                MEMORY       => '0',
                IPS          => {
                    IP => [
                        '128.0.0.1',
                        '128.0.0.127',
                        '128.0.0.16',
                        '128.0.0.32',
                        '172.21.10.252',
                        '172.21.12.250',
                        '172.21.12.252',
                        '192.168.100.56',
                    ],
                },
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '4',
                        IFNAME           => 'lsi',
                        IFDESCR          => 'lsi',
                        IFTYPE           => '150',
                        IFSPEED          => '0',
                        IFMTU            => '1496',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1274) 0:00:12.74',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5',
                        IFNAME           => 'dsc',
                        IFDESCR          => 'dsc',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1272) 0:00:12.72',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '6',
                        IFNAME           => 'lo0',
                        IFDESCR          => 'lo0',
                        IFTYPE           => '24',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1274) 0:00:12.74',
                        IFINOCTETS       => '2508732132',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2508732132',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '7',
                        IFNAME           => 'tap',
                        IFDESCR          => 'tap',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1276) 0:00:12.76',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '8',
                        IFNAME           => 'gre',
                        IFDESCR          => 'gre',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1272) 0:00:12.72',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '9',
                        IFNAME           => 'ipip',
                        IFDESCR          => 'ipip',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1272) 0:00:12.72',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10',
                        IFNAME           => 'pime',
                        IFDESCR          => 'pime',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1276) 0:00:12.76',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '11',
                        IFNAME           => 'pimd',
                        IFDESCR          => 'pimd',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1276) 0:00:12.76',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '12',
                        IFNAME           => 'mtun',
                        IFDESCR          => 'mtun',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1275) 0:00:12.75',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '33',
                        IFNAME           => 'me0',
                        IFDESCR          => 'me0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:ff',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1275) 0:00:12.75',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '34',
                        IFNAME           => 'me0.0',
                        IFDESCR          => 'me0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '5c:5e:ab:6a:2a:ff',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1275) 0:00:12.75',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '37',
                        IFNAME           => 'bme0',
                        IFDESCR          => 'bme0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1576',
                        MAC              => '00:0b:ca:fe:00:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1271) 0:00:12.71',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1785427684',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '38',
                        IFNAME           => 'bme0.32768',
                        IFDESCR          => 'bme0.32768',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1562',
                        IP               => '128.0.0.32',
                        MAC              => '00:0b:ca:fe:00:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1271) 0:00:12.71',
                        IFINOCTETS       => '1738384031',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '126',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '501',
                        IFNAME           => 'ge-0/0/0',
                        IFDESCR          => 'ge-0/0/0',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(447510701) 51 days, 19:05:07.01',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '14886930',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2088716720',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '502',
                        IFNAME           => 'ge-0/0/0.0',
                        IFDESCR          => 'ge-0/0/0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(447510701) 51 days, 19:05:07.01',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '551410',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '290498861',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '503',
                        IFNAME           => 'ge-0/0/1',
                        IFDESCR          => 'ge-0/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:81',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(466665331) 54 days, 0:17:33.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '601042193',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3516529619',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '504',
                        IFNAME           => 'ge-0/0/2',
                        IFDESCR          => 'ge-0/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:82',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2593) 0:00:25.93',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '505',
                        IFNAME           => 'ge-0/0/3',
                        IFDESCR          => 'ge-0/0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:83',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(473765341) 54 days, 20:00:53.41',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '771262090',
                        IFINERRORS       => '3',
                        IFOUTOCTETS      => '3851782501',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '506',
                        IFNAME           => 'ge-0/0/4',
                        IFDESCR          => 'ge-0/0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:84',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(474817601) 54 days, 22:56:16.01',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '32894071',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3088883923',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '507',
                        IFNAME           => 'jsrv',
                        IFDESCR          => 'jsrv',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '5c:5e:ab:6a:2a:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1273) 0:00:12.73',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '508',
                        IFNAME           => 'jsrv.1',
                        IFDESCR          => 'jsrv.1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '128.0.0.127',
                        MAC              => '5c:5e:ab:6a:2a:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2195) 0:00:21.95',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '42',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '509',
                        IFNAME           => 'vlan',
                        IFDESCR          => 'vlan',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '5c:5e:ab:6a:2a:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1277) 0:00:12.77',
                        IFINOCTETS       => '1941246604',
                        IFINERRORS       => '194',
                        IFOUTOCTETS      => '344927255',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '510',
                        IFNAME           => 'ge-0/0/1.0',
                        IFDESCR          => 'ge-0/0/1.0',
                        IFTYPE           => '53',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:81',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(466665331) 54 days, 0:17:33.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '121062',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '304609915',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '511',
                        IFNAME           => 'ge-0/0/2.0',
                        IFDESCR          => 'ge-0/0/2.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:82',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2594) 0:00:25.94',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '512',
                        IFNAME           => 'ge-0/0/3.0',
                        IFDESCR          => 'ge-0/0/3.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:83',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(473765341) 54 days, 20:00:53.41',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3314717',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '26864487',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '513',
                        IFNAME           => 'ge-0/0/4.0',
                        IFDESCR          => 'ge-0/0/4.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:84',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(474817601) 54 days, 22:56:16.01',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '235971',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '307847984',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '514',
                        IFNAME           => 'ge-0/0/5',
                        IFDESCR          => 'ge-0/0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:85',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2598) 0:00:25.98',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '515',
                        IFNAME           => 'ge-0/0/5.0',
                        IFDESCR          => 'ge-0/0/5.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:85',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2599) 0:00:25.99',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '516',
                        IFNAME           => 'ge-0/0/6',
                        IFDESCR          => 'ge-0/0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:86',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(473224181) 54 days, 18:30:41.81',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1081420155',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3064383349',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '517',
                        IFNAME           => 'ge-0/0/6.0',
                        IFDESCR          => 'ge-0/0/6.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:86',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(473224181) 54 days, 18:30:41.81',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '16460',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '296795332',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '518',
                        IFNAME           => 'ge-0/0/7',
                        IFDESCR          => 'ge-0/0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:87',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(473422983) 54 days, 19:03:49.83',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '730460325',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3754870149',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '519',
                        IFNAME           => 'ge-0/0/7.0',
                        IFDESCR          => 'ge-0/0/7.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:87',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(473422983) 54 days, 19:03:49.83',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '496699',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '54295427',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '520',
                        IFNAME           => 'ge-0/0/8',
                        IFDESCR          => 'ge-0/0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:88',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(471981381) 54 days, 15:03:33.81',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1833035239',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3313914163',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '521',
                        IFNAME           => 'ge-0/0/8.0',
                        IFDESCR          => 'ge-0/0/8.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:88',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(471981381) 54 days, 15:03:33.81',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '186142',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '34341515',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '522',
                        IFNAME           => 'ge-0/0/9',
                        IFDESCR          => 'ge-0/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:89',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2606) 0:00:26.06',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '523',
                        IFNAME           => 'ge-0/0/9.0',
                        IFDESCR          => 'ge-0/0/9.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:89',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2606) 0:00:26.06',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '524',
                        IFNAME           => 'ge-0/0/10',
                        IFDESCR          => 'ge-0/0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:8a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2607) 0:00:26.07',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '525',
                        IFNAME           => 'ge-0/0/10.0',
                        IFDESCR          => 'ge-0/0/10.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:8a',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2608) 0:00:26.08',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '526',
                        IFNAME           => 'ge-0/0/11',
                        IFDESCR          => 'ge-0/0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:8b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2609) 0:00:26.09',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '527',
                        IFNAME           => 'ge-0/0/11.0',
                        IFDESCR          => 'ge-0/0/11.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:8b',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2610) 0:00:26.10',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '528',
                        IFNAME           => 'ge-0/0/12',
                        IFDESCR          => 'ge-0/0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:8c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(464082731) 53 days, 17:07:07.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3016626552',
                        IFINERRORS       => '23',
                        IFOUTOCTETS      => '794285937',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '529',
                        IFNAME           => 'ge-0/0/12.0',
                        IFDESCR          => 'ge-0/0/12.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:8c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(464082731) 53 days, 17:07:07.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '14343542',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '308033408',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '530',
                        IFNAME           => 'ge-0/0/13',
                        IFDESCR          => 'ge-0/0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:8d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2613) 0:00:26.13',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '531',
                        IFNAME           => 'ge-0/0/13.0',
                        IFDESCR          => 'ge-0/0/13.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:8d',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2614) 0:00:26.14',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '532',
                        IFNAME           => 'ge-0/0/14',
                        IFDESCR          => 'ge-0/0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:8e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(401656041) 46 days, 11:42:40.41',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '4060424',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '603143102',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '533',
                        IFNAME           => 'ge-0/0/14.0',
                        IFDESCR          => 'ge-0/0/14.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:8e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(401656041) 46 days, 11:42:40.41',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1571357',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '50320347',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '534',
                        IFNAME           => 'ge-0/0/15',
                        IFDESCR          => 'ge-0/0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:8f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2616) 0:00:26.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '535',
                        IFNAME           => 'ge-0/0/15.0',
                        IFDESCR          => 'ge-0/0/15.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:8f',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2617) 0:00:26.17',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '536',
                        IFNAME           => 'ge-0/0/16',
                        IFDESCR          => 'ge-0/0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:90',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2618) 0:00:26.18',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '537',
                        IFNAME           => 'ge-0/0/16.0',
                        IFDESCR          => 'ge-0/0/16.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:90',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2619) 0:00:26.19',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '538',
                        IFNAME           => 'ge-0/0/17',
                        IFDESCR          => 'ge-0/0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:91',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(474571629) 54 days, 22:15:16.29',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '200952724',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '586411337',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '539',
                        IFNAME           => 'ge-0/0/17.0',
                        IFDESCR          => 'ge-0/0/17.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:91',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(474571629) 54 days, 22:15:16.29',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '397720',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '13299334',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '540',
                        IFNAME           => 'ge-0/0/18',
                        IFDESCR          => 'ge-0/0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:92',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(474806931) 54 days, 22:54:29.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2413734880',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4043599409',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '541',
                        IFNAME           => 'ge-0/0/18.0',
                        IFDESCR          => 'ge-0/0/18.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:92',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(474806931) 54 days, 22:54:29.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '815785',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '32444373',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '542',
                        IFNAME           => 'ge-0/0/19',
                        IFDESCR          => 'ge-0/0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:93',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2623) 0:00:26.23',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '543',
                        IFNAME           => 'ge-0/0/19.0',
                        IFDESCR          => 'ge-0/0/19.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:93',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2624) 0:00:26.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '544',
                        IFNAME           => 'ge-0/0/20',
                        IFDESCR          => 'ge-0/0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:94',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(328099523) 37 days, 23:23:15.23',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '9593090',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '122546996',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '545',
                        IFNAME           => 'ge-0/0/20.0',
                        IFDESCR          => 'ge-0/0/20.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:94',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(328099523) 37 days, 23:23:15.23',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '158982',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1941658',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '546',
                        IFNAME           => 'ge-0/0/21',
                        IFDESCR          => 'ge-0/0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:95',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(473786149) 54 days, 20:04:21.49',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '910143171',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3292994931',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '547',
                        IFNAME           => 'ge-0/0/21.0',
                        IFDESCR          => 'ge-0/0/21.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:95',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(473786149) 54 days, 20:04:21.49',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2444044',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '42155232',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '548',
                        IFNAME           => 'ge-0/0/22',
                        IFDESCR          => 'ge-0/0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:96',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(474666851) 54 days, 22:31:08.51',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '216122988',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2000485885',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '549',
                        IFNAME           => 'ge-0/0/22.0',
                        IFDESCR          => 'ge-0/0/22.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:96',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(474666851) 54 days, 22:31:08.51',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1641680',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '10861331',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '550',
                        IFNAME           => 'ge-0/0/23',
                        IFDESCR          => 'ge-0/0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:97',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(449070911) 51 days, 23:25:09.11',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '666544062',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1571272994',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '551',
                        IFNAME           => 'ge-0/0/23.0',
                        IFDESCR          => 'ge-0/0/23.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:97',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(449070911) 51 days, 23:25:09.11',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '40043',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '7808014',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '552',
                        IFNAME           => 'ge-0/0/24',
                        IFDESCR          => 'ge-0/0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:98',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(474699291) 54 days, 22:36:32.91',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1058614693',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1622927813',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '553',
                        IFNAME           => 'ge-0/0/24.0',
                        IFDESCR          => 'ge-0/0/24.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:98',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(474699291) 54 days, 22:36:32.91',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '296591',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '308007181',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '554',
                        IFNAME           => 'ge-0/0/25',
                        IFDESCR          => 'ge-0/0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:99',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2881) 0:00:28.81',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '528263847',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1279432526',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '555',
                        IFNAME           => 'ge-0/0/25.0',
                        IFDESCR          => 'ge-0/0/25.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:99',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2881) 0:00:28.81',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '143161',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '308037572',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '556',
                        IFNAME           => 'ge-0/0/26',
                        IFDESCR          => 'ge-0/0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:9a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(474818413) 54 days, 22:56:24.13',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '545505781',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3766544875',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '557',
                        IFNAME           => 'ge-0/0/26.0',
                        IFDESCR          => 'ge-0/0/26.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:9a',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(474818413) 54 days, 22:56:24.13',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '961240',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '23693862',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '558',
                        IFNAME           => 'ge-0/0/27',
                        IFDESCR          => 'ge-0/0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:9b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(474471131) 54 days, 21:58:31.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1666756622',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1417421358',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '559',
                        IFNAME           => 'ge-0/0/27.0',
                        IFDESCR          => 'ge-0/0/27.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:9b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(474471131) 54 days, 21:58:31.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '352430',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '308017345',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '560',
                        IFNAME           => 'ge-0/0/28',
                        IFDESCR          => 'ge-0/0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:9c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(466228065) 53 days, 23:04:40.65',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '50598995',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '352981116',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '561',
                        IFNAME           => 'ge-0/0/28.0',
                        IFDESCR          => 'ge-0/0/28.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:9c',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(466228065) 53 days, 23:04:40.65',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '77642',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1874420',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '562',
                        IFNAME           => 'ge-0/0/29',
                        IFDESCR          => 'ge-0/0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:9d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2640) 0:00:26.40',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '563',
                        IFNAME           => 'ge-0/0/29.0',
                        IFDESCR          => 'ge-0/0/29.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:9d',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2641) 0:00:26.41',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '564',
                        IFNAME           => 'ge-0/0/30',
                        IFDESCR          => 'ge-0/0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:9e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(474724931) 54 days, 22:40:49.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '71493516',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2860500344',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '565',
                        IFNAME           => 'ge-0/0/30.0',
                        IFDESCR          => 'ge-0/0/30.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:9e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(474724931) 54 days, 22:40:49.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '39546',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '276415302',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '566',
                        IFNAME           => 'ge-0/0/31',
                        IFDESCR          => 'ge-0/0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:9f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(386442931) 44 days, 17:27:09.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1373339167',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1480696221',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '567',
                        IFNAME           => 'ge-0/0/31.0',
                        IFDESCR          => 'ge-0/0/31.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:9f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(386442931) 44 days, 17:27:09.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '249068',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '308032688',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '568',
                        IFNAME           => 'ge-0/0/32',
                        IFDESCR          => 'ge-0/0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:a0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(474803051) 54 days, 22:53:50.51',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '968879',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '439333937',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '569',
                        IFNAME           => 'ge-0/0/32.0',
                        IFDESCR          => 'ge-0/0/32.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:a0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(474803051) 54 days, 22:53:50.51',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '821367',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '307779041',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '570',
                        IFNAME           => 'ge-0/0/33',
                        IFDESCR          => 'ge-0/0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:a1',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2648) 0:00:26.48',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '571',
                        IFNAME           => 'ge-0/0/33.0',
                        IFDESCR          => 'ge-0/0/33.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:a1',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2649) 0:00:26.49',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '572',
                        IFNAME           => 'ge-0/0/34',
                        IFDESCR          => 'ge-0/0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:a2',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(474779731) 54 days, 22:49:57.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3776487528',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '308100617',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '573',
                        IFNAME           => 'ge-0/0/34.0',
                        IFDESCR          => 'ge-0/0/34.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:a2',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(474779731) 54 days, 22:49:57.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1127518',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '296932693',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '574',
                        IFNAME           => 'ge-0/0/35',
                        IFDESCR          => 'ge-0/0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:a3',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(473621355) 54 days, 19:36:53.55',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '177826879',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4200369213',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '575',
                        IFNAME           => 'ge-0/0/35.0',
                        IFDESCR          => 'ge-0/0/35.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:a3',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(473621355) 54 days, 19:36:53.55',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '427371',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '215447078',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '576',
                        IFNAME           => 'ge-0/0/36',
                        IFDESCR          => 'ge-0/0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:a4',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(472891711) 54 days, 17:35:17.11',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '627849190',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3532210109',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '577',
                        IFNAME           => 'ge-0/0/36.0',
                        IFDESCR          => 'ge-0/0/36.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:a4',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(472891711) 54 days, 17:35:17.11',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '145978',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '304763529',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '578',
                        IFNAME           => 'ge-0/0/37',
                        IFDESCR          => 'ge-0/0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:a5',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(457382961) 52 days, 22:30:29.61',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2759011',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '216762972',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '579',
                        IFNAME           => 'ge-0/0/37.0',
                        IFDESCR          => 'ge-0/0/37.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:a5',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(457382961) 52 days, 22:30:29.61',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1057803',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '11561523',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '580',
                        IFNAME           => 'ge-0/0/38',
                        IFDESCR          => 'ge-0/0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:a6',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(448152515) 51 days, 20:52:05.15',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1327042861',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '321449166',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '581',
                        IFNAME           => 'ge-0/0/38.0',
                        IFDESCR          => 'ge-0/0/38.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:a6',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(448152515) 51 days, 20:52:05.15',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '240627',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2639044',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '582',
                        IFNAME           => 'ge-0/0/39',
                        IFDESCR          => 'ge-0/0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:a7',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2662) 0:00:26.62',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '583',
                        IFNAME           => 'ge-0/0/39.0',
                        IFDESCR          => 'ge-0/0/39.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:a7',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2663) 0:00:26.63',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '584',
                        IFNAME           => 'ge-0/0/40',
                        IFDESCR          => 'ge-0/0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:a8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(471983661) 54 days, 15:03:56.61',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2168703795',
                        IFINERRORS       => '2',
                        IFOUTOCTETS      => '4219083410',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '585',
                        IFNAME           => 'ge-0/0/40.0',
                        IFDESCR          => 'ge-0/0/40.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:a8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(471983661) 54 days, 15:03:56.61',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '743164',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '308013381',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '586',
                        IFNAME           => 'ge-0/0/41',
                        IFDESCR          => 'ge-0/0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:a9',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2666) 0:00:26.66',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '587',
                        IFNAME           => 'ge-0/0/41.0',
                        IFDESCR          => 'ge-0/0/41.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:a9',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2667) 0:00:26.67',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '588',
                        IFNAME           => 'ge-0/0/42',
                        IFDESCR          => 'ge-0/0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:aa',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(344169975) 39 days, 20:01:39.75',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '509474',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '5672787',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '589',
                        IFNAME           => 'ge-0/0/42.0',
                        IFDESCR          => 'ge-0/0/42.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:aa',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(344169975) 39 days, 20:01:39.75',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '5643',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '17516',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '590',
                        IFNAME           => 'ge-0/0/43',
                        IFDESCR          => 'ge-0/0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:ab',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2670) 0:00:26.70',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '591',
                        IFNAME           => 'ge-0/0/43.0',
                        IFDESCR          => 'ge-0/0/43.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:ab',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(2671) 0:00:26.71',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '592',
                        IFNAME           => 'ge-0/0/44',
                        IFDESCR          => 'ge-0/0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:ac',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(457276321) 52 days, 22:12:43.21',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '16253803',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2003256603',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '593',
                        IFNAME           => 'ge-0/0/44.0',
                        IFDESCR          => 'ge-0/0/44.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:ac',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(457276321) 52 days, 22:12:43.21',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '57156',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '304452124',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '594',
                        IFNAME           => 'ge-0/0/45',
                        IFDESCR          => 'ge-0/0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:ad',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(473664981) 54 days, 19:44:09.81',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '925998916',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2796870118',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '595',
                        IFNAME           => 'ge-0/0/45.0',
                        IFDESCR          => 'ge-0/0/45.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:ad',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(473664981) 54 days, 19:44:09.81',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '682000',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '33355715',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '596',
                        IFNAME           => 'ge-0/0/46',
                        IFDESCR          => 'ge-0/0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4121) 0:00:41.21',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1094192709',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2345397936',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '597',
                        IFNAME           => 'ge-0/0/46.0',
                        IFDESCR          => 'ge-0/0/46.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4121) 0:00:41.21',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '52234794',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '418748502',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFNUMBER => '1050',
                                IFDESCR  => 'ge-2/0/1.0',
                                SYSNAME  => 'jmse-01',
                                SYSDESCR => 'Juniper Networks, Inc. ex4200-48p , version 10.4R3.4 Build date: 2011-03-19 22:17:08 UTC ',
                                SYSMAC   => '5c:5e:ab:66:60:80',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '598',
                        IFNAME           => 'ge-0/0/47',
                        IFDESCR          => 'ge-0/0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4141) 0:00:41.41',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '302235082',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '741470555',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '599',
                        IFNAME           => 'ge-0/0/47.0',
                        IFDESCR          => 'ge-0/0/47.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4141) 0:00:41.41',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '52076509',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '52076076',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFNUMBER => '954',
                                IFDESCR  => 'ge-3/0/1.0',
                                SYSNAME  => 'jmse-01',
                                SYSDESCR => 'Juniper Networks, Inc. ex4200-48p , version 10.4R3.4 Build date: 2011-03-19 22:17:08 UTC ',
                                SYSMAC   => '5c:5e:ab:66:60:80',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '604',
                        IFNAME           => 'vlan.0',
                        IFDESCR          => 'vlan.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '192.168.100.56',
                        MAC              => '5c:5e:ab:6a:2a:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4329) 0:00:43.29',
                        IFINOCTETS       => '1234212430',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '18289848',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '605',
                        IFNAME           => 'ae0',
                        IFDESCR          => 'ae0',
                        IFTYPE           => '161',
                        IFSPEED          => '2000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4324) 0:00:43.24',
                        IFINOCTETS       => '1396427791',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3086868491',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '606',
                        IFNAME           => 'ae1',
                        IFDESCR          => 'ae1',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:81',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1269) 0:00:12.69',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '607',
                        IFNAME           => 'ae2',
                        IFDESCR          => 'ae2',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:82',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1270) 0:00:12.70',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '608',
                        IFNAME           => 'ae3',
                        IFDESCR          => 'ae3',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:83',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1270) 0:00:12.70',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '609',
                        IFNAME           => 'ae4',
                        IFDESCR          => 'ae4',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:84',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1271) 0:00:12.71',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '610',
                        IFNAME           => 'ae0.0',
                        IFDESCR          => 'ae0.0',
                        IFTYPE           => '161',
                        IFSPEED          => '2000000000',
                        IFMTU            => '1514',
                        MAC              => '5c:5e:ab:6a:2a:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4324) 0:00:43.24',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '366673242',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '611',
                        IFNAME           => 'vlan.1114',
                        IFDESCR          => 'vlan.1114',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '172.21.10.252',
                        MAC              => '5c:5e:ab:6a:2a:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4327) 0:00:43.27',
                        IFINOCTETS       => '707041490',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '144426',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '612',
                        IFNAME           => 'vlan.1116',
                        IFDESCR          => 'vlan.1116',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '172.21.12.252',
                        MAC              => '5c:5e:ab:6a:2a:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4331) 0:00:43.31',
                        IFINOCTETS       => '1872',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '325004856',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        },
    ],
    'juniper/ex3200.03.walk' => [
        {
            TYPE         => 'NETWORKING',
            MANUFACTURER => 'Juniper',
            MODEL        => 'EX3200-24t',
            DESCRIPTION  => 'Juniper Networks, Inc. ex3200-48p internet router, kernel JUNOS 10.4R2.6 #0: 2011-02-06 23:48:13 UTC     builder@warth.juniper.net:/volume/build/junos/10.4/release/10.4R2.6/obj-powerpc/bsd/sys/compile/JUNIPER-EX Build date: 2011-02-06 23:17:05 UTC Copyri',

            SNMPHOSTNAME => 'jtc20-03',
            LOCATION     => 'repartiteur PMF 20eme',
            SERIAL       => 'BL0210129540',
            UPTIME       => '(690611103) 79 days, 22:21:51.03',
            MEMORY       => '0',
            MAC          => '2c:6b:f5:9a:7e:80',
            IPS          => {
                IP => [
                    '128.0.0.1',
                    '128.0.0.127',
                    '128.0.0.16',
                    '128.0.0.32',
                    '192.168.100.44',
                ],
            },
        },
        {
            INFO => {
                ID           => undef,
                TYPE         => 'NETWORKING',
                MANUFACTURER => 'Juniper',
                MODEL        => 'EX3200-24t',
                COMMENTS     => 'Juniper Networks, Inc. ex3200-48p internet router, kernel JUNOS 10.4R2.6 #0: 2011-02-06 23:48:13 UTC     builder@warth.juniper.net:/volume/build/junos/10.4/release/10.4R2.6/obj-powerpc/bsd/sys/compile/JUNIPER-EX Build date: 2011-02-06 23:17:05 UTC Copyri',
                NAME         => 'jtc20-03',
                LOCATION     => 'repartiteur PMF 20eme',
                SERIAL       => 'BL0210129540',
                UPTIME       => '(690611103) 79 days, 22:21:51.03',
                MEMORY       => '0',
                MAC          => '2c:6b:f5:9a:7e:80',
                IPS          => {
                    IP => [
                        '128.0.0.1',
                        '128.0.0.127',
                        '128.0.0.16',
                        '128.0.0.32',
                        '192.168.100.44',
                    ],
                },
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '4',
                        IFNAME           => 'lsi',
                        IFDESCR          => 'lsi',
                        IFTYPE           => '150',
                        IFSPEED          => '0',
                        IFMTU            => '1496',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5',
                        IFNAME           => 'dsc',
                        IFDESCR          => 'dsc',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '6',
                        IFNAME           => 'lo0',
                        IFDESCR          => 'lo0',
                        IFTYPE           => '24',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '2161453172',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2161453172',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '7',
                        IFNAME           => 'tap',
                        IFDESCR          => 'tap',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '8',
                        IFNAME           => 'gre',
                        IFDESCR          => 'gre',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '9',
                        IFNAME           => 'ipip',
                        IFDESCR          => 'ipip',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10',
                        IFNAME           => 'pime',
                        IFDESCR          => 'pime',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '11',
                        IFNAME           => 'pimd',
                        IFDESCR          => 'pimd',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '12',
                        IFNAME           => 'mtun',
                        IFDESCR          => 'mtun',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '33',
                        IFNAME           => 'me0',
                        IFDESCR          => 'me0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:ff',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '34',
                        IFNAME           => 'me0.0',
                        IFDESCR          => 'me0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '2c:6b:f5:9a:7e:ff',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '37',
                        IFNAME           => 'bme0',
                        IFDESCR          => 'bme0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1576',
                        MAC              => '00:0b:ca:fe:00:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4291428678',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '38',
                        IFNAME           => 'bme0.32768',
                        IFDESCR          => 'bme0.32768',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1562',
                        IP               => '128.0.0.32',
                        MAC              => '00:0b:ca:fe:00:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '3718526292',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '126',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '501',
                        IFNAME           => 'ge-0/0/0',
                        IFDESCR          => 'ge-0/0/0',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(494) 0:00:04.94',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2034641916',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3894747062',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '502',
                        IFNAME           => 'ge-0/0/0.0',
                        IFDESCR          => 'ge-0/0/0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(494) 0:00:04.94',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '101494486',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '105772066',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:01:30:12:91:80',
                                    '00:01:30:12:a6:c0',
                                    '00:01:30:12:a6:d0',
                                    '00:01:30:12:a8:30',
                                    '00:01:30:fd:05:f0',
                                    '00:0b:60:b0:b0:1b',
                                    '00:0f:34:aa:ee:1b',
                                    '00:10:db:ff:10:02',
                                    '00:02:b3:31:fa:f9',
                                    '00:e0:86:11:1a:27',
                                    '00:e0:86:11:1d:b0',
                                    '00:e0:86:12:d9:6f',
                                    '00:1b:ec:00:04:09',
                                    '00:1d:09:68:40:c8',
                                    '00:1e:c9:da:3b:fc',
                                    '00:1e:c9:f2:c0:81',
                                    '00:1e:c9:f2:ca:8d',
                                    '00:1e:4f:1f:3c:44',
                                    '00:1e:4f:1f:57:4b',
                                    '00:1e:4f:31:a9:a0',
                                    '00:1e:4f:31:ab:88',
                                    '00:1e:4f:31:ab:ab',
                                    '00:1e:4f:32:e1:d3',
                                    '00:1e:4f:32:e4:69',
                                    '00:1e:4f:32:f7:9e',
                                    '00:1e:4f:33:14:d1',
                                    '00:1e:4f:33:07:e1',
                                    '00:1e:4f:41:d0:a4',
                                    '00:1e:4f:41:d8:69',
                                    '00:1e:4f:41:dc:7e',
                                    '00:1e:4f:41:dd:53',
                                    '00:1e:4f:41:e2:8c',
                                    '00:1e:4f:08:e5:ca',
                                    '00:1e:4f:08:e6:62',
                                    '00:20:4a:0b:24:06',
                                    '00:20:4a:b1:3d:da',
                                    '00:20:4a:08:72:d2',
                                    '00:20:4a:08:73:01',
                                    '00:20:4a:08:ac:f6',
                                    '00:20:4a:08:ac:56',
                                    '00:20:4a:08:e1:6d',
                                    '00:20:4a:08:60:c6',
                                    '00:22:19:7b:be:11',
                                    '00:22:19:7b:be:da',
                                    '00:22:19:7b:bf:e6',
                                    '00:22:19:85:d9:70',
                                    '00:22:19:63:0f:55',
                                    '00:23:ae:fb:fd:89',
                                    '00:23:ae:fb:fd:b0',
                                    '00:23:ae:fc:00:cd',
                                    '00:23:ae:fc:00:d3',
                                    '00:23:ae:fc:00:d8',
                                    '00:23:ae:fe:9c:e0',
                                    '00:23:ae:fe:a9:e0',
                                    '00:04:96:18:6e:93',
                                    '00:04:96:18:5b:61',
                                    '00:04:96:1c:6f:f0',
                                    '00:04:96:1c:71:00',
                                    '00:04:96:1f:8f:0f',
                                    '00:04:96:1f:91:50',
                                    '00:04:96:27:93:f9',
                                    '00:04:96:34:69:ab',
                                    '00:04:96:34:69:b1',
                                    '00:04:96:34:89:5c',
                                    '00:04:96:34:8b:82',
                                    '00:04:96:34:8b:f8',
                                    '00:04:96:34:8c:10',
                                    '00:04:96:34:8c:11',
                                    '00:04:96:34:92:82',
                                    '00:04:96:34:92:31',
                                    '00:04:96:34:92:47',
                                    '00:04:96:34:af:ae',
                                    '00:04:96:35:77:14',
                                    '00:04:96:35:77:16',
                                    '00:04:96:35:90:67',
                                    '00:04:96:35:90:4d',
                                    '00:04:96:35:93:b9',
                                    '00:04:96:35:ad:e4',
                                    '00:04:96:35:c8:14',
                                    '00:04:96:35:c8:1f',
                                    '00:04:96:35:fa:ae',
                                    '00:04:96:35:fa:b1',
                                    '00:04:96:08:1e:70',
                                    '00:05:1e:08:f8:20',
                                    '00:05:1e:08:f9:12',
                                    '00:05:1e:09:21:2d',
                                    '00:05:1e:09:21:50',
                                    '00:05:33:f4:d9:df',
                                    '00:05:33:43:78:2d',
                                    '00:05:33:54:16:aa',
                                    '00:50:56:bc:31:8a',
                                    '00:50:56:50:30:a0',
                                    '00:50:56:50:30:a2',
                                    '00:50:56:50:38:30',
                                    '00:50:56:50:38:32',
                                    '00:60:16:1e:64:79',
                                    '00:60:16:1e:68:23',
                                    '00:60:16:1e:56:f6',
                                    '00:60:16:1e:57:3d',
                                    '64:87:88:b7:a5:c1',
                                    '64:87:88:b7:b6:41',
                                    '64:b9:e8:c0:b7:04',
                                    '78:fe:3d:3f:84:00',
                                    '78:fe:3d:45:28:01',
                                    '84:18:88:a6:06:33',
                                    '84:2b:2b:71:30:f3',
                                    '10:8c:cf:cb:85:5d',
                                    '10:8c:cf:cb:9e:92',
                                    '10:8c:cf:cb:bc:71',
                                    'ac:4b:c8:22:b8:41',
                                    'ac:4b:c8:23:1d:81',
                                    'ac:4b:c8:23:4d:81',
                                    'b0:a8:6e:9a:39:41',
                                    '02:04:96:35:f9:24',
                                    'd0:d0:fd:ab:1a:b6',
                                    'd0:d0:fd:ac:ae:b6',
                                    'd0:57:4c:74:16:01',
                                    'd0:57:4c:86:cd:00',
                                    '18:03:73:0a:29:c2',
                                    '18:03:73:09:ae:8c',
                                    'f0:4d:a2:6e:cf:89',
                                    'f0:4d:a2:6e:d3:e6',
                                    'f0:4d:a2:6e:d4:96',
                                    'f0:4d:a2:6e:d4:1c',
                                    'f0:4d:a2:6f:03:39',
                                    'f0:4d:a2:6f:03:5b',
                                    'f0:4d:a2:d9:bc:3f',
                                    '28:c0:da:3e:36:6f',
                                    '2c:36:f8:4b:6a:4a',
                                    '2c:36:f8:4b:6b:4c',
                                    '58:35:d9:94:d3:1a',
                                    '5c:26:0a:a5:b9:93',
                                    '5c:5e:ab:65:4a:81',
                                    '5c:5e:ab:66:60:80',
                                    '5c:5e:ab:78:0e:80',
                                    '00:19:d1:79:ff:9d',
                                    '00:80:77:ec:d6:f9',
                                    '00:9c:02:07:8d:ed',
                                    '00:17:08:91:da:f1',
                                    '00:03:81:82:3e:45',
                                    '00:03:2d:1c:e3:8b',
                                    '00:03:2d:1c:e3:de',
                                    '00:03:2d:1c:e4:51',
                                    '00:1f:29:20:1e:5c',
                                    '00:1f:29:31:8f:02',
                                    '00:20:6b:7a:68:84',
                                    '00:20:6b:7a:88:78',
                                    '00:20:6b:7a:88:7b',
                                    '00:20:6b:7a:8a:e0',
                                    '00:20:6b:7a:d0:06',
                                    '00:20:6b:7a:d1:00',
                                    '00:20:6b:7a:d1:71',
                                    '00:20:6b:7a:d1:3c',
                                    '00:20:6b:7a:d2:76',
                                    '00:20:6b:7a:d2:9e',
                                    '00:20:6b:7a:d2:4b',
                                    '00:20:6b:7a:61:f1',
                                    '00:20:6b:7c:c3:24',
                                    '00:20:6b:7c:df:6b',
                                    '00:20:6b:7c:f8:09',
                                    '00:20:6b:7e:e5:a8',
                                    '00:20:4a:66:3e:02',
                                    '00:21:5a:8a:d9:79',
                                    '00:23:7d:70:d9:75',
                                    '00:23:7d:7d:e0:d6',
                                    '00:23:7d:7d:2c:4b',
                                    '00:23:7d:81:77:61',
                                    '00:23:7d:85:a4:41',
                                    '00:25:b3:ea:7d:11',
                                    '00:25:b3:ea:7d:ff',
                                    '00:25:b3:fa:d3:49',
                                    '00:04:00:b9:55:01',
                                    '00:04:00:2d:25:fd',
                                    '78:e3:b5:f7:f0:ca',
                                    '78:e7:d1:a3:1f:6f',
                                    'ac:16:2d:39:c4:3a',
                                    'c8:cb:b8:60:89:fb',
                                    'd4:85:64:1b:72:a1',
                                    'd4:85:64:1b:2e:9b',
                                    'd4:85:64:1f:4c:49',
                                    'd4:85:64:41:60:52',
                                    'f4:ce:46:3c:72:b6',
                                    '1c:6f:65:0b:cf:8d',
                                    '1c:c1:de:82:2a:e3',
                                    '1c:c1:de:82:3a:75',
                                    '1c:c1:de:83:7e:ab',
                                    '2c:76:8a:3f:b6:bf',
                                    '2c:76:8a:40:ff:fc',
                                    '00:1c:c0:8e:71:05',
                                    '00:1c:c0:ed:15:0b',
                                    '00:27:0e:01:2b:bd',
                                    '70:f3:95:1b:84:d8',
                                    '70:f3:95:1b:85:2b',
                                    '70:f3:95:1b:85:43',
                                    '70:f3:95:1b:86:16',
                                    '70:f3:95:1b:87:3b',
                                    '78:2b:cb:7e:64:f2',
                                    '84:2b:2b:9d:8a:ef',
                                    'a8:20:66:52:44:97',
                                    'cc:52:af:4a:5d:1f',
                                    'cc:52:af:4c:22:32',
                                    'cc:52:af:4c:27:69',
                                    'cc:52:af:4c:28:bf',
                                    '1c:6f:65:0b:cf:da',
                                    '1c:6f:65:0b:d0:02',
                                    '1c:6f:65:0e:51:6b',
                                    '3c:97:0e:46:7d:53',
                                    '3c:07:54:38:e0:33',
                                    '44:37:e6:bb:a4:4a',
                                    '44:37:e6:63:50:86',
                                    '00:13:d4:b8:17:a9',
                                    '00:15:c5:7b:ba:74',
                                    '00:1c:c0:90:d8:be',
                                    '00:1c:c0:5e:11:af',
                                    '00:1d:09:36:51:dd',
                                    '00:25:64:49:ce:3e',
                                    '10:78:d2:c3:e1:6b',
                                    'f0:4d:a2:bc:35:18',
                                    '1c:6f:65:00:cc:e3',
                                    '1c:6f:65:07:55:2d',
                                    '20:c9:d0:29:d8:21',
                                    '2c:41:38:02:a5:75',
                                    '3c:97:0e:54:44:37',
                                    '44:37:e6:62:27:35',
                                    '58:55:ca:25:35:d5',
                                    '00:13:20:32:81:47',
                                    '00:16:cb:ae:3d:f1',
                                    '00:e0:db:0c:ef:43',
                                    '00:1a:a0:ba:a1:2c',
                                    '00:1a:a0:ba:e1:35',
                                    '00:1a:a0:ba:e2:a6',
                                    '00:1c:c0:7f:3e:ca',
                                    '00:1c:c0:9b:30:e9',
                                    '00:1c:c0:9b:31:e2',
                                    '00:1c:c0:9b:58:fd',
                                    '00:1c:c0:e3:6f:13',
                                    '00:1e:4f:f4:2c:d6',
                                    '00:1e:4f:f4:2d:4a',
                                    '00:1e:4f:f4:31:2d',
                                    '00:1f:f3:fc:79:e8',
                                    '00:21:70:bf:28:64',
                                    '00:22:19:63:0f:4d',
                                    '00:23:32:2e:80:5d',
                                    '00:25:64:92:7d:88',
                                    '00:25:64:bd:f1:fb',
                                    '00:25:64:bd:f1:5f',
                                    '00:27:0e:02:f9:9d',
                                    '00:08:9b:80:83:38',
                                    '64:b9:e8:bc:71:c2',
                                    '84:2b:2b:ab:ef:b4',
                                    '84:2b:2b:bc:56:04',
                                    'a8:20:66:03:64:2c',
                                    'c4:2c:03:21:ca:b2',
                                    'cc:52:af:41:38:5e',
                                    'f8:d1:11:3d:56:1d',
                                    '1c:6f:65:0d:f0:52',
                                    '1c:6f:65:0e:4f:b9',
                                    '1c:6f:65:0e:4f:e2',
                                    '1c:6f:65:0e:50:e5',
                                    '1c:6f:65:0e:51:02',
                                    '1c:6f:65:0e:51:06',
                                    '3c:07:54:35:11:7a',
                                    '3c:07:54:35:22:51',
                                    '40:6c:8f:bb:d2:fa',
                                    '44:37:e6:6f:30:d8',
                                    '44:37:e6:87:65:e6',
                                    '44:37:e6:63:4c:f7',
                                    '5c:26:0a:12:2e:62',
                                    '5c:26:0a:2e:02:69',
                                    '00:19:d1:ae:3e:36',
                                    '00:19:d1:df:7f:3f',
                                    '00:26:b9:ed:20:53',
                                    '00:27:0e:01:25:4a',
                                    '70:f3:95:13:86:cc',
                                    '70:f3:95:1b:84:96',
                                    '70:f3:95:1b:85:37',
                                    '84:2b:2b:9d:8b:73',
                                    '84:2b:2b:9d:8c:20',
                                    '84:2b:2b:9d:8c:32',
                                    '84:2b:2b:a0:44:4e',
                                    '00:0c:29:86:0c:c0',
                                    '00:0c:29:94:f8:bc',
                                    '00:0c:29:b9:6d:7d',
                                    '00:0c:29:ca:32:91',
                                    '00:0c:29:2b:12:ce',
                                    '00:0c:29:56:6b:7a',
                                    '00:13:20:e4:0a:53',
                                    '00:17:08:87:8e:28',
                                    '00:19:d1:7a:5d:68',
                                    '00:19:d1:7a:5d:52',
                                    '00:19:d1:ae:27:a6',
                                    '00:19:d1:17:b0:2c',
                                    '00:1c:c0:7f:3c:67',
                                    '00:1c:c0:7f:3d:03',
                                    '00:1c:c0:8f:2b:f1',
                                    '00:1c:c0:8f:44:f4',
                                    '00:1c:c0:8f:45:0c',
                                    '00:1c:c0:8f:46:67',
                                    '00:1c:c0:8f:46:69',
                                    '00:1c:c0:8f:46:74',
                                    '00:1c:c0:8f:46:75',
                                    '00:1c:c0:8f:46:14',
                                    '00:1c:c0:ed:15:0d',
                                    '00:1c:c0:ed:15:8c',
                                    '00:1c:c0:f0:88:19',
                                    '00:1c:c0:f1:f7:ae',
                                    '00:1c:c0:f8:1d:a7',
                                    '00:1c:c0:f8:1d:c6',
                                    '00:1c:c0:1b:04:a3',
                                    '00:1e:4f:c0:59:04',
                                    '00:1e:4f:32:ea:9a',
                                    '00:23:ae:92:f7:90',
                                    '00:23:ae:93:2d:65',
                                    '00:23:ae:93:2d:e6',
                                    '00:25:64:94:49:b1',
                                    '00:25:64:bd:f1:a0',
                                    '00:27:0e:00:9a:d2',
                                    '00:27:0e:01:25:67',
                                    '00:27:0e:01:25:75',
                                    '00:27:0e:01:25:7a',
                                    '00:27:0e:01:25:84',
                                    '00:27:0e:01:28:5a',
                                    '00:27:0e:01:29:2d',
                                    '00:27:0e:02:64:91',
                                    '00:27:0e:02:56:0d',
                                    '00:27:0e:02:56:22',
                                    '00:27:0e:02:56:40',
                                    '00:27:0e:02:56:57',
                                    '00:50:56:bc:00:48',
                                    '00:50:56:bc:31:89',
                                    '00:50:56:50:30:b8',
                                    '00:50:56:50:30:ba',
                                    '00:50:56:51:4d:58',
                                    '00:50:56:51:4d:5a',
                                    '70:f3:95:13:d5:a2',
                                    '70:f3:95:13:d6:54',
                                    '70:f3:95:19:1c:47',
                                    '70:f3:95:19:2a:3a',
                                    '84:2b:2b:9d:8a:df',
                                    '84:2b:2b:ad:56:26',
                                    '10:78:d2:c3:df:fc',
                                    'ac:16:2d:37:1b:c0',
                                    'cc:52:af:41:26:63',
                                    'cc:52:af:41:34:5f',
                                    'f0:4d:a2:0e:72:20',
                                    'f0:4d:a2:0e:2c:5f',
                                    '1c:6f:65:0b:cc:d9',
                                    '1c:6f:65:0d:ed:6c',
                                    '1c:6f:65:0d:f0:06',
                                    '1c:6f:65:0d:f8:10',
                                    '1c:6f:65:0d:fc:b2',
                                    '1c:6f:65:0e:90:4d',
                                    '1c:6f:65:0f:e1:2e',
                                    '1c:6f:65:09:57:46',
                                    '2c:36:f8:4b:6f:3f',
                                    '44:37:e6:62:26:f7',
                                    '44:37:e6:63:4c:e1',
                                    '44:37:e6:63:4c:e9',
                                    '44:37:e6:63:4c:eb',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '503',
                        IFNAME           => 'ge-0/0/1',
                        IFDESCR          => 'ge-0/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:81',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(665916869) 77 days, 1:46:08.69',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3013356695',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2048911018',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '504',
                        IFNAME           => 'ge-0/0/10',
                        IFDESCR          => 'ge-0/0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:8a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(399) 0:00:03.99',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '505',
                        IFNAME           => 'ge-0/0/11',
                        IFDESCR          => 'ge-0/0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:8b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(400) 0:00:04.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '506',
                        IFNAME           => 'ge-0/0/12',
                        IFDESCR          => 'ge-0/0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:8c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(689446000) 79 days, 19:07:40.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1571184393',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1999701488',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '507',
                        IFNAME           => 'ge-0/0/13',
                        IFDESCR          => 'ge-0/0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:8d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(690118870) 79 days, 20:59:48.70',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1444043283',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '932766504',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '508',
                        IFNAME           => 'ge-0/0/14',
                        IFDESCR          => 'ge-0/0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:8e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(406) 0:00:04.06',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '509',
                        IFNAME           => 'ge-0/0/15',
                        IFDESCR          => 'ge-0/0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:8f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(680552839) 78 days, 18:25:28.39',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '473789460',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3632242426',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '510',
                        IFNAME           => 'ge-0/0/16',
                        IFDESCR          => 'ge-0/0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:90',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(682689929) 79 days, 0:21:39.29',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2486916912',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2403893481',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '511',
                        IFNAME           => 'ge-0/0/17',
                        IFDESCR          => 'ge-0/0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:91',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(77140369) 8 days, 22:16:43.69',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '108183',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '384425',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '512',
                        IFNAME           => 'ge-0/0/18',
                        IFDESCR          => 'ge-0/0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:92',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(327809860) 37 days, 22:34:58.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1778337716',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1325429110',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '513',
                        IFNAME           => 'ge-0/0/19',
                        IFDESCR          => 'ge-0/0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:93',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(339) 0:00:03.39',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '514',
                        IFNAME           => 'ge-0/0/2',
                        IFDESCR          => 'ge-0/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:82',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(424349950) 49 days, 2:44:59.50',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1902005570',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1584758679',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '515',
                        IFNAME           => 'ge-0/0/20',
                        IFDESCR          => 'ge-0/0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:94',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(340) 0:00:03.40',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '516',
                        IFNAME           => 'ge-0/0/21',
                        IFDESCR          => 'ge-0/0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:95',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(690152520) 79 days, 21:05:25.20',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1206753935',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4210758575',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '517',
                        IFNAME           => 'ge-0/0/22',
                        IFDESCR          => 'ge-0/0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:96',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(671751825) 77 days, 17:58:38.25',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '215929658',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2000058785',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '518',
                        IFNAME           => 'ge-0/0/23',
                        IFDESCR          => 'ge-0/0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:97',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(690069390) 79 days, 20:51:33.90',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '188865545',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3090429957',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '519',
                        IFNAME           => 'ge-0/0/24',
                        IFDESCR          => 'ge-0/0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:98',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(409) 0:00:04.09',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '520',
                        IFNAME           => 'ge-0/0/25',
                        IFDESCR          => 'ge-0/0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:99',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(411) 0:00:04.11',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '521',
                        IFNAME           => 'ge-0/0/26',
                        IFDESCR          => 'ge-0/0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:9a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(414) 0:00:04.14',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '522',
                        IFNAME           => 'ge-0/0/27',
                        IFDESCR          => 'ge-0/0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:9b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(654852400) 75 days, 19:02:04.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3287311125',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3349027873',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '523',
                        IFNAME           => 'ge-0/0/28',
                        IFDESCR          => 'ge-0/0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:9c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(682860119) 79 days, 0:50:01.19',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '762667247',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1750605592',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '524',
                        IFNAME           => 'ge-0/0/29',
                        IFDESCR          => 'ge-0/0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:9d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(425) 0:00:04.25',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '525',
                        IFNAME           => 'ge-0/0/3',
                        IFDESCR          => 'ge-0/0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:83',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(690200000) 79 days, 21:13:20.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3546212557',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3594306636',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '526',
                        IFNAME           => 'ge-0/0/30',
                        IFDESCR          => 'ge-0/0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:9e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(681550555) 78 days, 21:11:45.55',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '136129037',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1849272137',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '527',
                        IFNAME           => 'ge-0/0/31',
                        IFDESCR          => 'ge-0/0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:9f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(690560437) 79 days, 22:13:24.37',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '93466915',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '201306124',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '528',
                        IFNAME           => 'ge-0/0/32',
                        IFDESCR          => 'ge-0/0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:a0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(386) 0:00:03.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '529',
                        IFNAME           => 'ge-0/0/33',
                        IFDESCR          => 'ge-0/0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:a1',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(387) 0:00:03.87',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '530',
                        IFNAME           => 'ge-0/0/34',
                        IFDESCR          => 'ge-0/0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:a2',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(59567179) 6 days, 21:27:51.79',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '53211885',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '539220717',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '531',
                        IFNAME           => 'ge-0/0/35',
                        IFDESCR          => 'ge-0/0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:a3',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(690486680) 79 days, 22:01:06.80',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '118822572',
                        IFINERRORS       => '102',
                        IFOUTOCTETS      => '2447844600',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '532',
                        IFNAME           => 'ge-0/0/36',
                        IFDESCR          => 'ge-0/0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:a4',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(208327439) 24 days, 2:41:14.39',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '8076917',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '438379336',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '533',
                        IFNAME           => 'ge-0/0/37',
                        IFDESCR          => 'ge-0/0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:a5',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(533708490) 61 days, 18:31:24.90',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2685287865',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3049509646',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '534',
                        IFNAME           => 'ge-0/0/38',
                        IFDESCR          => 'ge-0/0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:a6',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(682821860) 79 days, 0:43:38.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1241053012',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3840965297',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '535',
                        IFNAME           => 'ge-0/0/39',
                        IFDESCR          => 'ge-0/0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:a7',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(690387400) 79 days, 21:44:34.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1030838465',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4181007764',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '536',
                        IFNAME           => 'ge-0/0/4',
                        IFDESCR          => 'ge-0/0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:84',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(672589500) 77 days, 20:18:15.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '354731055',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3768060268',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '537',
                        IFNAME           => 'ge-0/0/40',
                        IFDESCR          => 'ge-0/0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:a8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(689500550) 79 days, 19:16:45.50',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1165890653',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2069283093',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '538',
                        IFNAME           => 'ge-0/0/41',
                        IFDESCR          => 'ge-0/0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:a9',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(148050739) 17 days, 3:15:07.39',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '81453084',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1543143617',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '539',
                        IFNAME           => 'ge-0/0/42',
                        IFDESCR          => 'ge-0/0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:aa',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(682354629) 78 days, 23:25:46.29',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1552651383',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2351683718',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '540',
                        IFNAME           => 'ge-0/0/43',
                        IFDESCR          => 'ge-0/0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:ab',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(595918169) 68 days, 23:19:41.69',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '829983992',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3925839742',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '541',
                        IFNAME           => 'ge-0/0/44',
                        IFDESCR          => 'ge-0/0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:ac',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(690512280) 79 days, 22:05:22.80',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1704785039',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2373360839',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '542',
                        IFNAME           => 'ge-0/0/45',
                        IFDESCR          => 'ge-0/0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:ad',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(672157520) 77 days, 19:06:15.20',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1721208124',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3695657617',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '543',
                        IFNAME           => 'ge-0/0/46',
                        IFDESCR          => 'ge-0/0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:ae',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(595611380) 68 days, 22:28:33.80',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1256689629',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '740549357',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '544',
                        IFNAME           => 'ge-0/0/47',
                        IFDESCR          => 'ge-0/0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:af',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(595611051) 68 days, 22:28:30.51',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2956582641',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '348225454',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '545',
                        IFNAME           => 'ge-0/0/5',
                        IFDESCR          => 'ge-0/0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:85',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(683883700) 79 days, 3:40:37.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '894824395',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3675464067',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '546',
                        IFNAME           => 'ge-0/0/6',
                        IFDESCR          => 'ge-0/0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:86',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(681483205) 78 days, 21:00:32.05',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2506833587',
                        IFINERRORS       => '4',
                        IFOUTOCTETS      => '2081076951',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '547',
                        IFNAME           => 'ge-0/0/7',
                        IFDESCR          => 'ge-0/0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:87',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(394) 0:00:03.94',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '548',
                        IFNAME           => 'ge-0/0/8',
                        IFDESCR          => 'ge-0/0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:88',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1166) 0:00:11.66',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2234030194',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2009640690',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '549',
                        IFNAME           => 'ge-0/0/9',
                        IFDESCR          => 'ge-0/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:89',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(683567821) 79 days, 2:47:58.21',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1130591759',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1128824234',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '550',
                        IFNAME           => 'vlan',
                        IFDESCR          => 'vlan',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '2c:6b:f5:9a:7e:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(245) 0:00:02.45',
                        IFINOCTETS       => '1805109523',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '30471514',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '553',
                        IFNAME           => 'ge-0/0/1.0',
                        IFDESCR          => 'ge-0/0/1.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:81',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(665916869) 77 days, 1:46:08.69',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '5857',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '416395996',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '554',
                        IFNAME           => 'ge-0/0/10.0',
                        IFDESCR          => 'ge-0/0/10.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:8a',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(400) 0:00:04.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '555',
                        IFNAME           => 'ge-0/0/11.0',
                        IFDESCR          => 'ge-0/0/11.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:8b',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(401) 0:00:04.01',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '556',
                        IFNAME           => 'ge-0/0/12.0',
                        IFDESCR          => 'ge-0/0/12.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:8c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(689446000) 79 days, 19:07:40.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2214652',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '69695210',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:26:b9:02:f8:16',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '557',
                        IFNAME           => 'ge-0/0/13.0',
                        IFDESCR          => 'ge-0/0/13.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:8d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(690118870) 79 days, 20:59:48.70',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1047225',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '72149489',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:19:d1:ae:24:94',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '558',
                        IFNAME           => 'ge-0/0/14.0',
                        IFDESCR          => 'ge-0/0/14.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:8e',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(407) 0:00:04.07',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '559',
                        IFNAME           => 'ge-0/0/15.0',
                        IFDESCR          => 'ge-0/0/15.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:8f',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(680552839) 78 days, 18:25:28.39',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1447979',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '15965923',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '560',
                        IFNAME           => 'ge-0/0/16.0',
                        IFDESCR          => 'ge-0/0/16.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:90',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(682689929) 79 days, 0:21:39.29',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1618691',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '442853532',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '561',
                        IFNAME           => 'ge-0/0/17.0',
                        IFDESCR          => 'ge-0/0/17.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:91',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(77140369) 8 days, 22:16:43.69',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '22941',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '23702',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '562',
                        IFNAME           => 'ge-0/0/18.0',
                        IFDESCR          => 'ge-0/0/18.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:92',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(327809860) 37 days, 22:34:58.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '223721',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '441314897',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:27:0e:02:d5:23',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '563',
                        IFNAME           => 'ge-0/0/19.0',
                        IFDESCR          => 'ge-0/0/19.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:93',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(662) 0:00:06.62',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '564',
                        IFNAME           => 'ge-0/0/2.0',
                        IFDESCR          => 'ge-0/0/2.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:82',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(424349950) 49 days, 2:44:59.50',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '469097',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '446847194',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:1f:29:1e:42:1b',
                                    '00:27:0e:02:d5:73',
                                    '00:27:0e:02:d5:ee',
                                    '00:27:0e:02:ec:f3',
                                    '00:27:0e:02:f9:73',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '565',
                        IFNAME           => 'ge-0/0/20.0',
                        IFDESCR          => 'ge-0/0/20.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:94',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(687) 0:00:06.87',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '566',
                        IFNAME           => 'ge-0/0/21.0',
                        IFDESCR          => 'ge-0/0/21.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:95',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(690152520) 79 days, 21:05:25.20',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '173239',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '447475036',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'cc:52:af:41:34:21',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '567',
                        IFNAME           => 'ge-0/0/22.0',
                        IFDESCR          => 'ge-0/0/22.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:96',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(671751825) 77 days, 17:58:38.25',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '350154',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '79929851',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '568',
                        IFNAME           => 'ge-0/0/23.0',
                        IFDESCR          => 'ge-0/0/23.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:97',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(690069390) 79 days, 20:51:33.90',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '44505',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '447678496',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'cc:52:af:41:34:ea',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '569',
                        IFNAME           => 'ge-0/0/24.0',
                        IFDESCR          => 'ge-0/0/24.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:98',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(410) 0:00:04.10',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '570',
                        IFNAME           => 'ge-0/0/25.0',
                        IFDESCR          => 'ge-0/0/25.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:99',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(413) 0:00:04.13',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '571',
                        IFNAME           => 'ge-0/0/26.0',
                        IFDESCR          => 'ge-0/0/26.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:9a',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(416) 0:00:04.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '572',
                        IFNAME           => 'ge-0/0/27.0',
                        IFDESCR          => 'ge-0/0/27.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:9b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(654852400) 75 days, 19:02:04.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '10178',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '448228334',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:1a:1e:c5:a7:4a',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '573',
                        IFNAME           => 'ge-0/0/28.0',
                        IFDESCR          => 'ge-0/0/28.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:9c',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(682860119) 79 days, 0:50:01.19',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2685687',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '16975010',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '574',
                        IFNAME           => 'ge-0/0/29.0',
                        IFDESCR          => 'ge-0/0/29.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:9d',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(426) 0:00:04.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '575',
                        IFNAME           => 'ge-0/0/3.0',
                        IFDESCR          => 'ge-0/0/3.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:83',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(690200000) 79 days, 21:13:20.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2303780',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '256970338',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:26:b9:ed:1f:71',
                                    'd4:3d:7e:1f:c4:2a',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '576',
                        IFNAME           => 'ge-0/0/30.0',
                        IFDESCR          => 'ge-0/0/30.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:9e',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(681550555) 78 days, 21:11:45.55',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '24694',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '385335962',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '577',
                        IFNAME           => 'ge-0/0/31.0',
                        IFDESCR          => 'ge-0/0/31.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:9f',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(690560437) 79 days, 22:13:24.37',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '50282',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3882652',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '578',
                        IFNAME           => 'ge-0/0/32.0',
                        IFDESCR          => 'ge-0/0/32.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:a0',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(643) 0:00:06.43',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '579',
                        IFNAME           => 'ge-0/0/33.0',
                        IFDESCR          => 'ge-0/0/33.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:a1',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(665) 0:00:06.65',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '580',
                        IFNAME           => 'ge-0/0/34.0',
                        IFDESCR          => 'ge-0/0/34.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:a2',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(59567179) 6 days, 21:27:51.79',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '147975',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '7302800',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '581',
                        IFNAME           => 'ge-0/0/35.0',
                        IFDESCR          => 'ge-0/0/35.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:a3',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(690486680) 79 days, 22:01:06.80',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '137977',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '447041540',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '582',
                        IFNAME           => 'ge-0/0/36.0',
                        IFDESCR          => 'ge-0/0/36.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:a4',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(208327439) 24 days, 2:41:14.39',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '156339',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '93089646',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '583',
                        IFNAME           => 'ge-0/0/37.0',
                        IFDESCR          => 'ge-0/0/37.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:a5',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(533708490) 61 days, 18:31:24.90',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3263553',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '279079429',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:1c:c0:ee:80:4b',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '584',
                        IFNAME           => 'ge-0/0/38.0',
                        IFDESCR          => 'ge-0/0/38.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:a6',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(682821860) 79 days, 0:43:38.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1911627',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '447293405',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:14:38:5a:1d:d0',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '585',
                        IFNAME           => 'ge-0/0/39.0',
                        IFDESCR          => 'ge-0/0/39.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:a7',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(690387400) 79 days, 21:44:34.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3365162',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '83617872',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '5c:26:0a:63:7c:f2',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '586',
                        IFNAME           => 'ge-0/0/4.0',
                        IFDESCR          => 'ge-0/0/4.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:84',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(672589500) 77 days, 20:18:15.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '439264',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '447533137',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '587',
                        IFNAME           => 'ge-0/0/40.0',
                        IFDESCR          => 'ge-0/0/40.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:a8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(689500550) 79 days, 19:16:45.50',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '11338164',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '81215246',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '24:b6:fd:18:21:f4',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '588',
                        IFNAME           => 'ge-0/0/41.0',
                        IFDESCR          => 'ge-0/0/41.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:a9',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(148050739) 17 days, 3:15:07.39',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '215806',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2041083',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '589',
                        IFNAME           => 'ge-0/0/42.0',
                        IFDESCR          => 'ge-0/0/42.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:aa',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(682354629) 78 days, 23:25:46.29',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '76619276',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '442621726',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '590',
                        IFNAME           => 'ge-0/0/43.0',
                        IFDESCR          => 'ge-0/0/43.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:ab',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(595918169) 68 days, 23:19:41.69',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3425509',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '49542723',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '591',
                        IFNAME           => 'ge-0/0/44.0',
                        IFDESCR          => 'ge-0/0/44.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:ac',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(690512280) 79 days, 22:05:22.80',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '4537101',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '102760044',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:26:b9:05:c3:7a',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '592',
                        IFNAME           => 'ge-0/0/45.0',
                        IFDESCR          => 'ge-0/0/45.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:ad',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(672157520) 77 days, 19:06:15.20',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '76592',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '354018094',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '593',
                        IFNAME           => 'ge-0/0/46.0',
                        IFDESCR          => 'ge-0/0/46.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:ae',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(595611380) 68 days, 22:28:33.80',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '952616',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '61630220',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:26:b0:e8:dd:1e',
                                    'cc:52:af:41:25:f2',
                                    '44:37:e6:87:63:68',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '594',
                        IFNAME           => 'ge-0/0/47.0',
                        IFDESCR          => 'ge-0/0/47.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:af',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(595611051) 68 days, 22:28:30.51',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '4911565',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '285952935',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '595',
                        IFNAME           => 'ge-0/0/5.0',
                        IFDESCR          => 'ge-0/0/5.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:85',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(683883700) 79 days, 3:40:37.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2655317',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '447689671',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '596',
                        IFNAME           => 'ge-0/0/6.0',
                        IFDESCR          => 'ge-0/0/6.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:86',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(681483205) 78 days, 21:00:32.05',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '340907',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '88449606',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '597',
                        IFNAME           => 'ge-0/0/7.0',
                        IFDESCR          => 'ge-0/0/7.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:87',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(395) 0:00:03.95',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '598',
                        IFNAME           => 'ge-0/0/8.0',
                        IFDESCR          => 'ge-0/0/8.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:88',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1166) 0:00:11.66',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '8463015',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '447755052',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '40:6c:8f:49:66:30',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '599',
                        IFNAME           => 'ge-0/0/9.0',
                        IFDESCR          => 'ge-0/0/9.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9a:7e:89',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(683567821) 79 days, 2:47:58.21',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2799490',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '46465074',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '602',
                        IFNAME           => 'vlan.0',
                        IFDESCR          => 'vlan.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '192.168.100.44',
                        MAC              => '2c:6b:f5:9a:7e:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(497) 0:00:04.97',
                        IFINOCTETS       => '1805113747',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '28643566',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '603',
                        IFNAME           => 'jsrv',
                        IFDESCR          => 'jsrv',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '2c:6b:f5:9a:7e:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '604',
                        IFNAME           => 'jsrv.1',
                        IFDESCR          => 'jsrv.1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '128.0.0.127',
                        MAC              => '2c:6b:f5:9a:7e:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '42',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        },
    ],
    'juniper/ex4200.01.walk' => [
        {
            TYPE         => 'NETWORKING',
            MANUFACTURER => 'Juniper',
            MODEL        => 'EX4200-24t',
            DESCRIPTION  => 'Juniper Networks, Inc. ex4200-48p internet router, kernel JUNOS 10.4R3.4 #0: 2011-03-19 22:06:32 UTC     builder@warth.juniper.net:/volume/build/junos/10.4/release/10.4R3.4/obj-powerpc/bsd/sys/compile/JUNIPER-EX Build date: 2011-03-19 21:51:24 UTC Copyri',

            SNMPHOSTNAME => 'jte4-01',
            LOCATION     => 'Salle informatique E4 PMF',
            SERIAL       => 'BQ0210122093',
            UPTIME       => '(1579491875) 182 days, 19:28:38.75',
            MEMORY       => '0',
            MAC          => '2c:6b:f5:9b:48:80',
            IPS          => {
                IP => [
                    '128.0.0.1',
                    '128.0.0.127',
                    '128.0.0.16',
                    '128.0.0.32',
                    '192.168.100.31',
                ],
            },
        },
        {
            INFO => {
                ID           => undef,
                TYPE         => 'NETWORKING',
                MANUFACTURER => 'Juniper',
                MODEL        => 'EX4200-24t',
                COMMENTS     => 'Juniper Networks, Inc. ex4200-48p internet router, kernel JUNOS 10.4R3.4 #0: 2011-03-19 22:06:32 UTC     builder@warth.juniper.net:/volume/build/junos/10.4/release/10.4R3.4/obj-powerpc/bsd/sys/compile/JUNIPER-EX Build date: 2011-03-19 21:51:24 UTC Copyri',
                NAME         => 'jte4-01',
                LOCATION     => 'Salle informatique E4 PMF',
                SERIAL       => 'BQ0210122093',
                UPTIME       => '(1579491875) 182 days, 19:28:38.75',
                MEMORY       => '0',
                MAC          => '2c:6b:f5:9b:48:80',
                IPS          => {
                    IP => [
                        '128.0.0.1',
                        '128.0.0.127',
                        '128.0.0.16',
                        '128.0.0.32',
                        '192.168.100.31',
                    ],
                },
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '4',
                        IFNAME           => 'lsi',
                        IFDESCR          => 'lsi',
                        IFTYPE           => '150',
                        IFSPEED          => '0',
                        IFMTU            => '1496',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5',
                        IFNAME           => 'dsc',
                        IFDESCR          => 'dsc',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5840) 0:00:58.40',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '6',
                        IFNAME           => 'lo0',
                        IFDESCR          => 'lo0',
                        IFTYPE           => '24',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5842) 0:00:58.42',
                        IFINOCTETS       => '628200578',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '630161982',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '7',
                        IFNAME           => 'tap',
                        IFDESCR          => 'tap',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5845) 0:00:58.45',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '8',
                        IFNAME           => 'gre',
                        IFDESCR          => 'gre',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5840) 0:00:58.40',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '9',
                        IFNAME           => 'ipip',
                        IFDESCR          => 'ipip',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5841) 0:00:58.41',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10',
                        IFNAME           => 'pime',
                        IFDESCR          => 'pime',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5844) 0:00:58.44',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '11',
                        IFNAME           => 'pimd',
                        IFDESCR          => 'pimd',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5844) 0:00:58.44',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '12',
                        IFNAME           => 'mtun',
                        IFDESCR          => 'mtun',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '33',
                        IFNAME           => 'me0',
                        IFDESCR          => 'me0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:81',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '34',
                        IFNAME           => 'me0.0',
                        IFDESCR          => 'me0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:81',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1634) 0:00:16.34',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '35',
                        IFNAME           => 'vme',
                        IFDESCR          => 'vme',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '2c:6b:f5:9b:48:81',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '37',
                        IFNAME           => 'bme0',
                        IFDESCR          => 'bme0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1576',
                        MAC              => '00:0b:ca:fe:00:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3190556671',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '38',
                        IFNAME           => 'bme0.32768',
                        IFDESCR          => 'bme0.32768',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1562',
                        IP               => '128.0.0.32',
                        MAC              => '00:0b:ca:fe:00:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '1267757312',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2909561371',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '40',
                        IFNAME           => 'bme0.32770',
                        IFDESCR          => 'bme0.32770',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1576',
                        MAC              => '00:0b:ca:fe:00:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(717450037) 83 days, 0:55:00.37',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '41',
                        IFNAME           => 'bme0.32771',
                        IFDESCR          => 'bme0.32771',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1576',
                        MAC              => '00:0b:ca:fe:00:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(889645996) 102 days, 23:14:19.96',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '42',
                        IFNAME           => 'bme0.32772',
                        IFDESCR          => 'bme0.32772',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1576',
                        MAC              => '00:0b:ca:fe:00:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(889646000) 102 days, 23:14:20.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '43',
                        IFNAME           => 'bme0.32773',
                        IFDESCR          => 'bme0.32773',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1576',
                        MAC              => '00:0b:ca:fe:00:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(1071466411) 124 days, 0:17:44.11',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '44',
                        IFNAME           => 'bme0.32774',
                        IFDESCR          => 'bme0.32774',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1576',
                        MAC              => '00:0b:ca:fe:00:00',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(1071466415) 124 days, 0:17:44.15',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '49',
                        IFNAME           => 'vcp-0',
                        IFDESCR          => 'vcp-0',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717449455) 83 days, 0:54:54.55',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '50',
                        IFNAME           => 'vcp-0.32768',
                        IFDESCR          => 'vcp-0.32768',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717449455) 83 days, 0:54:54.55',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '51',
                        IFNAME           => 'vcp-1',
                        IFDESCR          => 'vcp-1',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717449456) 83 days, 0:54:54.56',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '52',
                        IFNAME           => 'vcp-1.32768',
                        IFDESCR          => 'vcp-1.32768',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717449456) 83 days, 0:54:54.56',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '105',
                        IFNAME           => 'vcp-255/1/2',
                        IFDESCR          => 'vcp-255/1/2',
                        IFTYPE           => '1',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889641113) 102 days, 23:13:31.13',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '106',
                        IFNAME           => 'vcp-255/1/2.32768',
                        IFDESCR          => 'vcp-255/1/2.32768',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889641113) 102 days, 23:13:31.13',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '501',
                        IFNAME           => 'jsrv',
                        IFDESCR          => 'jsrv',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '2c:6b:f5:9b:05:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(665) 0:00:06.65',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '502',
                        IFNAME           => 'ge-0/0/0',
                        IFDESCR          => 'ge-0/0/0',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:81',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2877542534',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1218507182',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '503',
                        IFNAME           => 'ge-0/0/0.0',
                        IFDESCR          => 'ge-0/0/0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:81',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '173229412',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '173363747',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFNUMBER => '502',
                                IFDESCR  => 'ge-0/0/0.0',
                                SYSNAME  => 'jte4-02',
                                SYSDESCR => 'Juniper Networks, Inc. ex3200-48p , version 10.3R1.9 Build date: 2010-08-13 12:56:38 UTC ',
                                SYSMAC   => '2c:6b:f5:99:7c:00',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '504',
                        IFNAME           => 'ge-0/0/1',
                        IFDESCR          => 'ge-0/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:81',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '505',
                        IFNAME           => 'ge-0/0/1.0',
                        IFDESCR          => 'ge-0/0/1.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:81',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '506',
                        IFNAME           => 'ge-0/0/2',
                        IFDESCR          => 'ge-0/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:82',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1501251026) 173 days, 18:08:30.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '329254826',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4242153267',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '507',
                        IFNAME           => 'ge-0/0/2.0',
                        IFDESCR          => 'ge-0/0/2.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:82',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1501251026) 173 days, 18:08:30.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '766023',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '13561778',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '508',
                        IFNAME           => 'ge-0/0/3',
                        IFDESCR          => 'ge-0/0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:83',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1485512394) 171 days, 22:25:23.94',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3333121183',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '846561719',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '509',
                        IFNAME           => 'ge-0/0/3.0',
                        IFDESCR          => 'ge-0/0/3.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:83',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1485512394) 171 days, 22:25:23.94',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '31352',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '667472987',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:50:60:05:61:43',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '510',
                        IFNAME           => 'ge-0/0/4',
                        IFDESCR          => 'ge-0/0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:84',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1547843164) 179 days, 3:33:51.64',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2623698044',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4057307380',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '511',
                        IFNAME           => 'ge-0/0/4.0',
                        IFDESCR          => 'ge-0/0/4.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:84',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1547843164) 179 days, 3:33:51.64',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2085494',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '40748111',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '512',
                        IFNAME           => 'ge-0/0/5',
                        IFDESCR          => 'ge-0/0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:85',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '513',
                        IFNAME           => 'ge-0/0/5.0',
                        IFDESCR          => 'ge-0/0/5.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:85',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '514',
                        IFNAME           => 'ge-0/0/6',
                        IFDESCR          => 'ge-0/0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:86',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(250446944) 28 days, 23:41:09.44',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '620574',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '10228408',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '515',
                        IFNAME           => 'ge-0/0/6.0',
                        IFDESCR          => 'ge-0/0/6.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:86',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(250446944) 28 days, 23:41:09.44',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '75363',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '384364',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '516',
                        IFNAME           => 'ge-0/0/7',
                        IFDESCR          => 'ge-0/0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:87',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(251603028) 29 days, 2:53:50.28',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '12346184',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '67868236',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '517',
                        IFNAME           => 'ge-0/0/7.0',
                        IFDESCR          => 'ge-0/0/7.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:87',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(251603028) 29 days, 2:53:50.28',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '50345',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1308607',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '518',
                        IFNAME           => 'ge-0/0/8',
                        IFDESCR          => 'ge-0/0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:88',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578982254) 182 days, 18:03:42.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2086798177',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '865615864',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '519',
                        IFNAME           => 'ge-0/0/8.0',
                        IFDESCR          => 'ge-0/0/8.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:88',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578982254) 182 days, 18:03:42.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '5801536',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '576687990',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'cc:52:af:4a:4b:98',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '520',
                        IFNAME           => 'ge-0/0/9',
                        IFDESCR          => 'ge-0/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:89',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '521',
                        IFNAME           => 'ge-0/0/9.0',
                        IFDESCR          => 'ge-0/0/9.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:89',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '522',
                        IFNAME           => 'ge-0/0/10',
                        IFDESCR          => 'ge-0/0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '523',
                        IFNAME           => 'ge-0/0/10.0',
                        IFDESCR          => 'ge-0/0/10.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8a',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '524',
                        IFNAME           => 'ge-0/0/11',
                        IFDESCR          => 'ge-0/0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1424310274) 164 days, 20:25:02.74',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '245249012',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2689590785',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '525',
                        IFNAME           => 'ge-0/0/11.0',
                        IFDESCR          => 'ge-0/0/11.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1424310274) 164 days, 20:25:02.74',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3345796',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1022331172',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:14:38:db:4a:fb',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '526',
                        IFNAME           => 'ge-0/0/12',
                        IFDESCR          => 'ge-0/0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1441359724) 166 days, 19:46:37.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1891728511',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6496905',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '527',
                        IFNAME           => 'ge-0/0/12.0',
                        IFDESCR          => 'ge-0/0/12.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1441359724) 166 days, 19:46:37.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '7133205',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1022495546',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:20:6b:7a:d0:12',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '528',
                        IFNAME           => 'ge-0/0/13',
                        IFDESCR          => 'ge-0/0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '529',
                        IFNAME           => 'ge-0/0/13.0',
                        IFDESCR          => 'ge-0/0/13.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8d',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '530',
                        IFNAME           => 'ge-0/0/14',
                        IFDESCR          => 'ge-0/0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '531',
                        IFNAME           => 'ge-0/0/14.0',
                        IFDESCR          => 'ge-0/0/14.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8e',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '532',
                        IFNAME           => 'ge-0/0/15',
                        IFDESCR          => 'ge-0/0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578486224) 182 days, 16:41:02.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2031804275',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3490600419',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '533',
                        IFNAME           => 'ge-0/0/15.0',
                        IFDESCR          => 'ge-0/0/15.0',
                        IFTYPE           => '53',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578486224) 182 days, 16:41:02.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '5712789',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '723121448',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '70:f3:95:19:32:39',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '534',
                        IFNAME           => 'ge-0/0/16',
                        IFDESCR          => 'ge-0/0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:90',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '535',
                        IFNAME           => 'ge-0/0/16.0',
                        IFDESCR          => 'ge-0/0/16.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:90',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '536',
                        IFNAME           => 'ge-0/0/17',
                        IFDESCR          => 'ge-0/0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:91',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1544196424) 178 days, 17:26:04.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '514989432',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2004357564',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '537',
                        IFNAME           => 'ge-0/0/17.0',
                        IFDESCR          => 'ge-0/0/17.0',
                        IFTYPE           => '53',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:91',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1544196424) 178 days, 17:26:04.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '12390212',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1024363386',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '70:f3:95:1b:84:bc',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '538',
                        IFNAME           => 'ge-0/0/18',
                        IFDESCR          => 'ge-0/0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:92',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(958677754) 110 days, 22:59:37.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1493202',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '559200749',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '539',
                        IFNAME           => 'ge-0/0/18.0',
                        IFDESCR          => 'ge-0/0/18.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:92',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(958677754) 110 days, 22:59:37.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '435817132',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '540',
                        IFNAME           => 'ge-0/0/19',
                        IFDESCR          => 'ge-0/0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:93',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '541',
                        IFNAME           => 'ge-0/0/19.0',
                        IFDESCR          => 'ge-0/0/19.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:93',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '542',
                        IFNAME           => 'ge-0/0/20',
                        IFDESCR          => 'ge-0/0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:94',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578927064) 182 days, 17:54:30.64',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '951730651',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3733951690',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '543',
                        IFNAME           => 'ge-0/0/20.0',
                        IFDESCR          => 'ge-0/0/20.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:94',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578927064) 182 days, 17:54:30.64',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2249453',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '952648962',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '70:f3:95:19:29:db',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '544',
                        IFNAME           => 'ge-0/0/21',
                        IFDESCR          => 'ge-0/0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:95',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578418614) 182 days, 16:29:46.14',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '630699913',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4030961043',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '545',
                        IFNAME           => 'ge-0/0/21.0',
                        IFDESCR          => 'ge-0/0/21.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:95',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578418614) 182 days, 16:29:46.14',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '114948',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '151247500',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:19:d1:79:ac:5b',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '546',
                        IFNAME           => 'ge-0/0/22',
                        IFDESCR          => 'ge-0/0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:96',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '547',
                        IFNAME           => 'ge-0/0/22.0',
                        IFDESCR          => 'ge-0/0/22.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:96',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '548',
                        IFNAME           => 'ge-0/0/23',
                        IFDESCR          => 'ge-0/0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:97',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '549',
                        IFNAME           => 'ge-0/0/23.0',
                        IFDESCR          => 'ge-0/0/23.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:97',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '550',
                        IFNAME           => 'ge-0/0/24',
                        IFDESCR          => 'ge-0/0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:98',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '551',
                        IFNAME           => 'ge-0/0/24.0',
                        IFDESCR          => 'ge-0/0/24.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:98',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '552',
                        IFNAME           => 'ge-0/0/25',
                        IFDESCR          => 'ge-0/0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:99',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '553',
                        IFNAME           => 'ge-0/0/25.0',
                        IFDESCR          => 'ge-0/0/25.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:99',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '554',
                        IFNAME           => 'ge-0/0/26',
                        IFDESCR          => 'ge-0/0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9a',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1579124494) 182 days, 18:27:24.94',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2253413489',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '580268911',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '555',
                        IFNAME           => 'ge-0/0/26.0',
                        IFDESCR          => 'ge-0/0/26.0',
                        IFTYPE           => '53',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9a',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1579124494) 182 days, 18:27:24.94',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3686909',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '263400955',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:19:d1:01:98:ae',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '556',
                        IFNAME           => 'ge-0/0/27',
                        IFDESCR          => 'ge-0/0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1579123944) 182 days, 18:27:19.44',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3044249961',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3810217102',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '557',
                        IFNAME           => 'ge-0/0/27.0',
                        IFDESCR          => 'ge-0/0/27.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1579123944) 182 days, 18:27:19.44',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '13839122',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '206015125',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '70:f3:95:1b:87:3d',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '558',
                        IFNAME           => 'ge-0/0/28',
                        IFDESCR          => 'ge-0/0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1570984464) 181 days, 19:50:44.64',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '285662439',
                        IFINERRORS       => '10',
                        IFOUTOCTETS      => '3058559542',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '559',
                        IFNAME           => 'ge-0/0/28.0',
                        IFDESCR          => 'ge-0/0/28.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1570984464) 181 days, 19:50:44.64',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '25800',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '201670561',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:1c:c0:5d:56:5f',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '560',
                        IFNAME           => 'ge-0/0/29',
                        IFDESCR          => 'ge-0/0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '561',
                        IFNAME           => 'ge-0/0/29.0',
                        IFDESCR          => 'ge-0/0/29.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9d',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '562',
                        IFNAME           => 'ge-0/0/30',
                        IFDESCR          => 'ge-0/0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '563',
                        IFNAME           => 'ge-0/0/30.0',
                        IFDESCR          => 'ge-0/0/30.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9e',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '564',
                        IFNAME           => 'ge-0/0/31',
                        IFDESCR          => 'ge-0/0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '565',
                        IFNAME           => 'ge-0/0/31.0',
                        IFDESCR          => 'ge-0/0/31.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9f',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '566',
                        IFNAME           => 'ge-0/0/32',
                        IFDESCR          => 'ge-0/0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '567',
                        IFNAME           => 'ge-0/0/32.0',
                        IFDESCR          => 'ge-0/0/32.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a0',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '568',
                        IFNAME           => 'ge-0/0/33',
                        IFDESCR          => 'ge-0/0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a1',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1579011084) 182 days, 18:08:30.84',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2905938019',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2493025772',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '569',
                        IFNAME           => 'ge-0/0/33.0',
                        IFDESCR          => 'ge-0/0/33.0',
                        IFTYPE           => '53',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a1',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1579011084) 182 days, 18:08:30.84',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '9569516',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '564930997',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '1c:6f:65:0b:cf:67',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '570',
                        IFNAME           => 'ge-0/0/34',
                        IFDESCR          => 'ge-0/0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a2',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '571',
                        IFNAME           => 'ge-0/0/34.0',
                        IFDESCR          => 'ge-0/0/34.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a2',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '572',
                        IFNAME           => 'ge-0/0/35',
                        IFDESCR          => 'ge-0/0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a3',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1390704494) 160 days, 23:04:04.94',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '5504522',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '666800395',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '573',
                        IFNAME           => 'ge-0/0/35.0',
                        IFDESCR          => 'ge-0/0/35.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a3',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1390704494) 160 days, 23:04:04.94',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '105099',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1021799248',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '574',
                        IFNAME           => 'ge-0/0/36',
                        IFDESCR          => 'ge-0/0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a4',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '575',
                        IFNAME           => 'ge-0/0/36.0',
                        IFDESCR          => 'ge-0/0/36.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a4',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '576',
                        IFNAME           => 'ge-0/0/37',
                        IFDESCR          => 'ge-0/0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a5',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1442498948) 166 days, 22:56:29.48',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '28250947',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '485268381',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '577',
                        IFNAME           => 'ge-0/0/37.0',
                        IFDESCR          => 'ge-0/0/37.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a5',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1442498948) 166 days, 22:56:29.48',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '129766',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1742789',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '578',
                        IFNAME           => 'ge-0/0/38',
                        IFDESCR          => 'ge-0/0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a6',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1086769174) 125 days, 18:48:11.74',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '47896873',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '771874861',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '579',
                        IFNAME           => 'ge-0/0/38.0',
                        IFDESCR          => 'ge-0/0/38.0',
                        IFTYPE           => '53',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a6',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1086769174) 125 days, 18:48:11.74',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '153752',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '207932553',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '580',
                        IFNAME           => 'ge-0/0/39',
                        IFDESCR          => 'ge-0/0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a7',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1207397316) 139 days, 17:52:53.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2340866',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3301053918',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '581',
                        IFNAME           => 'ge-0/0/39.0',
                        IFDESCR          => 'ge-0/0/39.0',
                        IFTYPE           => '53',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a7',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1207397316) 139 days, 17:52:53.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '36715',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '756967915',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '582',
                        IFNAME           => 'ge-0/0/40',
                        IFDESCR          => 'ge-0/0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a8',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '583',
                        IFNAME           => 'ge-0/0/40.0',
                        IFDESCR          => 'ge-0/0/40.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a8',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '584',
                        IFNAME           => 'ge-0/0/41',
                        IFDESCR          => 'ge-0/0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a9',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '585',
                        IFNAME           => 'ge-0/0/41.0',
                        IFDESCR          => 'ge-0/0/41.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a9',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '586',
                        IFNAME           => 'ge-0/0/42',
                        IFDESCR          => 'ge-0/0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:aa',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '587',
                        IFNAME           => 'ge-0/0/42.0',
                        IFDESCR          => 'ge-0/0/42.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:aa',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '588',
                        IFNAME           => 'ge-0/0/43',
                        IFDESCR          => 'ge-0/0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ab',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '589',
                        IFNAME           => 'ge-0/0/43.0',
                        IFDESCR          => 'ge-0/0/43.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ab',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '590',
                        IFNAME           => 'ge-0/0/44',
                        IFDESCR          => 'ge-0/0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ac',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '591',
                        IFNAME           => 'ge-0/0/44.0',
                        IFDESCR          => 'ge-0/0/44.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ac',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '592',
                        IFNAME           => 'ge-0/0/45',
                        IFDESCR          => 'ge-0/0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ad',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1574449874) 182 days, 5:28:18.74',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2047226430',
                        IFINERRORS       => '4',
                        IFOUTOCTETS      => '3415014528',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '593',
                        IFNAME           => 'ge-0/0/45.0',
                        IFDESCR          => 'ge-0/0/45.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ad',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1574449874) 182 days, 5:28:18.74',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '386668',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '14671618',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '594',
                        IFNAME           => 'ge-0/0/46',
                        IFDESCR          => 'ge-0/0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ae',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1554279644) 179 days, 21:26:36.44',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '4080782095',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '961673912',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '595',
                        IFNAME           => 'ge-0/0/46.0',
                        IFDESCR          => 'ge-0/0/46.0',
                        IFTYPE           => '53',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ae',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1554279644) 179 days, 21:26:36.44',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '7598296',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1023840701',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:19:d1:04:c2:29',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '596',
                        IFNAME           => 'ge-0/0/47',
                        IFDESCR          => 'ge-0/0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:af',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1512743176) 175 days, 2:03:51.76',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2316772724',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3200792434',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '597',
                        IFNAME           => 'ge-0/0/47.0',
                        IFDESCR          => 'ge-0/0/47.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:af',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1512743176) 175 days, 2:03:51.76',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1781000',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '60956226',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '598',
                        IFNAME           => 'vlan.0',
                        IFDESCR          => 'vlan.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '192.168.100.31',
                        MAC              => '2c:6b:f5:9b:48:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(668) 0:00:06.68',
                        IFINOCTETS       => '593793507',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '762086845',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '599',
                        IFNAME           => 'ge-1/0/0',
                        IFDESCR          => 'ge-1/0/0',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:81',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450883) 83 days, 0:55:08.83',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2135333642',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2251187669',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '600',
                        IFNAME           => 'ge-1/0/1',
                        IFDESCR          => 'ge-1/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:81',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450534) 83 days, 0:55:05.34',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '601',
                        IFNAME           => 'ge-1/0/2',
                        IFDESCR          => 'ge-1/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:82',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1518159237) 175 days, 17:06:32.37',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1298647280',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2001027785',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '602',
                        IFNAME           => 'ge-1/0/3',
                        IFDESCR          => 'ge-1/0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:83',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450566) 83 days, 0:55:05.66',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '603',
                        IFNAME           => 'ge-1/0/4',
                        IFDESCR          => 'ge-1/0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:84',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1579371027) 182 days, 19:08:30.27',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '269999393',
                        IFINERRORS       => '12',
                        IFOUTOCTETS      => '1396723681',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '604',
                        IFNAME           => 'ge-1/0/5',
                        IFDESCR          => 'ge-1/0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:85',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450580) 83 days, 0:55:05.80',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '605',
                        IFNAME           => 'ge-1/0/6',
                        IFDESCR          => 'ge-1/0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:86',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1303083182) 150 days, 19:40:31.82',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3005189',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '74508102',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '606',
                        IFNAME           => 'ge-1/0/7',
                        IFDESCR          => 'ge-1/0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:87',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450594) 83 days, 0:55:05.94',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '607',
                        IFNAME           => 'ge-1/0/8',
                        IFDESCR          => 'ge-1/0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:88',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450596) 83 days, 0:55:05.96',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '608',
                        IFNAME           => 'ge-1/0/9',
                        IFDESCR          => 'ge-1/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:89',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1380784997) 159 days, 19:30:49.97',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '17126975',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '816666142',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '609',
                        IFNAME           => 'ge-1/0/10',
                        IFDESCR          => 'ge-1/0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450601) 83 days, 0:55:06.01',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '610',
                        IFNAME           => 'ge-1/0/11',
                        IFDESCR          => 'ge-1/0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1564125317) 181 days, 0:47:33.17',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1788658958',
                        IFINERRORS       => '18',
                        IFOUTOCTETS      => '792282323',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '611',
                        IFNAME           => 'ge-1/0/12',
                        IFDESCR          => 'ge-1/0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1573444441) 182 days, 2:40:44.41',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '226432893',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1621258788',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '612',
                        IFNAME           => 'ge-1/0/13',
                        IFDESCR          => 'ge-1/0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450613) 83 days, 0:55:06.13',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '613',
                        IFNAME           => 'ge-1/0/14',
                        IFDESCR          => 'ge-1/0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717452073) 83 days, 0:55:20.73',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3939751043',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '287056337',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '614',
                        IFNAME           => 'ge-1/0/15',
                        IFDESCR          => 'ge-1/0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450621) 83 days, 0:55:06.21',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '615',
                        IFNAME           => 'ge-1/0/16',
                        IFDESCR          => 'ge-1/0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:90',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450628) 83 days, 0:55:06.28',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '616',
                        IFNAME           => 'ge-1/0/17',
                        IFDESCR          => 'ge-1/0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:91',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450630) 83 days, 0:55:06.30',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '617',
                        IFNAME           => 'ge-1/0/18',
                        IFDESCR          => 'ge-1/0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:92',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450633) 83 days, 0:55:06.33',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '618',
                        IFNAME           => 'ge-1/0/19',
                        IFDESCR          => 'ge-1/0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:93',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1579481427) 182 days, 19:26:54.27',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3300639445',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3578805041',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '619',
                        IFNAME           => 'ge-1/0/20',
                        IFDESCR          => 'ge-1/0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:94',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578881557) 182 days, 17:46:55.57',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2439052536',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3399781437',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '620',
                        IFNAME           => 'ge-1/0/21',
                        IFDESCR          => 'ge-1/0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:95',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450646) 83 days, 0:55:06.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '621',
                        IFNAME           => 'ge-1/0/22',
                        IFDESCR          => 'ge-1/0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:96',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450654) 83 days, 0:55:06.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '622',
                        IFNAME           => 'ge-1/0/23',
                        IFDESCR          => 'ge-1/0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:97',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450655) 83 days, 0:55:06.55',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '623',
                        IFNAME           => 'ge-1/0/24',
                        IFDESCR          => 'ge-1/0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:98',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1573311367) 182 days, 2:18:33.67',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2028846815',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2506332140',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '624',
                        IFNAME           => 'ge-1/0/25',
                        IFDESCR          => 'ge-1/0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:99',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578898697) 182 days, 17:49:46.97',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '884165878',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2549919197',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '625',
                        IFNAME           => 'ge-1/0/26',
                        IFDESCR          => 'ge-1/0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1277650841) 147 days, 21:01:48.41',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3793046',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '56162371',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '626',
                        IFNAME           => 'ge-1/0/27',
                        IFDESCR          => 'ge-1/0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450674) 83 days, 0:55:06.74',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '627',
                        IFNAME           => 'ge-1/0/28',
                        IFDESCR          => 'ge-1/0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(975037268) 112 days, 20:26:12.68',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '4380162',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '12228656',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '628',
                        IFNAME           => 'ge-1/0/29',
                        IFDESCR          => 'ge-1/0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1579233077) 182 days, 18:45:30.77',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '563115901',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3111134514',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '629',
                        IFNAME           => 'ge-1/0/30',
                        IFDESCR          => 'ge-1/0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450694) 83 days, 0:55:06.94',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '630',
                        IFNAME           => 'ge-1/0/31',
                        IFDESCR          => 'ge-1/0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450701) 83 days, 0:55:07.01',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '631',
                        IFNAME           => 'ge-1/0/32',
                        IFDESCR          => 'ge-1/0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450705) 83 days, 0:55:07.05',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '632',
                        IFNAME           => 'ge-1/0/33',
                        IFDESCR          => 'ge-1/0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a1',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1564340617) 181 days, 1:23:26.17',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1037085341',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '746979838',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '633',
                        IFNAME           => 'ge-1/0/34',
                        IFDESCR          => 'ge-1/0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a2',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450710) 83 days, 0:55:07.10',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '634',
                        IFNAME           => 'ge-1/0/35',
                        IFDESCR          => 'ge-1/0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a3',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450713) 83 days, 0:55:07.13',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '635',
                        IFNAME           => 'ge-1/0/36',
                        IFDESCR          => 'ge-1/0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a4',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450715) 83 days, 0:55:07.15',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '636',
                        IFNAME           => 'ge-1/0/37',
                        IFDESCR          => 'ge-1/0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a5',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1563250557) 180 days, 22:21:45.57',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '585874889',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1068326842',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '637',
                        IFNAME           => 'ge-1/0/38',
                        IFDESCR          => 'ge-1/0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a6',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450727) 83 days, 0:55:07.27',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '638',
                        IFNAME           => 'ge-1/0/39',
                        IFDESCR          => 'ge-1/0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a7',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578926177) 182 days, 17:54:21.77',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '120478821',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3329871698',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '639',
                        IFNAME           => 'ge-1/0/40',
                        IFDESCR          => 'ge-1/0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889630237) 102 days, 23:11:42.37',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '21191446',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4128639709',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '640',
                        IFNAME           => 'ge-1/0/41',
                        IFDESCR          => 'ge-1/0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a9',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1579225957) 182 days, 18:44:19.57',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3728173756',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1765117400',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '641',
                        IFNAME           => 'ge-1/0/42',
                        IFDESCR          => 'ge-1/0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:aa',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1547175007) 179 days, 1:42:30.07',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '4128186084',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '266988943',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '642',
                        IFNAME           => 'ge-1/0/43',
                        IFDESCR          => 'ge-1/0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ab',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1562377137) 180 days, 19:56:11.37',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '23818785',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '33757331',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '643',
                        IFNAME           => 'ge-1/0/44',
                        IFDESCR          => 'ge-1/0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ac',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450752) 83 days, 0:55:07.52',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '644',
                        IFNAME           => 'ge-1/0/45',
                        IFDESCR          => 'ge-1/0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ad',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450753) 83 days, 0:55:07.53',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '645',
                        IFNAME           => 'ge-1/0/46',
                        IFDESCR          => 'ge-1/0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ae',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450759) 83 days, 0:55:07.59',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '646',
                        IFNAME           => 'ge-1/0/47',
                        IFDESCR          => 'ge-1/0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:af',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450764) 83 days, 0:55:07.64',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '647',
                        IFNAME           => 'ge-1/0/1.0',
                        IFDESCR          => 'ge-1/0/1.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:81',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450537) 83 days, 0:55:05.37',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '648',
                        IFNAME           => 'vlan',
                        IFDESCR          => 'vlan',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '2c:6b:f5:9b:48:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(668) 0:00:06.68',
                        IFINOCTETS       => '593798147',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '835095128',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '649',
                        IFNAME           => 'xe-0/1/0',
                        IFDESCR          => 'xe-0/1/0',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717514804) 83 days, 1:05:48.04',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2680710288',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1448828997',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '650',
                        IFNAME           => 'xe-0/1/0.0',
                        IFDESCR          => 'xe-0/1/0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717514804) 83 days, 1:05:48.04',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '10540',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '164679696',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '653',
                        IFNAME           => 'ge-1/0/10.0',
                        IFDESCR          => 'ge-1/0/10.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8a',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450648) 83 days, 0:55:06.48',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '654',
                        IFNAME           => 'ae0',
                        IFDESCR          => 'ae0',
                        IFTYPE           => '161',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(783398403) 90 days, 16:06:24.03',
                        IFINOCTETS       => '1587472469',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2323266978',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '655',
                        IFNAME           => 'ae1',
                        IFDESCR          => 'ae1',
                        IFTYPE           => '161',
                        IFSPEED          => '2000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:81',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1401320591) 162 days, 4:33:25.91',
                        IFINOCTETS       => '717973288',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3469730016',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '656',
                        IFNAME           => 'ae2',
                        IFDESCR          => 'ae2',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:82',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5836) 0:00:58.36',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '657',
                        IFNAME           => 'ae3',
                        IFDESCR          => 'ae3',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:83',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5837) 0:00:58.37',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '658',
                        IFNAME           => 'ae4',
                        IFDESCR          => 'ae4',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:84',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(5837) 0:00:58.37',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '659',
                        IFNAME           => 'ae0.0',
                        IFDESCR          => 'ae0.0',
                        IFTYPE           => '161',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(783398403) 90 days, 16:06:24.03',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '890130265',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:01:30:12:80:80',
                                    '00:01:30:12:91:80',
                                    '00:01:30:12:a6:c0',
                                    '00:01:30:12:a6:d0',
                                    '00:01:30:12:a8:30',
                                    '00:01:30:fd:05:f0',
                                    '00:0b:60:b0:b0:1b',
                                    '00:0f:34:aa:ee:1b',
                                    '00:10:db:ff:10:02',
                                    '00:02:b3:31:fa:f9',
                                    '00:e0:86:11:1a:27',
                                    '00:e0:86:11:1d:b0',
                                    '00:e0:86:12:d9:6f',
                                    '00:e0:2b:00:00:01',
                                    '00:1b:ec:00:04:09',
                                    '00:1d:09:68:40:c8',
                                    '00:1e:c9:da:3b:fc',
                                    '00:1e:c9:f2:c0:81',
                                    '00:1e:c9:f2:ca:8d',
                                    '00:1e:4f:1f:3c:44',
                                    '00:1e:4f:1f:57:4b',
                                    '00:1e:4f:31:a9:a0',
                                    '00:1e:4f:31:ab:88',
                                    '00:1e:4f:31:ab:ab',
                                    '00:1e:4f:32:e1:d3',
                                    '00:1e:4f:32:e4:69',
                                    '00:1e:4f:32:f7:9e',
                                    '00:1e:4f:33:14:d1',
                                    '00:1e:4f:33:07:e1',
                                    '00:1e:4f:41:d0:a4',
                                    '00:1e:4f:41:d8:69',
                                    '00:1e:4f:41:dc:7e',
                                    '00:1e:4f:41:dd:53',
                                    '00:1e:4f:41:e2:8c',
                                    '00:20:4a:0b:24:06',
                                    '00:20:4a:b1:3d:da',
                                    '00:20:4a:08:72:d2',
                                    '00:20:4a:08:73:01',
                                    '00:20:4a:08:ac:f6',
                                    '00:20:4a:08:ac:56',
                                    '00:20:4a:08:e1:6d',
                                    '00:20:4a:08:60:c6',
                                    '00:22:19:7b:be:11',
                                    '00:22:19:7b:be:da',
                                    '00:22:19:7b:bf:e6',
                                    '00:22:19:85:d9:70',
                                    '00:22:19:63:0f:55',
                                    '00:23:ae:fb:fd:89',
                                    '00:23:ae:fb:fd:b0',
                                    '00:23:ae:fc:00:cd',
                                    '00:23:ae:fc:00:d3',
                                    '00:23:ae:fc:00:d8',
                                    '00:23:ae:fe:9c:e0',
                                    '00:23:ae:fe:a9:e0',
                                    '00:04:96:18:6e:93',
                                    '00:04:96:18:5b:61',
                                    '00:04:96:1c:6f:f0',
                                    '00:04:96:1c:71:00',
                                    '00:04:96:1f:8f:0f',
                                    '00:04:96:1f:91:50',
                                    '00:04:96:27:93:f9',
                                    '00:04:96:04:58:20',
                                    '00:04:96:34:69:ab',
                                    '00:04:96:34:69:b1',
                                    '00:04:96:34:89:5c',
                                    '00:04:96:34:8b:82',
                                    '00:04:96:34:8b:f8',
                                    '00:04:96:34:8c:10',
                                    '00:04:96:34:8c:11',
                                    '00:04:96:34:92:82',
                                    '00:04:96:34:92:31',
                                    '00:04:96:34:92:47',
                                    '00:04:96:34:af:ae',
                                    '00:04:96:35:77:14',
                                    '00:04:96:35:77:16',
                                    '00:04:96:35:90:67',
                                    '00:04:96:35:90:4d',
                                    '00:04:96:35:93:b9',
                                    '00:04:96:35:ad:e4',
                                    '00:04:96:35:c8:14',
                                    '00:04:96:35:c8:1f',
                                    '00:04:96:35:fa:ae',
                                    '00:04:96:35:fa:b1',
                                    '00:04:96:08:1e:70',
                                    '00:04:96:09:07:00',
                                    '00:05:1e:08:f8:20',
                                    '00:05:1e:08:f9:12',
                                    '00:05:1e:09:21:2d',
                                    '00:05:1e:09:21:50',
                                    '00:05:33:ec:d7:ee',
                                    '00:05:33:f5:6b:fd',
                                    '00:05:33:f5:49:ae',
                                    '00:05:33:43:78:2d',
                                    '00:05:33:54:16:aa',
                                    '00:50:56:bc:31:8a',
                                    '00:50:56:50:30:a0',
                                    '00:50:56:50:30:a2',
                                    '00:50:56:50:38:30',
                                    '00:50:56:50:38:32',
                                    '64:87:88:b7:a5:c1',
                                    '64:87:88:5c:2f:f7',
                                    '64:b9:e8:c0:b7:04',
                                    '78:fe:3d:df:c1:82',
                                    '78:fe:3d:36:f7:01',
                                    '84:2b:2b:71:30:f3',
                                    'ac:4b:c8:23:0b:01',
                                    'b0:a8:6e:86:08:41',
                                    'b0:a8:6e:9a:2c:c1',
                                    'b0:a8:6e:9a:2d:41',
                                    'b0:a8:6e:9a:2f:81',
                                    'b0:a8:6e:9a:39:41',
                                    '02:04:96:35:f9:24',
                                    'd0:d0:fd:ab:1a:b5',
                                    'd0:d0:fd:ab:26:35',
                                    'd0:d0:fd:ac:ae:b5',
                                    'e4:1f:13:76:ca:35',
                                    'e4:1f:13:76:cd:e9',
                                    '18:03:73:0a:29:c2',
                                    '18:03:73:09:ae:8c',
                                    'f0:4d:a2:6e:cf:89',
                                    'f0:4d:a2:6e:d3:e6',
                                    'f0:4d:a2:6e:d4:96',
                                    'f0:4d:a2:6e:d4:1c',
                                    'f0:4d:a2:6f:03:39',
                                    'f0:4d:a2:6f:03:5b',
                                    'f0:4d:a2:d9:bc:3f',
                                    '28:c0:da:3e:36:40',
                                    '58:35:d9:95:38:7e',
                                    '5c:5e:ab:66:60:80',
                                    '5c:5e:ab:6b:ec:01',
                                    '5c:5e:ab:78:0e:80',
                                    '00:00:aa:98:5a:72',
                                    '00:00:aa:ab:02:ba',
                                    '00:00:aa:f6:d7:bd',
                                    '00:00:5e:00:01:01',
                                    '00:14:38:a2:c7:95',
                                    '00:17:08:84:f0:38',
                                    '00:22:f3:89:1f:1e',
                                    '68:b5:99:40:8d:62',
                                    '6c:3b:e5:04:b8:da',
                                    '78:ac:c0:81:2b:9e',
                                    '78:e3:b5:f7:cd:e5',
                                    'b4:99:ba:c3:65:45',
                                    '00:00:5e:00:01:01',
                                    '00:0c:f1:cd:60:da',
                                    '00:0f:fe:ce:b0:6c',
                                    '00:11:43:7d:c6:da',
                                    '00:12:3f:76:d3:0c',
                                    '00:13:72:1a:72:ba',
                                    '00:13:72:39:f1:22',
                                    '00:15:17:2b:0f:64',
                                    '00:16:76:91:25:7c',
                                    '00:16:cb:9b:d8:84',
                                    '00:16:d3:53:c3:46',
                                    '00:18:8b:0d:35:c5',
                                    '00:19:0f:0b:18:e9',
                                    '00:1a:80:d5:a0:ba',
                                    '00:1a:a0:c1:8c:36',
                                    '00:1a:a0:cd:46:8a',
                                    '00:1a:a0:ea:94:19',
                                    '00:1c:c0:7f:3e:dc',
                                    '00:1c:c0:ed:8f:6a',
                                    '00:1c:c0:ed:96:87',
                                    '00:1c:c0:f1:f6:4c',
                                    '00:1c:c0:fc:40:00',
                                    '00:1c:c0:fe:a8:05',
                                    '00:1d:ba:c1:08:49',
                                    '00:1e:c2:13:b3:1e',
                                    '00:1e:c9:2c:7d:c3',
                                    '00:1e:4f:de:4f:6f',
                                    '00:1f:16:15:d6:b8',
                                    '00:1f:f3:56:c8:74',
                                    '00:21:9b:64:91:a6',
                                    '00:21:9b:7a:75:78',
                                    '00:21:9b:3e:3d:a4',
                                    '00:22:19:15:ea:40',
                                    '00:22:19:16:a8:fe',
                                    '00:22:19:1c:1c:c0',
                                    '00:22:19:1e:17:c9',
                                    '00:22:19:1e:18:84',
                                    '00:22:19:1e:19:40',
                                    '00:22:19:07:23:a2',
                                    '00:22:19:08:60:6a',
                                    '00:22:61:03:04:46',
                                    '00:23:ae:0f:6b:17',
                                    '00:24:e8:ba:dd:59',
                                    '00:26:6c:a4:13:4c',
                                    '00:26:9e:2f:2d:84',
                                    '00:26:b9:ed:1f:cd',
                                    '00:08:74:ae:d5:71',
                                    '6c:3b:e5:27:07:30',
                                    '70:f3:95:1b:85:66',
                                    '78:ac:c0:81:2b:9e',
                                    '78:ac:c0:a0:ab:5e',
                                    '78:ac:c0:b8:6c:1c',
                                    '80:c1:6e:e6:bc:2f',
                                    '80:c1:6e:ec:96:4e',
                                    '80:c1:6e:fd:13:e1',
                                    '80:c1:6e:fd:13:eb',
                                    '80:ee:73:41:a4:2d',
                                    '84:2b:2b:9e:f4:fb',
                                    '9c:eb:e8:00:96:2e',
                                    '10:60:4b:68:0a:e2',
                                    '10:60:4b:85:4e:d8',
                                    'a0:b3:cc:f7:26:3d',
                                    'a0:b3:cc:f9:16:42',
                                    'ac:16:2d:46:3a:b5',
                                    'b4:b5:2f:bd:b2:bd',
                                    'b4:b5:2f:bf:df:ba',
                                    'b8:ac:6f:6e:92:cf',
                                    'bc:30:5b:99:77:36',
                                    'c8:0a:a9:3a:a5:43',
                                    'c8:2a:14:0f:96:16',
                                    'cc:52:af:41:33:38',
                                    'd4:85:64:b8:c1:c6',
                                    'd4:85:64:b8:c5:e2',
                                    'd4:85:64:1b:52:5d',
                                    'd4:be:d9:3d:3a:3f',
                                    'd4:3d:7e:1f:c4:d3',
                                    'f0:4d:a2:25:d3:64',
                                    'f0:4d:a2:28:51:a4',
                                    'f0:4d:a2:28:51:d2',
                                    '1c:6f:65:0e:90:05',
                                    '1c:6f:65:0f:e2:08',
                                    '1c:6f:65:09:58:9a',
                                    '20:6a:8a:16:d2:81',
                                    '24:be:05:27:32:86',
                                    '2c:27:d7:2a:e2:40',
                                    '2c:27:d7:35:cf:01',
                                    '2c:41:38:92:28:24',
                                    '2c:41:38:93:aa:df',
                                    '3c:07:54:2d:a8:95',
                                    '08:2e:5f:0e:a8:aa',
                                    '00:0c:29:86:0c:c0',
                                    '00:0c:29:b9:6d:7d',
                                    '00:0c:29:ca:32:91',
                                    '00:0c:29:2b:12:ce',
                                    '00:0c:29:56:6b:7a',
                                    '00:13:20:e4:0a:53',
                                    '00:16:76:4a:dd:70',
                                    '00:17:08:87:8e:28',
                                    '00:19:d1:7a:5d:68',
                                    '00:19:d1:ae:27:a6',
                                    '00:19:d1:17:b0:2c',
                                    '00:1a:a0:65:6c:c0',
                                    '00:1a:a0:65:6e:cc',
                                    '00:1c:c0:7f:3c:67',
                                    '00:1c:c0:7f:3d:0e',
                                    '00:1c:c0:8f:2b:f1',
                                    '00:1c:c0:8f:45:0c',
                                    '00:1c:c0:8f:46:67',
                                    '00:1c:c0:8f:46:69',
                                    '00:1c:c0:8f:46:74',
                                    '00:1c:c0:8f:46:14',
                                    '00:1c:c0:9b:30:f6',
                                    '00:1c:c0:ed:15:0d',
                                    '00:1c:c0:ed:15:8c',
                                    '00:1c:c0:f0:88:19',
                                    '00:1c:c0:f0:f9:52',
                                    '00:1c:c0:f1:f7:ae',
                                    '00:1c:c0:f8:1d:a7',
                                    '00:1c:c0:f8:1d:c6',
                                    '00:1c:c0:1b:04:a3',
                                    '00:1e:4f:c0:59:04',
                                    '00:1e:4f:32:ea:9a',
                                    '00:23:ae:92:f7:90',
                                    '00:25:64:94:49:b1',
                                    '00:25:64:bd:f1:a0',
                                    '00:27:0e:00:9a:d2',
                                    '00:27:0e:01:25:67',
                                    '00:27:0e:01:25:75',
                                    '00:27:0e:01:25:7a',
                                    '00:27:0e:01:25:84',
                                    '00:27:0e:01:28:5a',
                                    '00:27:0e:01:29:2d',
                                    '00:27:0e:02:64:91',
                                    '00:27:0e:02:56:22',
                                    '00:27:0e:02:56:40',
                                    '00:27:0e:02:56:57',
                                    '00:50:56:bc:00:48',
                                    '00:50:56:bc:31:89',
                                    '00:50:56:50:30:b8',
                                    '00:50:56:50:30:ba',
                                    '00:50:56:51:4d:58',
                                    '00:50:56:51:4d:5a',
                                    '70:f3:95:13:d4:d3',
                                    '70:f3:95:13:d5:a2',
                                    '70:f3:95:13:d6:54',
                                    '70:f3:95:19:1c:47',
                                    '70:f3:95:19:2a:3a',
                                    '70:f3:95:1b:84:cd',
                                    '84:2b:2b:9d:79:cc',
                                    '10:78:d2:c3:df:fc',
                                    'ac:16:2d:37:1b:c0',
                                    'cc:52:af:41:26:63',
                                    'cc:52:af:41:34:5f',
                                    '1c:6f:65:0b:cc:d9',
                                    '1c:6f:65:0d:f0:06',
                                    '1c:6f:65:0d:f8:10',
                                    '1c:6f:65:0d:fc:b2',
                                    '1c:6f:65:0f:e1:2e',
                                    '44:37:e6:62:26:f7',
                                    '44:37:e6:63:4c:eb',
                                    '00:0c:f1:e2:7a:aa',
                                    '00:0c:f1:e2:7a:4a',
                                    '00:0c:f1:e2:7b:8d',
                                    '00:0c:f1:e8:bd:3a',
                                    '00:0c:f1:e8:bd:06',
                                    '00:13:20:4a:d7:44',
                                    '00:16:76:86:64:41',
                                    '00:11:43:a2:83:c1',
                                    '00:11:43:a2:d3:e5',
                                    '00:1d:09:2b:67:5e',
                                    '00:60:ef:04:7b:a9',
                                    '00:60:ef:04:7b:38',
                                    '00:19:d1:79:ff:9d',
                                    '00:80:77:ec:d6:f9',
                                    '00:9c:02:07:8d:ed',
                                    '00:e0:81:d1:26:14',
                                    '00:17:08:91:da:f1',
                                    '00:03:81:82:3e:45',
                                    '00:03:2d:1c:e3:8b',
                                    '00:03:2d:1c:e3:de',
                                    '00:03:2d:1c:e4:51',
                                    '00:1f:29:20:1e:5c',
                                    '00:1f:29:31:8f:02',
                                    '00:20:6b:7a:68:84',
                                    '00:20:6b:7a:88:78',
                                    '00:20:6b:7a:88:7b',
                                    '00:20:6b:7a:d1:00',
                                    '00:20:6b:7a:d1:71',
                                    '00:20:6b:7a:d2:9e',
                                    '00:20:6b:7a:d2:4b',
                                    '00:20:6b:7a:f0:5b',
                                    '00:20:6b:7a:61:f1',
                                    '00:20:6b:7a:63:3c',
                                    '00:20:6b:7c:c3:24',
                                    '00:20:6b:7c:ef:75',
                                    '00:20:6b:7d:08:de',
                                    '00:20:6b:7e:e5:a8',
                                    '00:20:6b:8f:a5:c4',
                                    '00:20:4a:66:3e:02',
                                    '00:21:5a:8a:d9:79',
                                    '00:23:7d:70:d9:75',
                                    '00:23:7d:7d:e0:d6',
                                    '00:23:7d:7d:2c:4b',
                                    '00:23:7d:81:77:61',
                                    '00:23:7d:85:a4:41',
                                    '00:25:b3:ea:7d:11',
                                    '00:25:b3:ea:7d:ff',
                                    '00:25:b3:fa:d3:49',
                                    '00:04:00:b9:55:01',
                                    '00:04:00:2d:25:fd',
                                    '78:e7:d1:a3:1f:6f',
                                    'ac:16:2d:39:c4:3a',
                                    'c8:cb:b8:60:89:fb',
                                    'd4:85:64:1b:72:a1',
                                    'd4:85:64:1b:2e:9b',
                                    'd4:85:64:1f:4c:49',
                                    'd4:85:64:41:60:52',
                                    'f4:ce:46:3c:72:b6',
                                    '1c:c1:de:82:2a:e3',
                                    '1c:c1:de:82:3a:75',
                                    '1c:c1:de:83:7e:ab',
                                    '2c:76:8a:3f:b6:bf',
                                    '3c:4a:92:b4:06:17',
                                    '00:19:d1:a0:53:26',
                                    '00:1c:c0:8e:71:05',
                                    '00:27:0e:01:2b:bd',
                                    '64:b9:e8:d2:34:e2',
                                    '70:f3:95:1b:85:43',
                                    '70:f3:95:1b:86:16',
                                    '70:f3:95:1b:87:3b',
                                    '78:2b:cb:7e:64:f2',
                                    '84:2b:2b:9d:8a:ef',
                                    'cc:52:af:4c:22:32',
                                    'cc:52:af:4c:28:bf',
                                    '1c:6f:65:0b:d0:02',
                                    '1c:6f:65:0e:51:6b',
                                    '1c:6f:65:0f:e2:42',
                                    '00:50:56:bc:28:f0',
                                    '00:50:56:51:4d:58',
                                    '00:50:56:51:4d:5a',
                                    '70:f3:95:19:23:77',
                                    '70:f3:95:19:28:a7',
                                    '70:f3:95:1b:86:65',
                                    '70:f3:95:1b:87:45',
                                    '70:f3:95:1b:87:50',
                                    '70:f3:95:1b:87:54',
                                    'cc:52:af:4c:23:23',
                                    '1c:6f:65:0d:f2:20',
                                    '40:2c:f4:eb:d1:2d',
                                    '40:2c:f4:eb:d8:b3',
                                    '08:00:27:55:37:09',
                                    '00:1c:c0:8e:71:21',
                                    '1c:6f:65:0d:e1:16',
                                    '1c:6f:65:0d:e1:43',
                                    '1c:6f:65:0d:ea:82',
                                    '1c:6f:65:0d:eb:c5',
                                    '1c:6f:65:0d:eb:d0',
                                    '1c:6f:65:0d:fc:d3',
                                    '1c:6f:65:0d:fc:fa',
                                    '1c:6f:65:0d:fd:0d',
                                    '1c:6f:65:0e:4b:de',
                                    '08:00:27:77:82:6f',
                                    '08:00:27:80:d4:a0',
                                    '08:00:27:88:d5:81',
                                    '08:00:27:8d:37:d9',
                                    '08:00:27:b8:c3:da',
                                    '08:00:27:b9:00:8f',
                                    '08:00:27:b9:01:96',
                                    '08:00:27:bd:e6:9b',
                                    '08:00:27:bf:7e:31',
                                    '08:00:27:c2:d9:23',
                                    '08:00:27:e8:66:ad',
                                    '08:00:27:31:24:e9',
                                    '08:00:27:3b:71:20',
                                    '08:00:27:41:77:df',
                                    '08:00:27:5d:ae:bd',
                                    '08:00:27:61:76:ed',
                                    '00:1c:c0:9b:31:d1',
                                    '00:27:0e:01:25:fa',
                                    '70:f3:95:1b:85:4c',
                                    '00:13:d4:b8:17:a9',
                                    '00:16:76:86:69:cb',
                                    '00:19:d1:7f:7d:dd',
                                    '00:19:d1:ae:24:94',
                                    '00:1c:c0:90:d8:be',
                                    '00:1c:c0:ee:80:4b',
                                    '00:1c:c0:f8:1d:91',
                                    '00:1c:c0:5e:11:af',
                                    '00:25:64:49:ce:3e',
                                    '00:26:b0:e8:dd:1e',
                                    '00:26:b9:02:f8:16',
                                    '00:26:b9:ed:1f:71',
                                    '84:2b:2b:ad:58:65',
                                    '10:78:d2:c3:e1:6b',
                                    'cc:52:af:41:25:f2',
                                    'd4:3d:7e:1f:c4:2a',
                                    'ec:9a:74:40:a8:99',
                                    'f0:4d:a2:bc:35:18',
                                    '1c:6f:65:00:cc:e3',
                                    '20:c9:d0:29:d8:21',
                                    '24:b6:fd:18:21:f4',
                                    '3c:97:0e:54:44:37',
                                    '58:55:ca:25:35:d5',
                                    '00:1c:c0:fc:f0:8a',
                                    '00:1c:c0:fc:f9:ca',
                                    '00:1c:c0:fc:f9:f3',
                                    '00:1c:c0:fc:fa:0c',
                                    '00:1c:c0:fc:fa:12',
                                    '00:1c:c0:fc:fa:30',
                                    '00:27:0e:02:ed:83',
                                    '10:60:4b:19:b3:0b',
                                    'cc:52:af:4c:27:43',
                                    '1c:6f:65:0e:8c:8f',
                                    '3c:d9:2b:0f:41:19',
                                    '40:2c:f4:eb:fb:d9',
                                    '40:2c:f4:eb:fb:dd',
                                    '40:2c:f4:eb:fb:f8',
                                    '40:2c:f4:eb:fc:67',
                                    '40:2c:f4:eb:fc:77',
                                    '40:2c:f4:eb:fc:7a',
                                    '40:2c:f4:eb:fc:7f',
                                    '40:2c:f4:eb:fc:1f',
                                    '40:2c:f4:eb:fd:17',
                                    '40:2c:f4:eb:fe:ed',
                                    '40:2c:f4:ec:00:0b',
                                    '40:2c:f4:ec:00:80',
                                    '40:2c:f4:ec:00:13',
                                    '40:2c:f4:ec:00:03',
                                    '40:2c:f4:ec:01:90',
                                    '40:2c:f4:ec:01:a7',
                                    '40:2c:f4:ec:01:c3',
                                    '40:2c:f4:ec:01:d9',
                                    '40:2c:f4:ec:01:dc',
                                    '40:2c:f4:ec:01:e1',
                                    '40:2c:f4:ec:01:e9',
                                    '40:2c:f4:ec:01:37',
                                    '40:2c:f4:ec:02:25',
                                    '44:37:e6:91:c6:ba',
                                    '44:37:e6:91:c7:a1',
                                    '44:37:e6:91:c7:a5',
                                    '44:37:e6:92:3a:d4',
                                    '44:37:e6:92:3a:1d',
                                    '44:37:e6:92:3a:61',
                                    '44:37:e6:92:3b:00',
                                    '08:00:27:65:16:eb',
                                    '08:00:27:6f:e0:d2',
                                    '08:00:27:70:5b:3a',
                                    '08:00:27:77:b9:62',
                                    '08:00:27:83:d3:c7',
                                    '08:00:27:88:a7:b2',
                                    '08:00:27:8b:c3:dc',
                                    '08:00:27:8f:99:1d',
                                    '08:00:27:93:d0:3d',
                                    '08:00:27:96:13:e6',
                                    '08:00:27:a4:85:e2',
                                    '08:00:27:a8:ea:ce',
                                    '08:00:27:ab:eb:83',
                                    '08:00:27:ac:71:9b',
                                    '08:00:27:ad:6e:13',
                                    '08:00:27:b8:ff:b0',
                                    '08:00:27:b9:13:7d',
                                    '08:00:27:ca:b0:eb',
                                    '08:00:27:d3:12:39',
                                    '08:00:27:db:9d:69',
                                    '08:00:27:e7:0c:68',
                                    '08:00:27:ea:b3:e0',
                                    '08:00:27:ec:21:cb',
                                    '08:00:27:f0:7f:37',
                                    '08:00:27:fa:f2:b3',
                                    '08:00:27:1a:22:36',
                                    '08:00:27:1c:7d:d0',
                                    '08:00:27:2e:c8:42',
                                    '08:00:27:30:42:4c',
                                    '08:00:27:33:a6:3e',
                                    '08:00:27:37:17:f1',
                                    '08:00:27:40:b2:13',
                                    '08:00:27:40:56:c4',
                                    '08:00:27:48:ff:de',
                                    '08:00:27:4b:70:cf',
                                    '08:00:27:4d:c9:b4',
                                    '08:00:27:53:8c:5b',
                                    '08:00:27:5d:dd:96',
                                    '08:00:27:60:46:4b',
                                    '08:00:27:63:f0:41',
                                    'a8:20:66:0c:e6:2a',
                                    '00:13:20:32:81:47',
                                    '00:16:cb:aa:6d:75',
                                    '00:16:cb:ae:3d:f1',
                                    '00:e0:db:0c:ef:43',
                                    '00:18:51:c7:ad:5f',
                                    '00:1a:a0:ba:96:26',
                                    '00:1a:a0:ba:a1:2c',
                                    '00:1a:a0:36:6d:b3',
                                    '00:1a:a0:36:ac:4d',
                                    '00:1c:c0:e3:6f:13',
                                    '00:1e:4f:f4:2c:d6',
                                    '00:1f:f3:fc:79:e8',
                                    '00:22:19:63:0f:4d',
                                    '00:23:32:2e:80:5d',
                                    '00:25:64:92:7d:88',
                                    '00:25:64:bd:e3:24',
                                    '00:25:64:bd:e6:e7',
                                    '00:25:64:bd:f1:5f',
                                    '00:27:0e:02:f9:9d',
                                    '64:b9:e8:bc:71:c2',
                                    '64:b9:e8:c0:af:d8',
                                    '70:cd:60:f1:fb:d0',
                                    '84:2b:2b:ab:ef:b4',
                                    '84:2b:2b:bc:56:04',
                                    'a8:20:66:1d:64:2b',
                                    'a8:20:66:03:64:2c',
                                    'c4:2c:03:21:ca:b2',
                                    'cc:52:af:41:38:5e',
                                    'f0:4d:a2:0e:2c:38',
                                    'f0:4d:a2:38:38:b4',
                                    'f8:d1:11:3d:56:1d',
                                    '1c:6f:65:0d:ed:2a',
                                    '1c:6f:65:0d:f1:e8',
                                    '1c:6f:65:0e:4f:b9',
                                    '1c:6f:65:0e:4f:e2',
                                    '1c:6f:65:0e:50:e5',
                                    '1c:6f:65:0e:50:f6',
                                    '1c:6f:65:0e:51:02',
                                    '1c:6f:65:0e:51:06',
                                    '3c:07:54:35:11:7a',
                                    '3c:07:54:35:22:51',
                                    '40:6c:8f:bb:d2:fa',
                                    '40:6c:8f:49:66:30',
                                    '44:37:e6:6f:30:d8',
                                    '44:37:e6:87:65:e6',
                                    '44:37:e6:63:4c:f7',
                                    '5c:26:0a:12:2e:62',
                                    '5c:26:0a:2e:02:69',
                                    '00:0c:29:cf:f4:09',
                                    '00:0c:29:d4:b1:ab',
                                    '00:0c:29:f1:eb:69',
                                    '00:18:51:72:8e:eb',
                                    '00:18:51:7d:14:84',
                                    '00:18:51:91:7b:7c',
                                    '00:18:51:d6:bc:c1',
                                    '00:18:51:f1:c6:1f',
                                    '00:18:51:1c:b8:09',
                                    '00:22:19:63:0f:4d',
                                    '00:23:ae:fe:9d:7c',
                                    '00:50:56:bc:00:27',
                                    '00:50:56:bc:00:2f',
                                    '00:50:56:bc:00:05',
                                    '00:50:56:bc:26:84',
                                    '00:50:56:bc:31:8b',
                                    '00:50:56:bc:57:2f',
                                    '00:50:56:50:30:b8',
                                    '00:50:56:50:30:ba',
                                    '00:50:56:51:4d:58',
                                    '00:50:56:51:4d:5a',
                                    'd4:be:d9:f1:22:8d',
                                    '00:1d:09:68:4f:e1',
                                    '00:22:19:63:0f:4d',
                                    '00:50:56:bc:03:4b',
                                    '00:50:56:50:30:b8',
                                    '00:50:56:50:30:ba',
                                    '00:50:56:51:4d:58',
                                    '00:50:56:51:4d:5a',
                                    '00:10:5a:c7:8d:62',
                                    '00:50:04:54:86:6f',
                                    '00:16:ea:47:d3:68',
                                    '00:22:fa:9b:8d:22',
                                    '00:26:5e:fa:a6:2d',
                                    '68:a3:c4:f4:6d:f2',
                                    '70:56:81:aa:87:2b',
                                    '10:40:f3:7a:35:00',
                                    '28:37:37:23:aa:04',
                                    '00:15:5d:32:c3:01',
                                    '00:50:56:bc:03:4a',
                                    '00:50:56:51:4d:58',
                                    '00:50:56:51:4d:5a',
                                    '70:f3:95:1b:84:b8',
                                    '00:11:11:3a:83:e7',
                                    '00:17:f2:94:41:c4',
                                    '00:18:51:00:00:b3',
                                    '00:18:51:00:00:54',
                                    '00:18:51:00:01:51',
                                    '00:18:51:6a:b1:c9',
                                    '00:18:51:76:41:62',
                                    '00:18:51:8d:91:71',
                                    '00:18:51:91:62:38',
                                    '00:18:51:93:24:ec',
                                    '00:18:51:99:f9:a1',
                                    '00:18:51:a0:3a:36',
                                    '00:18:51:a4:e9:03',
                                    '00:18:51:11:12:86',
                                    '00:18:51:11:39:e0',
                                    '00:18:51:ab:03:e0',
                                    '00:18:51:bd:01:02',
                                    '00:18:51:c1:2e:a8',
                                    '00:18:51:c5:19:7a',
                                    '00:18:51:c7:06:38',
                                    '00:18:51:c8:af:d3',
                                    '00:18:51:da:13:48',
                                    '00:18:51:de:bf:33',
                                    '00:18:51:e0:d2:47',
                                    '00:18:51:e1:5c:00',
                                    '00:18:51:17:e7:29',
                                    '00:18:51:ec:1e:3b',
                                    '00:18:51:ee:71:fe',
                                    '00:18:51:f6:da:b5',
                                    '00:18:51:24:f4:eb',
                                    '00:18:51:24:40:88',
                                    '00:18:51:04:f4:d7',
                                    '00:18:51:04:2d:18',
                                    '00:18:51:37:05:fa',
                                    '00:18:51:3a:3f:f2',
                                    '00:18:51:44:08:78',
                                    '00:18:51:47:8c:c5',
                                    '00:18:51:4e:e7:a3',
                                    '00:18:51:4f:b5:c3',
                                    '00:18:51:51:f1:8d',
                                    '00:18:51:5c:d2:3b',
                                    '00:18:51:5e:18:6c',
                                    '00:18:51:5e:25:c8',
                                    '00:19:d1:b1:f9:4f',
                                    '00:1c:c0:22:f4:d4',
                                    '00:20:4a:d7:39:5a',
                                    '00:22:19:63:0f:4d',
                                    '00:23:ae:fe:9d:7c',
                                    '00:24:36:f4:02:3e',
                                    '00:24:36:f4:02:62',
                                    '00:26:b9:77:17:f6',
                                    '00:04:23:ab:dd:ae',
                                    '00:30:48:76:ab:88',
                                    '00:30:48:82:e7:72',
                                    '00:30:48:2a:f4:2c',
                                    '00:50:56:bc:00:0d',
                                    '00:50:56:bc:00:09',
                                    '00:50:56:bc:19:00',
                                    '00:50:56:bc:28:f1',
                                    '00:50:56:bc:35:da',
                                    '00:50:56:50:30:b8',
                                    '00:50:56:50:30:ba',
                                    '00:50:56:51:4d:58',
                                    '00:50:56:51:4d:5a',
                                    'bc:30:5b:ea:d5:a8',
                                    '00:1f:29:1e:42:1b',
                                    '00:27:0e:02:d5:73',
                                    '00:27:0e:02:d5:ee',
                                    '00:27:0e:02:d5:23',
                                    '00:27:0e:02:ec:f3',
                                    '00:27:0e:02:f9:73',
                                    '00:19:d1:ae:3e:36',
                                    '00:19:d1:df:7f:3f',
                                    '00:1c:c0:8e:70:cd',
                                    '00:1c:c0:8e:70:eb',
                                    '00:23:7d:1d:d7:de',
                                    '00:27:0e:01:25:4a',
                                    '70:f3:95:1b:84:96',
                                    '70:f3:95:1b:85:37',
                                    '84:2b:2b:9d:8b:73',
                                    '84:2b:2b:9d:8c:20',
                                    '84:2b:2b:9d:8c:32',
                                    '1c:6f:65:0d:f7:3d',
                                    '00:10:db:ff:10:03',
                                    '00:11:11:6a:8d:da',
                                    '00:13:20:e4:0a:3e',
                                    '00:16:76:d5:60:cc',
                                    '00:16:76:46:13:b1',
                                    '00:19:d1:6e:6c:6a',
                                    '00:19:d1:b1:c9:15',
                                    '00:19:d1:b1:f9:08',
                                    '00:1a:a0:cd:bc:20',
                                    '00:1a:a0:cd:d4:b8',
                                    '00:1c:c0:7f:3b:97',
                                    '00:1c:c0:8f:30:b5',
                                    '00:1c:c0:b1:be:75',
                                    '00:1c:c0:b2:2a:20',
                                    '00:1c:c0:ed:15:7d',
                                    '00:1c:c0:ed:15:2a',
                                    '00:1c:c0:f0:f9:5c',
                                    '00:1c:c0:f1:57:12',
                                    '00:1c:c0:fd:73:90',
                                    '00:1c:c0:fd:73:4a',
                                    '00:1c:c0:fd:75:0e',
                                    '00:1c:c0:fd:75:12',
                                    '00:1c:c0:fd:75:56',
                                    '00:1c:c0:fd:75:63',
                                    '00:1c:c0:fd:5b:40',
                                    '00:1e:4f:bf:c9:16',
                                    '00:1e:4f:c0:a0:17',
                                    '00:20:6b:7a:d2:6f',
                                    '00:21:9b:61:bc:f7',
                                    '00:21:9b:61:bf:0d',
                                    '00:21:9b:61:bf:50',
                                    '00:25:64:94:8c:ec',
                                    '00:25:64:94:40:e9',
                                    '00:25:64:94:46:b0',
                                    '00:25:64:94:47:bf',
                                    '00:25:64:94:47:d8',
                                    '00:25:64:94:48:70',
                                    '00:25:64:94:48:f1',
                                    '00:25:64:94:48:49',
                                    '00:25:64:94:49:68',
                                    '00:25:64:94:49:7a',
                                    '00:25:64:a0:72:d9',
                                    '00:25:64:a0:72:4b',
                                    '00:25:64:a0:73:1c',
                                    '00:25:64:a0:38:e2',
                                    '00:25:64:a0:39:8f',
                                    '00:25:64:a0:39:13',
                                    '00:25:64:a0:39:4d',
                                    '00:25:64:a0:3a:d7',
                                    '00:25:64:a0:3b:14',
                                    '00:25:64:a0:3b:2b',
                                    '00:25:64:a0:3b:34',
                                    '00:27:0e:01:25:52',
                                    '00:27:0e:01:26:0c',
                                    '00:27:0e:01:28:6c',
                                    '00:27:0e:01:2a:ce',
                                    '70:f3:95:13:86:bf',
                                    '70:f3:95:19:28:70',
                                    '70:f3:95:19:28:92',
                                    '70:f3:95:19:28:9d',
                                    '70:f3:95:19:28:9e',
                                    '70:f3:95:19:2a:05',
                                    '70:f3:95:19:2a:46',
                                    '70:f3:95:19:32:31',
                                    '70:f3:95:19:35:64',
                                    '70:f3:95:19:3e:6b',
                                    '70:f3:95:1b:84:a2',
                                    '70:f3:95:1b:84:b9',
                                    '70:f3:95:1b:84:bf',
                                    '70:f3:95:1b:84:f8',
                                    '70:f3:95:1b:85:7c',
                                    '70:f3:95:1b:85:9a',
                                    '70:f3:95:1b:85:f1',
                                    '70:f3:95:1b:86:34',
                                    '70:f3:95:1b:86:35',
                                    '70:f3:95:1b:86:37',
                                    '78:e7:d1:a4:81:2d',
                                    '84:2b:2b:9d:89:a7',
                                    '84:2b:2b:9d:96:e7',
                                    '84:2b:2b:9d:97:b7',
                                    '84:2b:2b:9d:97:15',
                                    '84:2b:2b:ad:16:62',
                                    '84:2b:2b:ad:55:c9',
                                    '84:2b:2b:ad:57:ca',
                                    '84:2b:2b:ad:5e:b2',
                                    '10:78:d2:c3:db:b1',
                                    '10:78:d2:c3:db:b8',
                                    '10:78:d2:c3:de:af',
                                    '10:78:d2:c3:e0:0f',
                                    '10:78:d2:c3:e0:a3',
                                    'b8:ac:6f:0c:70:56',
                                    'cc:52:af:41:31:7d',
                                    'cc:52:af:4c:23:be',
                                    'cc:52:af:4c:27:8f',
                                    'cc:52:af:4c:27:36',
                                    'cc:52:af:4c:27:47',
                                    'cc:52:af:4c:28:45',
                                    'f0:4d:a2:25:4f:d0',
                                    '1c:6f:65:0d:ff:bb',
                                    '1c:6f:65:0f:e2:09',
                                    '1c:6f:65:0f:ef:75',
                                    '1c:6f:65:09:65:aa',
                                    '1c:6f:65:09:57:a9',
                                    '20:c9:d0:29:dd:5b',
                                    '04:7d:7b:18:3b:35',
                                    '44:37:e6:bb:a1:ab',
                                    '44:37:e6:bb:a1:47',
                                    '44:37:e6:bb:a2:e7',
                                    '44:37:e6:bb:a2:f1',
                                    '44:37:e6:bb:a3:a4',
                                    '44:37:e6:bb:a3:a8',
                                    '44:37:e6:bb:a3:c6',
                                    '44:37:e6:bb:a3:56',
                                    '44:37:e6:bb:a4:3a',
                                    '44:37:e6:bb:a4:3b',
                                    '44:37:e6:bb:a4:4b',
                                    '44:37:e6:62:24:7b',
                                    '44:37:e6:62:27:2d',
                                    '44:37:e6:63:50:69',
                                    '44:37:e6:63:50:f0',
                                    '44:37:e6:63:50:fb',
                                    '00:10:db:ff:10:03',
                                    '00:18:51:9f:43:e8',
                                    '00:23:ae:fe:9d:7c',
                                    '00:23:ae:fe:a9:c8',
                                    '00:50:56:bc:67:12',
                                    '00:50:56:bc:02:4d',
                                    '00:50:56:bc:1c:1b',
                                    '00:50:56:bc:4f:70',
                                    '00:50:56:bc:4f:75',
                                    '00:50:56:bc:59:a8',
                                    '00:50:56:bc:5d:69',
                                    '00:50:56:50:39:28',
                                    '00:50:56:50:39:2a',
                                    '18:03:73:0c:7c:0b',
                                    '00:50:56:50:39:28',
                                    '00:50:56:50:39:2a',
                                    '00:10:db:ff:10:03',
                                    '00:16:76:03:0b:42',
                                    '00:16:76:03:0b:61',
                                    '00:1c:c0:9b:8c:df',
                                    '00:1c:c0:f0:88:8f',
                                    '00:1c:c0:22:e9:56',
                                    'd4:3d:7e:1f:c4:99',
                                    'f0:4d:a2:24:5f:5e',
                                    'f0:4d:a2:28:52:4c',
                                    '44:37:e6:62:27:24',
                                    '44:37:e6:63:4c:e2',
                                    '00:22:19:1c:52:a8',
                                    '00:22:19:1c:53:77',
                                    '00:22:19:1c:53:90',
                                    '00:22:19:1c:53:b3',
                                    '00:22:19:1c:53:cb',
                                    '00:22:19:1c:53:e0',
                                    '00:22:19:1c:53:eb',
                                    '00:22:19:1c:53:4e',
                                    '00:22:19:1c:54:80',
                                    '00:22:19:1c:54:8a',
                                    '00:22:19:1c:55:69',
                                    '00:22:19:1c:55:8d',
                                    '00:22:19:1c:55:b9',
                                    '00:22:19:1c:55:c5',
                                    '00:22:19:1c:55:f7',
                                    '00:22:19:1c:56:01',
                                    '00:22:19:1c:56:71',
                                    '00:22:19:1c:56:37',
                                    '00:22:19:1c:57:c3',
                                    '00:22:19:1d:d5:d8',
                                    '00:22:19:1d:35:5e',
                                    '00:22:19:1e:19:58',
                                    '00:10:f3:1f:d3:3a',
                                    '00:10:f3:20:02:e8',
                                    '00:1e:67:03:93:04',
                                    '00:50:56:bc:00:24',
                                    '00:50:56:51:4d:58',
                                    '00:50:56:51:4d:5a',
                                    '00:0f:fe:fc:8d:a2',
                                    '00:12:3f:76:b6:91',
                                    '00:12:3f:76:b6:ae',
                                    '00:19:d1:b1:ce:50',
                                    '00:19:d1:04:bf:31',
                                    '00:24:e8:46:17:8e',
                                    '68:b5:99:90:64:4d',
                                    '70:f3:95:13:af:0d',
                                    '70:f3:95:1b:84:fc',
                                    'b8:ac:6f:2e:d1:1e',
                                    'c8:bc:c8:92:76:53',
                                    'd4:85:64:a9:96:94',
                                    '1c:6f:65:0e:90:39',
                                    '24:be:05:0d:a0:96',
                                    '24:be:05:0f:58:2f',
                                    '2c:41:38:ab:f9:76',
                                    '3c:d9:2b:5a:ec:d6',
                                    '00:24:e8:46:17:97',
                                    '00:24:e8:46:17:b8',
                                    '00:24:e8:46:25:ba',
                                    '00:24:e8:46:26:10',
                                    '00:24:e8:46:27:5b',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '660',
                        IFNAME           => 'ge-1/0/11.0',
                        IFDESCR          => 'ge-1/0/11.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8b',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1564125317) 181 days, 0:47:33.17',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '920045',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '59684653',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '661',
                        IFNAME           => 'ae4.0',
                        IFDESCR          => 'ae4.0',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:84',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '662',
                        IFNAME           => 'ge-2/0/0',
                        IFDESCR          => 'ge-2/0/0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:80',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889647615) 102 days, 23:14:36.15',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '663',
                        IFNAME           => 'ge-2/0/1',
                        IFDESCR          => 'ge-2/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:81',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1277376497) 147 days, 20:16:04.97',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '19694799',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '860831427',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '664',
                        IFNAME           => 'ge-2/0/2',
                        IFDESCR          => 'ge-2/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:82',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1579089654) 182 days, 18:21:36.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '16264718',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1942432931',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '665',
                        IFNAME           => 'ge-2/0/3',
                        IFDESCR          => 'ge-2/0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:83',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578862754) 182 days, 17:43:47.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '885026649',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2105078228',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '666',
                        IFNAME           => 'ge-2/0/4',
                        IFDESCR          => 'ge-2/0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:84',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889647628) 102 days, 23:14:36.28',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '667',
                        IFNAME           => 'ge-2/0/5',
                        IFDESCR          => 'ge-2/0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:85',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1579193654) 182 days, 18:38:56.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '864105490',
                        IFINERRORS       => '123',
                        IFOUTOCTETS      => '1279880336',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '668',
                        IFNAME           => 'ge-2/0/6',
                        IFDESCR          => 'ge-2/0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:86',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578905654) 182 days, 17:50:56.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1777328163',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '761161215',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '669',
                        IFNAME           => 'ge-2/0/7',
                        IFDESCR          => 'ge-2/0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:87',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889647637) 102 days, 23:14:36.37',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '670',
                        IFNAME           => 'ge-2/0/8',
                        IFDESCR          => 'ge-2/0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:88',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1192428913) 138 days, 0:18:09.13',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '259165073',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3934855324',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '671',
                        IFNAME           => 'ge-2/0/9',
                        IFDESCR          => 'ge-2/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:89',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889647652) 102 days, 23:14:36.52',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '672',
                        IFNAME           => 'ge-2/0/10',
                        IFDESCR          => 'ge-2/0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889647654) 102 days, 23:14:36.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '673',
                        IFNAME           => 'ge-2/0/11',
                        IFDESCR          => 'ge-2/0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578979224) 182 days, 18:03:12.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1438500117',
                        IFINERRORS       => '124',
                        IFOUTOCTETS      => '3257498147',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '674',
                        IFNAME           => 'ge-2/0/12',
                        IFDESCR          => 'ge-2/0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578972824) 182 days, 18:02:08.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2051222865',
                        IFINERRORS       => '133',
                        IFOUTOCTETS      => '3007395638',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '675',
                        IFNAME           => 'ge-2/0/13',
                        IFDESCR          => 'ge-2/0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889647674) 102 days, 23:14:36.74',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '676',
                        IFNAME           => 'ge-2/0/14',
                        IFDESCR          => 'ge-2/0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889647681) 102 days, 23:14:36.81',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '677',
                        IFNAME           => 'ge-2/0/15',
                        IFDESCR          => 'ge-2/0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578928254) 182 days, 17:54:42.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '857341064',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1972105888',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '678',
                        IFNAME           => 'ge-2/0/16',
                        IFDESCR          => 'ge-2/0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:90',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889647696) 102 days, 23:14:36.96',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '679',
                        IFNAME           => 'ge-2/0/17',
                        IFDESCR          => 'ge-2/0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:91',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889647703) 102 days, 23:14:37.03',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '680',
                        IFNAME           => 'ge-2/0/18',
                        IFDESCR          => 'ge-2/0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:92',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1572916894) 182 days, 1:12:48.94',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '794886388',
                        IFINERRORS       => '62',
                        IFOUTOCTETS      => '522097451',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '681',
                        IFNAME           => 'ge-2/0/19',
                        IFDESCR          => 'ge-2/0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:93',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578584634) 182 days, 16:57:26.34',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '4936307',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '946574273',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '682',
                        IFNAME           => 'ge-2/0/20',
                        IFDESCR          => 'ge-2/0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:94',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578587184) 182 days, 16:57:51.84',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1153312159',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '516539527',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '683',
                        IFNAME           => 'ge-2/0/21',
                        IFDESCR          => 'ge-2/0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:95',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1328744065) 153 days, 18:57:20.65',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '38238',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '59156',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '684',
                        IFNAME           => 'ge-2/0/22',
                        IFDESCR          => 'ge-2/0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:96',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889647726) 102 days, 23:14:37.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '685',
                        IFNAME           => 'ge-2/0/23',
                        IFDESCR          => 'ge-2/0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:97',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889647733) 102 days, 23:14:37.33',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '686',
                        IFNAME           => 'ge-2/0/24',
                        IFDESCR          => 'ge-2/0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:98',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889647735) 102 days, 23:14:37.35',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '687',
                        IFNAME           => 'ge-2/0/25',
                        IFDESCR          => 'ge-2/0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:99',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578771194) 182 days, 17:28:31.94',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1252700608',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1346700443',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '688',
                        IFNAME           => 'ge-2/0/26',
                        IFDESCR          => 'ge-2/0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889647741) 102 days, 23:14:37.41',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '689',
                        IFNAME           => 'ge-2/0/27',
                        IFDESCR          => 'ge-2/0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889647743) 102 days, 23:14:37.43',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '690',
                        IFNAME           => 'ge-2/0/28',
                        IFDESCR          => 'ge-2/0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1579064374) 182 days, 18:17:23.74',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1949901923',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3933167650',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '691',
                        IFNAME           => 'ge-2/0/29',
                        IFDESCR          => 'ge-2/0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889647746) 102 days, 23:14:37.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '692',
                        IFNAME           => 'ge-2/0/30',
                        IFDESCR          => 'ge-2/0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889647749) 102 days, 23:14:37.49',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '693',
                        IFNAME           => 'ge-2/0/31',
                        IFDESCR          => 'ge-2/0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889647771) 102 days, 23:14:37.71',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '694',
                        IFNAME           => 'ge-2/0/32',
                        IFDESCR          => 'ge-2/0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889647772) 102 days, 23:14:37.72',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '695',
                        IFNAME           => 'ge-2/0/33',
                        IFDESCR          => 'ge-2/0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a1',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889647775) 102 days, 23:14:37.75',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '696',
                        IFNAME           => 'ge-2/0/34',
                        IFDESCR          => 'ge-2/0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a2',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1322849014) 153 days, 2:34:50.14',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '287684405',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3337289733',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '697',
                        IFNAME           => 'ge-2/0/35',
                        IFDESCR          => 'ge-2/0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a3',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889647798) 102 days, 23:14:37.98',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '698',
                        IFNAME           => 'ge-2/0/36',
                        IFDESCR          => 'ge-2/0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a4',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889647801) 102 days, 23:14:38.01',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '699',
                        IFNAME           => 'ge-2/0/37',
                        IFDESCR          => 'ge-2/0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a5',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578869584) 182 days, 17:44:55.84',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1014994314',
                        IFINERRORS       => '179',
                        IFOUTOCTETS      => '2218627453',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '700',
                        IFNAME           => 'ge-2/0/38',
                        IFDESCR          => 'ge-2/0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a6',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889647804) 102 days, 23:14:38.04',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '701',
                        IFNAME           => 'ge-2/0/39',
                        IFDESCR          => 'ge-2/0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a7',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578551944) 182 days, 16:51:59.44',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '890348094',
                        IFINERRORS       => '478',
                        IFOUTOCTETS      => '1670613775',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '702',
                        IFNAME           => 'ge-2/0/40',
                        IFDESCR          => 'ge-2/0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1485792124) 171 days, 23:12:01.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '84412015',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '110227968',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '703',
                        IFNAME           => 'ge-2/0/41',
                        IFDESCR          => 'ge-2/0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a9',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578870914) 182 days, 17:45:09.14',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1044124892',
                        IFINERRORS       => '462',
                        IFOUTOCTETS      => '3934721224',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '704',
                        IFNAME           => 'ge-2/0/42',
                        IFDESCR          => 'ge-2/0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:aa',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889647814) 102 days, 23:14:38.14',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '705',
                        IFNAME           => 'ge-2/0/43',
                        IFDESCR          => 'ge-2/0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ab',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889647815) 102 days, 23:14:38.15',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '706',
                        IFNAME           => 'ge-2/0/44',
                        IFDESCR          => 'ge-2/0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ac',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889647818) 102 days, 23:14:38.18',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '707',
                        IFNAME           => 'ge-2/0/45',
                        IFDESCR          => 'ge-2/0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ad',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889647822) 102 days, 23:14:38.22',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '708',
                        IFNAME           => 'ge-2/0/46',
                        IFDESCR          => 'ge-2/0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ae',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889647825) 102 days, 23:14:38.25',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '709',
                        IFNAME           => 'ge-2/0/47',
                        IFDESCR          => 'ge-2/0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:af',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889647826) 102 days, 23:14:38.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '710',
                        IFNAME           => 'xe-2/1/0',
                        IFDESCR          => 'xe-2/1/0',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889650343) 102 days, 23:15:03.43',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '928512917',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1057088068',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '711',
                        IFNAME           => 'ge-3/0/0',
                        IFDESCR          => 'ge-3/0/0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:80',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646413) 102 days, 23:14:24.13',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '712',
                        IFNAME           => 'ge-3/0/1',
                        IFDESCR          => 'ge-3/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:81',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646422) 102 days, 23:14:24.22',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '713',
                        IFNAME           => 'ge-3/0/2',
                        IFDESCR          => 'ge-3/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:82',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1520988290) 176 days, 0:58:02.90',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '4024299310',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1336085659',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '714',
                        IFNAME           => 'ge-3/0/3',
                        IFDESCR          => 'ge-3/0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:83',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1450384926) 167 days, 20:50:49.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '34005860',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3788064450',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '715',
                        IFNAME           => 'ge-3/0/4',
                        IFDESCR          => 'ge-3/0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:84',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1450387743) 167 days, 20:51:17.43',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '51906004',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4206370913',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '716',
                        IFNAME           => 'ge-3/0/5',
                        IFDESCR          => 'ge-3/0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:85',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1450387216) 167 days, 20:51:12.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '124374888',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '946583611',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '717',
                        IFNAME           => 'ge-3/0/6',
                        IFDESCR          => 'ge-3/0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:86',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1520369320) 175 days, 23:14:53.20',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '79883720',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3120502992',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '718',
                        IFNAME           => 'ge-3/0/7',
                        IFDESCR          => 'ge-3/0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:87',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1450388998) 167 days, 20:51:29.98',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '189074348',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '592790354',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '719',
                        IFNAME           => 'ge-3/0/8',
                        IFDESCR          => 'ge-3/0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:88',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1450401450) 167 days, 20:53:34.50',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '70052326',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3949735961',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '720',
                        IFNAME           => 'ge-3/0/9',
                        IFDESCR          => 'ge-3/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:89',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1520251378) 175 days, 22:55:13.78',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '63979213',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '714317279',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '721',
                        IFNAME           => 'ge-3/0/14',
                        IFDESCR          => 'ge-3/0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1450388428) 167 days, 20:51:24.28',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '25116574',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3775172564',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '722',
                        IFNAME           => 'ge-3/0/10',
                        IFDESCR          => 'ge-3/0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1453627976) 168 days, 5:51:19.76',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '19619677',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3443544221',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '723',
                        IFNAME           => 'ge-3/0/11',
                        IFDESCR          => 'ge-3/0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1364234866) 157 days, 21:32:28.66',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '16532151',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3014350545',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '724',
                        IFNAME           => 'ge-3/0/21',
                        IFDESCR          => 'ge-3/0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:95',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1338153164) 154 days, 21:05:31.64',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '37349525',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1050909558',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '725',
                        IFNAME           => 'ge-3/0/22',
                        IFDESCR          => 'ge-3/0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:96',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646599) 102 days, 23:14:25.99',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '726',
                        IFNAME           => 'ge-3/0/12',
                        IFDESCR          => 'ge-3/0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1450386691) 167 days, 20:51:06.91',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '36852723',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3712872109',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '727',
                        IFNAME           => 'ge-3/0/23',
                        IFDESCR          => 'ge-3/0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:97',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646609) 102 days, 23:14:26.09',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '728',
                        IFNAME           => 'ge-3/0/13',
                        IFDESCR          => 'ge-3/0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1450398878) 167 days, 20:53:08.78',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '110431033',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3711553524',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '729',
                        IFNAME           => 'ge-3/0/24',
                        IFDESCR          => 'ge-3/0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:98',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646614) 102 days, 23:14:26.14',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '730',
                        IFNAME           => 'ge-3/0/25',
                        IFDESCR          => 'ge-3/0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:99',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646627) 102 days, 23:14:26.27',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '731',
                        IFNAME           => 'ge-3/0/15',
                        IFDESCR          => 'ge-3/0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1450386802) 167 days, 20:51:08.02',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '23282650',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3814199236',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '732',
                        IFNAME           => 'ge-3/0/16',
                        IFDESCR          => 'ge-3/0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:90',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1520346686) 175 days, 23:11:06.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '65514699',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1132038986',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '733',
                        IFNAME           => 'ge-3/0/26',
                        IFDESCR          => 'ge-3/0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646629) 102 days, 23:14:26.29',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '734',
                        IFNAME           => 'ge-3/0/17',
                        IFDESCR          => 'ge-3/0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:91',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1520347478) 175 days, 23:11:14.78',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '20264914',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1135247476',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '735',
                        IFNAME           => 'ge-3/0/27',
                        IFDESCR          => 'ge-3/0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646632) 102 days, 23:14:26.32',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '736',
                        IFNAME           => 'ge-3/0/18',
                        IFDESCR          => 'ge-3/0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:92',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1338153052) 154 days, 21:05:30.52',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '24764343',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1075691635',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '737',
                        IFNAME           => 'ge-3/0/28',
                        IFDESCR          => 'ge-3/0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646636) 102 days, 23:14:26.36',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '738',
                        IFNAME           => 'ge-3/0/29',
                        IFDESCR          => 'ge-3/0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646640) 102 days, 23:14:26.40',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '739',
                        IFNAME           => 'ge-3/0/19',
                        IFDESCR          => 'ge-3/0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:93',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1338153360) 154 days, 21:05:33.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '19075908',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1046130957',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '740',
                        IFNAME           => 'ge-3/0/30',
                        IFDESCR          => 'ge-3/0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646641) 102 days, 23:14:26.41',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '741',
                        IFNAME           => 'ge-3/0/31',
                        IFDESCR          => 'ge-3/0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646649) 102 days, 23:14:26.49',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '742',
                        IFNAME           => 'ge-3/0/20',
                        IFDESCR          => 'ge-3/0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:94',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1338153274) 154 days, 21:05:32.74',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '26223796',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '599205085',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '743',
                        IFNAME           => 'ge-3/0/32',
                        IFDESCR          => 'ge-3/0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646657) 102 days, 23:14:26.57',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '744',
                        IFNAME           => 'ge-3/0/33',
                        IFDESCR          => 'ge-3/0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a1',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646660) 102 days, 23:14:26.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '745',
                        IFNAME           => 'ge-3/0/34',
                        IFDESCR          => 'ge-3/0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a2',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646662) 102 days, 23:14:26.62',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '746',
                        IFNAME           => 'ge-3/0/35',
                        IFDESCR          => 'ge-3/0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a3',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646664) 102 days, 23:14:26.64',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '747',
                        IFNAME           => 'ge-3/0/36',
                        IFDESCR          => 'ge-3/0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a4',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646668) 102 days, 23:14:26.68',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '748',
                        IFNAME           => 'ge-3/0/37',
                        IFDESCR          => 'ge-3/0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a5',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646674) 102 days, 23:14:26.74',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '749',
                        IFNAME           => 'ge-3/0/38',
                        IFDESCR          => 'ge-3/0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a6',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646684) 102 days, 23:14:26.84',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '750',
                        IFNAME           => 'ge-3/0/39',
                        IFDESCR          => 'ge-3/0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a7',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646688) 102 days, 23:14:26.88',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '751',
                        IFNAME           => 'ge-3/0/40',
                        IFDESCR          => 'ge-3/0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a8',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646691) 102 days, 23:14:26.91',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '752',
                        IFNAME           => 'ge-3/0/41',
                        IFDESCR          => 'ge-3/0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a9',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646696) 102 days, 23:14:26.96',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '753',
                        IFNAME           => 'ge-3/0/42',
                        IFDESCR          => 'ge-3/0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:aa',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646699) 102 days, 23:14:26.99',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '754',
                        IFNAME           => 'ge-3/0/43',
                        IFDESCR          => 'ge-3/0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ab',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646702) 102 days, 23:14:27.02',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '755',
                        IFNAME           => 'ge-3/0/44',
                        IFDESCR          => 'ge-3/0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ac',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646707) 102 days, 23:14:27.07',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '756',
                        IFNAME           => 'ge-3/0/45',
                        IFDESCR          => 'ge-3/0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ad',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646710) 102 days, 23:14:27.10',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '757',
                        IFNAME           => 'ge-3/0/46',
                        IFDESCR          => 'ge-3/0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ae',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646712) 102 days, 23:14:27.12',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '758',
                        IFNAME           => 'ge-3/0/47',
                        IFDESCR          => 'ge-3/0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:af',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646714) 102 days, 23:14:27.14',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '759',
                        IFNAME           => 'ge-1/0/12.0',
                        IFDESCR          => 'ge-1/0/12.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8c',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1573444441) 182 days, 2:40:44.41',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1923376',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '208503454',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '760',
                        IFNAME           => 'ge-4/0/0',
                        IFDESCR          => 'ge-4/0/0',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:80',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1442976434) 167 days, 0:16:04.34',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3011181804',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2323959792',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '761',
                        IFNAME           => 'ge-4/0/1',
                        IFDESCR          => 'ge-4/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:81',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1565042078) 181 days, 3:20:20.78',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '5522584',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '272770095',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '762',
                        IFNAME           => 'ge-4/0/2',
                        IFDESCR          => 'ge-4/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:82',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1071466878) 124 days, 0:17:48.78',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '763',
                        IFNAME           => 'ge-4/0/3',
                        IFDESCR          => 'ge-4/0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:83',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578609968) 182 days, 17:01:39.68',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1839442692',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2122308007',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '764',
                        IFNAME           => 'ge-4/0/4',
                        IFDESCR          => 'ge-4/0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:84',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1510174878) 174 days, 18:55:48.78',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1319966900',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3407244235',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '765',
                        IFNAME           => 'ge-4/0/5',
                        IFDESCR          => 'ge-4/0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:85',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1510153146) 174 days, 18:52:11.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '75987',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '565425',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '766',
                        IFNAME           => 'ge-4/0/6',
                        IFDESCR          => 'ge-4/0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:86',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578616548) 182 days, 17:02:45.48',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '67480194',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '891804136',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '767',
                        IFNAME           => 'ge-4/0/7',
                        IFDESCR          => 'ge-4/0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:87',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578616157) 182 days, 17:02:41.57',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '106356309',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1633240401',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '768',
                        IFNAME           => 'ge-4/0/8',
                        IFDESCR          => 'ge-4/0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:88',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1574023308) 182 days, 4:17:13.08',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '87099310',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1391538180',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '769',
                        IFNAME           => 'ge-4/0/9',
                        IFDESCR          => 'ge-4/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:89',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1071466928) 124 days, 0:17:49.28',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '770',
                        IFNAME           => 'ge-4/0/10',
                        IFDESCR          => 'ge-4/0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1513317590) 175 days, 3:39:35.90',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '28640055',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '208218658',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '771',
                        IFNAME           => 'ge-4/0/11',
                        IFDESCR          => 'ge-4/0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1547189561) 179 days, 1:44:55.61',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '14848691',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '61900792',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '772',
                        IFNAME           => 'ge-4/0/19',
                        IFDESCR          => 'ge-4/0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:93',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1563849546) 181 days, 0:01:35.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '25793187',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '209641642',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '773',
                        IFNAME           => 'ge-4/0/20',
                        IFDESCR          => 'ge-4/0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:94',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1457971644) 168 days, 17:55:16.44',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '58823807',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '708966548',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '774',
                        IFNAME           => 'ge-4/0/21',
                        IFDESCR          => 'ge-4/0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:95',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1260778133) 145 days, 22:09:41.33',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '16437056',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '78260776',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '775',
                        IFNAME           => 'ge-4/0/22',
                        IFDESCR          => 'ge-4/0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:96',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1521627060) 176 days, 2:44:30.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '8208903',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '117208148',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '776',
                        IFNAME           => 'ge-4/0/23',
                        IFDESCR          => 'ge-4/0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:97',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578618687) 182 days, 17:03:06.87',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '7348698',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1035937653',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '777',
                        IFNAME           => 'ge-4/0/24',
                        IFDESCR          => 'ge-4/0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:98',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1425677372) 165 days, 0:12:53.72',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '182087782',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '46782466',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '778',
                        IFNAME           => 'ge-4/0/25',
                        IFDESCR          => 'ge-4/0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:99',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1424888386) 164 days, 22:01:23.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '59330567',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '106396743',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '779',
                        IFNAME           => 'ge-4/0/26',
                        IFDESCR          => 'ge-4/0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1572311952) 181 days, 23:31:59.52',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '32710818',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '659616653',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '780',
                        IFNAME           => 'ge-4/0/27',
                        IFDESCR          => 'ge-4/0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1521697066) 176 days, 2:56:10.66',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '12358989',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '45929707',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '781',
                        IFNAME           => 'ge-4/0/12',
                        IFDESCR          => 'ge-4/0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1261267893) 145 days, 23:31:18.93',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '6290653',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '24869415',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '782',
                        IFNAME           => 'ge-4/0/28',
                        IFDESCR          => 'ge-4/0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1561658646) 180 days, 17:56:26.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '11989759',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '52432307',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '783',
                        IFNAME           => 'ge-4/0/29',
                        IFDESCR          => 'ge-4/0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1504620827) 174 days, 3:30:08.27',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2091974',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '12579632',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '784',
                        IFNAME           => 'ge-4/0/13',
                        IFDESCR          => 'ge-4/0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1573227018) 182 days, 2:04:30.18',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '18455400',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '77489201',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '785',
                        IFNAME           => 'ge-4/0/30',
                        IFDESCR          => 'ge-4/0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1548020706) 179 days, 4:03:27.06',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '16157248',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '216770794',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '786',
                        IFNAME           => 'ge-4/0/14',
                        IFDESCR          => 'ge-4/0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1502383224) 173 days, 21:17:12.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '74356189',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '278801129',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '787',
                        IFNAME           => 'ge-4/0/31',
                        IFDESCR          => 'ge-4/0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1444288680) 167 days, 3:54:46.80',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '38081993',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '211490099',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '788',
                        IFNAME           => 'ge-4/0/32',
                        IFDESCR          => 'ge-4/0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1346820566) 155 days, 21:10:05.66',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1556019',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4349392',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '789',
                        IFNAME           => 'ge-4/0/15',
                        IFDESCR          => 'ge-4/0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1562688204) 180 days, 20:48:02.04',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '21527530',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '132061897',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '790',
                        IFNAME           => 'ge-4/0/33',
                        IFDESCR          => 'ge-4/0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a1',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1494210849) 172 days, 22:35:08.49',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '9155591',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '23084470',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '791',
                        IFNAME           => 'ge-4/0/34',
                        IFDESCR          => 'ge-4/0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a2',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1579356778) 182 days, 19:06:07.78',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '55898539',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '482021407',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '792',
                        IFNAME           => 'ge-4/0/35',
                        IFDESCR          => 'ge-4/0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a3',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1563844404) 181 days, 0:00:44.04',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1037270',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2329257',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '793',
                        IFNAME           => 'ge-4/0/36',
                        IFDESCR          => 'ge-4/0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a4',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1486855674) 172 days, 2:09:16.74',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '12907713',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '69718295',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '794',
                        IFNAME           => 'ge-4/0/16',
                        IFDESCR          => 'ge-4/0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:90',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1486971782) 172 days, 2:28:37.82',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '23324170',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '244357305',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '795',
                        IFNAME           => 'ge-4/0/37',
                        IFDESCR          => 'ge-4/0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a5',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1554987262) 179 days, 23:24:32.62',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '140430144',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2299666323',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '796',
                        IFNAME           => 'ge-4/0/17',
                        IFDESCR          => 'ge-4/0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:91',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1452293958) 168 days, 2:08:59.58',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '24492045',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '224139829',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '797',
                        IFNAME           => 'ge-4/0/38',
                        IFDESCR          => 'ge-4/0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a6',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1555608214) 180 days, 1:08:02.14',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '10261944',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '79620577',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '798',
                        IFNAME           => 'ge-4/0/39',
                        IFDESCR          => 'ge-4/0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a7',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1545422722) 178 days, 20:50:27.22',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '47468099',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '526945080',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '799',
                        IFNAME           => 'ge-4/0/40',
                        IFDESCR          => 'ge-4/0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a8',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1563754030) 180 days, 23:45:40.30',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '20043930',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '119143863',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '800',
                        IFNAME           => 'ge-4/0/41',
                        IFDESCR          => 'ge-4/0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a9',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1555609888) 180 days, 1:08:18.88',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '11438989',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '56045039',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '801',
                        IFNAME           => 'ge-4/0/42',
                        IFDESCR          => 'ge-4/0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:aa',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1555987738) 180 days, 2:11:17.38',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '31559254',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '175945569',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '802',
                        IFNAME           => 'ge-4/0/43',
                        IFDESCR          => 'ge-4/0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ab',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1442185282) 166 days, 22:04:12.82',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1059664',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4597681',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '803',
                        IFNAME           => 'ge-4/0/44',
                        IFDESCR          => 'ge-4/0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ac',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1390509782) 160 days, 22:31:37.82',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '24234',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '21103',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '804',
                        IFNAME           => 'ge-4/0/45',
                        IFDESCR          => 'ge-4/0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ad',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1572042943) 181 days, 22:47:09.43',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '41616761',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '196610156',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '805',
                        IFNAME           => 'ge-4/0/46',
                        IFDESCR          => 'ge-4/0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ae',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1277476099) 147 days, 20:32:40.99',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3106421',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '18964541',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '806',
                        IFNAME           => 'ge-4/0/47',
                        IFDESCR          => 'ge-4/0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:af',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1450302458) 167 days, 20:37:04.58',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '12594073',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '71662773',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '807',
                        IFNAME           => 'ge-4/0/18',
                        IFDESCR          => 'ge-4/0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:92',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1451188038) 167 days, 23:04:40.38',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '585',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '808',
                        IFNAME           => 'ge-5/0/0',
                        IFDESCR          => 'ge-5/0/0',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:80',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1555387048) 180 days, 0:31:10.48',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '108117',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '809',
                        IFNAME           => 'ge-5/0/1',
                        IFDESCR          => 'ge-5/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:81',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1451300698) 167 days, 23:23:26.98',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '19041973',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '226123625',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '810',
                        IFNAME           => 'ge-5/0/2',
                        IFDESCR          => 'ge-5/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:82',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1484763324) 171 days, 20:20:33.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '4188493',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '9809920',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '811',
                        IFNAME           => 'ge-5/0/3',
                        IFDESCR          => 'ge-5/0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:83',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1555932102) 180 days, 2:02:01.02',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '48671934',
                        IFINERRORS       => '11',
                        IFOUTOCTETS      => '455002923',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '812',
                        IFNAME           => 'ge-5/0/4',
                        IFDESCR          => 'ge-5/0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:84',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1519665226) 175 days, 21:17:32.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '26771024',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '225047446',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '813',
                        IFNAME           => 'ge-5/0/5',
                        IFDESCR          => 'ge-5/0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:85',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1424586254) 164 days, 21:11:02.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '35815117',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '133190535',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '814',
                        IFNAME           => 'ge-5/0/6',
                        IFDESCR          => 'ge-5/0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:86',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1572359425) 181 days, 23:39:54.25',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '22128064',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '118092175',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '815',
                        IFNAME           => 'ge-5/0/7',
                        IFDESCR          => 'ge-5/0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:87',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1520500834) 175 days, 23:36:48.34',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1390694',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '11391141',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '816',
                        IFNAME           => 'ge-5/0/8',
                        IFDESCR          => 'ge-5/0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:88',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1546292486) 178 days, 23:15:24.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1457008',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '7694073',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '817',
                        IFNAME           => 'ge-5/0/9',
                        IFDESCR          => 'ge-5/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:89',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1579320303) 182 days, 19:00:03.03',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '67458660',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '173983369',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '818',
                        IFNAME           => 'ge-5/0/10',
                        IFDESCR          => 'ge-5/0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1261147396) 145 days, 23:11:13.96',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3982718',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '27342252',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '819',
                        IFNAME           => 'ge-5/0/11',
                        IFDESCR          => 'ge-5/0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1554633641) 179 days, 22:25:36.41',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1296155',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4908155',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '820',
                        IFNAME           => 'ge-5/0/12',
                        IFDESCR          => 'ge-5/0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1071467479) 124 days, 0:17:54.79',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '821',
                        IFNAME           => 'ge-5/0/13',
                        IFDESCR          => 'ge-5/0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1254004460) 145 days, 3:20:44.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '8033027',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '28724098',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '822',
                        IFNAME           => 'ge-5/0/18',
                        IFDESCR          => 'ge-5/0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:92',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1565237721) 181 days, 3:52:57.21',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '12027799',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '292045902',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '823',
                        IFNAME           => 'ge-5/0/19',
                        IFDESCR          => 'ge-5/0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:93',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1459729300) 168 days, 22:48:13.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '8454757',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '37712327',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '824',
                        IFNAME           => 'ge-5/0/14',
                        IFDESCR          => 'ge-5/0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1519633418) 175 days, 21:12:14.18',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '7327759',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '20751669',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '825',
                        IFNAME           => 'ge-5/0/20',
                        IFDESCR          => 'ge-5/0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:94',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1553552604) 179 days, 19:25:26.04',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1145465',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1173177',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '826',
                        IFNAME           => 'ge-5/0/21',
                        IFDESCR          => 'ge-5/0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:95',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1562109850) 180 days, 19:11:38.50',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '5598588',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '99054163',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '827',
                        IFNAME           => 'ge-5/0/15',
                        IFDESCR          => 'ge-5/0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1389868950) 160 days, 20:44:49.50',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '176329',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '91782',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '828',
                        IFNAME           => 'ge-5/0/22',
                        IFDESCR          => 'ge-5/0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:96',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1546933044) 179 days, 1:02:10.44',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1734458',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3745713',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '829',
                        IFNAME           => 'ge-5/0/23',
                        IFDESCR          => 'ge-5/0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:97',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1547856186) 179 days, 3:36:01.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '5068741',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '15728265',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '830',
                        IFNAME           => 'ge-5/0/16',
                        IFDESCR          => 'ge-5/0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:90',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1554786300) 179 days, 22:51:03.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '13667656',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '45982274',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '831',
                        IFNAME           => 'ge-5/0/24',
                        IFDESCR          => 'ge-5/0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:98',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1571619548) 181 days, 21:36:35.48',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '214452',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '207402',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '832',
                        IFNAME           => 'ge-5/0/17',
                        IFDESCR          => 'ge-5/0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:91',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1547593680) 179 days, 2:52:16.80',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '23689293',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '76692809',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '833',
                        IFNAME           => 'ge-5/0/25',
                        IFDESCR          => 'ge-5/0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:99',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1572400418) 181 days, 23:46:44.18',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '4214149',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '65567368',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '834',
                        IFNAME           => 'ge-5/0/26',
                        IFDESCR          => 'ge-5/0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1484727143) 171 days, 20:14:31.43',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '8375207',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '40972797',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '835',
                        IFNAME           => 'ge-5/0/27',
                        IFDESCR          => 'ge-5/0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1443271750) 167 days, 1:05:17.50',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '598634',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1047348',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '836',
                        IFNAME           => 'ge-5/0/28',
                        IFDESCR          => 'ge-5/0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1432715230) 165 days, 19:45:52.30',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2358',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '909',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '837',
                        IFNAME           => 'ge-5/0/29',
                        IFDESCR          => 'ge-5/0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1365333952) 158 days, 0:35:39.52',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '76433233',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '181589184',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '838',
                        IFNAME           => 'ge-5/0/30',
                        IFDESCR          => 'ge-5/0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1556438310) 180 days, 3:26:23.10',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '10015009',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '38992306',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '839',
                        IFNAME           => 'ge-5/0/31',
                        IFDESCR          => 'ge-5/0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1363902920) 157 days, 20:37:09.20',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '4234374',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '77300633',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '840',
                        IFNAME           => 'ge-5/0/32',
                        IFDESCR          => 'ge-5/0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1510880886) 174 days, 20:53:28.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '7094065',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '50617583',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '841',
                        IFNAME           => 'ge-5/0/33',
                        IFDESCR          => 'ge-5/0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a1',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1071467587) 124 days, 0:17:55.87',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '842',
                        IFNAME           => 'ge-5/0/34',
                        IFDESCR          => 'ge-5/0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a2',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1390508038) 160 days, 22:31:20.38',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2292784',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '56410855',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '843',
                        IFNAME           => 'ge-5/0/35',
                        IFDESCR          => 'ge-5/0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a3',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1071467590) 124 days, 0:17:55.90',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '844',
                        IFNAME           => 'ge-5/0/36',
                        IFDESCR          => 'ge-5/0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a4',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1391353106) 161 days, 0:52:11.06',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '6056220',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '136939566',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '845',
                        IFNAME           => 'ge-5/0/37',
                        IFDESCR          => 'ge-5/0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a5',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1391354470) 161 days, 0:52:24.70',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2521918',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '5653408',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '846',
                        IFNAME           => 'ge-5/0/38',
                        IFDESCR          => 'ge-5/0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a6',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1071467603) 124 days, 0:17:56.03',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '847',
                        IFNAME           => 'ge-5/0/39',
                        IFDESCR          => 'ge-5/0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a7',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1573567062) 182 days, 3:01:10.62',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '515256634',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1209604228',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '848',
                        IFNAME           => 'ge-5/0/40',
                        IFDESCR          => 'ge-5/0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a8',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1510174312) 174 days, 18:55:43.12',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '380129',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2578674',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '849',
                        IFNAME           => 'ge-5/0/41',
                        IFDESCR          => 'ge-5/0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a9',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1071467613) 124 days, 0:17:56.13',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '850',
                        IFNAME           => 'ge-5/0/42',
                        IFDESCR          => 'ge-5/0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:aa',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578548403) 182 days, 16:51:24.03',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1909371630',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2300728794',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '851',
                        IFNAME           => 'ge-5/0/43',
                        IFDESCR          => 'ge-5/0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ab',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1071467619) 124 days, 0:17:56.19',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '852',
                        IFNAME           => 'ge-5/0/44',
                        IFDESCR          => 'ge-5/0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ac',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1521519295) 176 days, 2:26:32.95',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '141601590',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2234563808',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '853',
                        IFNAME           => 'ge-5/0/45',
                        IFDESCR          => 'ge-5/0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ad',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1071469953) 124 days, 0:18:19.53',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '277977600',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1443091799',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '854',
                        IFNAME           => 'ge-5/0/46',
                        IFDESCR          => 'ge-5/0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ae',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1071469953) 124 days, 0:18:19.53',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '301200202',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1479450375',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '855',
                        IFNAME           => 'ge-5/0/47',
                        IFDESCR          => 'ge-5/0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:af',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1071481912) 124 days, 0:20:19.12',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1545186482',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2661505111',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '856',
                        IFNAME           => 'xe-5/1/0',
                        IFDESCR          => 'xe-5/1/0',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1071469993) 124 days, 0:18:19.93',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2273452514',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4112460048',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '857',
                        IFNAME           => 'xe-2/1/0.0',
                        IFDESCR          => 'xe-2/1/0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889650343) 102 days, 23:15:03.43',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1488',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '71723173',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '858',
                        IFNAME           => 'xe-5/1/0.0',
                        IFDESCR          => 'xe-5/1/0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1071469993) 124 days, 0:18:19.93',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '744',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '330232315',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '859',
                        IFNAME           => 'ge-1/0/13.0',
                        IFDESCR          => 'ge-1/0/13.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8d',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450703) 83 days, 0:55:07.03',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '860',
                        IFNAME           => 'ge-1/0/14.0',
                        IFDESCR          => 'ge-1/0/14.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717452073) 83 days, 0:55:20.73',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '37518681',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '579998571',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:27:0c:58:68:2d',
                                    '00:22:19:26:34:08',
                                    '00:25:64:a0:3c:09',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '861',
                        IFNAME           => 'ge-1/0/15.0',
                        IFDESCR          => 'ge-1/0/15.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8f',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450742) 83 days, 0:55:07.42',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '862',
                        IFNAME           => 'ge-1/0/16.0',
                        IFDESCR          => 'ge-1/0/16.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:90',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450758) 83 days, 0:55:07.58',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '863',
                        IFNAME           => 'ge-1/0/17.0',
                        IFDESCR          => 'ge-1/0/17.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:91',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450767) 83 days, 0:55:07.67',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '864',
                        IFNAME           => 'ge-1/0/18.0',
                        IFDESCR          => 'ge-1/0/18.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:92',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450774) 83 days, 0:55:07.74',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '865',
                        IFNAME           => 'ge-1/0/19.0',
                        IFDESCR          => 'ge-1/0/19.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:93',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1579481427) 182 days, 19:26:54.27',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '4809495',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '231735707',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '40:6c:8f:51:ac:bd',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '866',
                        IFNAME           => 'ge-1/0/2.0',
                        IFDESCR          => 'ge-1/0/2.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:82',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1518159237) 175 days, 17:06:32.37',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '4146130',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '558700068',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:21:9b:2e:6e:d2',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '867',
                        IFNAME           => 'ge-1/0/20.0',
                        IFDESCR          => 'ge-1/0/20.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:94',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578881557) 182 days, 17:46:55.57',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '5033863',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '275850692',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '7c:c3:a1:89:71:d5',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '868',
                        IFNAME           => 'ge-1/0/21.0',
                        IFDESCR          => 'ge-1/0/21.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:95',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450784) 83 days, 0:55:07.84',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '869',
                        IFNAME           => 'ge-1/0/22.0',
                        IFDESCR          => 'ge-1/0/22.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:96',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450786) 83 days, 0:55:07.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '870',
                        IFNAME           => 'ge-1/0/23.0',
                        IFDESCR          => 'ge-1/0/23.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:97',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450789) 83 days, 0:55:07.89',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '871',
                        IFNAME           => 'ge-1/0/24.0',
                        IFDESCR          => 'ge-1/0/24.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:98',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1573311367) 182 days, 2:18:33.67',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3680489',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '61557623',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '872',
                        IFNAME           => 'ge-1/0/25.0',
                        IFDESCR          => 'ge-1/0/25.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:99',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578898697) 182 days, 17:49:46.97',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '12971366',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '88783975',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'c8:2a:14:42:4b:e0',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '873',
                        IFNAME           => 'ge-1/0/26.0',
                        IFDESCR          => 'ge-1/0/26.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9a',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1277650841) 147 days, 21:01:48.41',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '33323',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '438265',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '874',
                        IFNAME           => 'ge-1/0/27.0',
                        IFDESCR          => 'ge-1/0/27.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9b',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450825) 83 days, 0:55:08.25',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '875',
                        IFNAME           => 'ge-1/0/28.0',
                        IFDESCR          => 'ge-1/0/28.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9c',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(975037268) 112 days, 20:26:12.68',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '47896',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '486269',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '876',
                        IFNAME           => 'ge-1/0/29.0',
                        IFDESCR          => 'ge-1/0/29.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1579233077) 182 days, 18:45:30.77',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '978662',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '145945569',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'e8:9a:8f:6d:c9:80',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '877',
                        IFNAME           => 'ge-1/0/3.0',
                        IFDESCR          => 'ge-1/0/3.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:83',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450570) 83 days, 0:55:05.70',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '878',
                        IFNAME           => 'ge-1/0/30.0',
                        IFDESCR          => 'ge-1/0/30.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9e',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450846) 83 days, 0:55:08.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '879',
                        IFNAME           => 'ge-1/0/31.0',
                        IFDESCR          => 'ge-1/0/31.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9f',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450851) 83 days, 0:55:08.51',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '880',
                        IFNAME           => 'ge-1/0/32.0',
                        IFDESCR          => 'ge-1/0/32.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a0',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450860) 83 days, 0:55:08.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '881',
                        IFNAME           => 'ge-1/0/33.0',
                        IFDESCR          => 'ge-1/0/33.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a1',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1564340617) 181 days, 1:23:26.17',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1240794',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '81620896',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '882',
                        IFNAME           => 'ge-1/0/34.0',
                        IFDESCR          => 'ge-1/0/34.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a2',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450875) 83 days, 0:55:08.75',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '883',
                        IFNAME           => 'ge-1/0/35.0',
                        IFDESCR          => 'ge-1/0/35.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a3',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450885) 83 days, 0:55:08.85',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '884',
                        IFNAME           => 'ge-1/0/36.0',
                        IFDESCR          => 'ge-1/0/36.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a4',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450897) 83 days, 0:55:08.97',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '885',
                        IFNAME           => 'ge-1/0/37.0',
                        IFDESCR          => 'ge-1/0/37.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a5',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1563250557) 180 days, 22:21:45.57',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '157173',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '557581059',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '886',
                        IFNAME           => 'ge-1/0/38.0',
                        IFDESCR          => 'ge-1/0/38.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a6',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450906) 83 days, 0:55:09.06',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '887',
                        IFNAME           => 'ge-1/0/39.0',
                        IFDESCR          => 'ge-1/0/39.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a7',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578926177) 182 days, 17:54:21.77',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '439536',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '22582434',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '70:f3:95:19:28:f0',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '888',
                        IFNAME           => 'ge-1/0/4.0',
                        IFDESCR          => 'ge-1/0/4.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:84',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1579371027) 182 days, 19:08:30.27',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '4487602',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '81018645',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'f0:de:f1:a8:93:e1',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '889',
                        IFNAME           => 'ge-1/0/40.0',
                        IFDESCR          => 'ge-1/0/40.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889630237) 102 days, 23:11:42.37',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '77870',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '526809134',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:14:38:d9:ad:17',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '890',
                        IFNAME           => 'ge-1/0/41.0',
                        IFDESCR          => 'ge-1/0/41.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a9',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1579225957) 182 days, 18:44:19.57',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '202825',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '154169972',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:1c:c0:fd:72:fb',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '891',
                        IFNAME           => 'ge-1/0/42.0',
                        IFDESCR          => 'ge-1/0/42.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:aa',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1547175007) 179 days, 1:42:30.07',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2001766',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '559025754',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '892',
                        IFNAME           => 'ge-1/0/43.0',
                        IFDESCR          => 'ge-1/0/43.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ab',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1562377137) 180 days, 19:56:11.37',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '125601',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '554394456',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:1b:78:1b:e4:8b',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '893',
                        IFNAME           => 'ge-1/0/44.0',
                        IFDESCR          => 'ge-1/0/44.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ac',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450953) 83 days, 0:55:09.53',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '894',
                        IFNAME           => 'ge-1/0/45.0',
                        IFDESCR          => 'ge-1/0/45.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ad',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450959) 83 days, 0:55:09.59',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '895',
                        IFNAME           => 'ge-1/0/46.0',
                        IFDESCR          => 'ge-1/0/46.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ae',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450968) 83 days, 0:55:09.68',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '896',
                        IFNAME           => 'ge-1/0/47.0',
                        IFDESCR          => 'ge-1/0/47.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:af',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450976) 83 days, 0:55:09.76',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '897',
                        IFNAME           => 'ge-1/0/5.0',
                        IFDESCR          => 'ge-1/0/5.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:85',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450583) 83 days, 0:55:05.83',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '898',
                        IFNAME           => 'ge-1/0/6.0',
                        IFDESCR          => 'ge-1/0/6.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:86',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1303083182) 150 days, 19:40:31.82',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '48063',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '335567',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '899',
                        IFNAME           => 'ge-1/0/7.0',
                        IFDESCR          => 'ge-1/0/7.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:87',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450604) 83 days, 0:55:06.04',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '900',
                        IFNAME           => 'ge-1/0/8.0',
                        IFDESCR          => 'ge-1/0/8.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:88',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450618) 83 days, 0:55:06.18',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '901',
                        IFNAME           => 'ge-1/0/9.0',
                        IFDESCR          => 'ge-1/0/9.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:89',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1380784997) 159 days, 19:30:49.97',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '123727',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '558733495',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:14:38:a4:ea:7a',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '902',
                        IFNAME           => 'ge-2/0/0.0',
                        IFDESCR          => 'ge-2/0/0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:80',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889649022) 102 days, 23:14:50.22',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '903',
                        IFNAME           => 'ge-2/0/1.0',
                        IFDESCR          => 'ge-2/0/1.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:81',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1277376497) 147 days, 20:16:04.97',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '66569',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4920691',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '904',
                        IFNAME           => 'ge-2/0/10.0',
                        IFDESCR          => 'ge-2/0/10.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8a',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889649029) 102 days, 23:14:50.29',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '905',
                        IFNAME           => 'ge-2/0/11.0',
                        IFDESCR          => 'ge-2/0/11.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578979224) 182 days, 18:03:12.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '107861',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '446314475',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:1c:c0:8f:46:75',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '906',
                        IFNAME           => 'ge-2/0/12.0',
                        IFDESCR          => 'ge-2/0/12.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578972824) 182 days, 18:02:08.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '84585',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '446320174',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:1c:c0:8f:44:f4',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '907',
                        IFNAME           => 'ge-2/0/13.0',
                        IFDESCR          => 'ge-2/0/13.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8d',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889649030) 102 days, 23:14:50.30',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '908',
                        IFNAME           => 'ge-2/0/14.0',
                        IFDESCR          => 'ge-2/0/14.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8e',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889649031) 102 days, 23:14:50.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '909',
                        IFNAME           => 'ge-2/0/15.0',
                        IFDESCR          => 'ge-2/0/15.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578928254) 182 days, 17:54:42.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '64500',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '447223543',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '44:37:e6:63:50:86',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '910',
                        IFNAME           => 'ge-2/0/16.0',
                        IFDESCR          => 'ge-2/0/16.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:90',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889649032) 102 days, 23:14:50.32',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '911',
                        IFNAME           => 'ge-2/0/17.0',
                        IFDESCR          => 'ge-2/0/17.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:91',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889649033) 102 days, 23:14:50.33',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '912',
                        IFNAME           => 'ge-2/0/18.0',
                        IFDESCR          => 'ge-2/0/18.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:92',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1572916894) 182 days, 1:12:48.94',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '67302',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '446310721',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '913',
                        IFNAME           => 'ge-2/0/19.0',
                        IFDESCR          => 'ge-2/0/19.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:93',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578584634) 182 days, 16:57:26.34',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '722484',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '69604822',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:1f:29:20:ce:bd',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '914',
                        IFNAME           => 'ge-2/0/2.0',
                        IFDESCR          => 'ge-2/0/2.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:82',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1579089654) 182 days, 18:21:36.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1754026',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '163649008',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '2c:76:8a:40:ff:fc',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '915',
                        IFNAME           => 'ge-2/0/20.0',
                        IFDESCR          => 'ge-2/0/20.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:94',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578587184) 182 days, 16:57:51.84',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '667694',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '213968655',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '44:37:e6:bb:a4:4a',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '916',
                        IFNAME           => 'ge-2/0/21.0',
                        IFDESCR          => 'ge-2/0/21.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:95',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1328744065) 153 days, 18:57:20.65',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '5700',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '91401',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '917',
                        IFNAME           => 'ge-2/0/22.0',
                        IFDESCR          => 'ge-2/0/22.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:96',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889649037) 102 days, 23:14:50.37',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '918',
                        IFNAME           => 'ge-2/0/23.0',
                        IFDESCR          => 'ge-2/0/23.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:97',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889649038) 102 days, 23:14:50.38',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '919',
                        IFNAME           => 'ge-2/0/24.0',
                        IFDESCR          => 'ge-2/0/24.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:98',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889649039) 102 days, 23:14:50.39',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '920',
                        IFNAME           => 'ge-2/0/25.0',
                        IFDESCR          => 'ge-2/0/25.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:99',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578771194) 182 days, 17:28:31.94',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '76277',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '446302343',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '1c:6f:65:0e:90:4d',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '921',
                        IFNAME           => 'ge-2/0/26.0',
                        IFDESCR          => 'ge-2/0/26.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9a',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889649040) 102 days, 23:14:50.40',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '922',
                        IFNAME           => 'ge-2/0/27.0',
                        IFDESCR          => 'ge-2/0/27.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9b',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889649040) 102 days, 23:14:50.40',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '923',
                        IFNAME           => 'ge-2/0/28.0',
                        IFDESCR          => 'ge-2/0/28.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1579064374) 182 days, 18:17:23.74',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '47679',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '446256829',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '44:37:e6:63:4c:e9',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '924',
                        IFNAME           => 'ge-2/0/29.0',
                        IFDESCR          => 'ge-2/0/29.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9d',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889649041) 102 days, 23:14:50.41',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '925',
                        IFNAME           => 'ge-2/0/3.0',
                        IFDESCR          => 'ge-2/0/3.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:83',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578862754) 182 days, 17:43:47.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '624410',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '446047083',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '1c:6f:65:09:57:46',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '926',
                        IFNAME           => 'ge-2/0/30.0',
                        IFDESCR          => 'ge-2/0/30.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9e',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889649042) 102 days, 23:14:50.42',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '927',
                        IFNAME           => 'ge-2/0/31.0',
                        IFDESCR          => 'ge-2/0/31.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9f',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889649043) 102 days, 23:14:50.43',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '928',
                        IFNAME           => 'ge-2/0/32.0',
                        IFDESCR          => 'ge-2/0/32.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a0',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889649043) 102 days, 23:14:50.43',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '929',
                        IFNAME           => 'ge-2/0/33.0',
                        IFDESCR          => 'ge-2/0/33.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a1',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889649044) 102 days, 23:14:50.44',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '930',
                        IFNAME           => 'ge-2/0/34.0',
                        IFDESCR          => 'ge-2/0/34.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a2',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1322849014) 153 days, 2:34:50.14',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '98115',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '446560381',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:20:6b:7a:1f:8c',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '931',
                        IFNAME           => 'ge-2/0/35.0',
                        IFDESCR          => 'ge-2/0/35.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a3',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889649045) 102 days, 23:14:50.45',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '932',
                        IFNAME           => 'ge-2/0/36.0',
                        IFDESCR          => 'ge-2/0/36.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a4',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889649046) 102 days, 23:14:50.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '933',
                        IFNAME           => 'ge-2/0/37.0',
                        IFDESCR          => 'ge-2/0/37.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a5',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578869584) 182 days, 17:44:55.84',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '296918',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '447214884',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:1c:c0:9b:31:e2',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '934',
                        IFNAME           => 'ge-2/0/38.0',
                        IFDESCR          => 'ge-2/0/38.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a6',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889649052) 102 days, 23:14:50.52',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '935',
                        IFNAME           => 'ge-2/0/39.0',
                        IFDESCR          => 'ge-2/0/39.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a7',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578551944) 182 days, 16:51:59.44',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '515540',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '447074797',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:1c:c0:9b:30:e9',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '936',
                        IFNAME           => 'ge-2/0/4.0',
                        IFDESCR          => 'ge-2/0/4.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:84',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889649025) 102 days, 23:14:50.25',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '937',
                        IFNAME           => 'ge-2/0/40.0',
                        IFDESCR          => 'ge-2/0/40.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1485792124) 171 days, 23:12:01.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1775857',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '446280862',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '78:e3:b5:f7:f0:ca',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '938',
                        IFNAME           => 'ge-2/0/41.0',
                        IFDESCR          => 'ge-2/0/41.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a9',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578870914) 182 days, 17:45:09.14',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '425059',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '447065337',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:1c:c0:9b:58:fd',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '939',
                        IFNAME           => 'ge-2/0/42.0',
                        IFDESCR          => 'ge-2/0/42.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:aa',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889649057) 102 days, 23:14:50.57',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '940',
                        IFNAME           => 'ge-2/0/43.0',
                        IFDESCR          => 'ge-2/0/43.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ab',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889649058) 102 days, 23:14:50.58',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '941',
                        IFNAME           => 'ge-2/0/44.0',
                        IFDESCR          => 'ge-2/0/44.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ac',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889649059) 102 days, 23:14:50.59',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '942',
                        IFNAME           => 'ge-2/0/45.0',
                        IFDESCR          => 'ge-2/0/45.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ad',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889649060) 102 days, 23:14:50.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '943',
                        IFNAME           => 'ge-2/0/46.0',
                        IFDESCR          => 'ge-2/0/46.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ae',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889649061) 102 days, 23:14:50.61',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '944',
                        IFNAME           => 'ge-2/0/47.0',
                        IFDESCR          => 'ge-2/0/47.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:af',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889649063) 102 days, 23:14:50.63',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '945',
                        IFNAME           => 'ge-2/0/5.0',
                        IFDESCR          => 'ge-2/0/5.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:85',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1579193654) 182 days, 18:38:56.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '92917',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '446027667',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:1c:c0:7f:3d:03',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '946',
                        IFNAME           => 'ge-2/0/6.0',
                        IFDESCR          => 'ge-2/0/6.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:86',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578905654) 182 days, 17:50:56.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '66331',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '446779566',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '70:f3:95:13:86:cc',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '947',
                        IFNAME           => 'ge-2/0/7.0',
                        IFDESCR          => 'ge-2/0/7.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:87',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889649026) 102 days, 23:14:50.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '948',
                        IFNAME           => 'ge-2/0/8.0',
                        IFDESCR          => 'ge-2/0/8.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:88',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1192428913) 138 days, 0:18:09.13',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '72863',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '446348488',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:20:6b:7c:f8:09',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '949',
                        IFNAME           => 'ge-2/0/9.0',
                        IFDESCR          => 'ge-2/0/9.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:89',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889649028) 102 days, 23:14:50.28',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '950',
                        IFNAME           => 'ae1.0',
                        IFDESCR          => 'ae1.0',
                        IFTYPE           => '161',
                        IFSPEED          => '2000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:81',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1401320591) 162 days, 4:33:25.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '889063067',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:0b:dc:00:b2:11',
                                    '2c:6b:f5:99:7c:00',
                                    '2c:6b:f5:99:7c:01',
                                    '00:17:08:87:8e:32',
                                    '00:1b:78:11:e8:82',
                                    '00:20:6b:7a:d0:06',
                                    '00:0b:5d:9a:0d:3f',
                                    '00:21:9b:60:d0:4e',
                                    '00:25:64:94:47:8b',
                                    '84:2b:2b:ad:5a:d8',
                                    '88:f0:77:59:d9:ae',
                                    '14:fe:b5:b8:c2:03',
                                    'e8:11:32:61:38:ef',
                                    'f0:4d:a2:61:f0:98',
                                    'f0:4d:a2:61:f0:e8',
                                    '5c:f9:dd:41:55:61',
                                    '00:08:5d:29:93:38',
                                    '00:50:60:0d:11:08',
                                    '00:50:60:05:e9:8b',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '951',
                        IFNAME           => 'ge-1/0/0.0',
                        IFDESCR          => 'ge-1/0/0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:81',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(717450883) 83 days, 0:55:08.83',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '94543444',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '579626734',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFNUMBER => '504',
                                IFDESCR  => 'ge-0/0/1.0',
                                SYSNAME  => 'jte4-02',
                                SYSDESCR => 'Juniper Networks, Inc. ex3200-48p , version 10.3R1.9 Build date: 2010-08-13 12:56:38 UTC ',
                                SYSMAC   => '2c:6b:f5:99:7c:00',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '952',
                        IFNAME           => 'ge-4/0/0.0',
                        IFDESCR          => 'ge-4/0/0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:80',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1442976434) 167 days, 0:16:04.34',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '180298',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '240732643',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '953',
                        IFNAME           => 'ge-4/0/1.0',
                        IFDESCR          => 'ge-4/0/1.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:81',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1565042078) 181 days, 3:20:20.78',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '7182',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '11166785',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '954',
                        IFNAME           => 'ge-4/0/2.0',
                        IFDESCR          => 'ge-4/0/2.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:82',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1071466880) 124 days, 0:17:48.80',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '955',
                        IFNAME           => 'ge-4/0/3.0',
                        IFDESCR          => 'ge-4/0/3.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:83',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578609968) 182 days, 17:01:39.68',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '11040',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '319003774',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:1a:a0:ba:e2:a6',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '956',
                        IFNAME           => 'ge-4/0/4.0',
                        IFDESCR          => 'ge-4/0/4.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:84',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1510174878) 174 days, 18:55:48.78',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '96031',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '88477095',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '84:2b:2b:ab:ee:ad',
                                    '84:2b:2b:ab:ef:d7',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '957',
                        IFNAME           => 'ge-4/0/5.0',
                        IFDESCR          => 'ge-4/0/5.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:85',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1510153146) 174 days, 18:52:11.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '750',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4685',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '958',
                        IFNAME           => 'ge-5/0/38.0',
                        IFDESCR          => 'ge-5/0/38.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a6',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1071467904) 124 days, 0:17:59.04',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '959',
                        IFNAME           => 'ge-5/0/39.0',
                        IFDESCR          => 'ge-5/0/39.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a7',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1573567062) 182 days, 3:01:10.62',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3138238',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '94885107',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '960',
                        IFNAME           => 'ge-5/0/41.0',
                        IFDESCR          => 'ge-5/0/41.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a9',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1071467937) 124 days, 0:17:59.37',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '961',
                        IFNAME           => 'ge-5/0/42.0',
                        IFDESCR          => 'ge-5/0/42.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:aa',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578548403) 182 days, 16:51:24.03',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '108613',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '105532936',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:25:64:bd:f1:fb',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '962',
                        IFNAME           => 'ge-5/0/43.0',
                        IFDESCR          => 'ge-5/0/43.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ab',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1071467955) 124 days, 0:17:59.55',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '963',
                        IFNAME           => 'ge-5/0/44.0',
                        IFDESCR          => 'ge-5/0/44.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ac',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1521519295) 176 days, 2:26:32.95',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '42279',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '33655471',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '964',
                        IFNAME           => 'ge-5/0/45.0',
                        IFDESCR          => 'ge-5/0/45.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ad',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1071469953) 124 days, 0:18:19.53',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '329379227',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:0d:a0:01:51:38',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '965',
                        IFNAME           => 'ge-5/0/46.0',
                        IFDESCR          => 'ge-5/0/46.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ae',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1071469953) 124 days, 0:18:19.53',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '329386182',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:0d:a0:01:50:14',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '966',
                        IFNAME           => 'ge-4/0/23.0',
                        IFDESCR          => 'ge-4/0/23.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:97',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578618687) 182 days, 17:03:06.87',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '97504252',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:08:9b:80:83:38',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '967',
                        IFNAME           => 'ge-4/0/6.0',
                        IFDESCR          => 'ge-4/0/6.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:86',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578616548) 182 days, 17:02:45.48',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '7680',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '84556688',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '968',
                        IFNAME           => 'ge-4/0/7.0',
                        IFDESCR          => 'ge-4/0/7.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:87',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1578616157) 182 days, 17:02:41.57',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '9720',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '133065023',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '969',
                        IFNAME           => 'ge-4/0/8.0',
                        IFDESCR          => 'ge-4/0/8.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:88',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1574023308) 182 days, 4:17:13.08',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '22284',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '329192800',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '970',
                        IFNAME           => 'ge-4/0/9.0',
                        IFDESCR          => 'ge-4/0/9.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:89',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1071466953) 124 days, 0:17:49.53',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '971',
                        IFNAME           => 'ge-3/0/1.0',
                        IFDESCR          => 'ge-3/0/1.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:81',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646425) 102 days, 23:14:24.25',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '972',
                        IFNAME           => 'ge-3/0/10.0',
                        IFDESCR          => 'ge-3/0/10.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8a',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1453627976) 168 days, 5:51:19.76',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '37976',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6084067',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '973',
                        IFNAME           => 'ge-3/0/11.0',
                        IFDESCR          => 'ge-3/0/11.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8b',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1364234866) 157 days, 21:32:28.66',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '28156',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3630454',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '974',
                        IFNAME           => 'ge-3/0/12.0',
                        IFDESCR          => 'ge-3/0/12.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8c',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1450386691) 167 days, 20:51:06.91',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '45497',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4231984',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '975',
                        IFNAME           => 'ge-3/0/13.0',
                        IFDESCR          => 'ge-3/0/13.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8d',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1450398878) 167 days, 20:53:08.78',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '44968',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4354705',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '976',
                        IFNAME           => 'ge-3/0/14.0',
                        IFDESCR          => 'ge-3/0/14.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8e',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1450388428) 167 days, 20:51:24.28',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '43143',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4354982',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '977',
                        IFNAME           => 'ge-3/0/15.0',
                        IFDESCR          => 'ge-3/0/15.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8f',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1450386802) 167 days, 20:51:08.02',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '47871',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4344816',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '978',
                        IFNAME           => 'ge-3/0/16.0',
                        IFDESCR          => 'ge-3/0/16.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:90',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1520346686) 175 days, 23:11:06.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '22483',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2965103',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '979',
                        IFNAME           => 'ge-3/0/17.0',
                        IFDESCR          => 'ge-3/0/17.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:91',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1520347478) 175 days, 23:11:14.78',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '22570',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2963669',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '980',
                        IFNAME           => 'ge-3/0/18.0',
                        IFDESCR          => 'ge-3/0/18.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:92',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1338153052) 154 days, 21:05:30.52',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '19880',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2856466',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '981',
                        IFNAME           => 'ge-3/0/19.0',
                        IFDESCR          => 'ge-3/0/19.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:93',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1338153360) 154 days, 21:05:33.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '19505',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2907424',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '982',
                        IFNAME           => 'ge-3/0/2.0',
                        IFDESCR          => 'ge-3/0/2.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:82',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1520988290) 176 days, 0:58:02.90',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '143030',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '11200811',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '983',
                        IFNAME           => 'ge-3/0/20.0',
                        IFDESCR          => 'ge-3/0/20.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:94',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1338153274) 154 days, 21:05:32.74',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '27279',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2777341',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '984',
                        IFNAME           => 'ge-3/0/21.0',
                        IFDESCR          => 'ge-3/0/21.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:95',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1338153164) 154 days, 21:05:31.64',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '31430',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3138332',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '985',
                        IFNAME           => 'ge-3/0/22.0',
                        IFDESCR          => 'ge-3/0/22.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:96',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646729) 102 days, 23:14:27.29',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '986',
                        IFNAME           => 'ge-3/0/23.0',
                        IFDESCR          => 'ge-3/0/23.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:97',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646736) 102 days, 23:14:27.36',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '987',
                        IFNAME           => 'ge-3/0/24.0',
                        IFDESCR          => 'ge-3/0/24.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:98',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646744) 102 days, 23:14:27.44',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '988',
                        IFNAME           => 'ge-3/0/25.0',
                        IFDESCR          => 'ge-3/0/25.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:99',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646752) 102 days, 23:14:27.52',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '989',
                        IFNAME           => 'ge-3/0/26.0',
                        IFDESCR          => 'ge-3/0/26.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9a',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646762) 102 days, 23:14:27.62',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '990',
                        IFNAME           => 'ge-3/0/27.0',
                        IFDESCR          => 'ge-3/0/27.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9b',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646777) 102 days, 23:14:27.77',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '991',
                        IFNAME           => 'ge-3/0/28.0',
                        IFDESCR          => 'ge-3/0/28.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9c',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646767) 102 days, 23:14:27.67',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '992',
                        IFNAME           => 'ge-3/0/29.0',
                        IFDESCR          => 'ge-3/0/29.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9d',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646786) 102 days, 23:14:27.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '993',
                        IFNAME           => 'ge-3/0/3.0',
                        IFDESCR          => 'ge-3/0/3.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:83',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1450384926) 167 days, 20:50:49.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '55144',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4511091',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '994',
                        IFNAME           => 'ge-3/0/30.0',
                        IFDESCR          => 'ge-3/0/30.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9e',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646796) 102 days, 23:14:27.96',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '995',
                        IFNAME           => 'ge-3/0/31.0',
                        IFDESCR          => 'ge-3/0/31.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9f',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646804) 102 days, 23:14:28.04',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '996',
                        IFNAME           => 'ge-3/0/32.0',
                        IFDESCR          => 'ge-3/0/32.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a0',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646814) 102 days, 23:14:28.14',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '997',
                        IFNAME           => 'ge-3/0/33.0',
                        IFDESCR          => 'ge-3/0/33.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a1',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646820) 102 days, 23:14:28.20',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '998',
                        IFNAME           => 'ge-3/0/34.0',
                        IFDESCR          => 'ge-3/0/34.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a2',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646826) 102 days, 23:14:28.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '999',
                        IFNAME           => 'ge-3/0/35.0',
                        IFDESCR          => 'ge-3/0/35.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a3',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646832) 102 days, 23:14:28.32',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1000',
                        IFNAME           => 'ge-3/0/36.0',
                        IFDESCR          => 'ge-3/0/36.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a4',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646840) 102 days, 23:14:28.40',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1001',
                        IFNAME           => 'ge-3/0/37.0',
                        IFDESCR          => 'ge-3/0/37.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a5',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646849) 102 days, 23:14:28.49',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1002',
                        IFNAME           => 'ge-3/0/38.0',
                        IFDESCR          => 'ge-3/0/38.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a6',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646857) 102 days, 23:14:28.57',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1003',
                        IFNAME           => 'ge-3/0/39.0',
                        IFDESCR          => 'ge-3/0/39.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a7',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646864) 102 days, 23:14:28.64',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1004',
                        IFNAME           => 'ge-3/0/4.0',
                        IFDESCR          => 'ge-3/0/4.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:84',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1450387743) 167 days, 20:51:17.43',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '56034',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6127299',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1005',
                        IFNAME           => 'ge-3/0/40.0',
                        IFDESCR          => 'ge-3/0/40.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a8',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646871) 102 days, 23:14:28.71',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1006',
                        IFNAME           => 'ge-3/0/41.0',
                        IFDESCR          => 'ge-3/0/41.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a9',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646879) 102 days, 23:14:28.79',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1007',
                        IFNAME           => 'ge-3/0/42.0',
                        IFDESCR          => 'ge-3/0/42.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:aa',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646902) 102 days, 23:14:29.02',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1008',
                        IFNAME           => 'ge-3/0/43.0',
                        IFDESCR          => 'ge-3/0/43.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ab',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646934) 102 days, 23:14:29.34',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1009',
                        IFNAME           => 'ge-3/0/44.0',
                        IFDESCR          => 'ge-3/0/44.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ac',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646938) 102 days, 23:14:29.38',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1010',
                        IFNAME           => 'ge-3/0/45.0',
                        IFDESCR          => 'ge-3/0/45.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ad',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646958) 102 days, 23:14:29.58',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1011',
                        IFNAME           => 'ge-3/0/46.0',
                        IFDESCR          => 'ge-3/0/46.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ae',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646978) 102 days, 23:14:29.78',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1012',
                        IFNAME           => 'ge-3/0/47.0',
                        IFDESCR          => 'ge-3/0/47.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:af',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646986) 102 days, 23:14:29.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1013',
                        IFNAME           => 'ge-3/0/5.0',
                        IFDESCR          => 'ge-3/0/5.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:85',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1450387216) 167 days, 20:51:12.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '64944',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '8987124',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1014',
                        IFNAME           => 'ge-3/0/6.0',
                        IFDESCR          => 'ge-3/0/6.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:86',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1520369320) 175 days, 23:14:53.20',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '64493',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '5600333',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1015',
                        IFNAME           => 'ge-3/0/7.0',
                        IFDESCR          => 'ge-3/0/7.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:87',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1450388998) 167 days, 20:51:29.98',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '69468',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '8647621',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1016',
                        IFNAME           => 'ge-3/0/8.0',
                        IFDESCR          => 'ge-3/0/8.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:88',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1450401450) 167 days, 20:53:34.50',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '45500',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2946953',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1017',
                        IFNAME           => 'ge-3/0/9.0',
                        IFDESCR          => 'ge-3/0/9.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:89',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1520251378) 175 days, 22:55:13.78',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '65024',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6387035',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1018',
                        IFNAME           => 'ge-4/0/10.0',
                        IFDESCR          => 'ge-4/0/10.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8a',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1513317590) 175 days, 3:39:35.90',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '405945',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1777313',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1019',
                        IFNAME           => 'ge-4/0/11.0',
                        IFDESCR          => 'ge-4/0/11.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8b',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1547189561) 179 days, 1:44:55.61',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '271960',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2685389',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1020',
                        IFNAME           => 'ge-4/0/12.0',
                        IFDESCR          => 'ge-4/0/12.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8c',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1261267893) 145 days, 23:31:18.93',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '42474',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '183215',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1021',
                        IFNAME           => 'ge-4/0/13.0',
                        IFDESCR          => 'ge-4/0/13.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8d',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1573227018) 182 days, 2:04:30.18',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '485324',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1957349',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1022',
                        IFNAME           => 'ge-4/0/14.0',
                        IFDESCR          => 'ge-4/0/14.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8e',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1502383224) 173 days, 21:17:12.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '302171',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3246961',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1023',
                        IFNAME           => 'ge-4/0/15.0',
                        IFDESCR          => 'ge-4/0/15.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8f',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1562688204) 180 days, 20:48:02.04',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '270593',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2360225',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1024',
                        IFNAME           => 'ge-4/0/16.0',
                        IFDESCR          => 'ge-4/0/16.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:90',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1486971782) 172 days, 2:28:37.82',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '142748',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1607515',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1025',
                        IFNAME           => 'ge-4/0/17.0',
                        IFDESCR          => 'ge-4/0/17.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:91',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1452293958) 168 days, 2:08:59.58',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '245536',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2005526',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1026',
                        IFNAME           => 'ge-4/0/18.0',
                        IFDESCR          => 'ge-4/0/18.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:92',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1451188038) 167 days, 23:04:40.38',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '796',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1027',
                        IFNAME           => 'ge-4/0/19.0',
                        IFDESCR          => 'ge-4/0/19.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:93',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1563849546) 181 days, 0:01:35.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '182760',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1416969',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1028',
                        IFNAME           => 'ge-4/0/20.0',
                        IFDESCR          => 'ge-4/0/20.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:94',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1457971644) 168 days, 17:55:16.44',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '262017',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2011766',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1029',
                        IFNAME           => 'ge-4/0/21.0',
                        IFDESCR          => 'ge-4/0/21.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:95',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1260778133) 145 days, 22:09:41.33',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '293820',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2323281',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1030',
                        IFNAME           => 'ge-4/0/22.0',
                        IFDESCR          => 'ge-4/0/22.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:96',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1521627060) 176 days, 2:44:30.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '78693',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '869618',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1031',
                        IFNAME           => 'ge-4/0/24.0',
                        IFDESCR          => 'ge-4/0/24.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:98',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1425677372) 165 days, 0:12:53.72',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '248218',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '875417',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1032',
                        IFNAME           => 'ge-4/0/25.0',
                        IFDESCR          => 'ge-4/0/25.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:99',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1424888386) 164 days, 22:01:23.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '254265',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1314895',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1033',
                        IFNAME           => 'ge-4/0/26.0',
                        IFDESCR          => 'ge-4/0/26.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9a',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1572311952) 181 days, 23:31:59.52',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '835968',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3161191',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1034',
                        IFNAME           => 'ge-4/0/27.0',
                        IFDESCR          => 'ge-4/0/27.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9b',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1521697066) 176 days, 2:56:10.66',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '111918',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1405760',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1035',
                        IFNAME           => 'ge-4/0/28.0',
                        IFDESCR          => 'ge-4/0/28.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9c',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1561658646) 180 days, 17:56:26.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '334526',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1726456',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1036',
                        IFNAME           => 'ge-4/0/29.0',
                        IFDESCR          => 'ge-4/0/29.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9d',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1504620827) 174 days, 3:30:08.27',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '17051',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '196812',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1037',
                        IFNAME           => 'ge-4/0/30.0',
                        IFDESCR          => 'ge-4/0/30.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9e',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1548020706) 179 days, 4:03:27.06',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '478691',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1977677',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1038',
                        IFNAME           => 'ge-4/0/31.0',
                        IFDESCR          => 'ge-4/0/31.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9f',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1444288680) 167 days, 3:54:46.80',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '383327',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1554424',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1039',
                        IFNAME           => 'ge-4/0/32.0',
                        IFDESCR          => 'ge-4/0/32.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a0',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1346820566) 155 days, 21:10:05.66',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '82189',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '549718',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1040',
                        IFNAME           => 'ge-4/0/33.0',
                        IFDESCR          => 'ge-4/0/33.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a1',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1494210849) 172 days, 22:35:08.49',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '320148',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '882286',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1041',
                        IFNAME           => 'ge-4/0/34.0',
                        IFDESCR          => 'ge-4/0/34.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a2',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1579356778) 182 days, 19:06:07.78',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '583990',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '5185945',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:21:cc:57:73:30',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1042',
                        IFNAME           => 'ge-4/0/35.0',
                        IFDESCR          => 'ge-4/0/35.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a3',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1563844404) 181 days, 0:00:44.04',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '28033',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '55291',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1043',
                        IFNAME           => 'ge-4/0/36.0',
                        IFDESCR          => 'ge-4/0/36.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a4',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1486855674) 172 days, 2:09:16.74',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '219827',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1262005',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1044',
                        IFNAME           => 'ge-4/0/37.0',
                        IFDESCR          => 'ge-4/0/37.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a5',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1554987262) 179 days, 23:24:32.62',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '39436',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '507797',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1045',
                        IFNAME           => 'ge-4/0/38.0',
                        IFDESCR          => 'ge-4/0/38.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a6',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1555608214) 180 days, 1:08:02.14',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '431743',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2505337',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1046',
                        IFNAME           => 'ge-4/0/39.0',
                        IFDESCR          => 'ge-4/0/39.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a7',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1545422722) 178 days, 20:50:27.22',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '471935',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3019233',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1047',
                        IFNAME           => 'ge-4/0/40.0',
                        IFDESCR          => 'ge-4/0/40.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a8',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1563754030) 180 days, 23:45:40.30',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '388026',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1654144',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1048',
                        IFNAME           => 'ge-4/0/41.0',
                        IFDESCR          => 'ge-4/0/41.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a9',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1555609888) 180 days, 1:08:18.88',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '265438',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1525142',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1049',
                        IFNAME           => 'ge-4/0/42.0',
                        IFDESCR          => 'ge-4/0/42.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:aa',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1555987738) 180 days, 2:11:17.38',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '424780',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3875390',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1050',
                        IFNAME           => 'ge-4/0/43.0',
                        IFDESCR          => 'ge-4/0/43.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ab',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1442185282) 166 days, 22:04:12.82',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '50074',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '199380',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1051',
                        IFNAME           => 'ge-4/0/44.0',
                        IFDESCR          => 'ge-4/0/44.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ac',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1390509782) 160 days, 22:31:37.82',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '6744',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1545',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1052',
                        IFNAME           => 'ge-4/0/45.0',
                        IFDESCR          => 'ge-4/0/45.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ad',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1572042943) 181 days, 22:47:09.43',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '691379',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '5820489',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1053',
                        IFNAME           => 'ge-4/0/46.0',
                        IFDESCR          => 'ge-4/0/46.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:ae',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1277476099) 147 days, 20:32:40.99',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '31883',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '545866',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1054',
                        IFNAME           => 'ge-4/0/47.0',
                        IFDESCR          => 'ge-4/0/47.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:af',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1450302458) 167 days, 20:37:04.58',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '255078',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2473863',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1055',
                        IFNAME           => 'ge-5/0/1.0',
                        IFDESCR          => 'ge-5/0/1.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:81',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1451300698) 167 days, 23:23:26.98',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '189600',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '985388',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1056',
                        IFNAME           => 'ge-5/0/10.0',
                        IFDESCR          => 'ge-5/0/10.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8a',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1261147396) 145 days, 23:11:13.96',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '60332',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '530510',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1057',
                        IFNAME           => 'ge-5/0/11.0',
                        IFDESCR          => 'ge-5/0/11.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8b',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1554633641) 179 days, 22:25:36.41',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '15243',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '15630',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1058',
                        IFNAME           => 'ge-5/0/12.0',
                        IFDESCR          => 'ge-5/0/12.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8c',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1071467652) 124 days, 0:17:56.52',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1059',
                        IFNAME           => 'ge-5/0/13.0',
                        IFDESCR          => 'ge-5/0/13.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8d',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1254004460) 145 days, 3:20:44.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '103833',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '497765',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1060',
                        IFNAME           => 'ge-5/0/14.0',
                        IFDESCR          => 'ge-5/0/14.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8e',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1519633418) 175 days, 21:12:14.18',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '177072',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1143993',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1061',
                        IFNAME           => 'ge-5/0/15.0',
                        IFDESCR          => 'ge-5/0/15.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:8f',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1389868950) 160 days, 20:44:49.50',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '14492',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '15998',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1062',
                        IFNAME           => 'ge-5/0/16.0',
                        IFDESCR          => 'ge-5/0/16.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:90',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1554786300) 179 days, 22:51:03.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '236903',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1709315',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1063',
                        IFNAME           => 'ge-5/0/17.0',
                        IFDESCR          => 'ge-5/0/17.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:91',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1547593680) 179 days, 2:52:16.80',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '177990',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1655449',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1064',
                        IFNAME           => 'ge-5/0/18.0',
                        IFDESCR          => 'ge-5/0/18.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:92',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1565237721) 181 days, 3:52:57.21',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '100252',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1107028',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1065',
                        IFNAME           => 'ge-5/0/19.0',
                        IFDESCR          => 'ge-5/0/19.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:93',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1459729300) 168 days, 22:48:13.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '163554',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1179139',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1066',
                        IFNAME           => 'ge-5/0/2.0',
                        IFDESCR          => 'ge-5/0/2.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:82',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1484763324) 171 days, 20:20:33.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '266050',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1272858',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1067',
                        IFNAME           => 'ge-5/0/20.0',
                        IFDESCR          => 'ge-5/0/20.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:94',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1553552604) 179 days, 19:25:26.04',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '63978',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '81261',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1068',
                        IFNAME           => 'ge-5/0/21.0',
                        IFDESCR          => 'ge-5/0/21.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:95',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1562109850) 180 days, 19:11:38.50',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '99336',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '982447',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1069',
                        IFNAME           => 'ge-5/0/22.0',
                        IFDESCR          => 'ge-5/0/22.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:96',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1546933044) 179 days, 1:02:10.44',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '34792',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '458352',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1070',
                        IFNAME           => 'ge-5/0/23.0',
                        IFDESCR          => 'ge-5/0/23.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:97',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1547856186) 179 days, 3:36:01.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '127608',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1119889',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1071',
                        IFNAME           => 'ge-5/0/24.0',
                        IFDESCR          => 'ge-5/0/24.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:98',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1571619548) 181 days, 21:36:35.48',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '19620',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '38985',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1072',
                        IFNAME           => 'ge-5/0/25.0',
                        IFDESCR          => 'ge-5/0/25.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:99',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1572400418) 181 days, 23:46:44.18',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '141972',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '844932',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1073',
                        IFNAME           => 'ge-5/0/26.0',
                        IFDESCR          => 'ge-5/0/26.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9a',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1484727143) 171 days, 20:14:31.43',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '452868',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1011460',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1074',
                        IFNAME           => 'ge-5/0/27.0',
                        IFDESCR          => 'ge-5/0/27.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9b',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1443271750) 167 days, 1:05:17.50',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '37496',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '356792',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1075',
                        IFNAME           => 'ge-5/0/28.0',
                        IFDESCR          => 'ge-5/0/28.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9c',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1432715230) 165 days, 19:45:52.30',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '796',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1076',
                        IFNAME           => 'ge-5/0/29.0',
                        IFDESCR          => 'ge-5/0/29.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9d',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1365333952) 158 days, 0:35:39.52',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '951427',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1494699',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1077',
                        IFNAME           => 'ge-5/0/3.0',
                        IFDESCR          => 'ge-5/0/3.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:83',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1555932102) 180 days, 2:02:01.02',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '369814',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3030828',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1078',
                        IFNAME           => 'ge-5/0/30.0',
                        IFDESCR          => 'ge-5/0/30.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9e',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1556438310) 180 days, 3:26:23.10',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '189241',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1207069',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1079',
                        IFNAME           => 'ge-5/0/31.0',
                        IFDESCR          => 'ge-5/0/31.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:9f',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1363902920) 157 days, 20:37:09.20',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '132152',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1052473',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1080',
                        IFNAME           => 'ge-5/0/32.0',
                        IFDESCR          => 'ge-5/0/32.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a0',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1510880886) 174 days, 20:53:28.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '316337',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '495685',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1081',
                        IFNAME           => 'ge-5/0/33.0',
                        IFDESCR          => 'ge-5/0/33.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a1',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1071467855) 124 days, 0:17:58.55',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1082',
                        IFNAME           => 'ge-5/0/34.0',
                        IFDESCR          => 'ge-5/0/34.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a2',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1390508038) 160 days, 22:31:20.38',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '28297',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '74225',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1083',
                        IFNAME           => 'ge-5/0/35.0',
                        IFDESCR          => 'ge-5/0/35.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a3',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1071467875) 124 days, 0:17:58.75',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1084',
                        IFNAME           => 'ge-5/0/36.0',
                        IFDESCR          => 'ge-5/0/36.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a4',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1391353106) 161 days, 0:52:11.06',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '55934',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '610273',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1085',
                        IFNAME           => 'ge-5/0/37.0',
                        IFDESCR          => 'ge-5/0/37.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a5',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1391354470) 161 days, 0:52:24.70',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '89053',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '550394',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1086',
                        IFNAME           => 'ge-5/0/4.0',
                        IFDESCR          => 'ge-5/0/4.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:84',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1519665226) 175 days, 21:17:32.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '283783',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1784447',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1087',
                        IFNAME           => 'ge-5/0/40.0',
                        IFDESCR          => 'ge-5/0/40.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:a8',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1510174312) 174 days, 18:55:43.12',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1686',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '20663',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1088',
                        IFNAME           => 'ge-5/0/47.0',
                        IFDESCR          => 'ge-5/0/47.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:af',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1071481912) 124 days, 0:20:19.12',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '57471302',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '341928607',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFNUMBER => '534',
                                IFDESCR  => 'ge-0/0/23.0',
                                SYSNAME  => 'jta6-02',
                                SYSDESCR => 'Juniper Networks, Inc. ex2200-24p-4g , version 11.1R3.5 Build date: 2011-06-25 01:00:05 UTC ',
                                SYSMAC   => '78:fe:3d:3f:84:00',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1089',
                        IFNAME           => 'ge-5/0/5.0',
                        IFDESCR          => 'ge-5/0/5.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:85',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1424586254) 164 days, 21:11:02.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '326326',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2645111',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1090',
                        IFNAME           => 'ge-5/0/6.0',
                        IFDESCR          => 'ge-5/0/6.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:86',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1572359425) 181 days, 23:39:54.25',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '295188',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '709660',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1091',
                        IFNAME           => 'ge-5/0/7.0',
                        IFDESCR          => 'ge-5/0/7.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:87',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1520500834) 175 days, 23:36:48.34',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '23563',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '96567',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1092',
                        IFNAME           => 'ge-5/0/8.0',
                        IFDESCR          => 'ge-5/0/8.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:88',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1546292486) 178 days, 23:15:24.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '14015',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '340835',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1093',
                        IFNAME           => 'ge-5/0/9.0',
                        IFDESCR          => 'ge-5/0/9.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:89',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1579320303) 182 days, 19:00:03.03',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '212072',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '754344',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '54:04:a6:40:a2:e6',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1094',
                        IFNAME           => 'ge-3/0/0.0',
                        IFDESCR          => 'ge-3/0/0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '2c:6b:f5:9b:48:80',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(889646416) 102 days, 23:14:24.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1096',
                        IFNAME           => 'jsrv.1',
                        IFDESCR          => 'jsrv.1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '128.0.0.127',
                        MAC              => '2c:6b:f5:9b:05:80',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(665) 0:00:06.65',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        },
    ],
    'juniper/ex6210.01.walk' => [
        {
            TYPE         => 'NETWORKING',
            MANUFACTURER => 'Juniper',
            DESCRIPTION  => 'Juniper Networks, Inc. ex6210 Ethernet Switch, kernel JUNOS 12.3R3.4, Build date: 2013-06-14 01:37:19 UTC Copyright (c) 1996-2013 Juniper Networks, Inc.',

            SNMPHOSTNAME => 'sw-ex6210-tmk',
            LOCATION     => 'Nowhere',
            SERIAL       => 'FB1712090344',
            UPTIME       => '(97258803) 11 days, 6:09:48.03',
            MEMORY       => '0',
            MAC          => '88:e0:f3:b0:68:01',
            IPS          => {
                IP => [
                    '10.20.101.16',
                    '10.20.102.27',
                    '127.0.0.1',
                    '128.0.0.1',
                    '128.0.0.127',
                    '128.0.0.20',
                    '128.0.0.4',
                    '128.0.4.0',
                    '129.0.0.1',
                    '129.0.0.20',
                    '129.0.0.4',
                ],
            },
        },
        {
            INFO => {
                ID           => undef,
                TYPE         => 'NETWORKING',
                MANUFACTURER => 'Juniper',
                COMMENTS     => 'Juniper Networks, Inc. ex6210 Ethernet Switch, kernel JUNOS 12.3R3.4, Build date: 2013-06-14 01:37:19 UTC Copyright (c) 1996-2013 Juniper Networks, Inc.',
                NAME         => 'sw-ex6210-tmk',
                LOCATION     => 'Nowhere',
                SERIAL       => 'FB1712090344',
                UPTIME       => '(97258803) 11 days, 6:09:48.03',
                MEMORY       => '0',
                MAC          => '88:e0:f3:b0:68:01',
                IPS          => {
                    IP => [
                        '10.20.101.16',
                        '10.20.102.27',
                        '127.0.0.1',
                        '128.0.0.1',
                        '128.0.0.127',
                        '128.0.0.20',
                        '128.0.0.4',
                        '128.0.4.0',
                        '129.0.0.1',
                        '129.0.0.20',
                        '129.0.0.4',
                    ],
                },
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '4',
                        IFNAME           => 'lsi',
                        IFDESCR          => 'lsi',
                        IFTYPE           => '150',
                        IFSPEED          => '0',
                        IFMTU            => '1496',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5',
                        IFNAME           => 'dsc',
                        IFDESCR          => 'dsc',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(838) 0:00:08.38',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '6',
                        IFNAME           => 'lo0',
                        IFDESCR          => 'lo0',
                        IFTYPE           => '24',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(838) 0:00:08.38',
                        IFINOCTETS       => '2769770198',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2769945418',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '7',
                        IFNAME           => 'tap',
                        IFDESCR          => 'tap',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(838) 0:00:08.38',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '8',
                        IFNAME           => 'gre',
                        IFDESCR          => 'gre',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(838) 0:00:08.38',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '9',
                        IFNAME           => 'ipip',
                        IFDESCR          => 'ipip',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(838) 0:00:08.38',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10',
                        IFNAME           => 'pime',
                        IFDESCR          => 'pime',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(838) 0:00:08.38',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '11',
                        IFNAME           => 'pimd',
                        IFDESCR          => 'pimd',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(838) 0:00:08.38',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '12',
                        IFNAME           => 'mtun',
                        IFDESCR          => 'mtun',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(838) 0:00:08.38',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '21',
                        IFNAME           => 'lo0.16384',
                        IFDESCR          => 'lo0.16384',
                        IFTYPE           => '24',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IP               => '127.0.0.1',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(838) 0:00:08.38',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '33',
                        IFNAME           => 'me0',
                        IFDESCR          => 'me0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:ff',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(838) 0:00:08.38',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '34',
                        IFNAME           => 'me0.0',
                        IFDESCR          => 'me0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        IP               => '10.20.101.16',
                        MAC              => '88:e0:f3:b0:69:ff',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(17184) 0:02:51.84',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '37',
                        IFNAME           => 'bme0',
                        IFDESCR          => 'bme0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1990',
                        MAC              => '02:44:81:00:00:04',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(834) 0:00:08.34',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2030210619',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '38',
                        IFNAME           => 'bme0.32768',
                        IFDESCR          => 'bme0.32768',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1976',
                        IP               => '128.0.0.4',
                        MAC              => '02:44:81:00:00:04',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(836) 0:00:08.36',
                        IFINOCTETS       => '108770725',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1089703391',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '109',
                        IFNAME           => 'bme1',
                        IFDESCR          => 'bme1',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1990',
                        MAC              => '00:0b:ca:fe:00:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(836) 0:00:08.36',
                        IFINOCTETS       => '2402094266',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3762226682',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '111',
                        IFNAME           => 'bme1.32768',
                        IFDESCR          => 'bme1.32768',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1990',
                        MAC              => '00:0b:ca:fe:00:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(836) 0:00:08.36',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '42755188',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '112',
                        IFNAME           => 'bme2',
                        IFDESCR          => 'bme2',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1990',
                        MAC              => '00:0b:ca:fe:00:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(836) 0:00:08.36',
                        IFINOCTETS       => '525119880',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '56359164',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '114',
                        IFNAME           => 'bme2.32768',
                        IFDESCR          => 'bme2.32768',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1990',
                        MAC              => '00:0b:ca:fe:00:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(837) 0:00:08.37',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '42755224',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '166',
                        IFNAME           => 'bme0.36862',
                        IFDESCR          => 'bme0.36862',
                        IFTYPE           => '135',
                        IFSPEED          => '0',
                        IFMTU            => '1972',
                        IP               => '129.0.0.4',
                        MAC              => '02:44:81:00:00:04',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(836) 0:00:08.36',
                        IFINOCTETS       => '723428982',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '374342061',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '501',
                        IFNAME           => 'jsrv',
                        IFDESCR          => 'jsrv',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '88:e0:f3:b0:68:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(838) 0:00:08.38',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '502',
                        IFNAME           => 'jsrv.1',
                        IFDESCR          => 'jsrv.1',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '128.0.0.127',
                        MAC              => '88:e0:f3:b0:68:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(838) 0:00:08.38',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '42',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '503',
                        IFNAME           => 'vlan',
                        IFDESCR          => 'vlan',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '88:e0:f3:b0:68:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(838) 0:00:08.38',
                        IFINOCTETS       => '365304703',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '417207722',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '504',
                        IFNAME           => 'xe-4/0/0',
                        IFDESCR          => 'xe-4/0/0',
                        IFALIAS          => 'AE to sw-ex8208-tmk',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:1e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(46994329) 5 days, 10:32:23.29',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2772184617',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1729931030',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '508',
                        IFNAME           => 'ge-0/0/0',
                        IFDESCR          => 'ge-0/0/0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:03',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6558) 0:01:05.58',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '509',
                        IFNAME           => 'ge-0/0/1',
                        IFDESCR          => 'ge-0/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:04',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6558) 0:01:05.58',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '510',
                        IFNAME           => 'ge-0/0/2',
                        IFDESCR          => 'ge-0/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:05',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6558) 0:01:05.58',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '511',
                        IFNAME           => 'ge-0/0/3',
                        IFDESCR          => 'ge-0/0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:06',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6558) 0:01:05.58',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '512',
                        IFNAME           => 'ge-0/0/4',
                        IFDESCR          => 'ge-0/0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:07',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6569) 0:01:05.69',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '513',
                        IFNAME           => 'ge-0/0/5',
                        IFDESCR          => 'ge-0/0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:08',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6569) 0:01:05.69',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '514',
                        IFNAME           => 'ge-0/0/6',
                        IFDESCR          => 'ge-0/0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:09',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6570) 0:01:05.70',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '515',
                        IFNAME           => 'ge-0/0/7',
                        IFDESCR          => 'ge-0/0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:0a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6570) 0:01:05.70',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '516',
                        IFNAME           => 'ge-0/0/8',
                        IFDESCR          => 'ge-0/0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:0b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6571) 0:01:05.71',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '517',
                        IFNAME           => 'ge-0/0/9',
                        IFDESCR          => 'ge-0/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:0c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6578) 0:01:05.78',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '518',
                        IFNAME           => 'ge-0/0/10',
                        IFDESCR          => 'ge-0/0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:0d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6578) 0:01:05.78',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '519',
                        IFNAME           => 'ge-0/0/11',
                        IFDESCR          => 'ge-0/0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:0e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6578) 0:01:05.78',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '520',
                        IFNAME           => 'ge-0/0/12',
                        IFDESCR          => 'ge-0/0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:0f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6579) 0:01:05.79',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '521',
                        IFNAME           => 'ge-0/0/13',
                        IFDESCR          => 'ge-0/0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:10',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6588) 0:01:05.88',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '522',
                        IFNAME           => 'ge-0/0/14',
                        IFDESCR          => 'ge-0/0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:11',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6588) 0:01:05.88',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '523',
                        IFNAME           => 'ge-0/0/15',
                        IFDESCR          => 'ge-0/0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:12',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(6589) 0:01:05.89',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '524',
                        IFNAME           => 'ge-0/0/17',
                        IFDESCR          => 'ge-0/0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:14',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7116) 0:01:11.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '525',
                        IFNAME           => 'ge-0/0/16',
                        IFDESCR          => 'ge-0/0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:13',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7115) 0:01:11.15',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '526',
                        IFNAME           => 'ge-0/0/18',
                        IFDESCR          => 'ge-0/0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:15',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7116) 0:01:11.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '527',
                        IFNAME           => 'ge-0/0/19',
                        IFDESCR          => 'ge-0/0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:16',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7117) 0:01:11.17',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '528',
                        IFNAME           => 'ge-0/0/20',
                        IFDESCR          => 'ge-0/0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:17',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7117) 0:01:11.17',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '529',
                        IFNAME           => 'ge-0/0/21',
                        IFDESCR          => 'ge-0/0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:18',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7118) 0:01:11.18',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '530',
                        IFNAME           => 'ge-0/0/22',
                        IFDESCR          => 'ge-0/0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:19',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7118) 0:01:11.18',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '531',
                        IFNAME           => 'ge-0/0/23',
                        IFDESCR          => 'ge-0/0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:1a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7119) 0:01:11.19',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '532',
                        IFNAME           => 'ge-0/0/24',
                        IFDESCR          => 'ge-0/0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:1b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7119) 0:01:11.19',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '533',
                        IFNAME           => 'ge-0/0/25',
                        IFDESCR          => 'ge-0/0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:1c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7120) 0:01:11.20',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '534',
                        IFNAME           => 'ge-0/0/26',
                        IFDESCR          => 'ge-0/0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:1d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7120) 0:01:11.20',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '535',
                        IFNAME           => 'ge-0/0/27',
                        IFDESCR          => 'ge-0/0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:1e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7121) 0:01:11.21',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '536',
                        IFNAME           => 'ge-0/0/28',
                        IFDESCR          => 'ge-0/0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:1f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7121) 0:01:11.21',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '537',
                        IFNAME           => 'ge-0/0/29',
                        IFDESCR          => 'ge-0/0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:20',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7121) 0:01:11.21',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '538',
                        IFNAME           => 'ge-0/0/30',
                        IFDESCR          => 'ge-0/0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:21',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7122) 0:01:11.22',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '539',
                        IFNAME           => 'ge-0/0/31',
                        IFDESCR          => 'ge-0/0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:22',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7122) 0:01:11.22',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '540',
                        IFNAME           => 'ge-0/0/32',
                        IFDESCR          => 'ge-0/0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:23',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7123) 0:01:11.23',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '541',
                        IFNAME           => 'ge-0/0/33',
                        IFDESCR          => 'ge-0/0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:24',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7123) 0:01:11.23',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '542',
                        IFNAME           => 'ge-0/0/34',
                        IFDESCR          => 'ge-0/0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:25',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7124) 0:01:11.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '543',
                        IFNAME           => 'ge-0/0/35',
                        IFDESCR          => 'ge-0/0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:26',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7125) 0:01:11.25',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '544',
                        IFNAME           => 'ge-0/0/36',
                        IFDESCR          => 'ge-0/0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:27',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7125) 0:01:11.25',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '545',
                        IFNAME           => 'ge-0/0/37',
                        IFDESCR          => 'ge-0/0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:28',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7126) 0:01:11.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '546',
                        IFNAME           => 'ge-0/0/38',
                        IFDESCR          => 'ge-0/0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:29',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7126) 0:01:11.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '547',
                        IFNAME           => 'ge-0/0/39',
                        IFDESCR          => 'ge-0/0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:2a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7126) 0:01:11.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '548',
                        IFNAME           => 'ge-0/0/40',
                        IFDESCR          => 'ge-0/0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:2b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7127) 0:01:11.27',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '549',
                        IFNAME           => 'ge-0/0/41',
                        IFDESCR          => 'ge-0/0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:2c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7128) 0:01:11.28',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '550',
                        IFNAME           => 'ge-0/0/42',
                        IFDESCR          => 'ge-0/0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:2d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7128) 0:01:11.28',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '551',
                        IFNAME           => 'ge-0/0/43',
                        IFDESCR          => 'ge-0/0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:2e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7128) 0:01:11.28',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '552',
                        IFNAME           => 'ge-0/0/44',
                        IFDESCR          => 'ge-0/0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:2f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7128) 0:01:11.28',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '553',
                        IFNAME           => 'ge-0/0/45',
                        IFDESCR          => 'ge-0/0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:30',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7129) 0:01:11.29',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '554',
                        IFNAME           => 'ge-0/0/46',
                        IFDESCR          => 'ge-0/0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:31',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7129) 0:01:11.29',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '555',
                        IFNAME           => 'ge-0/0/47',
                        IFDESCR          => 'ge-0/0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:32',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7130) 0:01:11.30',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '556',
                        IFNAME           => 'ge-1/0/0',
                        IFDESCR          => 'ge-1/0/0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:33',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7130) 0:01:11.30',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '557',
                        IFNAME           => 'ge-1/0/1',
                        IFDESCR          => 'ge-1/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:34',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7131) 0:01:11.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '558',
                        IFNAME           => 'ge-1/0/2',
                        IFDESCR          => 'ge-1/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:35',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7131) 0:01:11.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '559',
                        IFNAME           => 'ge-1/0/3',
                        IFDESCR          => 'ge-1/0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:36',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7132) 0:01:11.32',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '560',
                        IFNAME           => 'ge-1/0/4',
                        IFDESCR          => 'ge-1/0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:37',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7132) 0:01:11.32',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '561',
                        IFNAME           => 'ge-1/0/5',
                        IFDESCR          => 'ge-1/0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:38',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7133) 0:01:11.33',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '562',
                        IFNAME           => 'ge-1/0/6',
                        IFDESCR          => 'ge-1/0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:39',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7133) 0:01:11.33',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '563',
                        IFNAME           => 'ge-1/0/7',
                        IFDESCR          => 'ge-1/0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:3a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7134) 0:01:11.34',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '564',
                        IFNAME           => 'ge-1/0/8',
                        IFDESCR          => 'ge-1/0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:3b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7135) 0:01:11.35',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '565',
                        IFNAME           => 'ge-1/0/9',
                        IFDESCR          => 'ge-1/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:3c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7136) 0:01:11.36',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '566',
                        IFNAME           => 'ge-1/0/10',
                        IFDESCR          => 'ge-1/0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:3d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7136) 0:01:11.36',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '567',
                        IFNAME           => 'ge-1/0/11',
                        IFDESCR          => 'ge-1/0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:3e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7137) 0:01:11.37',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '568',
                        IFNAME           => 'ge-1/0/12',
                        IFDESCR          => 'ge-1/0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:3f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7138) 0:01:11.38',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '569',
                        IFNAME           => 'ge-1/0/13',
                        IFDESCR          => 'ge-1/0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:40',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7138) 0:01:11.38',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '570',
                        IFNAME           => 'ge-1/0/14',
                        IFDESCR          => 'ge-1/0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:41',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7139) 0:01:11.39',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '571',
                        IFNAME           => 'ge-1/0/15',
                        IFDESCR          => 'ge-1/0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:42',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7139) 0:01:11.39',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '572',
                        IFNAME           => 'ge-1/0/16',
                        IFDESCR          => 'ge-1/0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:43',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7139) 0:01:11.39',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '573',
                        IFNAME           => 'ge-1/0/17',
                        IFDESCR          => 'ge-1/0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:44',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7140) 0:01:11.40',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '574',
                        IFNAME           => 'ge-1/0/18',
                        IFDESCR          => 'ge-1/0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:45',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7141) 0:01:11.41',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '575',
                        IFNAME           => 'ge-1/0/19',
                        IFDESCR          => 'ge-1/0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:46',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7141) 0:01:11.41',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '576',
                        IFNAME           => 'ge-1/0/20',
                        IFDESCR          => 'ge-1/0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:47',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7141) 0:01:11.41',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '577',
                        IFNAME           => 'ge-1/0/21',
                        IFDESCR          => 'ge-1/0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:48',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7142) 0:01:11.42',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '578',
                        IFNAME           => 'ge-1/0/22',
                        IFDESCR          => 'ge-1/0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:49',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7142) 0:01:11.42',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '579',
                        IFNAME           => 'ge-1/0/23',
                        IFDESCR          => 'ge-1/0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:4a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7143) 0:01:11.43',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '580',
                        IFNAME           => 'ge-1/0/24',
                        IFDESCR          => 'ge-1/0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:4b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7144) 0:01:11.44',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '581',
                        IFNAME           => 'ge-1/0/25',
                        IFDESCR          => 'ge-1/0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:4c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7144) 0:01:11.44',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '582',
                        IFNAME           => 'ge-1/0/26',
                        IFDESCR          => 'ge-1/0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:4d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7145) 0:01:11.45',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '583',
                        IFNAME           => 'ge-1/0/27',
                        IFDESCR          => 'ge-1/0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:4e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7146) 0:01:11.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '584',
                        IFNAME           => 'ge-1/0/28',
                        IFDESCR          => 'ge-1/0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:4f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7147) 0:01:11.47',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '585',
                        IFNAME           => 'ge-1/0/29',
                        IFDESCR          => 'ge-1/0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:50',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7148) 0:01:11.48',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '586',
                        IFNAME           => 'ge-1/0/30',
                        IFDESCR          => 'ge-1/0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:51',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7149) 0:01:11.49',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '587',
                        IFNAME           => 'ge-1/0/31',
                        IFDESCR          => 'ge-1/0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:52',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7149) 0:01:11.49',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '588',
                        IFNAME           => 'ge-1/0/32',
                        IFDESCR          => 'ge-1/0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:53',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7149) 0:01:11.49',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '589',
                        IFNAME           => 'ge-1/0/33',
                        IFDESCR          => 'ge-1/0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:54',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7151) 0:01:11.51',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '590',
                        IFNAME           => 'ge-1/0/34',
                        IFDESCR          => 'ge-1/0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:55',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7151) 0:01:11.51',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '591',
                        IFNAME           => 'ge-1/0/35',
                        IFDESCR          => 'ge-1/0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:56',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7151) 0:01:11.51',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '592',
                        IFNAME           => 'ge-1/0/36',
                        IFDESCR          => 'ge-1/0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:57',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7152) 0:01:11.52',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '593',
                        IFNAME           => 'ge-1/0/37',
                        IFDESCR          => 'ge-1/0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:58',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7153) 0:01:11.53',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '594',
                        IFNAME           => 'ge-1/0/38',
                        IFDESCR          => 'ge-1/0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:59',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7153) 0:01:11.53',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '595',
                        IFNAME           => 'ge-1/0/39',
                        IFDESCR          => 'ge-1/0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:5a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7154) 0:01:11.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '596',
                        IFNAME           => 'ge-1/0/40',
                        IFDESCR          => 'ge-1/0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:5b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7154) 0:01:11.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '597',
                        IFNAME           => 'ge-1/0/41',
                        IFDESCR          => 'ge-1/0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:5c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7155) 0:01:11.55',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '598',
                        IFNAME           => 'ge-1/0/42',
                        IFDESCR          => 'ge-1/0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:5d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7155) 0:01:11.55',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '599',
                        IFNAME           => 'ge-1/0/43',
                        IFDESCR          => 'ge-1/0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:5e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7156) 0:01:11.56',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '600',
                        IFNAME           => 'ge-1/0/44',
                        IFDESCR          => 'ge-1/0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:5f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7157) 0:01:11.57',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '601',
                        IFNAME           => 'ge-1/0/45',
                        IFDESCR          => 'ge-1/0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:60',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7158) 0:01:11.58',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '602',
                        IFNAME           => 'ge-1/0/46',
                        IFDESCR          => 'ge-1/0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:61',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7158) 0:01:11.58',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '603',
                        IFNAME           => 'ge-1/0/47',
                        IFDESCR          => 'ge-1/0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:62',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7158) 0:01:11.58',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '604',
                        IFNAME           => 'ge-6/0/0',
                        IFDESCR          => 'ge-6/0/0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:23',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8367) 0:01:23.67',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '605',
                        IFNAME           => 'ge-6/0/1',
                        IFDESCR          => 'ge-6/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:24',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8367) 0:01:23.67',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '606',
                        IFNAME           => 'ge-6/0/2',
                        IFDESCR          => 'ge-6/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:25',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8367) 0:01:23.67',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '607',
                        IFNAME           => 'ge-6/0/3',
                        IFDESCR          => 'ge-6/0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:26',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8368) 0:01:23.68',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '608',
                        IFNAME           => 'ge-6/0/4',
                        IFDESCR          => 'ge-6/0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:27',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8378) 0:01:23.78',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '609',
                        IFNAME           => 'ge-6/0/5',
                        IFDESCR          => 'ge-6/0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:28',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8379) 0:01:23.79',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '610',
                        IFNAME           => 'ge-6/0/6',
                        IFDESCR          => 'ge-6/0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:29',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8384) 0:01:23.84',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '611',
                        IFNAME           => 'ge-6/0/7',
                        IFDESCR          => 'ge-6/0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:2a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8387) 0:01:23.87',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '612',
                        IFNAME           => 'ge-6/0/8',
                        IFDESCR          => 'ge-6/0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:2b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8388) 0:01:23.88',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '613',
                        IFNAME           => 'ge-6/0/9',
                        IFDESCR          => 'ge-6/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:2c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8391) 0:01:23.91',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '614',
                        IFNAME           => 'ge-6/0/10',
                        IFDESCR          => 'ge-6/0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:2d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8394) 0:01:23.94',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '615',
                        IFNAME           => 'ge-6/0/11',
                        IFDESCR          => 'ge-6/0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:2e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8395) 0:01:23.95',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '616',
                        IFNAME           => 'ge-6/0/12',
                        IFDESCR          => 'ge-6/0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:2f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8397) 0:01:23.97',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '617',
                        IFNAME           => 'ge-6/0/13',
                        IFDESCR          => 'ge-6/0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:30',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8399) 0:01:23.99',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '618',
                        IFNAME           => 'ge-6/0/14',
                        IFDESCR          => 'ge-6/0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:31',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8403) 0:01:24.03',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '619',
                        IFNAME           => 'ge-6/0/15',
                        IFDESCR          => 'ge-6/0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:32',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8408) 0:01:24.08',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '620',
                        IFNAME           => 'ge-6/0/16',
                        IFDESCR          => 'ge-6/0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:33',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8411) 0:01:24.11',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '621',
                        IFNAME           => 'ge-6/0/17',
                        IFDESCR          => 'ge-6/0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:34',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8414) 0:01:24.14',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '622',
                        IFNAME           => 'ge-6/0/18',
                        IFDESCR          => 'ge-6/0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:35',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8417) 0:01:24.17',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '623',
                        IFNAME           => 'ge-6/0/19',
                        IFDESCR          => 'ge-6/0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:36',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8422) 0:01:24.22',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '624',
                        IFNAME           => 'ge-6/0/20',
                        IFDESCR          => 'ge-6/0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:37',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8424) 0:01:24.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '625',
                        IFNAME           => 'ge-6/0/21',
                        IFDESCR          => 'ge-6/0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:38',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8428) 0:01:24.28',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '626',
                        IFNAME           => 'ge-6/0/22',
                        IFDESCR          => 'ge-6/0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:39',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8434) 0:01:24.34',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '627',
                        IFNAME           => 'ge-6/0/23',
                        IFDESCR          => 'ge-6/0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:3a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8435) 0:01:24.35',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '628',
                        IFNAME           => 'ge-6/0/24',
                        IFDESCR          => 'ge-6/0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:3b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8440) 0:01:24.40',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '629',
                        IFNAME           => 'ge-6/0/25',
                        IFDESCR          => 'ge-6/0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:3c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8441) 0:01:24.41',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '630',
                        IFNAME           => 'ge-6/0/26',
                        IFDESCR          => 'ge-6/0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:3d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8444) 0:01:24.44',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '631',
                        IFNAME           => 'ge-6/0/27',
                        IFDESCR          => 'ge-6/0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:3e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8446) 0:01:24.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '632',
                        IFNAME           => 'ge-6/0/28',
                        IFDESCR          => 'ge-6/0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:3f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8448) 0:01:24.48',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '633',
                        IFNAME           => 'ge-6/0/29',
                        IFDESCR          => 'ge-6/0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:40',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8449) 0:01:24.49',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '634',
                        IFNAME           => 'ge-6/0/30',
                        IFDESCR          => 'ge-6/0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:41',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8451) 0:01:24.51',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '635',
                        IFNAME           => 'ge-6/0/31',
                        IFDESCR          => 'ge-6/0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:42',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8454) 0:01:24.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '636',
                        IFNAME           => 'ge-6/0/32',
                        IFDESCR          => 'ge-6/0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:43',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8459) 0:01:24.59',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '637',
                        IFNAME           => 'ge-6/0/33',
                        IFDESCR          => 'ge-6/0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:44',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8459) 0:01:24.59',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '638',
                        IFNAME           => 'ge-6/0/34',
                        IFDESCR          => 'ge-6/0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:45',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8463) 0:01:24.63',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '639',
                        IFNAME           => 'ge-6/0/35',
                        IFDESCR          => 'ge-6/0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:46',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8470) 0:01:24.70',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '640',
                        IFNAME           => 'ge-6/0/36',
                        IFDESCR          => 'ge-6/0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:47',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8474) 0:01:24.74',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '641',
                        IFNAME           => 'ge-6/0/37',
                        IFDESCR          => 'ge-6/0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:48',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8477) 0:01:24.77',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '642',
                        IFNAME           => 'ge-6/0/38',
                        IFDESCR          => 'ge-6/0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:49',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8479) 0:01:24.79',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '643',
                        IFNAME           => 'ge-6/0/39',
                        IFDESCR          => 'ge-6/0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:4a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8482) 0:01:24.82',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '644',
                        IFNAME           => 'ge-6/0/40',
                        IFDESCR          => 'ge-6/0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:4b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8483) 0:01:24.83',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '645',
                        IFNAME           => 'ge-6/0/41',
                        IFDESCR          => 'ge-6/0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:4c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8485) 0:01:24.85',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '646',
                        IFNAME           => 'ge-6/0/42',
                        IFDESCR          => 'ge-6/0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:4d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8487) 0:01:24.87',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '647',
                        IFNAME           => 'ge-6/0/43',
                        IFDESCR          => 'ge-6/0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:4e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8487) 0:01:24.87',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '648',
                        IFNAME           => 'ge-6/0/44',
                        IFDESCR          => 'ge-6/0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:4f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8490) 0:01:24.90',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '649',
                        IFNAME           => 'ge-6/0/45',
                        IFDESCR          => 'ge-6/0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:50',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8491) 0:01:24.91',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '650',
                        IFNAME           => 'ge-6/0/46',
                        IFDESCR          => 'ge-6/0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:51',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8493) 0:01:24.93',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '651',
                        IFNAME           => 'ge-6/0/47',
                        IFDESCR          => 'ge-6/0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:52',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8497) 0:01:24.97',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '652',
                        IFNAME           => 'xe-5/0/0',
                        IFDESCR          => 'xe-5/0/0',
                        IFALIAS          => 'AE to sw-ex8208-tmk',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:1e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(46996723) 5 days, 10:32:47.23',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '70798344',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1448517959',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '653',
                        IFNAME           => 'ge-2/0/0',
                        IFDESCR          => 'ge-2/0/0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:63',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7204) 0:01:12.04',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '654',
                        IFNAME           => 'ge-2/0/1',
                        IFDESCR          => 'ge-2/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:64',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7205) 0:01:12.05',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '655',
                        IFNAME           => 'ge-2/0/2',
                        IFDESCR          => 'ge-2/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:65',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7216) 0:01:12.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '656',
                        IFNAME           => 'ge-2/0/3',
                        IFDESCR          => 'ge-2/0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:66',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7217) 0:01:12.17',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '657',
                        IFNAME           => 'ge-2/0/4',
                        IFDESCR          => 'ge-2/0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:67',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7218) 0:01:12.18',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '658',
                        IFNAME           => 'ge-2/0/5',
                        IFDESCR          => 'ge-2/0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:68',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7220) 0:01:12.20',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '659',
                        IFNAME           => 'ge-2/0/6',
                        IFDESCR          => 'ge-2/0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:69',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7220) 0:01:12.20',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '660',
                        IFNAME           => 'ge-2/0/7',
                        IFDESCR          => 'ge-2/0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:6a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7226) 0:01:12.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '661',
                        IFNAME           => 'ge-2/0/8',
                        IFDESCR          => 'ge-2/0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:6b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7227) 0:01:12.27',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '662',
                        IFNAME           => 'ge-2/0/9',
                        IFDESCR          => 'ge-2/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:6c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7228) 0:01:12.28',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '663',
                        IFNAME           => 'ge-2/0/10',
                        IFDESCR          => 'ge-2/0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:6d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7234) 0:01:12.34',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '664',
                        IFNAME           => 'ge-2/0/11',
                        IFDESCR          => 'ge-2/0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:6e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7235) 0:01:12.35',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '665',
                        IFNAME           => 'ge-2/0/12',
                        IFDESCR          => 'ge-2/0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:6f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7245) 0:01:12.45',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '666',
                        IFNAME           => 'ge-2/0/13',
                        IFDESCR          => 'ge-2/0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:70',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7245) 0:01:12.45',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '667',
                        IFNAME           => 'ge-2/0/14',
                        IFDESCR          => 'ge-2/0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:71',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7246) 0:01:12.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '668',
                        IFNAME           => 'ge-2/0/15',
                        IFDESCR          => 'ge-2/0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:72',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7247) 0:01:12.47',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '669',
                        IFNAME           => 'ge-2/0/16',
                        IFDESCR          => 'ge-2/0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:73',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7263) 0:01:12.63',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '670',
                        IFNAME           => 'ge-2/0/17',
                        IFDESCR          => 'ge-2/0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:74',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7266) 0:01:12.66',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '671',
                        IFNAME           => 'ge-2/0/18',
                        IFDESCR          => 'ge-2/0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:75',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7276) 0:01:12.76',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '672',
                        IFNAME           => 'ge-2/0/19',
                        IFDESCR          => 'ge-2/0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:76',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7276) 0:01:12.76',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '673',
                        IFNAME           => 'ge-2/0/20',
                        IFDESCR          => 'ge-2/0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:77',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7286) 0:01:12.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '674',
                        IFNAME           => 'ge-2/0/21',
                        IFDESCR          => 'ge-2/0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:78',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7286) 0:01:12.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '675',
                        IFNAME           => 'ge-2/0/22',
                        IFDESCR          => 'ge-2/0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:79',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7286) 0:01:12.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '676',
                        IFNAME           => 'ge-2/0/23',
                        IFDESCR          => 'ge-2/0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:7a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7287) 0:01:12.87',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '677',
                        IFNAME           => 'ge-2/0/24',
                        IFDESCR          => 'ge-2/0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:7b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7288) 0:01:12.88',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '678',
                        IFNAME           => 'ge-2/0/25',
                        IFDESCR          => 'ge-2/0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:7c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7295) 0:01:12.95',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '679',
                        IFNAME           => 'ge-2/0/26',
                        IFDESCR          => 'ge-2/0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:7d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7295) 0:01:12.95',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '680',
                        IFNAME           => 'ge-2/0/27',
                        IFDESCR          => 'ge-2/0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:7e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7307) 0:01:13.07',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '681',
                        IFNAME           => 'ge-2/0/28',
                        IFDESCR          => 'ge-2/0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:7f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7307) 0:01:13.07',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '682',
                        IFNAME           => 'ge-2/0/29',
                        IFDESCR          => 'ge-2/0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:80',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7309) 0:01:13.09',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '683',
                        IFNAME           => 'ge-2/0/30',
                        IFDESCR          => 'ge-2/0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:81',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7310) 0:01:13.10',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '684',
                        IFNAME           => 'ge-2/0/31',
                        IFDESCR          => 'ge-2/0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:82',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7310) 0:01:13.10',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '685',
                        IFNAME           => 'ge-2/0/32',
                        IFDESCR          => 'ge-2/0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:83',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7316) 0:01:13.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '686',
                        IFNAME           => 'ge-2/0/33',
                        IFDESCR          => 'ge-2/0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:84',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7316) 0:01:13.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '687',
                        IFNAME           => 'ge-2/0/34',
                        IFDESCR          => 'ge-2/0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:85',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7326) 0:01:13.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '688',
                        IFNAME           => 'ge-2/0/35',
                        IFDESCR          => 'ge-2/0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:86',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7326) 0:01:13.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '689',
                        IFNAME           => 'ge-2/0/36',
                        IFDESCR          => 'ge-2/0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:87',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7326) 0:01:13.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '690',
                        IFNAME           => 'ge-2/0/37',
                        IFDESCR          => 'ge-2/0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:88',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7326) 0:01:13.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '691',
                        IFNAME           => 'ge-2/0/38',
                        IFDESCR          => 'ge-2/0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:89',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7328) 0:01:13.28',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '692',
                        IFNAME           => 'ge-2/0/39',
                        IFDESCR          => 'ge-2/0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:8a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7336) 0:01:13.36',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '693',
                        IFNAME           => 'ge-2/0/40',
                        IFDESCR          => 'ge-2/0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:8b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7336) 0:01:13.36',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '694',
                        IFNAME           => 'ge-2/0/41',
                        IFDESCR          => 'ge-2/0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:8c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7336) 0:01:13.36',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '695',
                        IFNAME           => 'ge-2/0/42',
                        IFDESCR          => 'ge-2/0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:8d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7346) 0:01:13.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '696',
                        IFNAME           => 'ge-2/0/43',
                        IFDESCR          => 'ge-2/0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:8e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7347) 0:01:13.47',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '697',
                        IFNAME           => 'ge-2/0/44',
                        IFDESCR          => 'ge-2/0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:8f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7347) 0:01:13.47',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '698',
                        IFNAME           => 'ge-2/0/45',
                        IFDESCR          => 'ge-2/0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:90',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7348) 0:01:13.48',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '699',
                        IFNAME           => 'ge-2/0/46',
                        IFDESCR          => 'ge-2/0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:91',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7356) 0:01:13.56',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '700',
                        IFNAME           => 'ge-2/0/47',
                        IFDESCR          => 'ge-2/0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:92',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7356) 0:01:13.56',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '704',
                        IFNAME           => 'ge-3/0/0',
                        IFDESCR          => 'ge-3/0/0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:93',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7609) 0:01:16.09',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '705',
                        IFNAME           => 'ge-3/0/1',
                        IFDESCR          => 'ge-3/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:94',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7609) 0:01:16.09',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '706',
                        IFNAME           => 'ge-3/0/2',
                        IFDESCR          => 'ge-3/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:95',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7609) 0:01:16.09',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '707',
                        IFNAME           => 'ge-3/0/3',
                        IFDESCR          => 'ge-3/0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:96',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7619) 0:01:16.19',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '708',
                        IFNAME           => 'ge-3/0/4',
                        IFDESCR          => 'ge-3/0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:97',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7620) 0:01:16.20',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '709',
                        IFNAME           => 'ge-3/0/5',
                        IFDESCR          => 'ge-3/0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:98',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7619) 0:01:16.19',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '710',
                        IFNAME           => 'ge-3/0/6',
                        IFDESCR          => 'ge-3/0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:99',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7619) 0:01:16.19',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '711',
                        IFNAME           => 'ge-3/0/7',
                        IFDESCR          => 'ge-3/0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:9a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7629) 0:01:16.29',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '712',
                        IFNAME           => 'ge-3/0/8',
                        IFDESCR          => 'ge-3/0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:9b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7629) 0:01:16.29',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '713',
                        IFNAME           => 'ge-3/0/9',
                        IFDESCR          => 'ge-3/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:9c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7630) 0:01:16.30',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '714',
                        IFNAME           => 'ge-3/0/10',
                        IFDESCR          => 'ge-3/0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:9d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7631) 0:01:16.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '715',
                        IFNAME           => 'ge-3/0/11',
                        IFDESCR          => 'ge-3/0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:9e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7639) 0:01:16.39',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '716',
                        IFNAME           => 'ge-3/0/12',
                        IFDESCR          => 'ge-3/0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:9f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7639) 0:01:16.39',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '717',
                        IFNAME           => 'ge-3/0/13',
                        IFDESCR          => 'ge-3/0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:a0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7639) 0:01:16.39',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '718',
                        IFNAME           => 'ge-3/0/14',
                        IFDESCR          => 'ge-3/0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:a1',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7649) 0:01:16.49',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '719',
                        IFNAME           => 'ge-3/0/15',
                        IFDESCR          => 'ge-3/0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:a2',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7649) 0:01:16.49',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '720',
                        IFNAME           => 'ge-3/0/16',
                        IFDESCR          => 'ge-3/0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:a3',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7650) 0:01:16.50',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '721',
                        IFNAME           => 'ge-3/0/17',
                        IFDESCR          => 'ge-3/0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:a4',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7651) 0:01:16.51',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '722',
                        IFNAME           => 'ge-3/0/18',
                        IFDESCR          => 'ge-3/0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:a5',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7659) 0:01:16.59',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '723',
                        IFNAME           => 'ge-3/0/19',
                        IFDESCR          => 'ge-3/0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:a6',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7660) 0:01:16.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '724',
                        IFNAME           => 'ge-3/0/20',
                        IFDESCR          => 'ge-3/0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:a7',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7660) 0:01:16.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '725',
                        IFNAME           => 'ge-3/0/21',
                        IFDESCR          => 'ge-3/0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:a8',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7661) 0:01:16.61',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '726',
                        IFNAME           => 'ge-3/0/22',
                        IFDESCR          => 'ge-3/0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:a9',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7669) 0:01:16.69',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '727',
                        IFNAME           => 'ge-3/0/23',
                        IFDESCR          => 'ge-3/0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:aa',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7669) 0:01:16.69',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '728',
                        IFNAME           => 'ge-3/0/24',
                        IFDESCR          => 'ge-3/0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:ab',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7679) 0:01:16.79',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '729',
                        IFNAME           => 'ge-3/0/25',
                        IFDESCR          => 'ge-3/0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:ac',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7680) 0:01:16.80',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '730',
                        IFNAME           => 'ge-3/0/26',
                        IFDESCR          => 'ge-3/0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:ad',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7680) 0:01:16.80',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '731',
                        IFNAME           => 'ge-3/0/27',
                        IFDESCR          => 'ge-3/0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:ae',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7682) 0:01:16.82',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '732',
                        IFNAME           => 'ge-3/0/28',
                        IFDESCR          => 'ge-3/0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:af',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7683) 0:01:16.83',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '733',
                        IFNAME           => 'ge-3/0/29',
                        IFDESCR          => 'ge-3/0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:b0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7683) 0:01:16.83',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '734',
                        IFNAME           => 'ge-3/0/30',
                        IFDESCR          => 'ge-3/0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:b1',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7700) 0:01:17.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '735',
                        IFNAME           => 'ge-3/0/31',
                        IFDESCR          => 'ge-3/0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:b2',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7700) 0:01:17.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '736',
                        IFNAME           => 'ge-3/0/32',
                        IFDESCR          => 'ge-3/0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:b3',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7701) 0:01:17.01',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '737',
                        IFNAME           => 'ge-3/0/33',
                        IFDESCR          => 'ge-3/0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:b4',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7702) 0:01:17.02',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '738',
                        IFNAME           => 'ge-3/0/34',
                        IFDESCR          => 'ge-3/0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:b5',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7703) 0:01:17.03',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '739',
                        IFNAME           => 'ge-3/0/35',
                        IFDESCR          => 'ge-3/0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:b6',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7703) 0:01:17.03',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '740',
                        IFNAME           => 'ge-3/0/36',
                        IFDESCR          => 'ge-3/0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:b7',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7715) 0:01:17.15',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '741',
                        IFNAME           => 'ge-3/0/37',
                        IFDESCR          => 'ge-3/0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:b8',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7716) 0:01:17.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '742',
                        IFNAME           => 'ge-3/0/38',
                        IFDESCR          => 'ge-3/0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:b9',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7719) 0:01:17.19',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '743',
                        IFNAME           => 'ge-3/0/39',
                        IFDESCR          => 'ge-3/0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:ba',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7720) 0:01:17.20',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '744',
                        IFNAME           => 'ge-3/0/40',
                        IFDESCR          => 'ge-3/0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:bb',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7729) 0:01:17.29',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '745',
                        IFNAME           => 'ge-3/0/41',
                        IFDESCR          => 'ge-3/0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:bc',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7730) 0:01:17.30',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '746',
                        IFNAME           => 'ge-3/0/42',
                        IFDESCR          => 'ge-3/0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:bd',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7731) 0:01:17.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '747',
                        IFNAME           => 'ge-3/0/43',
                        IFDESCR          => 'ge-3/0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:be',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7731) 0:01:17.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '748',
                        IFNAME           => 'ge-3/0/44',
                        IFDESCR          => 'ge-3/0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:bf',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7731) 0:01:17.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '749',
                        IFNAME           => 'ge-3/0/45',
                        IFDESCR          => 'ge-3/0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:c0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7731) 0:01:17.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '750',
                        IFNAME           => 'ge-3/0/46',
                        IFDESCR          => 'ge-3/0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:c1',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7740) 0:01:17.40',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '751',
                        IFNAME           => 'ge-3/0/47',
                        IFDESCR          => 'ge-3/0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:c2',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7749) 0:01:17.49',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '752',
                        IFNAME           => 'ge-8/0/0',
                        IFDESCR          => 'ge-8/0/0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:83',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7860) 0:01:18.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '753',
                        IFNAME           => 'ge-8/0/1',
                        IFDESCR          => 'ge-8/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:84',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7861) 0:01:18.61',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '754',
                        IFNAME           => 'ge-8/0/2',
                        IFDESCR          => 'ge-8/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:85',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7871) 0:01:18.71',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '755',
                        IFNAME           => 'ge-8/0/3',
                        IFDESCR          => 'ge-8/0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:86',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7871) 0:01:18.71',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '756',
                        IFNAME           => 'ge-8/0/4',
                        IFDESCR          => 'ge-8/0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:87',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7873) 0:01:18.73',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '757',
                        IFNAME           => 'ge-8/0/5',
                        IFDESCR          => 'ge-8/0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:88',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7874) 0:01:18.74',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '758',
                        IFNAME           => 'ge-8/0/6',
                        IFDESCR          => 'ge-8/0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:89',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7892) 0:01:18.92',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '759',
                        IFNAME           => 'ge-8/0/7',
                        IFDESCR          => 'ge-8/0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:8a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7893) 0:01:18.93',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '760',
                        IFNAME           => 'ge-8/0/8',
                        IFDESCR          => 'ge-8/0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:8b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7893) 0:01:18.93',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '761',
                        IFNAME           => 'ge-8/0/9',
                        IFDESCR          => 'ge-8/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:8c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7894) 0:01:18.94',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '762',
                        IFNAME           => 'ge-8/0/10',
                        IFDESCR          => 'ge-8/0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:8d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7896) 0:01:18.96',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '763',
                        IFNAME           => 'ge-8/0/11',
                        IFDESCR          => 'ge-8/0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:8e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7901) 0:01:19.01',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '764',
                        IFNAME           => 'ge-8/0/12',
                        IFDESCR          => 'ge-8/0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:8f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7911) 0:01:19.11',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '765',
                        IFNAME           => 'ge-8/0/13',
                        IFDESCR          => 'ge-8/0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:90',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7912) 0:01:19.12',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '766',
                        IFNAME           => 'ge-8/0/14',
                        IFDESCR          => 'ge-8/0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:91',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7912) 0:01:19.12',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '767',
                        IFNAME           => 'ge-8/0/15',
                        IFDESCR          => 'ge-8/0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:92',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7913) 0:01:19.13',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '768',
                        IFNAME           => 'ge-8/0/16',
                        IFDESCR          => 'ge-8/0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:93',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7913) 0:01:19.13',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '769',
                        IFNAME           => 'ge-8/0/17',
                        IFDESCR          => 'ge-8/0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:94',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7923) 0:01:19.23',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '770',
                        IFNAME           => 'ge-8/0/18',
                        IFDESCR          => 'ge-8/0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:95',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7923) 0:01:19.23',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '771',
                        IFNAME           => 'ge-8/0/19',
                        IFDESCR          => 'ge-8/0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:96',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7924) 0:01:19.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '772',
                        IFNAME           => 'ge-8/0/20',
                        IFDESCR          => 'ge-8/0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:97',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7931) 0:01:19.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '773',
                        IFNAME           => 'ge-8/0/21',
                        IFDESCR          => 'ge-8/0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:98',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7931) 0:01:19.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '774',
                        IFNAME           => 'ge-8/0/22',
                        IFDESCR          => 'ge-8/0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:99',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7931) 0:01:19.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '775',
                        IFNAME           => 'ge-8/0/23',
                        IFDESCR          => 'ge-8/0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:9a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7941) 0:01:19.41',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '776',
                        IFNAME           => 'ge-8/0/24',
                        IFDESCR          => 'ge-8/0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:9b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7942) 0:01:19.42',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '777',
                        IFNAME           => 'ge-8/0/25',
                        IFDESCR          => 'ge-8/0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:9c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7942) 0:01:19.42',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '778',
                        IFNAME           => 'ge-8/0/26',
                        IFDESCR          => 'ge-8/0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:9d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7943) 0:01:19.43',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '779',
                        IFNAME           => 'ge-8/0/27',
                        IFDESCR          => 'ge-8/0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:9e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7943) 0:01:19.43',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '780',
                        IFNAME           => 'ge-8/0/28',
                        IFDESCR          => 'ge-8/0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:9f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7953) 0:01:19.53',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '781',
                        IFNAME           => 'ge-8/0/29',
                        IFDESCR          => 'ge-8/0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:a0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7953) 0:01:19.53',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '782',
                        IFNAME           => 'ge-8/0/30',
                        IFDESCR          => 'ge-8/0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:a1',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(7953) 0:01:19.53',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '783',
                        IFNAME           => 'ge-8/0/31',
                        IFDESCR          => 'ge-8/0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:a2',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(48597507) 5 days, 14:59:35.07',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '11786296',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2679045',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '784',
                        IFNAME           => 'ge-8/0/32',
                        IFDESCR          => 'ge-8/0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:a3',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(48597246) 5 days, 14:59:32.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '17660054',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3145263',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '785',
                        IFNAME           => 'ge-8/0/33',
                        IFDESCR          => 'ge-8/0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:a4',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(50047300) 5 days, 19:01:13.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '11786891',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '5491211',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '786',
                        IFNAME           => 'ge-8/0/34',
                        IFDESCR          => 'ge-8/0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:a5',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(49781219) 5 days, 18:16:52.19',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '11786352',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4911423',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '787',
                        IFNAME           => 'ge-8/0/35',
                        IFDESCR          => 'ge-8/0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:a6',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54735724) 6 days, 8:02:37.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '450384039',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2893447179',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '788',
                        IFNAME           => 'ge-8/0/36',
                        IFDESCR          => 'ge-8/0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:a7',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54737884) 6 days, 8:02:58.84',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '437837487',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2883264245',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '789',
                        IFNAME           => 'ge-8/0/37',
                        IFDESCR          => 'ge-8/0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:a8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54735974) 6 days, 8:02:39.74',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '437396497',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2889293062',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '790',
                        IFNAME           => 'ge-8/0/38',
                        IFDESCR          => 'ge-8/0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:a9',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54734994) 6 days, 8:02:29.94',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '439276882',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2868299474',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '791',
                        IFNAME           => 'ge-8/0/39',
                        IFDESCR          => 'ge-8/0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:aa',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54738424) 6 days, 8:03:04.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '449949488',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2877616158',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '792',
                        IFNAME           => 'ge-8/0/40',
                        IFDESCR          => 'ge-8/0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:ab',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54734064) 6 days, 8:02:20.64',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '438702356',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2868307286',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '793',
                        IFNAME           => 'ge-8/0/41',
                        IFDESCR          => 'ge-8/0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:ac',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54733624) 6 days, 8:02:16.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '450780390',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2874507982',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '794',
                        IFNAME           => 'ge-8/0/42',
                        IFDESCR          => 'ge-8/0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:ad',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(48921986) 5 days, 15:53:39.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1220',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '63291',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '795',
                        IFNAME           => 'ge-8/0/43',
                        IFDESCR          => 'ge-8/0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:ae',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(48921718) 5 days, 15:53:37.18',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '11789891',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2811889',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '796',
                        IFNAME           => 'ge-8/0/44',
                        IFDESCR          => 'ge-8/0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:af',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(49749351) 5 days, 18:11:33.51',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '9655',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2770156',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '797',
                        IFNAME           => 'ge-8/0/45',
                        IFDESCR          => 'ge-8/0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:b0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54733824) 6 days, 8:02:18.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '449509596',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2861033262',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '798',
                        IFNAME           => 'ge-8/0/46',
                        IFDESCR          => 'ge-8/0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:b1',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54733924) 6 days, 8:02:19.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '438747480',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2866819901',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '799',
                        IFNAME           => 'ge-8/0/47',
                        IFDESCR          => 'ge-8/0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:b2',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54733284) 6 days, 8:02:12.84',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '451244176',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2867635719',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '800',
                        IFNAME           => 'ge-9/0/0',
                        IFDESCR          => 'ge-9/0/0',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:b3',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(55254136) 6 days, 9:29:01.36',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '8427639',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1555215106',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '801',
                        IFNAME           => 'ge-9/0/1',
                        IFDESCR          => 'ge-9/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:b4',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(55241746) 6 days, 9:26:57.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '8708990',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1424344667',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '802',
                        IFNAME           => 'ge-9/0/2',
                        IFDESCR          => 'ge-9/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:b5',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(55197546) 6 days, 9:19:35.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '8684803',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1423481574',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '803',
                        IFNAME           => 'ge-9/0/3',
                        IFDESCR          => 'ge-9/0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:b6',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54600216) 6 days, 7:40:02.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '5008',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '547874943',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '804',
                        IFNAME           => 'ge-9/0/4',
                        IFDESCR          => 'ge-9/0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:b7',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54600216) 6 days, 7:40:02.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '260366',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '416784600',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '805',
                        IFNAME           => 'ge-9/0/5',
                        IFDESCR          => 'ge-9/0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:b8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54600216) 6 days, 7:40:02.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '5788',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '547916638',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '806',
                        IFNAME           => 'ge-9/0/6',
                        IFDESCR          => 'ge-9/0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:b9',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54600216) 6 days, 7:40:02.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '259471',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '416782031',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '807',
                        IFNAME           => 'ge-9/0/7',
                        IFDESCR          => 'ge-9/0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:ba',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(55209706) 6 days, 9:21:37.06',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '8415505',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1552150665',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '808',
                        IFNAME           => 'ge-9/0/8',
                        IFDESCR          => 'ge-9/0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:bb',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(55229056) 6 days, 9:24:50.56',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '11105958',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1426388481',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '809',
                        IFNAME           => 'ge-9/0/9',
                        IFDESCR          => 'ge-9/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:bc',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(55228916) 6 days, 9:24:49.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '13610611',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1422900217',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '810',
                        IFNAME           => 'ge-9/0/10',
                        IFDESCR          => 'ge-9/0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:bd',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(55095486) 6 days, 9:02:34.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '8730631',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1421839389',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '811',
                        IFNAME           => 'ge-9/0/11',
                        IFDESCR          => 'ge-9/0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:be',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(55241606) 6 days, 9:26:56.06',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '8691184',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1422049810',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '812',
                        IFNAME           => 'ge-9/0/12',
                        IFDESCR          => 'ge-9/0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:bf',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(55202706) 6 days, 9:20:27.06',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '8591736',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1421663027',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '813',
                        IFNAME           => 'ge-9/0/13',
                        IFDESCR          => 'ge-9/0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:c0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(71053626) 8 days, 5:22:16.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '245869719',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2373689782',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '814',
                        IFNAME           => 'ge-9/0/14',
                        IFDESCR          => 'ge-9/0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:c1',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(71053386) 8 days, 5:22:13.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '317568124',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2653161452',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '815',
                        IFNAME           => 'ge-9/0/15',
                        IFDESCR          => 'ge-9/0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:c2',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(71055246) 8 days, 5:22:32.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '309221293',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2354185914',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '816',
                        IFNAME           => 'ge-9/0/16',
                        IFDESCR          => 'ge-9/0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:c3',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(71053576) 8 days, 5:22:15.76',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '245095038',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2281615613',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '817',
                        IFNAME           => 'ge-9/0/17',
                        IFDESCR          => 'ge-9/0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:c4',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(71053536) 8 days, 5:22:15.36',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '243846417',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2274229072',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '818',
                        IFNAME           => 'ge-9/0/18',
                        IFDESCR          => 'ge-9/0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:c5',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(71055397) 8 days, 5:22:33.97',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '243564747',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2225632536',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '819',
                        IFNAME           => 'ge-9/0/19',
                        IFDESCR          => 'ge-9/0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:c6',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(55185366) 6 days, 9:17:33.66',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '9028643',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1416495910',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '820',
                        IFNAME           => 'ge-9/0/20',
                        IFDESCR          => 'ge-9/0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:c7',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(71055196) 8 days, 5:22:31.96',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '243203211',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2222924474',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '821',
                        IFNAME           => 'ge-9/0/21',
                        IFDESCR          => 'ge-9/0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:c8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(71054226) 8 days, 5:22:22.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '244737655',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2282215194',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '822',
                        IFNAME           => 'ge-9/0/22',
                        IFDESCR          => 'ge-9/0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:c9',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(71053586) 8 days, 5:22:15.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '309410734',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2350815193',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '823',
                        IFNAME           => 'ge-9/0/23',
                        IFDESCR          => 'ge-9/0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:ca',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(71053536) 8 days, 5:22:15.36',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '256434855',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3199419503',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '824',
                        IFNAME           => 'ge-9/0/24',
                        IFDESCR          => 'ge-9/0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:cb',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8646) 0:01:26.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '825',
                        IFNAME           => 'ge-9/0/25',
                        IFDESCR          => 'ge-9/0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:cc',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8648) 0:01:26.48',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '826',
                        IFNAME           => 'ge-9/0/26',
                        IFDESCR          => 'ge-9/0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:cd',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8651) 0:01:26.51',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '827',
                        IFNAME           => 'ge-9/0/27',
                        IFDESCR          => 'ge-9/0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:ce',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8654) 0:01:26.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '828',
                        IFNAME           => 'ge-9/0/28',
                        IFDESCR          => 'ge-9/0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:cf',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8656) 0:01:26.56',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '829',
                        IFNAME           => 'ge-9/0/29',
                        IFDESCR          => 'ge-9/0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:d0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8658) 0:01:26.58',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '830',
                        IFNAME           => 'ge-9/0/30',
                        IFDESCR          => 'ge-9/0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:d1',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8660) 0:01:26.60',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '831',
                        IFNAME           => 'ge-9/0/31',
                        IFDESCR          => 'ge-9/0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:d2',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8668) 0:01:26.68',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '832',
                        IFNAME           => 'ge-9/0/32',
                        IFDESCR          => 'ge-9/0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:d3',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8670) 0:01:26.70',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '833',
                        IFNAME           => 'ge-9/0/33',
                        IFDESCR          => 'ge-9/0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:d4',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54600197) 6 days, 7:40:01.97',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3622',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '548895558',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '834',
                        IFNAME           => 'ge-9/0/34',
                        IFDESCR          => 'ge-9/0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:d5',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54600197) 6 days, 7:40:01.97',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2614',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '375956863',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '835',
                        IFNAME           => 'ge-9/0/35',
                        IFDESCR          => 'ge-9/0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:d6',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54600247) 6 days, 7:40:02.47',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '9156',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '548952398',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '836',
                        IFNAME           => 'ge-9/0/36',
                        IFDESCR          => 'ge-9/0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:d7',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8683) 0:01:26.83',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '837',
                        IFNAME           => 'ge-9/0/37',
                        IFDESCR          => 'ge-9/0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:d8',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8685) 0:01:26.85',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '838',
                        IFNAME           => 'ge-9/0/38',
                        IFDESCR          => 'ge-9/0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:d9',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8689) 0:01:26.89',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '839',
                        IFNAME           => 'ge-9/0/39',
                        IFDESCR          => 'ge-9/0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:da',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8691) 0:01:26.91',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '840',
                        IFNAME           => 'ge-9/0/40',
                        IFDESCR          => 'ge-9/0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:db',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8693) 0:01:26.93',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '841',
                        IFNAME           => 'ge-9/0/41',
                        IFDESCR          => 'ge-9/0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:dc',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8698) 0:01:26.98',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '842',
                        IFNAME           => 'ge-9/0/42',
                        IFDESCR          => 'ge-9/0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:dd',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8701) 0:01:27.01',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '843',
                        IFNAME           => 'ge-9/0/43',
                        IFDESCR          => 'ge-9/0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:de',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8702) 0:01:27.02',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '844',
                        IFNAME           => 'ge-9/0/44',
                        IFDESCR          => 'ge-9/0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:df',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8703) 0:01:27.03',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '845',
                        IFNAME           => 'ge-9/0/45',
                        IFDESCR          => 'ge-9/0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:e0',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8705) 0:01:27.05',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '846',
                        IFNAME           => 'ge-9/0/46',
                        IFDESCR          => 'ge-9/0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:e1',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8705) 0:01:27.05',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '847',
                        IFNAME           => 'ge-9/0/47',
                        IFDESCR          => 'ge-9/0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:e2',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8707) 0:01:27.07',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '848',
                        IFNAME           => 'ge-7/0/0',
                        IFDESCR          => 'ge-7/0/0',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:53',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(49647481) 5 days, 17:54:34.81',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '6917',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3015852',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '849',
                        IFNAME           => 'ge-7/0/1',
                        IFDESCR          => 'ge-7/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:54',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54736383) 6 days, 8:02:43.83',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '438888961',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3003837008',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '850',
                        IFNAME           => 'ge-7/0/2',
                        IFDESCR          => 'ge-7/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:55',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54733983) 6 days, 8:02:19.83',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '437705341',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2884266701',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '851',
                        IFNAME           => 'ge-7/0/3',
                        IFDESCR          => 'ge-7/0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:56',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54736823) 6 days, 8:02:48.23',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '437522513',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3009583946',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '852',
                        IFNAME           => 'ge-7/0/4',
                        IFDESCR          => 'ge-7/0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:57',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54738293) 6 days, 8:03:02.93',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '438477623',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2885507170',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '853',
                        IFNAME           => 'ge-7/0/5',
                        IFDESCR          => 'ge-7/0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:58',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(49297440) 5 days, 16:56:14.40',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '250210',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '110419759',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '854',
                        IFNAME           => 'ge-7/0/6',
                        IFDESCR          => 'ge-7/0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:59',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(49645074) 5 days, 17:54:10.74',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '256223',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '112151886',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '855',
                        IFNAME           => 'ge-7/0/7',
                        IFDESCR          => 'ge-7/0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:5a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(49644282) 5 days, 17:54:02.82',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '7698',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3379650',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '856',
                        IFNAME           => 'ge-7/0/8',
                        IFDESCR          => 'ge-7/0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:5b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54733693) 6 days, 8:02:16.93',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '439496205',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2981813100',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '857',
                        IFNAME           => 'ge-7/0/9',
                        IFDESCR          => 'ge-7/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:5c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54738053) 6 days, 8:03:00.53',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '437898794',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2882162074',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '858',
                        IFNAME           => 'ge-7/0/10',
                        IFDESCR          => 'ge-7/0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:5d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54732673) 6 days, 8:02:06.73',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '439520444',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2979711550',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '859',
                        IFNAME           => 'ge-7/0/11',
                        IFDESCR          => 'ge-7/0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:5e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54733893) 6 days, 8:02:18.93',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '437932557',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2978421319',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '860',
                        IFNAME           => 'ge-7/0/12',
                        IFDESCR          => 'ge-7/0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:5f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8175) 0:01:21.75',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '861',
                        IFNAME           => 'ge-7/0/13',
                        IFDESCR          => 'ge-7/0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:60',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8178) 0:01:21.78',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '862',
                        IFNAME           => 'ge-7/0/14',
                        IFDESCR          => 'ge-7/0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:61',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8181) 0:01:21.81',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '863',
                        IFNAME           => 'ge-7/0/15',
                        IFDESCR          => 'ge-7/0/15',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:62',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8188) 0:01:21.88',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '864',
                        IFNAME           => 'ge-7/0/16',
                        IFDESCR          => 'ge-7/0/16',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:63',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8190) 0:01:21.90',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '865',
                        IFNAME           => 'ge-7/0/17',
                        IFDESCR          => 'ge-7/0/17',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:64',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8192) 0:01:21.92',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '866',
                        IFNAME           => 'ge-7/0/18',
                        IFDESCR          => 'ge-7/0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:65',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8195) 0:01:21.95',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '867',
                        IFNAME           => 'ge-7/0/19',
                        IFDESCR          => 'ge-7/0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:66',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8198) 0:01:21.98',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '868',
                        IFNAME           => 'ge-7/0/20',
                        IFDESCR          => 'ge-7/0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:67',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8201) 0:01:22.01',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '869',
                        IFNAME           => 'ge-7/0/21',
                        IFDESCR          => 'ge-7/0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:68',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8205) 0:01:22.05',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '870',
                        IFNAME           => 'ge-7/0/22',
                        IFDESCR          => 'ge-7/0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:69',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8206) 0:01:22.06',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '871',
                        IFNAME           => 'ge-7/0/23',
                        IFDESCR          => 'ge-7/0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:6a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8208) 0:01:22.08',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '872',
                        IFNAME           => 'ge-7/0/24',
                        IFDESCR          => 'ge-7/0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:6b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8209) 0:01:22.09',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '873',
                        IFNAME           => 'ge-7/0/25',
                        IFDESCR          => 'ge-7/0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:6c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8211) 0:01:22.11',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '874',
                        IFNAME           => 'ge-7/0/26',
                        IFDESCR          => 'ge-7/0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:6d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8217) 0:01:22.17',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '875',
                        IFNAME           => 'ge-7/0/27',
                        IFDESCR          => 'ge-7/0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:6e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8218) 0:01:22.18',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '876',
                        IFNAME           => 'ge-7/0/28',
                        IFDESCR          => 'ge-7/0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:6f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8224) 0:01:22.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '877',
                        IFNAME           => 'ge-7/0/29',
                        IFDESCR          => 'ge-7/0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:70',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8225) 0:01:22.25',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '878',
                        IFNAME           => 'ge-7/0/30',
                        IFDESCR          => 'ge-7/0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:71',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8227) 0:01:22.27',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '879',
                        IFNAME           => 'ge-7/0/31',
                        IFDESCR          => 'ge-7/0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:72',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8228) 0:01:22.28',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '880',
                        IFNAME           => 'ge-7/0/32',
                        IFDESCR          => 'ge-7/0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:73',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8230) 0:01:22.30',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '881',
                        IFNAME           => 'ge-7/0/33',
                        IFDESCR          => 'ge-7/0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:74',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8230) 0:01:22.30',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '882',
                        IFNAME           => 'ge-7/0/34',
                        IFDESCR          => 'ge-7/0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:75',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8232) 0:01:22.32',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '883',
                        IFNAME           => 'ge-7/0/35',
                        IFDESCR          => 'ge-7/0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:76',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8236) 0:01:22.36',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '884',
                        IFNAME           => 'ge-7/0/36',
                        IFDESCR          => 'ge-7/0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:77',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8250) 0:01:22.50',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '885',
                        IFNAME           => 'ge-7/0/37',
                        IFDESCR          => 'ge-7/0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:78',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8253) 0:01:22.53',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '886',
                        IFNAME           => 'ge-7/0/38',
                        IFDESCR          => 'ge-7/0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:79',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8255) 0:01:22.55',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '887',
                        IFNAME           => 'ge-7/0/39',
                        IFDESCR          => 'ge-7/0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:7a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8255) 0:01:22.55',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '888',
                        IFNAME           => 'ge-7/0/40',
                        IFDESCR          => 'ge-7/0/40',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:7b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8262) 0:01:22.62',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '889',
                        IFNAME           => 'ge-7/0/41',
                        IFDESCR          => 'ge-7/0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:7c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8264) 0:01:22.64',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '890',
                        IFNAME           => 'ge-7/0/42',
                        IFDESCR          => 'ge-7/0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:7d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8265) 0:01:22.65',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '891',
                        IFNAME           => 'ge-7/0/43',
                        IFDESCR          => 'ge-7/0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:7e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8266) 0:01:22.66',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '892',
                        IFNAME           => 'ge-7/0/44',
                        IFDESCR          => 'ge-7/0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:7f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8272) 0:01:22.72',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '893',
                        IFNAME           => 'ge-7/0/45',
                        IFDESCR          => 'ge-7/0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:80',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8278) 0:01:22.78',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '894',
                        IFNAME           => 'ge-7/0/46',
                        IFDESCR          => 'ge-7/0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:81',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(8279) 0:01:22.79',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '895',
                        IFNAME           => 'ge-7/0/47',
                        IFDESCR          => 'ge-7/0/47',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:82',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(47775700) 5 days, 12:42:37.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1415',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1040',
                        IFNAME           => 'ge-7/0/0.0',
                        IFDESCR          => 'ge-7/0/0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:53',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(49647481) 5 days, 17:54:34.81',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2652',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '76631',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1041',
                        IFNAME           => 'ge-7/0/1.0',
                        IFDESCR          => 'ge-7/0/1.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:54',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54736383) 6 days, 8:02:43.83',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '157285',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6562433',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'c8:1f:66:d0:2d:03',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1042',
                        IFNAME           => 'ge-7/0/10.0',
                        IFDESCR          => 'ge-7/0/10.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:5d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54732673) 6 days, 8:02:06.73',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '159513',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6609572',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'c8:1f:66:d0:33:c3',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1043',
                        IFNAME           => 'ge-7/0/11.0',
                        IFDESCR          => 'ge-7/0/11.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:5e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54733893) 6 days, 8:02:18.93',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '157784',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6610272',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'c8:1f:66:d0:66:cd',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1052',
                        IFNAME           => 'ge-7/0/2.0',
                        IFDESCR          => 'ge-7/0/2.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:55',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54733983) 6 days, 8:02:19.83',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '156614',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3830283',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'c8:1f:66:d0:3b:14',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1063',
                        IFNAME           => 'ge-7/0/3.0',
                        IFDESCR          => 'ge-7/0/3.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:56',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54736823) 6 days, 8:02:48.23',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '160056',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6577720',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'c8:1f:66:d0:4c:83',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1074',
                        IFNAME           => 'ge-7/0/4.0',
                        IFDESCR          => 'ge-7/0/4.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:57',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54738293) 6 days, 8:03:02.93',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '157639',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3814972',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'c8:1f:66:d0:75:e9',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1083',
                        IFNAME           => 'ge-7/0/5.0',
                        IFDESCR          => 'ge-7/0/5.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:58',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(49297440) 5 days, 16:56:14.40',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1600',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2791610',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1084',
                        IFNAME           => 'ge-7/0/6.0',
                        IFDESCR          => 'ge-7/0/6.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:59',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(49645074) 5 days, 17:54:10.74',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3762',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2832337',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1085',
                        IFNAME           => 'ge-7/0/7.0',
                        IFDESCR          => 'ge-7/0/7.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:5a',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(49644282) 5 days, 17:54:02.82',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1094',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '83880',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1086',
                        IFNAME           => 'ge-7/0/8.0',
                        IFDESCR          => 'ge-7/0/8.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:5b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54733693) 6 days, 8:02:16.93',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '157485',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6561497',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'c8:1f:66:d0:2c:d5',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1087',
                        IFNAME           => 'ge-7/0/9.0',
                        IFDESCR          => 'ge-7/0/9.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:5c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54738053) 6 days, 8:03:00.53',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '158306',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3953165',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'c8:1f:66:d0:7b:66',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1088',
                        IFNAME           => 'xe-4/0/0.0',
                        IFDESCR          => 'xe-4/0/0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:1e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(46994329) 5 days, 10:32:23.29',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '11079928',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '436132589',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFNUMBER => '573',
                                IFDESCR  => 'xe-0/0/7.0',
                                SYSNAME  => 'sw-ex8208-tmk',
                                SYSDESCR => 'Juniper Networks, Inc. ex8208 , version 12.3R3.4 Build date: 2013-06-14 01:38:46 UTC ',
                                SYSMAC   => '78:19:f7:05:fb:f0',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1092',
                        IFNAME           => 'xe-5/0/0.0',
                        IFDESCR          => 'xe-5/0/0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:1e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(46996723) 5 days, 10:32:47.23',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '10444226',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '9305729',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFNUMBER => '581',
                                IFDESCR  => 'xe-1/0/7.0',
                                SYSNAME  => 'sw-ex8208-tmk',
                                SYSDESCR => 'Juniper Networks, Inc. ex8208 , version 12.3R3.4 Build date: 2013-06-14 01:38:46 UTC ',
                                SYSMAC   => '78:19:f7:05:fb:f0',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1209',
                        IFNAME           => 'ge-8/0/24.0',
                        IFDESCR          => 'ge-8/0/24.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:9b',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(47736536) 5 days, 12:36:05.36',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1210',
                        IFNAME           => 'ge-8/0/25.0',
                        IFDESCR          => 'ge-8/0/25.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:9c',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(47736536) 5 days, 12:36:05.36',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1211',
                        IFNAME           => 'ge-8/0/26.0',
                        IFDESCR          => 'ge-8/0/26.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:9d',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(47736537) 5 days, 12:36:05.37',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1212',
                        IFNAME           => 'ge-8/0/27.0',
                        IFDESCR          => 'ge-8/0/27.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:9e',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(47736558) 5 days, 12:36:05.58',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1213',
                        IFNAME           => 'ge-8/0/28.0',
                        IFDESCR          => 'ge-8/0/28.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:9f',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(47736558) 5 days, 12:36:05.58',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1214',
                        IFNAME           => 'ge-8/0/29.0',
                        IFDESCR          => 'ge-8/0/29.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:a0',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(47736558) 5 days, 12:36:05.58',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1216',
                        IFNAME           => 'ge-8/0/30.0',
                        IFDESCR          => 'ge-8/0/30.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:a1',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(47736558) 5 days, 12:36:05.58',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1217',
                        IFNAME           => 'ge-8/0/31.0',
                        IFDESCR          => 'ge-8/0/31.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:a2',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(48597507) 5 days, 14:59:35.07',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '674',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '67566',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1218',
                        IFNAME           => 'ge-8/0/32.0',
                        IFDESCR          => 'ge-8/0/32.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:a3',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(48597246) 5 days, 14:59:32.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3544',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '65250',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1219',
                        IFNAME           => 'ge-8/0/33.0',
                        IFDESCR          => 'ge-8/0/33.0',
                        IFTYPE           => '53',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:a4',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(50047300) 5 days, 19:01:13.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '954',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '140294',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1220',
                        IFNAME           => 'ge-8/0/34.0',
                        IFDESCR          => 'ge-8/0/34.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:a5',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(49781219) 5 days, 18:16:52.19',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '954',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '122398',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1221',
                        IFNAME           => 'ge-8/0/35.0',
                        IFDESCR          => 'ge-8/0/35.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:a6',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54735724) 6 days, 8:02:37.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '156309',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3880278',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'c8:1f:66:d0:53:26',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1222',
                        IFNAME           => 'ge-8/0/36.0',
                        IFDESCR          => 'ge-8/0/36.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:a7',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54737884) 6 days, 8:02:58.84',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '156734',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3811387',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'c8:1f:66:d0:75:d1',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1223',
                        IFNAME           => 'ge-8/0/37.0',
                        IFDESCR          => 'ge-8/0/37.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:a8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54735974) 6 days, 8:02:39.74',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '156724',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3811612',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'c8:1f:66:d0:41:62',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1224',
                        IFNAME           => 'ge-8/0/38.0',
                        IFDESCR          => 'ge-8/0/38.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:a9',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54734994) 6 days, 8:02:29.94',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '156217',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3815717',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'c8:1f:66:d0:2d:0b',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1225',
                        IFNAME           => 'ge-8/0/39.0',
                        IFDESCR          => 'ge-8/0/39.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:aa',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54738424) 6 days, 8:03:04.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '155799',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3886338',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'c8:1f:66:d0:7b:62',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1227',
                        IFNAME           => 'ge-8/0/40.0',
                        IFDESCR          => 'ge-8/0/40.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:ab',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54734064) 6 days, 8:02:20.64',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '156300',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3817757',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'c8:1f:66:d0:59:d0',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1228',
                        IFNAME           => 'ge-8/0/41.0',
                        IFDESCR          => 'ge-8/0/41.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:ac',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54733624) 6 days, 8:02:16.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '159806',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3889980',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'c8:1f:66:d0:41:6a',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1229',
                        IFNAME           => 'ge-8/0/42.0',
                        IFDESCR          => 'ge-8/0/42.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:ad',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(48921986) 5 days, 15:53:39.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '814',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1388',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1230',
                        IFNAME           => 'ge-8/0/43.0',
                        IFDESCR          => 'ge-8/0/43.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:ae',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(48921718) 5 days, 15:53:37.18',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2442',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '70866',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1231',
                        IFNAME           => 'ge-8/0/44.0',
                        IFDESCR          => 'ge-8/0/44.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:af',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(49749351) 5 days, 18:11:33.51',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1488',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '71372',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1232',
                        IFNAME           => 'ge-8/0/45.0',
                        IFDESCR          => 'ge-8/0/45.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:b0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54733824) 6 days, 8:02:18.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '157832',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3758245',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'c8:1f:66:d0:53:2e',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1233',
                        IFNAME           => 'ge-8/0/46.0',
                        IFDESCR          => 'ge-8/0/46.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:b1',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54733924) 6 days, 8:02:19.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '158197',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3846319',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'c8:1f:66:d0:3e:3b',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1234',
                        IFNAME           => 'ge-8/0/47.0',
                        IFDESCR          => 'ge-8/0/47.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:b2',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54733284) 6 days, 8:02:12.84',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '159371',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3908364',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'c8:1f:66:d0:53:86',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1240',
                        IFNAME           => 'ge-9/0/0.0',
                        IFDESCR          => 'ge-9/0/0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:b3',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(55254136) 6 days, 9:29:01.36',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '428169',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6623076',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '74:86:7a:ed:87:d8',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1241',
                        IFNAME           => 'ge-9/0/1.0',
                        IFDESCR          => 'ge-9/0/1.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:b4',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(55241746) 6 days, 9:26:57.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '428059',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6722312',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '74:86:7a:ed:86:ac',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1242',
                        IFNAME           => 'ge-9/0/10.0',
                        IFDESCR          => 'ge-9/0/10.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:bd',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(55095486) 6 days, 9:02:34.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '429964',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6750883',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '74:86:7a:ec:7d:74',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1243',
                        IFNAME           => 'ge-9/0/11.0',
                        IFDESCR          => 'ge-9/0/11.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:be',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(55241606) 6 days, 9:26:56.06',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '428779',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6748807',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '74:86:7a:ed:7e:58',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1244',
                        IFNAME           => 'ge-9/0/12.0',
                        IFDESCR          => 'ge-9/0/12.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:bf',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(55202706) 6 days, 9:20:27.06',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '427824',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6748137',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '74:86:7a:ed:84:30',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1245',
                        IFNAME           => 'ge-9/0/13.0',
                        IFDESCR          => 'ge-9/0/13.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:c0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(71053626) 8 days, 5:22:16.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '194133',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6659976',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'c8:1f:66:d0:4a:5e',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1246',
                        IFNAME           => 'ge-9/0/14.0',
                        IFDESCR          => 'ge-9/0/14.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:c1',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(71053386) 8 days, 5:22:13.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '196612',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6555243',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'c8:1f:66:d1:97:7a',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1247',
                        IFNAME           => 'ge-9/0/15.0',
                        IFDESCR          => 'ge-9/0/15.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:c2',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(71055246) 8 days, 5:22:32.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '191443',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6552765',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'c8:1f:66:d2:1f:6c',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1248',
                        IFNAME           => 'ge-9/0/16.0',
                        IFDESCR          => 'ge-9/0/16.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:c3',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(71053576) 8 days, 5:22:15.76',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '191976',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6552793',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'c8:1f:66:d1:9b:92',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1249',
                        IFNAME           => 'ge-9/0/17.0',
                        IFDESCR          => 'ge-9/0/17.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:c4',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(71053536) 8 days, 5:22:15.36',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '189026',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6537562',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'c8:1f:66:d2:17:b1',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1250',
                        IFNAME           => 'ge-9/0/18.0',
                        IFDESCR          => 'ge-9/0/18.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:c5',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(71055397) 8 days, 5:22:33.97',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '190220',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6554840',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'c8:1f:66:d0:9a:44',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1251',
                        IFNAME           => 'ge-9/0/19.0',
                        IFDESCR          => 'ge-9/0/19.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:c6',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(55185366) 6 days, 9:17:33.66',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '428588',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6646742',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '74:86:7a:ed:83:50',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1252',
                        IFNAME           => 'ge-9/0/2.0',
                        IFDESCR          => 'ge-9/0/2.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:b5',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(55197546) 6 days, 9:19:35.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '429048',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6719275',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '74:86:7a:ed:72:d4',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1253',
                        IFNAME           => 'ge-9/0/20.0',
                        IFDESCR          => 'ge-9/0/20.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:c7',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(71055196) 8 days, 5:22:31.96',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '188992',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6557467',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'c8:1f:66:d0:68:c0',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1254',
                        IFNAME           => 'ge-9/0/21.0',
                        IFDESCR          => 'ge-9/0/21.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:c8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(71054226) 8 days, 5:22:22.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '191042',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6556235',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'c8:1f:66:d0:74:cc',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1255',
                        IFNAME           => 'ge-9/0/22.0',
                        IFDESCR          => 'ge-9/0/22.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:c9',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(71053586) 8 days, 5:22:15.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '190768',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6552758',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'c8:1f:66:d0:2b:5f',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1256',
                        IFNAME           => 'ge-9/0/23.0',
                        IFDESCR          => 'ge-9/0/23.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:ca',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(71053536) 8 days, 5:22:15.36',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '204222',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6559750',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'c8:1f:66:d0:66:b1',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1257',
                        IFNAME           => 'ge-9/0/24.0',
                        IFDESCR          => 'ge-9/0/24.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:cb',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54581653) 6 days, 7:36:56.53',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1258',
                        IFNAME           => 'ge-9/0/25.0',
                        IFDESCR          => 'ge-9/0/25.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:cc',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54581662) 6 days, 7:36:56.62',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1259',
                        IFNAME           => 'ge-9/0/26.0',
                        IFDESCR          => 'ge-9/0/26.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:cd',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54581662) 6 days, 7:36:56.62',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1260',
                        IFNAME           => 'ge-9/0/27.0',
                        IFDESCR          => 'ge-9/0/27.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:ce',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54581673) 6 days, 7:36:56.73',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1261',
                        IFNAME           => 'ge-9/0/28.0',
                        IFDESCR          => 'ge-9/0/28.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:cf',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54581673) 6 days, 7:36:56.73',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1262',
                        IFNAME           => 'ge-9/0/29.0',
                        IFDESCR          => 'ge-9/0/29.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:d0',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54581683) 6 days, 7:36:56.83',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1263',
                        IFNAME           => 'ge-9/0/3.0',
                        IFDESCR          => 'ge-9/0/3.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:b6',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54600216) 6 days, 7:40:02.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '700',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6610221',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1264',
                        IFNAME           => 'ge-9/0/30.0',
                        IFDESCR          => 'ge-9/0/30.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:d1',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54581684) 6 days, 7:36:56.84',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1265',
                        IFNAME           => 'ge-9/0/31.0',
                        IFDESCR          => 'ge-9/0/31.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:d2',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54581693) 6 days, 7:36:56.93',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1266',
                        IFNAME           => 'ge-9/0/32.0',
                        IFDESCR          => 'ge-9/0/32.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:d3',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54581693) 6 days, 7:36:56.93',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1267',
                        IFNAME           => 'ge-9/0/33.0',
                        IFDESCR          => 'ge-9/0/33.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:d4',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54600197) 6 days, 7:40:01.97',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '560',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6635678',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1268',
                        IFNAME           => 'ge-9/0/34.0',
                        IFDESCR          => 'ge-9/0/34.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:d5',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54600197) 6 days, 7:40:01.97',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '140',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3792584',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1269',
                        IFNAME           => 'ge-9/0/35.0',
                        IFDESCR          => 'ge-9/0/35.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:d6',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54600247) 6 days, 7:40:02.47',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '700',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6638846',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1274',
                        IFNAME           => 'ge-9/0/4.0',
                        IFDESCR          => 'ge-9/0/4.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:b7',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54600216) 6 days, 7:40:02.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2274',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6701303',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1283',
                        IFNAME           => 'ge-9/0/5.0',
                        IFDESCR          => 'ge-9/0/5.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:b8',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54600216) 6 days, 7:40:02.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '840',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6609770',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1284',
                        IFNAME           => 'ge-9/0/6.0',
                        IFDESCR          => 'ge-9/0/6.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:b9',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(54600216) 6 days, 7:40:02.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2188',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6700090',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1285',
                        IFNAME           => 'ge-9/0/7.0',
                        IFDESCR          => 'ge-9/0/7.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:ba',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(55209706) 6 days, 9:21:37.06',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '429447',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6576343',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '74:86:7a:ed:76:6c',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1286',
                        IFNAME           => 'ge-9/0/8.0',
                        IFDESCR          => 'ge-9/0/8.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:bb',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(55229056) 6 days, 9:24:50.56',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '428618',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6721110',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '74:86:7a:ed:85:a0',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1287',
                        IFNAME           => 'ge-9/0/9.0',
                        IFDESCR          => 'ge-9/0/9.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:69:bc',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(55228916) 6 days, 9:24:49.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '428234',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6722266',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '74:86:7a:ed:84:3c',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1288',
                        IFNAME           => 'ae0',
                        IFDESCR          => 'ae0',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:03',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(825) 0:00:08.25',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1290',
                        IFNAME           => 'vlan.102',
                        IFDESCR          => 'vlan.102',
                        IFALIAS          => 'Net-mgmt',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.102.27',
                        MAC              => '88:e0:f3:b0:68:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(950) 0:00:09.50',
                        IFINOCTETS       => '365349581',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '392118911',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1291',
                        IFNAME           => 'ae1',
                        IFDESCR          => 'ae1',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:04',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(825) 0:00:08.25',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1292',
                        IFNAME           => 'ae2',
                        IFDESCR          => 'ae2',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:05',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(827) 0:00:08.27',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1293',
                        IFNAME           => 'ae3',
                        IFDESCR          => 'ae3',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:06',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(834) 0:00:08.34',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1294',
                        IFNAME           => 'ae4',
                        IFDESCR          => 'ae4',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:07',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(834) 0:00:08.34',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1295',
                        IFNAME           => 'ae5',
                        IFDESCR          => 'ae5',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:08',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(834) 0:00:08.34',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1296',
                        IFNAME           => 'ae6',
                        IFDESCR          => 'ae6',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:09',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(834) 0:00:08.34',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1297',
                        IFNAME           => 'ae7',
                        IFDESCR          => 'ae7',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:0a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(834) 0:00:08.34',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1298',
                        IFNAME           => 'ae8',
                        IFDESCR          => 'ae8',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:0b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(834) 0:00:08.34',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1299',
                        IFNAME           => 'ae9',
                        IFDESCR          => 'ae9',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:0c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(834) 0:00:08.34',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1300',
                        IFNAME           => 'ae10',
                        IFDESCR          => 'ae10',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:0d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(825) 0:00:08.25',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1301',
                        IFNAME           => 'ae11',
                        IFDESCR          => 'ae11',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:0e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(826) 0:00:08.26',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1302',
                        IFNAME           => 'ae12',
                        IFDESCR          => 'ae12',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:0f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(827) 0:00:08.27',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1303',
                        IFNAME           => 'ae13',
                        IFDESCR          => 'ae13',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:10',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(827) 0:00:08.27',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1304',
                        IFNAME           => 'ae14',
                        IFDESCR          => 'ae14',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:11',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(827) 0:00:08.27',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1305',
                        IFNAME           => 'ae15',
                        IFDESCR          => 'ae15',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:12',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(827) 0:00:08.27',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1306',
                        IFNAME           => 'ae16',
                        IFDESCR          => 'ae16',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:13',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(827) 0:00:08.27',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1307',
                        IFNAME           => 'ae17',
                        IFDESCR          => 'ae17',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:14',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(827) 0:00:08.27',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1308',
                        IFNAME           => 'ae18',
                        IFDESCR          => 'ae18',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:15',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(827) 0:00:08.27',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1309',
                        IFNAME           => 'ae19',
                        IFDESCR          => 'ae19',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:16',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(827) 0:00:08.27',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1310',
                        IFNAME           => 'ae20',
                        IFDESCR          => 'ae20',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:17',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(827) 0:00:08.27',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1311',
                        IFNAME           => 'ae21',
                        IFDESCR          => 'ae21',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:18',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(827) 0:00:08.27',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1312',
                        IFNAME           => 'ae22',
                        IFDESCR          => 'ae22',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:19',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(827) 0:00:08.27',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1313',
                        IFNAME           => 'ae23',
                        IFDESCR          => 'ae23',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:1a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(830) 0:00:08.30',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1314',
                        IFNAME           => 'ae24',
                        IFDESCR          => 'ae24',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:1b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(830) 0:00:08.30',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1315',
                        IFNAME           => 'ae25',
                        IFDESCR          => 'ae25',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:1c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(830) 0:00:08.30',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1316',
                        IFNAME           => 'ae26',
                        IFDESCR          => 'ae26',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:1d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(830) 0:00:08.30',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1317',
                        IFNAME           => 'ae27',
                        IFDESCR          => 'ae27',
                        IFALIAS          => 'sw-ex8208-tmk',
                        IFTYPE           => '161',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:1e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(945) 0:00:09.45',
                        IFINOCTETS       => '2843220484',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3178610497',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1318',
                        IFNAME           => 'ae27.0',
                        IFDESCR          => 'ae27.0',
                        IFTYPE           => '161',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '88:e0:f3:b0:68:1e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(945) 0:00:09.45',
                        IFINOCTETS       => '491983393',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '427186522',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:14:4f:02:0e:a2',
                                    '00:14:4f:4a:1e:aa',
                                    '78:19:f7:05:fa:01',
                                    '78:19:f7:05:fa:01',
                                    '00:14:4f:02:06:ee',
                                    '00:14:4f:49:d6:ee',
                                    '00:14:4f:49:d7:5a',
                                    '00:14:4f:49:d9:da',
                                    '00:14:4f:49:e1:82',
                                    '68:b5:99:6d:5b:a6',
                                    '78:19:f7:05:fa:01',
                                    '2c:76:8a:54:c5:04',
                                    '00:01:d7:c2:03:c0',
                                    '00:0c:29:d6:b8:64',
                                    '00:10:db:ff:10:01',
                                    '78:19:f7:05:fa:01',
                                    '78:19:f7:05:fa:01',
                                    '90:b1:1c:55:25:d8',
                                    '78:19:f7:05:fa:01',
                                    '9c:8e:99:1b:f2:54',
                                    '78:19:f7:05:fa:01',
                                    '00:01:d7:8a:76:1c',
                                    '78:19:f7:05:fa:01',
                                    '78:19:f7:05:fa:01',
                                ],
                            }
                        }
                    },
                ]
            },
        },
    ],
    'juniper/ex8208.01.walk' => [
        {
            TYPE         => 'NETWORKING',
            MANUFACTURER => 'Juniper',
            MODEL        => 'EX8208',
            DESCRIPTION  => 'Juniper Networks, Inc. ex8208 Ethernet Switch, kernel JUNOS 12.3R3.4, Build date: 2013-06-14 01:37:19 UTC Copyright (c) 1996-2013 Juniper Networks, Inc.',

            SNMPHOSTNAME => 'sw-ex8208-tmk',
            LOCATION     => 'Nowhere',
            SERIAL       => 'CA1612070587',
            UPTIME       => '(773970659) 89 days, 13:55:06.59',
            MEMORY       => '0',
            MAC          => '78:19:f7:05:fa:01',
            IPS          => {
                IP => [
                    '10.15.100.253',
                    '10.15.15.14',
                    '10.15.15.2',
                    '10.15.15.5',
                    '10.20.0.20',
                    '10.20.1.1',
                    '10.20.10.1',
                    '10.20.101.10',
                    '10.20.101.11',
                    '10.20.102.1',
                    '10.20.104.1',
                    '10.20.105.1',
                    '10.20.11.1',
                    '10.20.12.1',
                    '10.20.13.1',
                    '10.20.14.1',
                    '10.20.15.1',
                    '10.20.16.1',
                    '10.20.17.1',
                    '10.20.172.1',
                    '10.20.18.1',
                    '10.20.19.1',
                    '10.20.2.1',
                    '10.20.20.1',
                    '10.20.202.1',
                    '10.20.204.1',
                    '10.20.205.1',
                    '10.20.207.1',
                    '10.20.208.1',
                    '10.20.209.1',
                    '10.20.21.1',
                    '10.20.210.1',
                    '10.20.211.1',
                    '10.20.212.1',
                    '10.20.22.1',
                    '10.20.23.1',
                    '10.20.24.1',
                    '10.20.25.1',
                    '10.20.26.1',
                    '10.20.27.1',
                    '10.20.3.1',
                    '10.20.33.1',
                    '10.20.4.1',
                    '10.20.42.1',
                    '10.20.43.1',
                    '10.20.47.1',
                    '10.20.5.1',
                    '10.20.52.1',
                    '10.20.53.1',
                    '10.20.54.1',
                    '10.20.55.1',
                    '10.20.58.1',
                    '10.20.59.1',
                    '10.20.6.1',
                    '10.20.60.1',
                    '10.20.61.1',
                    '10.20.62.1',
                    '10.20.63.1',
                    '10.20.64.1',
                    '10.20.65.1',
                    '10.20.66.1',
                    '10.20.67.1',
                    '10.20.68.254',
                    '10.20.7.1',
                    '10.20.70.1',
                    '10.20.73.1',
                    '10.20.75.1',
                    '10.20.76.1',
                    '10.20.77.1',
                    '10.20.78.1',
                    '10.20.79.1',
                    '10.20.8.1',
                    '10.20.81.1',
                    '10.20.82.1',
                    '10.20.83.1',
                    '10.20.84.1',
                    '10.20.85.1',
                    '10.20.86.1',
                    '10.20.87.1',
                    '10.20.88.1',
                    '10.20.89.1',
                    '10.20.9.1',
                    '10.20.90.1',
                    '10.20.92.1',
                    '10.20.93.1',
                    '10.20.95.1',
                    '10.20.96.1',
                    '10.20.97.1',
                    '127.0.0.1',
                    '128.0.0.1',
                    '128.0.0.4',
                    '128.0.4.0',
                    '129.0.0.1',
                    '129.0.0.4',
                ],
            },
        },
        {
            INFO => {
                ID           => undef,
                TYPE         => 'NETWORKING',
                MANUFACTURER => 'Juniper',
                MODEL        => 'EX8208',
                COMMENTS     => 'Juniper Networks, Inc. ex8208 Ethernet Switch, kernel JUNOS 12.3R3.4, Build date: 2013-06-14 01:37:19 UTC Copyright (c) 1996-2013 Juniper Networks, Inc.',
                NAME         => 'sw-ex8208-tmk',
                LOCATION     => 'Nowhere',
                SERIAL       => 'CA1612070587',
                UPTIME       => '(773970659) 89 days, 13:55:06.59',
                MEMORY       => '0',
                MAC          => '78:19:f7:05:fa:01',
                IPS          => {
                    IP => [
                        '10.15.100.253',
                        '10.15.15.14',
                        '10.15.15.2',
                        '10.15.15.5',
                        '10.20.0.20',
                        '10.20.1.1',
                        '10.20.10.1',
                        '10.20.101.10',
                        '10.20.101.11',
                        '10.20.102.1',
                        '10.20.104.1',
                        '10.20.105.1',
                        '10.20.11.1',
                        '10.20.12.1',
                        '10.20.13.1',
                        '10.20.14.1',
                        '10.20.15.1',
                        '10.20.16.1',
                        '10.20.17.1',
                        '10.20.172.1',
                        '10.20.18.1',
                        '10.20.19.1',
                        '10.20.2.1',
                        '10.20.20.1',
                        '10.20.202.1',
                        '10.20.204.1',
                        '10.20.205.1',
                        '10.20.207.1',
                        '10.20.208.1',
                        '10.20.209.1',
                        '10.20.21.1',
                        '10.20.210.1',
                        '10.20.211.1',
                        '10.20.212.1',
                        '10.20.22.1',
                        '10.20.23.1',
                        '10.20.24.1',
                        '10.20.25.1',
                        '10.20.26.1',
                        '10.20.27.1',
                        '10.20.3.1',
                        '10.20.33.1',
                        '10.20.4.1',
                        '10.20.42.1',
                        '10.20.43.1',
                        '10.20.47.1',
                        '10.20.5.1',
                        '10.20.52.1',
                        '10.20.53.1',
                        '10.20.54.1',
                        '10.20.55.1',
                        '10.20.58.1',
                        '10.20.59.1',
                        '10.20.6.1',
                        '10.20.60.1',
                        '10.20.61.1',
                        '10.20.62.1',
                        '10.20.63.1',
                        '10.20.64.1',
                        '10.20.65.1',
                        '10.20.66.1',
                        '10.20.67.1',
                        '10.20.68.254',
                        '10.20.7.1',
                        '10.20.70.1',
                        '10.20.73.1',
                        '10.20.75.1',
                        '10.20.76.1',
                        '10.20.77.1',
                        '10.20.78.1',
                        '10.20.79.1',
                        '10.20.8.1',
                        '10.20.81.1',
                        '10.20.82.1',
                        '10.20.83.1',
                        '10.20.84.1',
                        '10.20.85.1',
                        '10.20.86.1',
                        '10.20.87.1',
                        '10.20.88.1',
                        '10.20.89.1',
                        '10.20.9.1',
                        '10.20.90.1',
                        '10.20.92.1',
                        '10.20.93.1',
                        '10.20.95.1',
                        '10.20.96.1',
                        '10.20.97.1',
                        '127.0.0.1',
                        '128.0.0.1',
                        '128.0.0.4',
                        '128.0.4.0',
                        '129.0.0.1',
                        '129.0.0.4',
                    ],
                },
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '4',
                        IFNAME           => 'lsi',
                        IFDESCR          => 'lsi',
                        IFTYPE           => '150',
                        IFSPEED          => '0',
                        IFMTU            => '1496',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5',
                        IFNAME           => 'dsc',
                        IFDESCR          => 'dsc',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(291) 0:00:02.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '6',
                        IFNAME           => 'lo0',
                        IFDESCR          => 'lo0',
                        IFTYPE           => '24',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(291) 0:00:02.91',
                        IFINOCTETS       => '1906581298',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1906588234',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '7',
                        IFNAME           => 'tap',
                        IFDESCR          => 'tap',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(295) 0:00:02.95',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '8',
                        IFNAME           => 'gre',
                        IFDESCR          => 'gre',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(291) 0:00:02.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '9',
                        IFNAME           => 'ipip',
                        IFDESCR          => 'ipip',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(291) 0:00:02.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10',
                        IFNAME           => 'pime',
                        IFDESCR          => 'pime',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(291) 0:00:02.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '11',
                        IFNAME           => 'pimd',
                        IFDESCR          => 'pimd',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(291) 0:00:02.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '12',
                        IFNAME           => 'mtun',
                        IFDESCR          => 'mtun',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '16',
                        IFNAME           => 'lo0.0',
                        IFDESCR          => 'lo0.0',
                        IFTYPE           => '24',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IP               => '10.20.2.1',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(291) 0:00:02.91',
                        IFINOCTETS       => '13378',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '13378',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '21',
                        IFNAME           => 'lo0.16384',
                        IFDESCR          => 'lo0.16384',
                        IFTYPE           => '24',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IP               => '127.0.0.1',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(291) 0:00:02.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '33',
                        IFNAME           => 'me0',
                        IFDESCR          => 'me0',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:ff',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(740661292) 85 days, 17:23:32.92',
                        IFINOCTETS       => '86964437',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '5782463',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '34',
                        IFNAME           => 'me0.0',
                        IFDESCR          => 'me0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.101.11',
                        MAC              => '78:19:f7:05:fb:ff',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(740661292) 85 days, 17:23:32.92',
                        IFINOCTETS       => '86964437',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '5782463',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '37',
                        IFNAME           => 'bme0',
                        IFDESCR          => 'bme0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1990',
                        MAC              => '02:44:81:00:00:04',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '928722308',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '38',
                        IFNAME           => 'bme0.32768',
                        IFDESCR          => 'bme0.32768',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1976',
                        IP               => '128.0.4.0',
                        MAC              => '02:44:81:00:00:04',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '1006830220',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3926454616',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '109',
                        IFNAME           => 'bme1',
                        IFDESCR          => 'bme1',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1990',
                        MAC              => '00:0b:ca:fe:00:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '1275175981',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2741654306',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '111',
                        IFNAME           => 'bme1.32768',
                        IFDESCR          => 'bme1.32768',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1990',
                        MAC              => '00:0b:ca:fe:00:00',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '278363080',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '112',
                        IFNAME           => 'bme2',
                        IFDESCR          => 'bme2',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1990',
                        MAC              => '00:0b:ca:fe:00:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(173009) 0:28:50.09',
                        IFINOCTETS       => '2360465484',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '386589284',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '114',
                        IFNAME           => 'bme2.32768',
                        IFDESCR          => 'bme2.32768',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1990',
                        MAC              => '00:0b:ca:fe:00:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(173009) 0:28:50.09',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '278344280',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '163',
                        IFNAME           => 'bme3',
                        IFDESCR          => 'bme3',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1990',
                        MAC              => '00:0b:ca:fe:00:02',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '386615392',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '165',
                        IFNAME           => 'bme3.32768',
                        IFDESCR          => 'bme3.32768',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1990',
                        MAC              => '00:0b:ca:fe:00:02',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '278363080',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '166',
                        IFNAME           => 'bme0.36862',
                        IFDESCR          => 'bme0.36862',
                        IFTYPE           => '135',
                        IFSPEED          => '0',
                        IFMTU            => '1972',
                        IP               => '129.0.0.4',
                        MAC              => '02:44:81:00:00:04',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '1750404176',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1180013020',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '501',
                        IFNAME           => 'vlan',
                        IFDESCR          => 'vlan',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1755) 0:00:17.55',
                        IFINOCTETS       => '659334756',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2675284635',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '502',
                        IFNAME           => 'xe-0/0/0',
                        IFDESCR          => 'xe-0/0/0',
                        IFALIAS          => 'To sw-6509-tmk',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:0d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21008) 0:03:30.08',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1720437595',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1071259838',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '503',
                        IFNAME           => 'xe-0/0/1',
                        IFDESCR          => 'xe-0/0/1',
                        IFALIAS          => 'To LTM',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:17',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(751001507) 86 days, 22:06:55.07',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3007748258',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1439350794',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '504',
                        IFNAME           => 'xe-0/0/2',
                        IFDESCR          => 'xe-0/0/2',
                        IFALIAS          => 'To-sw-c300-1-tmk',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:18',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21136) 0:03:31.36',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1166039697',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '545445184',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '505',
                        IFNAME           => 'xe-0/0/3',
                        IFDESCR          => 'xe-0/0/3',
                        IFALIAS          => 'To-sw-c300-2-tmk',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:19',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21136) 0:03:31.36',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2219698321',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3185305623',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '506',
                        IFNAME           => 'xe-0/0/4',
                        IFDESCR          => 'xe-0/0/4',
                        IFALIAS          => 'To sw-c300-3-tmk Te1/44 Te4/44',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1a',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21136) 0:03:31.36',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1117591493',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1309940545',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '507',
                        IFNAME           => 'xe-0/0/5',
                        IFDESCR          => 'xe-0/0/5',
                        IFALIAS          => 'To-sw-3750-2-tmk',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20998) 0:03:29.98',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2090196579',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1316645225',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '508',
                        IFNAME           => 'xe-0/0/6',
                        IFDESCR          => 'xe-0/0/6',
                        IFALIAS          => 'Tmp-to-sw3750-3-tmk',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:09',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1114606) 3:05:46.06',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3698340492',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4051968062',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '509',
                        IFNAME           => 'xe-0/0/7',
                        IFDESCR          => 'xe-0/0/7',
                        IFALIAS          => 'AE to ex6210',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(685814628) 79 days, 9:02:26.28',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '4185459806',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2265761808',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '510',
                        IFNAME           => 'xe-2/0/0',
                        IFDESCR          => 'xe-2/0/0',
                        IFALIAS          => 'Tmp to LTM',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(751001845) 86 days, 22:06:58.45',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3153928590',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3993980636',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '518',
                        IFNAME           => 'xe-1/0/0',
                        IFDESCR          => 'xe-1/0/0',
                        IFALIAS          => 'To sw-6509-tmk',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:0d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21606) 0:03:36.06',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '276924966',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '384051335',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '519',
                        IFNAME           => 'xe-1/0/1',
                        IFDESCR          => 'xe-1/0/1',
                        IFALIAS          => 'To LTM',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:17',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(751001511) 86 days, 22:06:55.11',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1682934263',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3638015566',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '520',
                        IFNAME           => 'xe-1/0/2',
                        IFDESCR          => 'xe-1/0/2',
                        IFALIAS          => 'To-sw-c300-1-tmk',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:18',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21515) 0:03:35.15',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1835869737',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3052092837',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '521',
                        IFNAME           => 'xe-1/0/3',
                        IFDESCR          => 'xe-1/0/3',
                        IFALIAS          => 'To-sw-c300-2-tmk',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:19',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21505) 0:03:35.05',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3964898874',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3850293558',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '522',
                        IFNAME           => 'xe-1/0/4',
                        IFDESCR          => 'xe-1/0/4',
                        IFALIAS          => 'To sw-c300-3-tmk Te1/44 Te4/44',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1a',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21505) 0:03:35.05',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3214439871',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2806957357',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '525',
                        IFNAME           => 'xe-1/0/7',
                        IFDESCR          => 'xe-1/0/7',
                        IFALIAS          => 'AE to ex6210',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(685817015) 79 days, 9:02:50.15',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '4187402335',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2105855509',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '526',
                        IFNAME           => 'xe-3/0/0',
                        IFDESCR          => 'xe-3/0/0',
                        IFALIAS          => 'Tmp to LTM',
                        IFTYPE           => '6',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(751001716) 86 days, 22:06:57.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '711343029',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3250636368',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '566',
                        IFNAME           => 'xe-0/0/0.0',
                        IFDESCR          => 'xe-0/0/0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:0d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21008) 0:03:30.08',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '581538706',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '88124084',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFNUMBER => 'Te1/2',
                                IFDESCR  => 'TenGigabitEthernet1/2',
                                SYSNAME  => 'sw-6509-tmk.ulan',
                                SYSDESCR => '"Cisco IOS Software, s72033_rp Software (s72033_rp-ADVIPSERVICESK9_WAN-M), Version 12.2(33)SXI9, RELEASE SOFTWARE (fc2)',
                                SYSMAC   => '00:19:07:db:18:00',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '567',
                        IFNAME           => 'xe-0/0/1.0',
                        IFDESCR          => 'xe-0/0/1.0',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:17',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(751001507) 86 days, 22:06:55.07',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '62095527',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '177707309',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '568',
                        IFNAME           => 'xe-0/0/2.0',
                        IFDESCR          => 'xe-0/0/2.0',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:18',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21136) 0:03:31.36',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '85664651',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '603304761',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFNUMBER => 'TenGigabitEthernet 0/44',
                                IFDESCR  => undef,
                                SYSNAME  => 'sw-c300-1-tmk',
                                SYSDESCR => 'Dell Force10 Real Time Operating System Software. Dell Force10 Operating System Version: 1.0. Dell Force10 Application Software Version: 8.4.2.7. Copyright (c) 1999-2012 Dell Inc. All Rights Reserved.Build Time: Thu Sep 27 14:19:20 PDT 2012',
                                SYSMAC   => '00:01:e8:84:99:92',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '569',
                        IFNAME           => 'xe-0/0/3.0',
                        IFDESCR          => 'xe-0/0/3.0',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:19',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21136) 0:03:31.36',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '85450276',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2955466533',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFNUMBER => 'TenGigabitEthernet 4/44',
                                IFDESCR  => undef,
                                SYSNAME  => 'sw-c300-2-tmk',
                                SYSDESCR => 'Dell Force10 Real Time Operating System Software. Dell Force10 Operating System Version: 1.0. Dell Force10 Application Software Version: 8.4.2.7. Copyright (c) 1999-2012 Dell Inc. All Rights Reserved.Build Time: Thu Sep 27 14:19:20 PDT 2012',
                                SYSMAC   => '00:01:e8:75:66:15',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '570',
                        IFNAME           => 'xe-0/0/4.0',
                        IFDESCR          => 'xe-0/0/4.0',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1a',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21136) 0:03:31.36',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '85554891',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1963059087',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFNUMBER => 'TenGigabitEthernet 1/44',
                                IFDESCR  => undef,
                                SYSNAME  => 'sw-c300-3-tmk',
                                SYSDESCR => 'Dell Force10 Real Time Operating System Software. Dell Force10 Operating System Version: 1.0. Dell Force10 Application Software Version: 8.4.2.7. Copyright (c) 1999-2012 Dell Inc. All Rights Reserved.Build Time: Thu Sep 27 14:19:20 PDT 2012',
                                SYSMAC   => '00:01:e8:80:e8:b3',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '571',
                        IFNAME           => 'xe-0/0/5.0',
                        IFDESCR          => 'xe-0/0/5.0',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20998) 0:03:29.98',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '94353912',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '248029272',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFNUMBER => 'Te8/0/1',
                                IFDESCR  => 'TenGigabitEthernet8/0/1',
                                SYSNAME  => 'sw-3750-2-tmk.ulan',
                                SYSDESCR => '"Cisco IOS Software, C3750 Software (C3750-IPSERVICESK9-M), Version 12.2(55)SE8, RELEASE SOFTWARE (fc2)',
                                SYSMAC   => '00:19:55:cd:ac:00',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '572',
                        IFNAME           => 'xe-0/0/6.0',
                        IFDESCR          => 'xe-0/0/6.0',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:09',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1114606) 3:05:46.06',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1207974849',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '128752177',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFNUMBER => 'Te1/0/1',
                                IFDESCR  => 'TenGigabitEthernet1/0/1',
                                SYSNAME  => 'sw-3750-3-tmk.ulan',
                                SYSDESCR => '"Cisco IOS Software, C3750 Software (C3750-IPSERVICESK9-M), Version 12.2(55)SE8, RELEASE SOFTWARE (fc2)',
                                SYSMAC   => '00:1a:e3:31:fc:00',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '573',
                        IFNAME           => 'xe-0/0/7.0',
                        IFDESCR          => 'xe-0/0/7.0',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(685814628) 79 days, 9:02:26.28',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '13633851',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '47468314',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFNUMBER => '1088',
                                IFDESCR  => 'xe-4/0/0.0',
                                SYSNAME  => 'sw-ex6210-tmk',
                                SYSDESCR => 'Juniper Networks, Inc. ex6210 , version 12.3R3.4 Build date: 2013-06-14 01:38:46 UTC ',
                                SYSMAC   => '88:e0:f3:b0:69:f0',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '574',
                        IFNAME           => 'xe-1/0/0.0',
                        IFDESCR          => 'xe-1/0/0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:0d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21606) 0:03:36.06',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '581534966',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '125683142',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFNUMBER => 'Te2/2',
                                IFDESCR  => 'TenGigabitEthernet2/2',
                                SYSNAME  => 'sw-6509-tmk.ulan',
                                SYSDESCR => '"Cisco IOS Software, s72033_rp Software (s72033_rp-ADVIPSERVICESK9_WAN-M), Version 12.2(33)SXI9, RELEASE SOFTWARE (fc2)',
                                SYSMAC   => '00:19:07:db:18:00',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '575',
                        IFNAME           => 'xe-1/0/1.0',
                        IFDESCR          => 'xe-1/0/1.0',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:17',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(751001511) 86 days, 22:06:55.11',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '62112914',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '80579872',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '576',
                        IFNAME           => 'xe-1/0/2.0',
                        IFDESCR          => 'xe-1/0/2.0',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:18',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21515) 0:03:35.15',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '85664651',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '83100474',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFNUMBER => 'TenGigabitEthernet 1/44',
                                IFDESCR  => undef,
                                SYSNAME  => 'sw-c300-1-tmk',
                                SYSDESCR => 'Dell Force10 Real Time Operating System Software. Dell Force10 Operating System Version: 1.0. Dell Force10 Application Software Version: 8.4.2.7. Copyright (c) 1999-2012 Dell Inc. All Rights Reserved.Build Time: Thu Sep 27 14:19:20 PDT 2012',
                                SYSMAC   => '00:01:e8:84:99:92',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '577',
                        IFNAME           => 'xe-1/0/3.0',
                        IFDESCR          => 'xe-1/0/3.0',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:19',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21505) 0:03:35.05',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '85450276',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '83112096',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFNUMBER => 'TenGigabitEthernet 5/44',
                                IFDESCR  => undef,
                                SYSNAME  => 'sw-c300-2-tmk',
                                SYSDESCR => 'Dell Force10 Real Time Operating System Software. Dell Force10 Operating System Version: 1.0. Dell Force10 Application Software Version: 8.4.2.7. Copyright (c) 1999-2012 Dell Inc. All Rights Reserved.Build Time: Thu Sep 27 14:19:20 PDT 2012',
                                SYSMAC   => '00:01:e8:75:66:15',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '578',
                        IFNAME           => 'xe-1/0/4.0',
                        IFDESCR          => 'xe-1/0/4.0',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1a',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21505) 0:03:35.05',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '85554891',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '83110308',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFNUMBER => 'TenGigabitEthernet 4/44',
                                IFDESCR  => undef,
                                SYSNAME  => 'sw-c300-3-tmk',
                                SYSDESCR => 'Dell Force10 Real Time Operating System Software. Dell Force10 Operating System Version: 1.0. Dell Force10 Application Software Version: 8.4.2.7. Copyright (c) 1999-2012 Dell Inc. All Rights Reserved.Build Time: Thu Sep 27 14:19:20 PDT 2012',
                                SYSMAC   => '00:01:e8:80:e8:b3',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '581',
                        IFNAME           => 'xe-1/0/7.0',
                        IFDESCR          => 'xe-1/0/7.0',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(685817015) 79 days, 9:02:50.15',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '13635867',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '16317374',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFNUMBER => '1092',
                                IFDESCR  => 'xe-5/0/0.0',
                                SYSNAME  => 'sw-ex6210-tmk',
                                SYSDESCR => 'Juniper Networks, Inc. ex6210 , version 12.3R3.4 Build date: 2013-06-14 01:38:46 UTC ',
                                SYSMAC   => '88:e0:f3:b0:69:f0',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '582',
                        IFNAME           => 'xe-2/0/0.0',
                        IFDESCR          => 'xe-2/0/0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(751001845) 86 days, 22:06:58.45',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1998180',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1622414',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '590',
                        IFNAME           => 'xe-3/0/0.0',
                        IFDESCR          => 'xe-3/0/0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(751001716) 86 days, 22:06:57.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1999096',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1014',
                        IFNAME           => 'ge-7/0/0',
                        IFDESCR          => 'ge-7/0/0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:53',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11132) 0:01:51.32',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1015',
                        IFNAME           => 'ge-7/0/1',
                        IFDESCR          => 'ge-7/0/1',
                        IFALIAS          => 'To fw-srx1400-tmk node0',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:41',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20718) 0:03:27.18',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2272800062',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3395993406',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1016',
                        IFNAME           => 'ge-7/0/2',
                        IFDESCR          => 'ge-7/0/2',
                        IFALIAS          => 'To fw-srx1400-tmk node0',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:41',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20718) 0:03:27.18',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1119088361',
                        IFINERRORS       => '9',
                        IFOUTOCTETS      => '930463043',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1017',
                        IFNAME           => 'ge-7/0/3',
                        IFDESCR          => 'ge-7/0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:56',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11152) 0:01:51.52',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1018',
                        IFNAME           => 'ge-7/0/4',
                        IFDESCR          => 'ge-7/0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:57',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11157) 0:01:51.57',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1019',
                        IFNAME           => 'ge-7/0/5',
                        IFDESCR          => 'ge-7/0/5',
                        IFALIAS          => 'To sw-2960-1-tmk',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:58',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20736) 0:03:27.36',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3479483349',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4108667781',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1020',
                        IFNAME           => 'ge-7/0/6',
                        IFDESCR          => 'ge-7/0/6',
                        IFALIAS          => 'To sw-2960-2-tmk',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:59',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(455383955) 52 days, 16:57:19.55',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1720715705',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '677997161',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1021',
                        IFNAME           => 'ge-7/0/7',
                        IFDESCR          => 'ge-7/0/7',
                        IFALIAS          => 'To sw-s50-5-tmk',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:5a',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20726) 0:03:27.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2059365047',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '640893991',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1022',
                        IFNAME           => 'ge-7/0/8',
                        IFDESCR          => 'ge-7/0/8',
                        IFALIAS          => 'To sw-s50-7-tmk',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:5b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(740661416) 85 days, 17:23:34.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2527560553',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2999569098',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1023',
                        IFNAME           => 'ge-7/0/9',
                        IFDESCR          => 'ge-7/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:5c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11180) 0:01:51.80',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1024',
                        IFNAME           => 'ge-7/0/10',
                        IFDESCR          => 'ge-7/0/10',
                        IFALIAS          => 'raritan2',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:5d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4257635) 11:49:36.35',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '86807131',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '732750119',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1025',
                        IFNAME           => 'ge-7/0/11',
                        IFDESCR          => 'ge-7/0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:5e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11182) 0:01:51.82',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1026',
                        IFNAME           => 'ge-7/0/12',
                        IFDESCR          => 'ge-7/0/12',
                        IFALIAS          => 'Trustwave',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:5f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(740656306) 85 days, 17:22:43.06',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '763245178',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1522026648',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1027',
                        IFNAME           => 'ge-7/0/13',
                        IFDESCR          => 'ge-7/0/13',
                        IFALIAS          => 'Remote VPN ASA5540 Inside',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:a0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(473084606) 54 days, 18:07:26.06',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1861940947',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '755514624',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1028',
                        IFNAME           => 'ge-7/0/14',
                        IFDESCR          => 'ge-7/0/14',
                        IFALIAS          => 'Raritan',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:61',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20646) 0:03:26.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '80755508',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '731614230',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1029',
                        IFNAME           => 'ge-7/0/15',
                        IFDESCR          => 'ge-7/0/15',
                        IFALIAS          => 'sw-3750-2-tmk Gi2/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(11200) 0:01:52.00',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1030',
                        IFNAME           => 'ge-7/0/16',
                        IFDESCR          => 'ge-7/0/16',
                        IFALIAS          => 'sw-3750-2-tmk Gi4/0/49',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(11210) 0:01:52.10',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1031',
                        IFNAME           => 'ge-7/0/17',
                        IFDESCR          => 'ge-7/0/17',
                        IFALIAS          => 'sw-3750-3-tmk Gi3/0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(11211) 0:01:52.11',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1032',
                        IFNAME           => 'ge-7/0/18',
                        IFDESCR          => 'ge-7/0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:65',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11221) 0:01:52.21',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1033',
                        IFNAME           => 'ge-7/0/19',
                        IFDESCR          => 'ge-7/0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:66',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11221) 0:01:52.21',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1034',
                        IFNAME           => 'ge-7/0/20',
                        IFDESCR          => 'ge-7/0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:67',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11230) 0:01:52.30',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1035',
                        IFNAME           => 'ge-7/0/21',
                        IFDESCR          => 'ge-7/0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:68',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11230) 0:01:52.30',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1036',
                        IFNAME           => 'ge-7/0/22',
                        IFDESCR          => 'ge-7/0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:69',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11230) 0:01:52.30',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1037',
                        IFNAME           => 'ge-7/0/23',
                        IFDESCR          => 'ge-7/0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:6a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11231) 0:01:52.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1038',
                        IFNAME           => 'ge-7/0/24',
                        IFDESCR          => 'ge-7/0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:6b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11231) 0:01:52.31',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1039',
                        IFNAME           => 'ge-7/0/25',
                        IFDESCR          => 'ge-7/0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:6c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11241) 0:01:52.41',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1040',
                        IFNAME           => 'ge-7/0/26',
                        IFDESCR          => 'ge-7/0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:6d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11241) 0:01:52.41',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1041',
                        IFNAME           => 'ge-7/0/27',
                        IFDESCR          => 'ge-7/0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:6e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11242) 0:01:52.42',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1042',
                        IFNAME           => 'ge-7/0/28',
                        IFDESCR          => 'ge-7/0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:6f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11251) 0:01:52.51',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1043',
                        IFNAME           => 'ge-7/0/29',
                        IFDESCR          => 'ge-7/0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:70',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11251) 0:01:52.51',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1044',
                        IFNAME           => 'ge-7/0/30',
                        IFDESCR          => 'ge-7/0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:71',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11251) 0:01:52.51',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1045',
                        IFNAME           => 'ge-7/0/31',
                        IFDESCR          => 'ge-7/0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:72',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11251) 0:01:52.51',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1046',
                        IFNAME           => 'ge-7/0/32',
                        IFDESCR          => 'ge-7/0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:73',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11251) 0:01:52.51',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1047',
                        IFNAME           => 'ge-7/0/33',
                        IFDESCR          => 'ge-7/0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:74',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11251) 0:01:52.51',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1048',
                        IFNAME           => 'ge-7/0/34',
                        IFDESCR          => 'ge-7/0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:75',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11261) 0:01:52.61',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1049',
                        IFNAME           => 'ge-7/0/35',
                        IFDESCR          => 'ge-7/0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:76',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11261) 0:01:52.61',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1050',
                        IFNAME           => 'ge-7/0/36',
                        IFDESCR          => 'ge-7/0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:77',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(511099556) 59 days, 3:43:15.56',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1051',
                        IFNAME           => 'ge-7/0/37',
                        IFDESCR          => 'ge-7/0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:78',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11271) 0:01:52.71',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1052',
                        IFNAME           => 'ge-7/0/38',
                        IFDESCR          => 'ge-7/0/38',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:79',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11271) 0:01:52.71',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1053',
                        IFNAME           => 'ge-7/0/39',
                        IFDESCR          => 'ge-7/0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:7a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11271) 0:01:52.71',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1054',
                        IFNAME           => 'ge-7/0/40',
                        IFDESCR          => 'ge-7/0/40',
                        IFALIAS          => 'Vadim',
                        IFTYPE           => '6',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:7b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(766327109) 88 days, 16:41:11.09',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '792068673',
                        IFINERRORS       => '2',
                        IFOUTOCTETS      => '4016295228',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1055',
                        IFNAME           => 'ge-7/0/41',
                        IFDESCR          => 'ge-7/0/41',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:7c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11272) 0:01:52.72',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1056',
                        IFNAME           => 'ge-7/0/42',
                        IFDESCR          => 'ge-7/0/42',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:7d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11282) 0:01:52.82',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1057',
                        IFNAME           => 'ge-7/0/43',
                        IFDESCR          => 'ge-7/0/43',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:7e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11282) 0:01:52.82',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1058',
                        IFNAME           => 'ge-7/0/44',
                        IFDESCR          => 'ge-7/0/44',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:7f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11282) 0:01:52.82',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1059',
                        IFNAME           => 'ge-7/0/45',
                        IFDESCR          => 'ge-7/0/45',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:80',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11283) 0:01:52.83',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1060',
                        IFNAME           => 'ge-7/0/46',
                        IFDESCR          => 'ge-7/0/46',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:81',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11292) 0:01:52.92',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1061',
                        IFNAME           => 'ge-7/0/47',
                        IFDESCR          => 'ge-7/0/47',
                        IFALIAS          => 'Sflow collector',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:c2',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20726) 0:03:27.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1653504',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4187878412',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1062',
                        IFNAME           => 'vlan.20',
                        IFDESCR          => 'vlan.20',
                        IFALIAS          => 'Routing',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.20.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20894) 0:03:28.94',
                        IFINOCTETS       => '139012558',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3500778476',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1063',
                        IFNAME           => 'ge-6/0/38.0',
                        IFDESCR          => 'ge-6/0/38.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:49',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(27592) 0:04:35.92',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:10:f3:29:8a:dc',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1064',
                        IFNAME           => 'ge-7/0/1.0',
                        IFDESCR          => 'ge-7/0/1.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:41',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20718) 0:03:27.18',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '620',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1065',
                        IFNAME           => 'ae0',
                        IFDESCR          => 'ae0',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:03',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(280) 0:00:02.80',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1066',
                        IFNAME           => 'ae1',
                        IFDESCR          => 'ae1',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:04',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(280) 0:00:02.80',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1067',
                        IFNAME           => 'ge-6/0/41',
                        IFDESCR          => 'ge-6/0/41',
                        IFALIAS          => 'Link to HongKong',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:8c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(27358) 0:04:33.58',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2601117634',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3580158288',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1068',
                        IFNAME           => 'ae2',
                        IFDESCR          => 'ae2',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:05',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(280) 0:00:02.80',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1069',
                        IFNAME           => 'ae3',
                        IFDESCR          => 'ae3',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:06',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(288) 0:00:02.88',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1070',
                        IFNAME           => 'ae4',
                        IFDESCR          => 'ae4',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:07',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(291) 0:00:02.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1071',
                        IFNAME           => 'ae5',
                        IFDESCR          => 'ae5',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:08',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(291) 0:00:02.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1072',
                        IFNAME           => 'ae6',
                        IFDESCR          => 'ae6',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:09',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(291) 0:00:02.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1073',
                        IFNAME           => 'ae7',
                        IFDESCR          => 'ae7',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:0a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(291) 0:00:02.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1074',
                        IFNAME           => 'ae8',
                        IFDESCR          => 'ae8',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:0b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(291) 0:00:02.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1075',
                        IFNAME           => 'ae9',
                        IFDESCR          => 'ae9',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:0c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(291) 0:00:02.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1076',
                        IFNAME           => 'ae10',
                        IFDESCR          => 'ae10',
                        IFALIAS          => 'To sw-6509-tmk',
                        IFTYPE           => '161',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:0d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21604) 0:03:36.04',
                        IFINOCTETS       => '2095910204',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2506111067',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1077',
                        IFNAME           => 'ae11',
                        IFDESCR          => 'ae11',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:0e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(280) 0:00:02.80',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1078',
                        IFNAME           => 'ae12',
                        IFDESCR          => 'ae12',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:0f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(280) 0:00:02.80',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1079',
                        IFNAME           => 'ae13',
                        IFDESCR          => 'ae13',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:10',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(280) 0:00:02.80',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1080',
                        IFNAME           => 'ae14',
                        IFDESCR          => 'ae14',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:11',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(280) 0:00:02.80',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1081',
                        IFNAME           => 'ae15',
                        IFDESCR          => 'ae15',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:12',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(280) 0:00:02.80',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1082',
                        IFNAME           => 'ge-7/0/10.0',
                        IFDESCR          => 'ge-7/0/10.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:5d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(4257635) 11:49:36.35',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '7037640',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '53210224',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:0d:5d:01:51:53',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1083',
                        IFNAME           => 'ge-6/0/41.0',
                        IFDESCR          => 'ge-6/0/41.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.15.15.5',
                        MAC              => '78:19:f7:05:fa:8c',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(27358) 0:04:33.58',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1473433446',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1621962547',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1084',
                        IFNAME           => 'vlan.517',
                        IFDESCR          => 'vlan.517',
                        IFALIAS          => 'Donotreply',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.67.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20856) 0:03:28.56',
                        IFINOCTETS       => '2330880308',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1945889562',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1086',
                        IFNAME           => 'vlan.210',
                        IFDESCR          => 'vlan.210',
                        IFALIAS          => 'Impala',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.210.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(578013391) 66 days, 21:35:33.91',
                        IFINOCTETS       => '5946341',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1736245913',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1087',
                        IFNAME           => 'vlan.102',
                        IFDESCR          => 'vlan.102',
                        IFALIAS          => 'Net-mgmt',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.102.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20649) 0:03:26.49',
                        IFINOCTETS       => '265063901',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '692119742',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1088',
                        IFNAME           => 'vlan.450',
                        IFDESCR          => 'vlan.450',
                        IFALIAS          => 'Mgmt',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.1.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20856) 0:03:28.56',
                        IFINOCTETS       => '198471991',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '900433418',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1089',
                        IFNAME           => 'ae10.0',
                        IFDESCR          => 'ae10.0',
                        IFTYPE           => '161',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:0d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21604) 0:03:36.04',
                        IFINOCTETS       => '10760817',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '42580694',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:19:07:db:18:00',
                                    '00:23:e9:54:7a:03',
                                    '00:23:e9:54:7b:03',
                                    '00:10:db:ff:10:00',
                                    '00:19:07:db:18:00',
                                    '00:23:e9:54:7a:04',
                                    '00:23:e9:54:7b:04',
                                    '00:10:db:ff:10:00',
                                    '00:19:07:db:18:00',
                                    '00:23:e9:54:7a:06',
                                    '00:23:e9:54:7b:06',
                                    '00:19:07:db:18:00',
                                    '00:19:07:db:18:00',
                                    '00:14:4f:02:0e:82',
                                    '00:14:4f:02:1b:de',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1090',
                        IFNAME           => 'ae16',
                        IFDESCR          => 'ae16',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:13',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(280) 0:00:02.80',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1091',
                        IFNAME           => 'ae17',
                        IFDESCR          => 'ae17',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:14',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(280) 0:00:02.80',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1092',
                        IFNAME           => 'ae18',
                        IFDESCR          => 'ae18',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:15',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(280) 0:00:02.80',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1093',
                        IFNAME           => 'ae19',
                        IFDESCR          => 'ae19',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:16',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(280) 0:00:02.80',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1094',
                        IFNAME           => 'ae20',
                        IFDESCR          => 'ae20',
                        IFALIAS          => 'To Ltm',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:17',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(751001472) 86 days, 22:06:54.72',
                        IFINOCTETS       => '1802014159',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2192956596',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1095',
                        IFNAME           => 'ae21',
                        IFDESCR          => 'ae21',
                        IFALIAS          => 'To-sw-c300-1-tmk',
                        IFTYPE           => '161',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:18',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21360) 0:03:33.60',
                        IFINOCTETS       => '3482787753',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3772234438',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1096',
                        IFNAME           => 'ae22',
                        IFDESCR          => 'ae22',
                        IFALIAS          => 'To-sw-c300-2-tmk',
                        IFTYPE           => '161',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:19',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21354) 0:03:33.54',
                        IFINOCTETS       => '3097853047',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3103800305',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1097',
                        IFNAME           => 'ae23',
                        IFDESCR          => 'ae23',
                        IFALIAS          => 'To-sw-c300-3-tmk',
                        IFTYPE           => '161',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1a',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21353) 0:03:33.53',
                        IFINOCTETS       => '1740339272',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '64445108',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1098',
                        IFNAME           => 'ae24',
                        IFDESCR          => 'ae24',
                        IFALIAS          => 'To-sw-3750-2-tmk',
                        IFTYPE           => '161',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21502) 0:03:35.02',
                        IFINOCTETS       => '2920048812',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1573504211',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1099',
                        IFNAME           => 'ae25',
                        IFDESCR          => 'ae25',
                        IFALIAS          => 'sw-3750-2-tmk Po25',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(286) 0:00:02.86',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1100',
                        IFNAME           => 'ae26',
                        IFDESCR          => 'ae26',
                        IFALIAS          => 'sw-3750-3-tmk Po26',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(286) 0:00:02.86',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1101',
                        IFNAME           => 'ae27',
                        IFDESCR          => 'ae27',
                        IFALIAS          => 'sw-ex6210-tmk',
                        IFTYPE           => '161',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(638821206) 73 days, 22:30:12.06',
                        IFINOCTETS       => '4091543409',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '81025479',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1102',
                        IFNAME           => 'ae28',
                        IFDESCR          => 'ae28',
                        IFTYPE           => '161',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(751001845) 86 days, 22:06:58.45',
                        IFINOCTETS       => '696101008',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4108458697',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1103',
                        IFNAME           => 'ae29',
                        IFDESCR          => 'ae29',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:20',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(288) 0:00:02.88',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1104',
                        IFNAME           => 'ae20.0',
                        IFDESCR          => 'ae20.0',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:17',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(751001472) 86 days, 22:06:54.72',
                        IFINOCTETS       => '848857398',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '92265013',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1105',
                        IFNAME           => 'ae21.0',
                        IFDESCR          => 'ae21.0',
                        IFTYPE           => '161',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:18',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21360) 0:03:33.60',
                        IFINOCTETS       => '364945849',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '515186685',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '3c:4a:92:f4:23:30',
                                    '3c:4a:92:f4:33:c0',
                                    '68:b5:99:c5:7c:30',
                                    '68:b5:99:c5:3f:d0',
                                    '68:b5:99:c5:5d:80',
                                    '78:e3:b5:0d:40:74',
                                    '3c:4a:92:e3:6e:20',
                                    '3c:4a:92:ea:68:b8',
                                    '3c:4a:92:ea:77:48',
                                    '3c:4a:92:ea:a8:58',
                                    '3c:4a:92:ea:f7:30',
                                    '3c:4a:92:ea:f8:94',
                                    '3c:4a:92:ea:38:f4',
                                    '78:e3:b5:08:5c:24',
                                    '3c:4a:92:e1:2c:f8',
                                    '3c:4a:92:e2:c2:4e',
                                    '3c:4a:92:e2:f6:c8',
                                    '3c:4a:92:e2:60:56',
                                    '3c:4a:92:e6:16:40',
                                    '3c:4a:92:e6:f5:80',
                                    '3c:4a:92:e6:f5:22',
                                    '3c:4a:92:e6:05:7c',
                                    '3c:4a:92:e6:06:70',
                                    '3c:4a:92:e6:06:be',
                                    '3c:4a:92:e7:12:d2',
                                    '3c:4a:92:e7:12:d8',
                                    '3c:4a:92:e7:12:fe',
                                    '3c:4a:92:e7:22:78',
                                    '3c:4a:92:e7:22:42',
                                    '3c:4a:92:f8:87:c6',
                                    '3c:4a:92:f8:97:7a',
                                    '3c:4a:92:f8:a7:7c',
                                    '3c:4a:92:f8:b7:fa',
                                    '3c:4a:92:f8:b7:52',
                                    '90:b1:1c:57:0c:b4',
                                    '3c:4a:92:e6:ad:6c',
                                    '3c:4a:92:e7:12:e4',
                                    '68:b5:99:6d:a3:7a',
                                    '68:b5:99:6d:a5:f0',
                                    '3c:4a:92:e7:12:a6',
                                    '3c:4a:92:e7:12:bc',
                                    '3c:4a:92:e7:12:c2',
                                    '3c:4a:92:e7:12:c4',
                                    '3c:4a:92:e7:12:fc',
                                    '3c:4a:92:e7:22:00',
                                    '3c:4a:92:e7:22:64',
                                    '00:01:e8:84:a0:96',
                                    'c8:1f:66:d1:c3:3b',
                                    'c8:1f:66:d1:c9:d6',
                                    'c8:1f:66:d2:0f:41',
                                    'c8:1f:66:d2:16:c0',
                                    'c8:1f:66:d2:1b:c3',
                                    '3c:4a:92:eb:93:a4',
                                    '3c:4a:92:ee:cd:6c',
                                    '3c:4a:92:ee:2d:a8',
                                    '3c:4a:92:ee:5d:38',
                                    '74:86:7a:e5:55:dc',
                                    '74:86:7a:e5:56:c8',
                                    '74:86:7a:e9:99:84',
                                    '74:86:7a:e9:99:c6',
                                    '74:86:7a:e9:9a:bc',
                                    '3c:4a:92:eb:13:dc',
                                    '3c:4a:92:f3:1f:cc',
                                    '3c:4a:92:f4:b1:70',
                                    '3c:4a:92:f4:13:4c',
                                    '3c:4a:92:f4:13:54',
                                    '3c:4a:92:f4:c1:a0',
                                    '3c:4a:92:f4:c2:88',
                                    '3c:4a:92:f4:23:54',
                                    '3c:4a:92:6f:d1:b4',
                                    '3c:4a:92:73:78:70',
                                    '78:e7:d1:f7:24:9c',
                                    '3c:4a:92:eb:64:30',
                                    '3c:4a:92:eb:74:00',
                                    '3c:4a:92:eb:92:ac',
                                    '3c:4a:92:eb:13:34',
                                    '3c:4a:92:f4:0a:dc',
                                    '3c:4a:92:f4:a1:e8',
                                    '3c:4a:92:f4:13:6c',
                                    '3c:4a:92:f4:d2:04',
                                    '3c:4a:92:f4:e2:e8',
                                    '3c:4a:92:6f:d0:62',
                                    '3c:4a:92:70:5f:e8',
                                    '3c:4a:92:70:63:94',
                                    '3c:4a:92:71:8c:ec',
                                    '3c:4a:92:71:9c:c8',
                                    '3c:4a:92:73:50:5e',
                                    '3c:4a:92:73:52:8e',
                                    '3c:4a:92:73:52:52',
                                    '3c:4a:92:ee:7d:a0',
                                    '3c:4a:92:ee:8d:70',
                                    '3c:4a:92:ee:cd:3c',
                                    '3c:4a:92:ee:4d:78',
                                    '3c:4a:92:ee:4d:e8',
                                    '3c:4a:92:ee:5d:0c',
                                    '6c:3b:e5:b3:71:fc',
                                    '6c:3b:e5:b3:81:f4',
                                    '6c:3b:e5:b3:81:38',
                                    '6c:3b:e5:b3:91:d0',
                                    '6c:3b:e5:b3:a1:98',
                                    '6c:3b:e5:b3:d1:a0',
                                    '6c:3b:e5:b3:23:ec',
                                    '6c:3b:e5:b3:23:5c',
                                    '6c:3b:e5:b2:66:a0',
                                    '6c:3b:e5:b2:66:a8',
                                    '6c:3b:e5:b2:66:c8',
                                    '6c:3b:e5:b2:66:da',
                                    '6c:3b:e5:b2:67:ba',
                                    '6c:3b:e5:b2:76:7e',
                                    '6c:3b:e5:b2:77:12',
                                    '6c:3b:e5:b2:77:da',
                                    '6c:3b:e5:b2:77:2c',
                                    '6c:3b:e5:b2:86:d8',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1106',
                        IFNAME           => 'ae22.0',
                        IFDESCR          => 'ae22.0',
                        IFTYPE           => '161',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:19',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21354) 0:03:33.54',
                        IFINOCTETS       => '1993689556',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2867339745',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '78:e7:d1:65:db:ac',
                                    '78:e7:d1:65:db:cc',
                                    '3c:4a:92:eb:82:f0',
                                    '78:e7:d1:f5:66:24',
                                    '78:e7:d1:f5:66:3e',
                                    '3c:4a:92:e6:bd:c8',
                                    '68:b5:99:c0:74:78',
                                    '68:b5:99:c5:b7:88',
                                    '68:b5:99:c5:09:64',
                                    '68:b5:99:cc:ac:a8',
                                    '68:b5:99:cc:ad:f4',
                                    '68:b5:99:cc:1d:24',
                                    '78:e7:d1:f7:64:c4',
                                    '78:e7:d1:f7:82:24',
                                    '78:e7:d1:f7:84:0c',
                                    '78:e7:d1:f7:92:f4',
                                    '78:e7:d1:f7:a4:78',
                                    '78:e7:d1:f7:c3:90',
                                    '78:e7:d1:f7:d3:64',
                                    '78:e7:d1:f7:e3:6c',
                                    '78:e7:d1:f7:e3:50',
                                    '78:e7:d1:f7:f3:c8',
                                    '78:e7:d1:f7:f3:2c',
                                    '78:e7:d1:f7:42:14',
                                    '78:e7:d1:fa:82:e4',
                                    '78:e7:d1:fa:92:e2',
                                    '78:e7:d1:fa:a2:fe',
                                    '78:e7:d1:fa:c2:c6',
                                    '78:e7:d1:fa:42:96',
                                    '78:e7:d1:fa:42:c2',
                                    '78:e7:d1:fa:42:f0',
                                    '78:e7:d1:fa:52:d8',
                                    '78:e7:d1:fa:52:e8',
                                    '78:e7:d1:fa:52:fc',
                                    '78:e7:d1:fa:62:1c',
                                    '78:e7:d1:fa:62:30',
                                    '1c:c1:de:78:3d:e0',
                                    '3c:4a:92:dc:84:a0',
                                    '3c:4a:92:dc:84:56',
                                    '3c:4a:92:dc:84:60',
                                    '3c:4a:92:e0:8c:e8',
                                    '3c:4a:92:e0:5a:8e',
                                    'd8:d3:85:fe:21:4a',
                                    '18:a9:05:c5:68:ba',
                                    'd8:d3:85:fe:21:52',
                                    '18:a9:05:c5:68:c2',
                                    '68:b5:99:c5:6f:6c',
                                    '68:b5:99:c5:8f:f4',
                                    '68:b5:99:c5:cf:e8',
                                    '68:b5:99:c5:df:20',
                                    '68:b5:99:c5:fb:b0',
                                    '68:b5:99:c5:2f:bc',
                                    '78:e7:d1:65:0b:78',
                                    '78:e7:d1:65:0c:c8',
                                    '78:e7:d1:65:db:1c',
                                    '78:e7:d1:65:fa:30',
                                    '78:e7:d1:65:1c:5c',
                                    '78:e7:d1:65:46:88',
                                    '78:e7:d1:65:56:a8',
                                    '78:e7:d1:f6:21:58',
                                    '78:e7:d1:f7:73:4c',
                                    '78:e7:d1:f7:e3:0c',
                                    '78:e7:d1:f7:e3:ec',
                                    '78:e7:d1:f7:04:a4',
                                    'd8:d3:85:e2:82:50',
                                    'd8:d3:85:e2:88:b8',
                                    '1c:c1:de:e5:3d:ec',
                                    '1c:c1:de:e5:4d:bc',
                                    '1c:c1:de:e5:4d:34',
                                    '1c:c1:de:e5:4d:50',
                                    '1c:c1:de:e6:83:34',
                                    '1c:c1:de:f3:0c:94',
                                    '1c:c1:de:f3:ca:68',
                                    '1c:c1:de:f3:2c:b8',
                                    '1c:c1:de:f3:3c:64',
                                    '1c:c1:de:f4:d3:70',
                                    '3c:4a:92:e3:7e:6c',
                                    '3c:4a:92:e3:7e:cc',
                                    '3c:4a:92:e3:0e:1c',
                                    '3c:4a:92:e3:8e:f4',
                                    '3c:4a:92:e3:9e:ec',
                                    '3c:4a:92:e3:de:dc',
                                    '3c:4a:92:e3:fe:08',
                                    '3c:4a:92:e3:1d:24',
                                    '3c:4a:92:e3:1e:54',
                                    '3c:4a:92:e3:4e:a0',
                                    '3c:4a:92:e3:4e:e8',
                                    '3c:4a:92:e3:5e:70',
                                    '3c:4a:92:f5:2a:dc',
                                    '00:c0:b7:c7:d3:be',
                                    '00:c0:b7:c7:d3:db',
                                    '00:c0:b7:2e:b7:4b',
                                    '00:c0:b7:51:e9:98',
                                    '00:c0:b7:51:e9:9b',
                                    '00:c0:b7:51:e9:a1',
                                    '00:c0:b7:51:e9:23',
                                    '00:c0:b7:51:e9:56',
                                    '00:c0:b7:51:eb:64',
                                    '00:c0:b7:51:eb:69',
                                    '00:c0:b7:51:eb:6a',
                                    '00:c0:b7:51:eb:6b',
                                    '00:c0:b7:51:eb:6d',
                                    '00:c0:b7:51:eb:ad',
                                    '00:c0:b7:51:eb:b0',
                                    '00:c0:b7:51:ec:18',
                                    '00:c0:b7:51:ec:26',
                                    '00:c0:b7:51:ec:09',
                                    '00:c0:b7:52:b7:ea',
                                    '00:c0:b7:55:03:96',
                                    '00:c0:b7:55:21:04',
                                    '00:c0:b7:55:08:29',
                                    '78:e7:d1:f5:66:02',
                                    '78:e7:d1:f5:66:e0',
                                    '78:e7:d1:f5:66:42',
                                    '78:e7:d1:f5:56:e0',
                                    '78:e7:d1:fa:72:fa',
                                    '78:e7:d1:fa:52:8a',
                                    '78:e7:d1:fa:52:d6',
                                    '78:e7:d1:fa:52:de',
                                    '78:e7:d1:61:d2:98',
                                    '78:e7:d1:62:7e:9e',
                                    '78:e7:d1:62:7e:10',
                                    '78:e7:d1:62:7e:18',
                                    '78:e7:d1:62:3e:ac',
                                    '78:e7:d1:62:3e:c6',
                                    '98:4b:e1:65:45:1e',
                                    'd4:85:64:45:b3:fa',
                                    'd4:85:64:45:e3:04',
                                    'd4:85:64:45:f3:72',
                                    'd4:85:64:4b:8f:14',
                                    '1c:c1:de:e9:cc:7a',
                                    '1c:c1:de:e9:cc:80',
                                    '1c:c1:de:e9:cc:92',
                                    '1c:c1:de:e9:dc:22',
                                    '1c:c1:de:ea:a9:bc',
                                    '1c:c1:de:f1:0c:ae',
                                    '3c:4a:92:e1:ff:6e',
                                    '3c:4a:92:e1:3c:c2',
                                    '3c:4a:92:e2:92:18',
                                    '3c:4a:92:e2:92:4c',
                                    '3c:4a:92:e2:a2:16',
                                    '3c:4a:92:e2:b2:68',
                                    '3c:4a:92:e2:b2:a2',
                                    '3c:4a:92:e2:16:6e',
                                    '3c:4a:92:e2:16:7e',
                                    '3c:4a:92:e2:16:ae',
                                    '3c:4a:92:e2:16:38',
                                    '3c:4a:92:e2:16:3c',
                                    '3c:4a:92:e2:16:44',
                                    '3c:4a:92:e2:16:52',
                                    '3c:4a:92:e2:26:a2',
                                    '3c:4a:92:e2:36:12',
                                    '3c:4a:92:e2:06:ce',
                                    '3c:4a:92:e2:06:f2',
                                    '68:b5:99:6d:8b:4e',
                                    '68:b5:99:6d:8b:56',
                                    '68:b5:99:6d:a8:8e',
                                    '68:b5:99:6e:d0:b0',
                                    '68:b5:99:6e:d1:96',
                                    '68:b5:99:6f:d0:a0',
                                    '68:b5:99:70:75:3c',
                                    '68:b5:99:70:93:c8',
                                    '68:b5:99:70:c3:3e',
                                    '68:b5:99:70:60:42',
                                    '68:b5:99:71:97:aa',
                                    '68:b5:99:71:c7:ca',
                                    '78:e7:d1:f5:66:76',
                                    '78:e7:d1:f5:66:14',
                                    '78:e7:d1:fa:d2:aa',
                                    '78:e7:d1:fa:42:f4',
                                    'd4:85:64:6b:98:6c',
                                    'd4:85:64:6c:56:94',
                                    'd8:d3:85:fe:2b:d4',
                                    '18:a9:05:c5:6b:24',
                                    '68:b5:99:6d:a8:86',
                                    '68:b5:99:6e:d0:a8',
                                    '68:b5:99:6e:d1:8e',
                                    '68:b5:99:6f:d0:98',
                                    '68:b5:99:70:75:34',
                                    '68:b5:99:70:93:c0',
                                    '68:b5:99:70:c3:36',
                                    '68:b5:99:70:60:3a',
                                    '68:b5:99:71:97:a2',
                                    '68:b5:99:71:c7:c2',
                                    '78:e7:d1:65:bb:8c',
                                    '78:e7:d1:65:2c:50',
                                    'd4:85:64:6b:98:64',
                                    'd4:85:64:6c:56:8c',
                                    'd8:d3:85:fe:2b:cc',
                                    '18:a9:05:c5:6b:1c',
                                    '00:00:87:13:d5:85',
                                    '00:00:87:13:d7:b3',
                                    '00:c0:dd:0c:c5:e3',
                                    '00:c0:dd:0c:c5:27',
                                    '00:27:f8:62:69:6d',
                                    '00:05:33:07:74:6b',
                                    '00:05:33:08:a2:c3',
                                    '00:05:33:50:9a:01',
                                    '00:40:8c:9e:d9:60',
                                    '00:01:e8:75:6d:19',
                                    '00:01:e8:d6:a8:f6',
                                    '00:01:e8:d6:be:59',
                                    '00:01:e8:d6:bf:94',
                                    '00:0d:5d:09:68:dc',
                                    'd4:85:64:cd:5a:f6',
                                    'd8:d3:85:af:3f:82',
                                    'd4:85:64:cd:5a:f4',
                                    'd8:d3:85:af:3f:80',
                                    '78:e7:d1:f7:73:88',
                                    '78:e7:d1:f7:73:04',
                                    '78:e7:d1:f7:82:ac',
                                    '78:e7:d1:f7:15:08',
                                    '78:e7:d1:f7:d3:8c',
                                    '78:e7:d1:f7:d3:fc',
                                    '78:e7:d1:f7:e3:14',
                                    '78:e7:d1:f7:e3:18',
                                    '78:e7:d1:f7:03:14',
                                    '78:e7:d1:f7:04:3c',
                                    '78:e7:d1:f7:34:90',
                                    '78:e7:d1:f7:44:28',
                                    '78:e7:d1:f7:63:a8',
                                    '78:e7:d1:f7:63:b0',
                                    '44:1e:a1:59:3e:d0',
                                    '78:e7:d1:fa:82:08',
                                    '78:e7:d1:fa:a2:12',
                                    '78:e7:d1:fa:12:a0',
                                    '78:e7:d1:fa:c2:32',
                                    '78:e7:d1:fa:52:92',
                                    '78:e7:d1:fa:52:94',
                                    '78:e7:d1:fa:52:b0',
                                    '78:e7:d1:fa:52:b4',
                                    '78:e7:d1:fa:52:ce',
                                    '78:e7:d1:fa:52:ec',
                                    '78:e7:d1:fa:52:f4',
                                    '78:e7:d1:fa:52:38',
                                    '78:e7:d1:fa:52:44',
                                    '78:e7:d1:fa:62:0a',
                                    '44:1e:a1:58:49:4e',
                                    '78:e7:d1:f7:02:cc',
                                    '68:b5:99:6d:5b:a6',
                                    '68:b5:99:6d:5b:ae',
                                    '78:e7:d1:f7:74:54',
                                    '78:e7:d1:65:db:84',
                                    '78:e7:d1:65:1c:a8',
                                    '78:e7:d1:f7:64:9c',
                                    '3c:4a:92:e4:d8:e8',
                                    '3c:4a:92:eb:d3:fc',
                                    '3c:4a:92:eb:54:e8',
                                    '78:e7:d1:f5:66:20',
                                    '78:e7:d1:f5:56:e8',
                                    '78:e7:d1:fa:52:06',
                                    '3c:4a:92:e2:cf:60',
                                    '3c:4a:92:e6:ad:38',
                                    '3c:4a:92:e6:bd:18',
                                    '3c:4a:92:eb:33:34',
                                    '3c:4a:92:e6:cd:e8',
                                    '78:e3:b5:14:c2:84',
                                    '78:e3:b5:18:17:18',
                                    '78:e7:d1:65:cb:ec',
                                    '78:e7:d1:f7:75:30',
                                    '78:e7:d1:f7:93:54',
                                    '78:e7:d1:f7:c4:38',
                                    '78:e7:d1:f7:c5:bc',
                                    '78:e7:d1:f7:c5:c0',
                                    '78:e7:d1:f7:15:b8',
                                    '78:e7:d1:f7:d3:b4',
                                    '78:e7:d1:f7:d5:a4',
                                    '78:e7:d1:f7:d5:d0',
                                    '78:e7:d1:f7:e3:e4',
                                    '78:e7:d1:f7:e4:b0',
                                    '78:e7:d1:f7:e4:c0',
                                    '78:e7:d1:f7:e5:9c',
                                    '78:e7:d1:f7:e5:1c',
                                    '78:e7:d1:f7:f8:74',
                                    '78:e7:d1:f7:f8:c4',
                                    '78:e7:d1:f7:f8:ec',
                                    '78:e7:d1:f7:58:00',
                                    '78:e7:d1:f8:76:cc',
                                    '78:e7:d1:f8:55:88',
                                    '9c:8e:99:14:01:98',
                                    '9c:8e:99:14:40:60',
                                    '9c:8e:99:2b:39:30',
                                    '9c:8e:99:2b:58:a4',
                                    '9c:8e:99:2d:ce:f8',
                                    '9c:8e:99:2d:1f:48',
                                    '9c:8e:99:2d:5d:a8',
                                    '2c:76:8a:54:cd:5c',
                                    '2c:76:8a:54:f6:24',
                                    '2c:76:8a:54:f6:2c',
                                    '2c:76:8a:54:fb:b4',
                                    '2c:76:8a:54:fb:c8',
                                    '2c:76:8a:54:fb:d4',
                                    '2c:76:8a:55:00:38',
                                    '2c:76:8a:55:01:10',
                                    '2c:76:8a:55:1b:cc',
                                    '2c:76:8a:55:46:08',
                                    '3c:4a:92:e9:2d:5c',
                                    '3c:4a:92:f3:bf:f0',
                                    '3c:4a:92:f4:9b:60',
                                    '3c:4a:92:f4:c2:5c',
                                    '3c:4a:92:f4:d7:ac',
                                    '3c:4a:92:f4:d9:98',
                                    '3c:4a:92:f4:f4:64',
                                    '3c:4a:92:f4:f8:b8',
                                    '3c:4a:92:f4:23:80',
                                    '3c:4a:92:f4:46:74',
                                    '78:e7:d1:f7:64:a8',
                                    '78:e7:d1:f7:64:48',
                                    '78:e7:d1:f7:73:0c',
                                    '78:e7:d1:f7:84:7c',
                                    '78:e7:d1:f7:02:40',
                                    '78:e7:d1:f7:14:d4',
                                    '78:e7:d1:f7:e2:74',
                                    '78:e7:d1:f7:e3:a4',
                                    '78:e7:d1:f7:f3:9c',
                                    '78:e7:d1:f7:04:28',
                                    '78:e7:d1:f7:52:1c',
                                    '78:e7:d1:f7:63:94',
                                    '78:e7:d1:f7:63:ac',
                                    '78:e7:d1:f7:63:d4',
                                    '9c:8e:99:1c:4a:b4',
                                    '1c:c1:de:e5:1e:a8',
                                    '1c:c1:de:e5:4e:04',
                                    '1c:c1:de:e5:5e:00',
                                    '3c:4a:92:eb:d3:e0',
                                    '78:e7:d1:fa:72:e2',
                                    '78:e7:d1:fa:92:ba',
                                    '78:e7:d1:fa:a2:5a',
                                    '78:e7:d1:fa:b2:52',
                                    '78:e7:d1:fa:42:86',
                                    '78:e7:d1:fa:42:8c',
                                    '78:e7:d1:fa:42:b8',
                                    '78:e7:d1:fa:42:c8',
                                    '78:e7:d1:fa:52:78',
                                    '78:e7:d1:fa:52:0e',
                                    '78:e7:d1:fa:52:96',
                                    '78:e7:d1:fa:52:a6',
                                    '78:e7:d1:fa:52:b2',
                                    '78:e7:d1:fa:52:ee',
                                    '9c:8e:99:1d:9b:a6',
                                    '1c:c1:de:e9:dc:b2',
                                    '1c:c1:de:e9:dc:32',
                                    '1c:c1:de:e9:dc:50',
                                    '3c:4a:92:e6:bd:00',
                                    '78:e3:b5:19:34:7a',
                                    '78:e7:d1:f5:66:1a',
                                    '78:e7:d1:fa:81:2e',
                                    '78:e7:d1:fa:a1:66',
                                    '78:e7:d1:fa:a1:6c',
                                    '78:e7:d1:fa:a1:6e',
                                    '78:e7:d1:fa:a1:74',
                                    '78:e7:d1:fa:a1:76',
                                    '78:e7:d1:fa:12:96',
                                    '78:e7:d1:fa:12:ea',
                                    '78:e7:d1:fa:12:f8',
                                    '78:e7:d1:fa:02:98',
                                    '78:e7:d1:fa:e1:96',
                                    '78:e7:d1:fa:f1:00',
                                    '78:e7:d1:fa:32:06',
                                    '78:e7:d1:fa:52:e2',
                                    '78:e7:d1:fa:62:16',
                                    '80:c1:6e:6b:ff:76',
                                    '80:c1:6e:70:a6:28',
                                    '80:c1:6e:70:a6:36',
                                    '80:c1:6e:70:b6:9c',
                                    '80:c1:6e:70:c5:c8',
                                    '80:c1:6e:70:c6:80',
                                    '80:c1:6e:70:c6:9a',
                                    '80:c1:6e:70:d5:62',
                                    '80:c1:6e:70:e6:30',
                                    '80:c1:6e:70:f6:78',
                                    '9c:8e:99:18:9a:6c',
                                    '9c:8e:99:18:9a:ee',
                                    '9c:8e:99:18:d8:3a',
                                    '9c:8e:99:25:d9:04',
                                    '9c:8e:99:25:e9:84',
                                    '9c:8e:99:2f:bc:84',
                                    '9c:8e:99:2f:bc:44',
                                    '9c:8e:99:2f:cc:f4',
                                    '1c:c1:de:6d:37:3c',
                                    '1c:c1:de:03:39:fe',
                                    '1c:c1:de:03:49:1c',
                                    '1c:c1:de:03:49:06',
                                    '1c:c1:de:08:31:60',
                                    '3c:4a:92:f2:a6:de',
                                    '3c:4a:92:f3:f8:1e',
                                    '3c:4a:92:f8:76:2a',
                                    '3c:4a:92:f8:81:04',
                                    '3c:4a:92:f8:91:a8',
                                    '3c:4a:92:f8:96:04',
                                    '3c:4a:92:f8:97:f8',
                                    '3c:4a:92:f8:a6:be',
                                    '3c:4a:92:f8:e4:5c',
                                    '3c:4a:92:f8:21:88',
                                    '3c:4a:92:e1:4c:a2',
                                    '3c:4a:92:e6:ad:b0',
                                    '3c:4a:92:e6:ad:18',
                                    '3c:4a:92:e6:ad:f8',
                                    '3c:4a:92:e6:ad:5e',
                                    '3c:4a:92:e6:bd:14',
                                    '3c:4a:92:e6:cd:06',
                                    '3c:4a:92:e6:15:e4',
                                    '3c:4a:92:e6:f5:c6',
                                    '3c:4a:92:e7:37:56',
                                    '68:b5:99:c5:eb:40',
                                    '3c:4a:92:ea:b7:20',
                                    '3c:4a:92:ea:b8:50',
                                    '3c:4a:92:eb:64:b8',
                                    '3c:4a:92:eb:13:c8',
                                    '3c:4a:92:eb:c2:34',
                                    '3c:4a:92:eb:d3:94',
                                    '3c:4a:92:eb:e3:a8',
                                    '3c:4a:92:eb:34:e8',
                                    '3c:4a:92:ee:cd:cc',
                                    '68:b5:99:c5:ff:60',
                                    '1c:c1:de:e5:6e:d0',
                                    '1c:c1:de:e5:73:a8',
                                    '1c:c1:de:e5:8c:40',
                                    '1c:c1:de:e5:bc:2c',
                                    '1c:c1:de:e5:bd:c0',
                                    '1c:c1:de:e5:cb:94',
                                    '1c:c1:de:e5:dc:74',
                                    '1c:c1:de:e5:5d:d8',
                                    '1c:c1:de:e6:83:38',
                                    '1c:c1:de:e6:83:08',
                                    '1c:c1:de:e6:26:38',
                                    '1c:c1:de:e6:51:54',
                                    '1c:c1:de:e6:53:00',
                                    '1c:c1:de:e6:53:28',
                                    '1c:c1:de:e6:54:50',
                                    '1c:c1:de:e6:63:18',
                                    '1c:c1:de:f3:5c:b4',
                                    '3c:4a:92:ea:8f:f8',
                                    '3c:4a:92:eb:64:1c',
                                    '3c:4a:92:eb:72:68',
                                    '3c:4a:92:eb:72:98',
                                    '3c:4a:92:eb:73:00',
                                    '3c:4a:92:eb:74:18',
                                    '3c:4a:92:eb:82:40',
                                    '3c:4a:92:eb:b2:e8',
                                    '3c:4a:92:eb:b2:54',
                                    '3c:4a:92:eb:b2:5c',
                                    '3c:4a:92:eb:13:cc',
                                    '3c:4a:92:eb:02:54',
                                    '3c:4a:92:eb:d3:64',
                                    '3c:4a:92:eb:d3:b4',
                                    '3c:4a:92:eb:d3:e4',
                                    '3c:4a:92:eb:e3:94',
                                    '3c:4a:92:eb:e3:a4',
                                    '3c:4a:92:eb:f2:b0',
                                    '3c:4a:92:eb:32:50',
                                    '3c:4a:92:eb:34:50',
                                    '3c:4a:92:eb:41:14',
                                    '3c:4a:92:ee:bd:b4',
                                    'd4:85:64:45:c3:24',
                                    '1c:c1:de:e9:6c:64',
                                    '1c:c1:de:e9:0c:fc',
                                    '1c:c1:de:e9:cc:f4',
                                    '1c:c1:de:e9:ec:88',
                                    '1c:c1:de:e9:fc:0c',
                                    '1c:c1:de:e9:1c:3c',
                                    '1c:c1:de:e9:2c:64',
                                    '1c:c1:de:e9:4c:d2',
                                    '1c:c1:de:ea:79:e2',
                                    '1c:c1:de:ea:99:e6',
                                    '1c:c1:de:ea:a9:b4',
                                    '1c:c1:de:ea:a9:b8',
                                    '1c:c1:de:ea:a9:1c',
                                    '1c:c1:de:ea:a9:20',
                                    '1c:c1:de:ea:a9:44',
                                    '1c:c1:de:ea:60:88',
                                    '3c:4a:92:e2:a2:b2',
                                    '3c:4a:92:e6:69:62',
                                    '3c:4a:92:e6:9d:dc',
                                    '3c:4a:92:e6:9d:e2',
                                    '3c:4a:92:e6:9d:e4',
                                    '3c:4a:92:e6:ad:7a',
                                    '3c:4a:92:e6:ad:be',
                                    '3c:4a:92:e6:ad:02',
                                    '3c:4a:92:e6:ad:de',
                                    '3c:4a:92:e6:ad:f6',
                                    '3c:4a:92:e6:ad:34',
                                    '3c:4a:92:e6:bd:70',
                                    '3c:4a:92:e6:bd:12',
                                    '3c:4a:92:e6:bd:02',
                                    '3c:4a:92:e6:bd:e8',
                                    '3c:4a:92:e6:bd:2a',
                                    '3c:4a:92:e6:cd:08',
                                    '3c:4a:92:e6:1c:b0',
                                    '3c:4a:92:e6:2c:6a',
                                    '3c:4a:92:e6:2c:20',
                                    '3c:4a:92:e6:3c:c0',
                                    '3c:4a:92:e6:5c:fa',
                                    '3c:4a:92:e7:37:68',
                                    '3c:4a:92:eb:64:78',
                                    '3c:4a:92:eb:64:8c',
                                    '3c:4a:92:eb:b2:c0',
                                    '3c:4a:92:eb:b2:d8',
                                    '3c:4a:92:eb:b2:38',
                                    '3c:4a:92:eb:d1:d8',
                                    '3c:4a:92:eb:d3:8c',
                                    '3c:4a:92:eb:23:1c',
                                    '3c:4a:92:eb:33:0c',
                                    '3c:4a:92:eb:62:08',
                                    '3c:4a:92:ee:bd:f0',
                                    '3c:4a:92:e6:9d:fe',
                                    '3c:4a:92:e6:ad:00',
                                    '3c:4a:92:e6:ad:f4',
                                    '3c:4a:92:e6:ad:2c',
                                    '3c:4a:92:e6:ad:46',
                                    '3c:4a:92:e6:ad:50',
                                    '3c:4a:92:e6:bd:fe',
                                    '3c:4a:92:e6:cd:f2',
                                    '3c:4a:92:e6:2c:44',
                                    '3c:4a:92:e6:3c:2e',
                                    '3c:4a:92:e7:37:52',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1107',
                        IFNAME           => 'ae23.0',
                        IFDESCR          => 'ae23.0',
                        IFTYPE           => '161',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1a',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21353) 0:03:33.53',
                        IFINOCTETS       => '1296315575',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1874943716',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '78:e3:b5:0d:c0:cc',
                                    '9c:8e:99:1c:39:74',
                                    '9c:8e:99:2d:0f:4c',
                                    '9c:8e:99:2d:5d:c4',
                                    'e4:11:5b:ed:6b:84',
                                    'e4:11:5b:ed:9a:d8',
                                    'e4:11:5b:ed:db:74',
                                    'e4:11:5b:ed:f9:78',
                                    'e4:11:5b:ed:1c:b8',
                                    'e4:11:5b:ed:48:54',
                                    'e4:11:5b:ed:4a:8c',
                                    'e4:11:5b:ed:58:d4',
                                    'e8:39:35:a7:63:5c',
                                    '44:1e:a1:59:0e:40',
                                    '44:1e:a1:59:8e:c8',
                                    '78:e3:b5:08:6c:8e',
                                    '9c:8e:99:1d:ab:50',
                                    '9c:8e:99:2f:bc:7a',
                                    '9c:8e:99:2f:bc:40',
                                    'e4:11:5b:e3:19:6e',
                                    'e8:39:35:ae:72:96',
                                    'e8:39:35:ae:72:e4',
                                    'e8:39:35:ae:75:ba',
                                    'e8:39:35:ae:85:84',
                                    'e8:39:35:ae:85:1c',
                                    'e8:39:35:ae:a5:24',
                                    'e8:39:35:ae:d2:fc',
                                    'e8:39:35:ae:d2:62',
                                    '44:1e:a1:58:19:c6',
                                    '44:1e:a1:58:19:60',
                                    '78:e3:b5:0d:70:88',
                                    '78:e3:b5:05:af:b0',
                                    '78:e3:b5:05:c6:b8',
                                    '98:4b:e1:6e:8b:b0',
                                    '9c:8e:99:1c:79:58',
                                    '9c:8e:99:2d:6e:7c',
                                    '9c:8e:99:2d:5d:80',
                                    '10:1f:74:2f:fb:30',
                                    'e4:11:5b:ed:6a:84',
                                    'e4:11:5b:ed:0b:fc',
                                    'e4:11:5b:ed:ae:ac',
                                    'e4:11:5b:ed:cb:a0',
                                    '78:e3:b5:07:ee:0e',
                                    '78:e3:b5:08:7d:8c',
                                    '78:e3:b5:08:5c:72',
                                    '98:4b:e1:6d:7f:2a',
                                    '9c:8e:99:1a:72:34',
                                    '9c:8e:99:2f:bc:5a',
                                    '9c:8e:99:2f:dc:d4',
                                    '10:1f:74:2c:56:4a',
                                    'e8:39:35:ae:82:bc',
                                    'e8:39:35:ae:92:8c',
                                    'e8:39:35:ae:95:bc',
                                    'e8:39:35:ae:b8:c4',
                                    '9c:8e:99:14:93:0c',
                                    '9c:8e:99:1b:82:00',
                                    '9c:8e:99:1b:c2:9c',
                                    '9c:8e:99:1b:d1:9c',
                                    '9c:8e:99:1b:e9:3c',
                                    '9c:8e:99:1b:f2:54',
                                    '9c:8e:99:1b:f3:94',
                                    '9c:8e:99:1b:42:6c',
                                    '9c:8e:99:1b:52:a4',
                                    '9c:8e:99:1b:53:94',
                                    'b4:99:ba:05:7c:a2',
                                    'b4:99:ba:08:7f:f6',
                                    '00:c0:b7:94:36:33',
                                    '00:c0:b7:98:8e:4d',
                                    '00:c0:b7:b3:eb:b1',
                                    '00:c0:b7:b3:ef:82',
                                    '00:c0:b7:c7:d3:bb',
                                    '00:c0:b7:c7:d3:bd',
                                    '00:c0:b7:c7:d3:f4',
                                    '00:c0:b7:c7:d4:ec',
                                    '00:c0:b7:c8:91:38',
                                    '00:c0:b7:51:ea:02',
                                    '00:c0:b7:55:1b:19',
                                    '00:c0:b7:55:1f:9c',
                                    '00:c0:b7:55:04:6d',
                                    '00:c0:b7:55:04:70',
                                    '00:c0:b7:55:04:82',
                                    '00:c0:b7:5a:ae:d4',
                                    '00:c0:b7:5a:af:2d',
                                    '00:c0:b7:5a:af:47',
                                    '00:c0:b7:5a:b8:07',
                                    '74:86:7a:dd:ae:60',
                                    '74:86:7a:dd:d1:98',
                                    '74:86:7a:dd:d7:d8',
                                    '74:86:7a:dd:e3:c0',
                                    '74:86:7a:dd:e3:18',
                                    '74:86:7a:dd:e3:2c',
                                    '74:86:7a:dd:e3:2e',
                                    '74:86:7a:dd:e3:36',
                                    '74:86:7a:dd:e8:10',
                                    '74:86:7a:de:17:f0',
                                    '74:86:7a:de:18:14',
                                    '74:86:7a:de:18:1a',
                                    '74:86:7a:e5:54:7c',
                                    '74:86:7a:e5:55:d8',
                                    '74:86:7a:e5:57:18',
                                    '74:86:7a:e9:99:a2',
                                    '74:86:7a:e9:9c:34',
                                    '9c:8e:99:18:8d:22',
                                    '9c:8e:99:19:7a:6c',
                                    '9c:8e:99:19:7a:44',
                                    '9c:8e:99:19:8a:9a',
                                    '9c:8e:99:19:96:b6',
                                    '9c:8e:99:19:b6:aa',
                                    '9c:8e:99:19:3a:68',
                                    '9c:8e:99:19:3a:0c',
                                    '9c:8e:99:19:58:7c',
                                    '9c:8e:99:19:5a:18',
                                    'b4:99:ba:05:7c:aa',
                                    'b4:99:ba:08:7f:fe',
                                    '00:14:4f:01:d6:4a',
                                    '00:14:4f:3a:47:4d',
                                    '00:14:4f:01:d6:4b',
                                    '78:e3:b5:18:98:80',
                                    '78:e3:b5:18:d3:64',
                                    '78:e3:b5:18:37:c0',
                                    '9c:8e:99:13:5f:98',
                                    '9c:8e:99:18:c8:ae',
                                    '9c:8e:99:18:c8:02',
                                    '9c:8e:99:18:19:e0',
                                    '9c:8e:99:18:49:e4',
                                    '78:e3:b5:13:ec:88',
                                    '9c:8e:99:2b:66:2c',
                                    '9c:8e:99:2b:e8:a4',
                                    '9c:8e:99:2d:5d:88',
                                    '44:1e:a1:59:6f:fc',
                                    '64:31:50:4b:7d:48',
                                    '64:31:50:50:e8:1e',
                                    '64:31:50:51:6d:5c',
                                    '64:31:50:51:a6:46',
                                    '64:31:50:51:c0:ae',
                                    '64:31:50:51:c9:28',
                                    '64:31:50:51:c9:50',
                                    '64:31:50:51:cb:9e',
                                    '64:31:50:51:cb:bc',
                                    '64:31:50:51:cb:ee',
                                    '64:31:50:51:ce:32',
                                    '64:31:50:51:dd:64',
                                    '64:31:50:51:f6:14',
                                    '64:31:50:51:45:7a',
                                    '64:31:50:51:48:a4',
                                    '64:31:50:51:60:3c',
                                    '64:31:50:51:61:c2',
                                    '78:e3:b5:18:cc:18',
                                    '78:e3:b5:1a:fc:4c',
                                    '78:e3:b5:08:6c:4c',
                                    '9c:8e:99:25:6c:76',
                                    '9c:8e:99:25:93:0a',
                                    '9c:8e:99:25:ac:38',
                                    '9c:8e:99:25:b9:44',
                                    '9c:8e:99:2f:bc:aa',
                                    '9c:8e:99:2f:bc:58',
                                    'e4:11:5b:ce:70:b6',
                                    '44:1e:a1:58:6a:d8',
                                    '44:1e:a1:58:07:3c',
                                    '64:31:50:4b:7d:40',
                                    '64:31:50:50:e8:16',
                                    '64:31:50:51:6d:54',
                                    '64:31:50:51:a6:3e',
                                    '64:31:50:51:c0:a6',
                                    '64:31:50:51:c9:20',
                                    '64:31:50:51:c9:48',
                                    '64:31:50:51:cb:96',
                                    '64:31:50:51:cb:b4',
                                    '64:31:50:51:cb:e6',
                                    '64:31:50:51:ce:2a',
                                    '64:31:50:51:dd:5c',
                                    '64:31:50:51:f6:0c',
                                    '64:31:50:51:45:72',
                                    '64:31:50:51:48:9c',
                                    '64:31:50:51:60:34',
                                    '64:31:50:51:61:ba',
                                    '78:e3:b5:0c:ef:cc',
                                    '9c:8e:99:2b:07:d4',
                                    '44:1e:a1:59:dd:2c',
                                    '44:1e:a1:5a:a5:b4',
                                    '00:a0:b8:29:29:26',
                                    '00:a0:b8:29:2c:a6',
                                    '00:05:1e:03:9d:3d',
                                    '00:05:1e:04:b3:2a',
                                    '00:40:8c:ab:82:95',
                                    '00:01:e8:80:ef:b7',
                                    '00:01:e8:d6:da:2b',
                                    '9c:8e:99:16:35:40',
                                    '9c:8e:99:2d:6d:1c',
                                    '98:4b:e1:73:6c:b0',
                                    'e4:11:5b:ed:73:60',
                                    'e4:11:5b:ed:77:a8',
                                    'e4:11:5b:ed:7a:84',
                                    'e4:11:5b:ed:89:38',
                                    'e4:11:5b:ed:db:b0',
                                    'e4:11:5b:ed:e8:38',
                                    'e4:11:5b:ed:19:00',
                                    'e4:11:5b:ed:05:dc',
                                    'e4:11:5b:ed:5b:f8',
                                    'e4:11:5b:ed:5b:30',
                                    'e8:39:35:b1:6c:58',
                                    '44:1e:a1:5a:66:18',
                                    '44:1e:a1:5a:76:bc',
                                    '44:1e:a1:5a:a2:8c',
                                    '44:1e:a1:5a:b3:f4',
                                    '44:1e:a1:5a:b5:b8',
                                    '44:1e:a1:5a:c3:48',
                                    '44:1e:a1:5a:26:e0',
                                    '44:1e:a1:5a:37:c0',
                                    '44:1e:a1:5a:56:24',
                                    '98:4b:e1:72:a2:8a',
                                    'e4:11:5b:ce:80:f6',
                                    'e4:11:5b:e3:14:f6',
                                    'e8:39:35:ae:75:d8',
                                    'e8:39:35:ae:75:f0',
                                    'e8:39:35:ae:82:ba',
                                    'e8:39:35:ae:82:e8',
                                    'e8:39:35:ae:85:20',
                                    'e8:39:35:ae:a2:6c',
                                    'e8:39:35:ae:a8:d4',
                                    'e8:39:35:ae:11:c2',
                                    'e8:39:35:ae:11:ea',
                                    'e8:39:35:ae:f0:2a',
                                    '44:1e:a1:58:6d:5a',
                                    '44:1e:a1:58:6d:62',
                                    '44:1e:a1:58:cd:1a',
                                    '44:1e:a1:58:1a:68',
                                    '44:1e:a1:58:1d:04',
                                    '44:1e:a1:58:1d:30',
                                    '44:1e:a1:58:4c:e6',
                                    '44:1e:a1:58:4c:f6',
                                    '74:86:7a:df:64:02',
                                    '74:86:7a:df:64:54',
                                    '74:86:7a:df:5a:46',
                                    '74:86:7a:df:5b:f8',
                                    '74:86:7a:df:5d:70',
                                    '74:86:7a:df:61:66',
                                    '74:86:7a:df:61:94',
                                    '74:86:7a:df:61:ce',
                                    '74:86:7a:df:61:f4',
                                    '74:86:7a:df:61:5c',
                                    '78:e3:b5:18:22:d8',
                                    '78:e3:b5:18:d9:24',
                                    '9c:8e:99:2b:a7:9c',
                                    '9c:8e:99:18:da:b0',
                                    '9c:8e:99:25:c9:f8',
                                    '78:e3:b5:18:0b:3c',
                                    '78:e3:b5:18:82:2c',
                                    '78:e3:b5:18:86:14',
                                    '78:e3:b5:18:c1:94',
                                    '78:e3:b5:18:06:78',
                                    '78:e3:b5:18:40:dc',
                                    '9c:8e:99:13:2f:24',
                                    '9c:8e:99:14:85:b0',
                                    '9c:8e:99:14:24:fc',
                                    '9c:8e:99:1b:31:2c',
                                    '9c:8e:99:14:83:c8',
                                    '9c:8e:99:1b:80:34',
                                    '9c:8e:99:1b:a1:18',
                                    '9c:8e:99:1b:f3:b4',
                                    '9c:8e:99:1b:27:58',
                                    '9c:8e:99:2b:47:c4',
                                    '78:e3:b5:19:25:b6',
                                    '78:e3:b5:1a:1d:50',
                                    '78:e3:b5:1a:4d:54',
                                    '78:e3:b5:06:7c:40',
                                    '9c:8e:99:18:b8:86',
                                    '9c:8e:99:18:bb:5a',
                                    '9c:8e:99:18:e8:96',
                                    '9c:8e:99:18:29:be',
                                    '9c:8e:99:18:5b:f8',
                                    '9c:8e:99:19:6a:7c',
                                    '9c:8e:99:18:8d:5a',
                                    '9c:8e:99:19:96:d6',
                                    '9c:8e:99:19:a6:aa',
                                    '9c:8e:99:19:a6:16',
                                    '9c:8e:99:1d:c2:ac',
                                    '9c:8e:99:25:4c:22',
                                    '68:b5:99:c5:a5:a4',
                                    '78:e3:b5:18:78:c4',
                                    '78:e3:b5:18:92:24',
                                    '78:e3:b5:18:96:60',
                                    '78:e3:b5:18:fa:c0',
                                    '78:e3:b5:18:fb:24',
                                    '78:e3:b5:1c:03:6c',
                                    '9c:8e:99:13:3f:74',
                                    '9c:8e:99:13:3f:fc',
                                    '9c:8e:99:13:3f:30',
                                    '9c:8e:99:14:83:78',
                                    '9c:8e:99:14:44:cc',
                                    '9c:8e:99:14:44:e0',
                                    '9c:8e:99:1b:80:08',
                                    '9c:8e:99:1b:c2:08',
                                    '9c:8e:99:1b:f2:00',
                                    '9c:8e:99:1b:31:cc',
                                    '9c:8e:99:1b:4b:e4',
                                    '3c:4a:92:ea:09:58',
                                    '3c:4a:92:eb:64:74',
                                    '3c:4a:92:eb:73:b4',
                                    '3c:4a:92:eb:73:b8',
                                    '3c:4a:92:eb:a2:88',
                                    '3c:4a:92:eb:b2:9c',
                                    '3c:4a:92:eb:e3:38',
                                    '3c:4a:92:eb:34:dc',
                                    '3c:4a:92:eb:52:f4',
                                    '78:e3:b5:19:a9:54',
                                    '78:e3:b5:19:25:88',
                                    '78:e3:b5:1a:31:72',
                                    '78:e3:b5:1a:31:34',
                                    '78:e3:b5:1a:31:48',
                                    '78:e3:b5:1a:31:62',
                                    '9c:8e:99:18:6b:0c',
                                    '9c:8e:99:18:6b:1e',
                                    '9c:8e:99:18:8d:04',
                                    '9c:8e:99:18:c9:da',
                                    '9c:8e:99:18:e8:ca',
                                    '9c:8e:99:18:39:5a',
                                    '9c:8e:99:19:7a:be',
                                    '9c:8e:99:19:88:2c',
                                    '9c:8e:99:19:a6:14',
                                    '9c:8e:99:19:b6:94',
                                    '9c:8e:99:19:3a:48',
                                    '3c:4a:92:e2:92:f6',
                                    '3c:4a:92:e6:9d:ea',
                                    '3c:4a:92:e6:ad:ae',
                                    '3c:4a:92:e6:ad:48',
                                    '3c:4a:92:e6:bd:34',
                                    '3c:4a:92:e6:bd:54',
                                    '3c:4a:92:e6:bd:56',
                                    '3c:4a:92:e6:cd:62',
                                    '3c:4a:92:e6:e5:c4',
                                    '3c:4a:92:e6:2c:2c',
                                    '9c:8e:99:14:01:18',
                                    '9c:8e:99:14:a0:30',
                                    '9c:8e:99:14:c0:28',
                                    '9c:8e:99:14:c0:2c',
                                    '9c:8e:99:14:e0:5c',
                                    '9c:8e:99:15:cd:a0',
                                    '9c:8e:99:1c:88:a8',
                                    '9c:8e:99:1c:a9:2c',
                                    '9c:8e:99:2d:1d:2c',
                                    '9c:8e:99:2d:2f:38',
                                    '9c:8e:99:18:9a:be',
                                    '9c:8e:99:18:9a:d2',
                                    '9c:8e:99:18:9a:e6',
                                    '9c:8e:99:18:9a:e8',
                                    '9c:8e:99:18:9a:36',
                                    '9c:8e:99:1d:ab:8c',
                                    '9c:8e:99:1d:ab:fe',
                                    '9c:8e:99:25:80:b2',
                                    '9c:8e:99:2f:cc:54',
                                    '9c:8e:99:2f:dc:9e',
                                    '74:86:7a:dd:b6:0e',
                                    '74:86:7a:dd:b6:1c',
                                    '74:86:7a:dd:d1:b8',
                                    '74:86:7a:dd:dc:b0',
                                    '74:86:7a:dd:dc:b4',
                                    '74:86:7a:dd:dc:d6',
                                    '74:86:7a:dd:dd:4a',
                                    '74:86:7a:dd:de:00',
                                    '74:86:7a:dd:e1:bc',
                                    '74:86:7a:dd:e1:be',
                                    '74:86:7a:dd:e2:6a',
                                    '74:86:7a:dd:e2:7e',
                                    '74:86:7a:dd:e2:ba',
                                    '74:86:7a:dd:e2:48',
                                    '74:86:7a:dd:e2:52',
                                    '74:86:7a:dd:e3:16',
                                    '74:86:7a:de:17:b2',
                                    '74:86:7a:de:18:30',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1108',
                        IFNAME           => 'ae24.0',
                        IFDESCR          => 'ae24.0',
                        IFTYPE           => '161',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21502) 0:03:35.02',
                        IFINOCTETS       => '2589803039',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '159905824',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:14:4f:01:e9:5a',
                                    '00:14:4f:01:ff:a2',
                                    '00:14:4f:01:ff:de',
                                    '00:14:4f:02:00:32',
                                    '00:14:4f:02:23:6a',
                                    '00:14:4f:49:dd:c2',
                                    '00:14:4f:49:e0:8e',
                                    '00:14:4f:49:e1:6a',
                                    '00:14:4f:4a:1d:02',
                                    '00:14:4f:4a:1e:6e',
                                    '00:14:4f:49:de:37',
                                    '00:14:4f:01:e9:0e',
                                    '00:14:4f:01:f3:ce',
                                    '00:14:4f:01:f5:c6',
                                    '00:14:4f:01:ff:8a',
                                    '00:14:4f:01:ff:e6',
                                    '00:14:4f:02:0a:f2',
                                    '00:14:4f:02:0e:36',
                                    '00:14:4f:02:1c:a6',
                                    '00:14:4f:49:d2:1a',
                                    '00:14:4f:49:d3:e6',
                                    '00:14:4f:49:db:aa',
                                    '00:14:4f:49:de:26',
                                    '00:14:4f:4a:1d:7a',
                                    '00:14:4f:4a:1d:c2',
                                    '00:14:4f:4a:1d:36',
                                    '00:14:4f:4a:1d:4e',
                                    '00:14:4f:4a:1e:7e',
                                    '00:14:4f:4a:1e:3e',
                                    '00:21:28:75:f2:a5',
                                    '00:21:28:76:14:ad',
                                    '00:21:28:50:47:97',
                                    '00:21:28:50:48:17',
                                    'd8:9d:67:13:73:54',
                                    'd8:9d:67:13:78:bc',
                                    'd8:9d:67:13:b0:e0',
                                    'd8:9d:67:13:b6:ec',
                                    'd8:9d:67:13:de:e0',
                                    'd8:9d:67:13:df:bc',
                                    'd8:9d:67:13:df:50',
                                    'd8:9d:67:13:e1:d4',
                                    'd8:9d:67:13:f1:44',
                                    'd8:9d:67:14:0c:d8',
                                    'd8:9d:67:14:11:dc',
                                    'd8:9d:67:14:07:e8',
                                    'd8:9d:67:14:09:84',
                                    'd8:9d:67:14:09:a0',
                                    '3c:4a:92:eb:c7:44',
                                    '3c:4a:92:eb:c8:c0',
                                    '3c:4a:92:eb:d8:4c',
                                    '3c:4a:92:eb:39:4c',
                                    '3c:4a:92:eb:49:3c',
                                    '3c:4a:92:f4:fa:a4',
                                    '3c:4a:92:f4:1b:2c',
                                    '3c:4a:92:f4:3b:f0',
                                    '3c:4a:92:f4:3b:1c',
                                    '3c:4a:92:f4:4a:a4',
                                    '00:21:28:50:47:d7',
                                    '00:21:28:50:47:ff',
                                    '00:21:28:50:47:2f',
                                    '90:b1:1c:55:1e:b3',
                                    '90:b1:1c:55:25:d8',
                                    '90:b1:1c:56:1b:d1',
                                    '2c:76:8a:54:c9:b4',
                                    '2c:76:8a:54:ca:68',
                                    '2c:76:8a:54:f5:94',
                                    '2c:76:8a:54:f5:e4',
                                    '2c:76:8a:54:f7:34',
                                    '2c:76:8a:54:f7:5c',
                                    '2c:76:8a:54:f8:a0',
                                    '2c:76:8a:54:f9:0c',
                                    '2c:76:8a:54:fa:50',
                                    '2c:76:8a:55:00:b4',
                                    '2c:76:8a:55:00:2c',
                                    '2c:76:8a:55:02:4c',
                                    '2c:76:8a:55:18:78',
                                    '2c:76:8a:55:3b:7c',
                                    '2c:76:8a:55:42:f4',
                                    '2c:76:8a:55:43:08',
                                    '3c:4a:92:eb:64:34',
                                    '3c:4a:92:eb:d8:5c',
                                    '00:14:4f:01:f3:c6',
                                    '00:14:4f:01:f6:42',
                                    '00:14:4f:02:0e:b2',
                                    '00:14:4f:02:03:8a',
                                    '00:14:4f:02:03:e2',
                                    '00:14:4f:02:03:36',
                                    '00:14:4f:02:06:be',
                                    '00:14:4f:02:06:3e',
                                    '00:14:4f:02:06:52',
                                    '00:14:4f:49:d5:66',
                                    '00:14:4f:49:d5:4a',
                                    '00:14:4f:49:d6:e2',
                                    '00:14:4f:49:d6:f2',
                                    '00:14:4f:49:d6:46',
                                    '00:14:4f:49:d6:5e',
                                    '00:14:4f:49:d7:0a',
                                    '00:14:4f:49:d7:72',
                                    '00:14:4f:49:d7:de',
                                    '00:14:4f:49:d7:06',
                                    '00:14:4f:49:d7:4e',
                                    '00:14:4f:49:d9:aa',
                                    '00:14:4f:49:e2:6e',
                                    '00:14:4f:49:e2:1e',
                                    '00:14:4f:49:e6:5e',
                                    '00:14:4f:49:e7:0e',
                                    '00:50:56:ac:22:05',
                                    '2c:76:8a:54:f5:b8',
                                    '2c:76:8a:54:f7:74',
                                    '2c:76:8a:54:fa:d8',
                                    '2c:76:8a:54:fa:30',
                                    '2c:76:8a:54:fb:3c',
                                    '2c:76:8a:54:fb:4c',
                                    '2c:76:8a:55:00:34',
                                    '2c:76:8a:55:37:98',
                                    '2c:76:8a:55:3e:7c',
                                    '2c:76:8a:55:45:74',
                                    '00:14:4f:49:de:36',
                                    '00:50:56:ac:4a:be',
                                    '00:14:4f:01:e8:c6',
                                    '00:14:4f:01:d6:ee',
                                    '00:14:4f:01:e2:32',
                                    '00:14:4f:02:06:76',
                                    '00:14:4f:49:d7:f6',
                                    '00:14:4f:49:d8:ba',
                                    '00:14:4f:49:e7:a6',
                                    '1c:c1:de:e5:5d:c8',
                                    '3c:4a:92:eb:d8:18',
                                    '3c:4a:92:eb:29:58',
                                    '3c:4a:92:eb:39:0c',
                                    '3c:4a:92:eb:39:08',
                                    '3c:4a:92:eb:49:2c',
                                    '00:14:4f:02:0a:d6',
                                    '00:14:4f:49:e1:d2',
                                    '00:50:56:89:64:36',
                                    '68:b5:99:6d:a3:72',
                                    '68:b5:99:6d:a5:e8',
                                    '2c:76:8a:4e:91:58',
                                    '2c:76:8a:4e:4e:54',
                                    '2c:76:8a:4e:57:54',
                                    '2c:76:8a:4e:5e:10',
                                    '2c:76:8a:4f:23:98',
                                    '2c:76:8a:54:d0:8c',
                                    '2c:76:8a:54:d2:dc',
                                    '3c:4a:92:eb:d8:48',
                                    '00:0c:29:f0:e6:ea',
                                    '00:14:4f:01:f4:1a',
                                    '00:0c:29:d6:b8:64',
                                    '00:14:4f:49:d2:62',
                                    '00:19:55:cd:ac:41',
                                    '3c:4a:92:eb:29:34',
                                    '3c:4a:92:eb:39:fc',
                                    '1c:c1:de:e5:4d:b0',
                                    '1c:c1:de:e5:4d:fc',
                                    '1c:c1:de:e5:5d:f8',
                                    '1c:c1:de:f3:6a:00',
                                    '1c:c1:de:f3:7c:54',
                                    '1c:c1:de:f3:5c:18',
                                    '2c:76:8a:54:c9:ac',
                                    '2c:76:8a:54:d9:d8',
                                    '3c:4a:92:eb:73:50',
                                    '3c:4a:92:ee:2d:44',
                                    '00:14:4f:01:e2:92',
                                    '00:14:4f:01:e8:ba',
                                    '00:14:4f:02:1d:b6',
                                    '00:14:4f:49:de:a6',
                                    '00:14:4f:02:06:ee',
                                    '00:14:4f:49:d6:ee',
                                    '00:14:4f:49:d7:5a',
                                    '00:14:4f:49:d9:da',
                                    '00:14:4f:49:db:4a',
                                    '00:14:4f:49:e1:82',
                                    '2c:76:8a:54:c5:04',
                                    '00:14:4f:49:db:6e',
                                    '00:14:4f:4a:1f:76',
                                    '00:21:28:50:47:5b',
                                    '00:14:4f:01:e9:42',
                                    '00:14:4f:01:ff:da',
                                    '00:14:4f:02:00:72',
                                    '00:14:4f:02:0a:de',
                                    '00:14:4f:02:0b:72',
                                    '00:14:4f:02:0e:a2',
                                    '00:14:4f:02:0e:ba',
                                    '00:14:4f:02:0e:f2',
                                    '00:14:4f:02:1f:fa',
                                    '00:14:4f:02:05:12',
                                    '00:14:4f:49:de:72',
                                    '00:14:4f:49:de:4a',
                                    '00:14:4f:4a:1d:e6',
                                    '00:14:4f:4a:1e:72',
                                    '00:14:4f:4a:1e:aa',
                                    '00:14:4f:4a:1e:fa',
                                    '00:14:4f:4a:1e:36',
                                    '3c:4a:92:6f:d1:ac',
                                    '3c:4a:92:73:78:68',
                                    '00:50:56:89:12:ed',
                                    '00:50:56:ac:3f:2f',
                                    '6c:3b:e5:a8:66:6c',
                                    '6c:3b:e5:b3:79:f8',
                                    '6c:3b:e5:b3:99:dc',
                                    '6c:3b:e5:b3:a9:84',
                                    '6c:3b:e5:b3:b9:44',
                                    '6c:3b:e5:b3:d9:7c',
                                    '6c:3b:e5:b3:d9:e8',
                                    '6c:3b:e5:b3:2a:bc',
                                    '6c:3b:e5:b3:2a:20',
                                    '6c:3b:e5:b3:2a:3c',
                                    '00:0c:29:7d:c6:9f',
                                    '3c:4a:92:ee:8d:c8',
                                    'ac:16:2d:7c:a5:10',
                                    'ac:16:2d:84:00:e8',
                                    'ac:16:2d:84:af:e4',
                                    'ac:16:2d:84:d2:3c',
                                    'ac:16:2d:85:29:ac',
                                    'ac:16:2d:85:29:58',
                                    'ac:16:2d:87:c5:fc',
                                    'ac:16:2d:87:c6:a8',
                                    'ac:16:2d:87:d0:d0',
                                    'ac:16:2d:87:d7:9c',
                                    'ac:16:2d:87:d8:00',
                                    'ac:16:2d:87:d8:30',
                                    'ac:16:2d:87:d9:d4',
                                    'ac:16:2d:87:dd:a8',
                                    'ac:16:2d:87:f3:4c',
                                    'ac:16:2d:87:f7:c4',
                                    '2c:76:8a:54:ca:a4',
                                    '2c:76:8a:54:f9:90',
                                    '2c:76:8a:54:f9:f8',
                                    '2c:76:8a:54:fb:98',
                                    '2c:76:8a:54:fb:d8',
                                    '2c:76:8a:54:fb:40',
                                    '2c:76:8a:54:ff:dc',
                                    '2c:76:8a:55:3c:38',
                                    '00:50:56:ac:50:4d',
                                    '00:0c:29:6c:6d:44',
                                    '6c:3b:e5:b3:81:70',
                                    '6c:3b:e5:b3:91:58',
                                    '6c:3b:e5:b3:b1:98',
                                    '6c:3b:e5:b3:b1:f0',
                                    '6c:3b:e5:b3:c1:94',
                                    '6c:3b:e5:b3:d1:b8',
                                    '6c:3b:e5:b3:d1:30',
                                    '6c:3b:e5:b3:d9:80',
                                    '6c:3b:e5:b3:e1:e0',
                                    '6c:3b:e5:b3:32:90',
                                    '6c:3b:e5:b3:43:70',
                                    '6c:3b:e5:b3:43:80',
                                    '6c:3b:e5:b3:52:a4',
                                    '90:b1:1c:55:b9:ed',
                                    '90:b1:1c:55:13:41',
                                    '90:b1:1c:56:14:b7',
                                    '90:b1:1c:56:19:c3',
                                    '90:b1:1c:57:09:b2',
                                    '10:60:4b:a9:53:18',
                                    '10:60:4b:af:89:48',
                                    '2c:76:8a:54:c4:2c',
                                    '2c:76:8a:54:c6:fc',
                                    '2c:76:8a:54:c7:10',
                                    '2c:76:8a:54:ca:14',
                                    '2c:76:8a:54:ca:40',
                                    '2c:76:8a:54:cd:08',
                                    '2c:76:8a:54:db:d0',
                                    '3c:4a:92:eb:82:94',
                                    '3c:4a:92:ee:6d:90',
                                    '3c:4a:92:ee:7b:68',
                                    '3c:4a:92:ee:ac:d0',
                                    '3c:4a:92:ee:ac:30',
                                    '3c:4a:92:ee:1e:f8',
                                    '3c:4a:92:ee:4d:f4',
                                    '6c:3b:e5:b2:66:4c',
                                    '10:60:4b:a1:47:48',
                                    '00:50:56:ac:40:86',
                                    '1c:c1:de:e5:8c:bc',
                                    '1c:c1:de:e5:eb:44',
                                    '1c:c1:de:e5:3e:90',
                                    '1c:c1:de:e6:26:b4',
                                    '1c:c1:de:f4:44:80',
                                    '00:50:56:89:6c:aa',
                                    '00:50:56:89:40:da',
                                    '00:50:56:ac:2f:8f',
                                    '6c:3b:e5:b3:71:f4',
                                    '6c:3b:e5:b3:13:e0',
                                    '1c:c1:de:e5:6d:44',
                                    '1c:c1:de:e5:4d:ec',
                                    '1c:c1:de:e5:4e:60',
                                    '2c:76:8a:54:c4:38',
                                    '2c:76:8a:54:c6:74',
                                    '2c:76:8a:54:c9:bc',
                                    '2c:76:8a:54:cb:74',
                                    '2c:76:8a:54:cb:3c',
                                    '2c:76:8a:54:cd:04',
                                    '2c:76:8a:54:d2:bc',
                                    '2c:76:8a:54:d5:34',
                                    '2c:76:8a:54:e1:10',
                                    '2c:76:8a:55:00:44',
                                    '00:14:4f:01:f3:52',
                                    '00:14:4f:49:de:5e',
                                    '00:0c:29:09:b4:01',
                                    '3c:4a:92:eb:c8:a8',
                                    '00:50:56:ac:75:83',
                                    '00:14:4f:01:d6:12',
                                    '00:14:4f:01:e8:92',
                                    'b8:ca:3a:ec:d8:c0',
                                    'b8:ca:3a:ec:d9:89',
                                    'b8:ca:3a:ec:d9:fd',
                                    'b8:ca:3a:ec:da:25',
                                    'b8:ca:3a:ec:de:cf',
                                    'b8:ca:3a:ec:ea:83',
                                    'b8:ca:3a:ec:ee:da',
                                    'b8:ca:3a:ed:64:1c',
                                    'b8:ca:3a:ed:67:d6',
                                    'b8:ca:3a:ed:69:df',
                                    'b8:ca:3a:ed:69:e7',
                                    'b8:ca:3a:ed:6b:1c',
                                    'b8:ca:3a:ed:72:f3',
                                    'b8:ca:3a:ed:02:1b',
                                    'b8:ca:3a:ed:5f:7a',
                                    '00:14:4f:4a:1d:4a',
                                    '00:14:4f:4a:1f:22',
                                    '00:14:4f:49:d6:fa',
                                    '00:14:4f:49:d9:ce',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1109',
                        IFNAME           => 'ge-7/0/2.0',
                        IFDESCR          => 'ge-7/0/2.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:41',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20718) 0:03:27.18',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '620',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '64994743',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1110',
                        IFNAME           => 'ge-7/0/40.0',
                        IFDESCR          => 'ge-7/0/40.0',
                        IFTYPE           => '53',
                        IFSPEED          => '10000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:7b',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(766327109) 88 days, 16:41:11.09',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1111',
                        IFNAME           => 'vlan.211',
                        IFDESCR          => 'vlan.211',
                        IFALIAS          => 'Scribe-router-mgmt',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.211.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(615188816) 71 days, 4:51:28.16',
                        IFINOCTETS       => '2739024',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '112214146',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1112',
                        IFNAME           => 'ae30',
                        IFDESCR          => 'ae30',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:21',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(288) 0:00:02.88',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1113',
                        IFNAME           => 'ae31',
                        IFDESCR          => 'ae31',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:22',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(289) 0:00:02.89',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1114',
                        IFNAME           => 'ae32',
                        IFDESCR          => 'ae32',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:23',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(289) 0:00:02.89',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1115',
                        IFNAME           => 'ae33',
                        IFDESCR          => 'ae33',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:24',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(289) 0:00:02.89',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1116',
                        IFNAME           => 'ae34',
                        IFDESCR          => 'ae34',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:25',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(289) 0:00:02.89',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1117',
                        IFNAME           => 'ae37',
                        IFDESCR          => 'ae37',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:28',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(291) 0:00:02.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1118',
                        IFNAME           => 'ae35',
                        IFDESCR          => 'ae35',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:26',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(289) 0:00:02.89',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1119',
                        IFNAME           => 'ae36',
                        IFDESCR          => 'ae36',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:27',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(291) 0:00:02.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1120',
                        IFNAME           => 'ae38',
                        IFDESCR          => 'ae38',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:29',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(291) 0:00:02.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1122',
                        IFNAME           => 'ae39',
                        IFDESCR          => 'ae39',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:2a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(291) 0:00:02.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1123',
                        IFNAME           => 'ae40',
                        IFDESCR          => 'ae40',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:2b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(291) 0:00:02.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1124',
                        IFNAME           => 'ae41',
                        IFDESCR          => 'ae41',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:2c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(291) 0:00:02.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1125',
                        IFNAME           => 'ae42',
                        IFDESCR          => 'ae42',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:2d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(291) 0:00:02.91',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1126',
                        IFNAME           => 'ae43',
                        IFDESCR          => 'ae43',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:2e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1843) 0:00:18.43',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1127',
                        IFNAME           => 'ae44',
                        IFDESCR          => 'ae44',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:2f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1844) 0:00:18.44',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1128',
                        IFNAME           => 'ae45',
                        IFDESCR          => 'ae45',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:30',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1844) 0:00:18.44',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1129',
                        IFNAME           => 'ae46',
                        IFDESCR          => 'ae46',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:31',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1847) 0:00:18.47',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1130',
                        IFNAME           => 'ae47',
                        IFDESCR          => 'ae47',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:32',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1847) 0:00:18.47',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1131',
                        IFNAME           => 'ae48',
                        IFDESCR          => 'ae48',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:33',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1849) 0:00:18.49',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1132',
                        IFNAME           => 'ae49',
                        IFDESCR          => 'ae49',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:34',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1850) 0:00:18.50',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1133',
                        IFNAME           => 'ae50',
                        IFDESCR          => 'ae50',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:35',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1852) 0:00:18.52',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1134',
                        IFNAME           => 'ae51',
                        IFDESCR          => 'ae51',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:36',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1852) 0:00:18.52',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1135',
                        IFNAME           => 'ae52',
                        IFDESCR          => 'ae52',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:37',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1852) 0:00:18.52',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1136',
                        IFNAME           => 'ae53',
                        IFDESCR          => 'ae53',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:38',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1856) 0:00:18.56',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1137',
                        IFNAME           => 'ae54',
                        IFDESCR          => 'ae54',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:39',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1857) 0:00:18.57',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1138',
                        IFNAME           => 'ae55',
                        IFDESCR          => 'ae55',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:3a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1857) 0:00:18.57',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1139',
                        IFNAME           => 'ae56',
                        IFDESCR          => 'ae56',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:3b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1866) 0:00:18.66',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1140',
                        IFNAME           => 'ae57',
                        IFDESCR          => 'ae57',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:3c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1866) 0:00:18.66',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1141',
                        IFNAME           => 'ae58',
                        IFDESCR          => 'ae58',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:3d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1868) 0:00:18.68',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1142',
                        IFNAME           => 'ae59',
                        IFDESCR          => 'ae59',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:3e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1868) 0:00:18.68',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1143',
                        IFNAME           => 'ae60',
                        IFDESCR          => 'ae60',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:3f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1868) 0:00:18.68',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1144',
                        IFNAME           => 'ae61',
                        IFDESCR          => 'ae61',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:40',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(1868) 0:00:18.68',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1145',
                        IFNAME           => 'ae62',
                        IFDESCR          => 'ae62',
                        IFALIAS          => 'To fw-srx1400-tmk node0',
                        IFTYPE           => '161',
                        IFSPEED          => '2000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:41',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21101) 0:03:31.01',
                        IFINOCTETS       => '3393089492',
                        IFINERRORS       => '9',
                        IFOUTOCTETS      => '32084124',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1146',
                        IFNAME           => 'ae63',
                        IFDESCR          => 'ae63',
                        IFALIAS          => 'To fw-srx1400-tmk node1',
                        IFTYPE           => '161',
                        IFSPEED          => '2000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:42',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(27987) 0:04:39.87',
                        IFINOCTETS       => '1981128960',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3219750695',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1147',
                        IFNAME           => 'ae62.0',
                        IFDESCR          => 'ae62.0',
                        IFTYPE           => '161',
                        IFSPEED          => '2000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:41',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(21101) 0:03:31.01',
                        IFINOCTETS       => '136264368',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '64994743',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:10:db:ff:10:01',
                                    '00:10:db:ff:10:01',
                                    '00:10:db:ff:10:01',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1148',
                        IFNAME           => 'ae63.0',
                        IFDESCR          => 'ae63.0',
                        IFTYPE           => '161',
                        IFSPEED          => '2000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:42',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(27987) 0:04:39.87',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '21270142',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1149',
                        IFNAME           => 'vlan.13',
                        IFDESCR          => 'vlan.13',
                        IFALIAS          => 'Cloud-mgmt',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.13.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20742) 0:03:27.42',
                        IFINOCTETS       => '104288862',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '161719891',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1150',
                        IFNAME           => 'vlan.470',
                        IFDESCR          => 'vlan.470',
                        IFALIAS          => 'Quarantine-mgmt',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.47.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20894) 0:03:28.94',
                        IFINOCTETS       => '114353997',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1734799853',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1151',
                        IFNAME           => 'vlan.700',
                        IFDESCR          => 'vlan.700',
                        IFALIAS          => 'Quarantine',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.207.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20894) 0:03:28.94',
                        IFINOCTETS       => '472570056',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '244649135',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1152',
                        IFNAME           => 'ge-7/0/5.0',
                        IFDESCR          => 'ge-7/0/5.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:58',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20736) 0:03:27.36',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '2704052605',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3475179282',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:14:4f:3a:48:ae',
                                    '00:14:4f:3a:48:d4',
                                    '00:14:4f:3a:48:fa',
                                    '00:14:4f:3a:4a:15',
                                    '00:14:4f:3a:4c:48',
                                    '00:14:4f:3a:50:38',
                                    '00:14:4f:3a:50:41',
                                    '00:14:4f:3a:51:b5',
                                    '00:14:4f:3a:51:d6',
                                    '00:03:ba:cd:7b:d1',
                                    '00:14:4f:39:ff:55',
                                    '00:14:4f:3a:47:f8',
                                    '00:14:4f:3a:47:3f',
                                    '00:14:4f:3a:47:45',
                                    '00:14:4f:3a:48:75',
                                    '00:14:4f:3a:48:4e',
                                    '00:14:4f:3a:4b:42',
                                    '00:14:4f:3a:4c:d9',
                                    '00:14:4f:3a:4e:87',
                                    '00:14:4f:3a:50:3a',
                                    '00:14:4f:3a:51:b0',
                                    '00:14:4f:3a:51:b8',
                                    '00:14:4f:3a:51:e7',
                                    '00:14:4f:3a:52:65',
                                    '00:14:4f:3a:52:85',
                                    '00:14:4f:3a:52:33',
                                    '00:14:4f:3a:52:4f',
                                    '00:03:ba:cd:6d:fc',
                                    '00:21:28:75:f2:a8',
                                    '00:21:28:76:14:b0',
                                    '00:21:28:46:80:d8',
                                    '00:21:28:46:80:e8',
                                    '6c:3b:e5:a7:74:8e',
                                    '6c:3b:e5:a7:74:42',
                                    '6c:3b:e5:a7:74:5a',
                                    '6c:3b:e5:a7:74:62',
                                    '6c:3b:e5:a7:b3:c8',
                                    '6c:3b:e5:a7:c3:98',
                                    '6c:3b:e5:a7:c3:f2',
                                    '6c:3b:e5:b8:7d:e8',
                                    '6c:3b:e5:b8:ad:0e',
                                    '6c:3b:e5:b8:ad:10',
                                    '6c:3b:e5:b8:df:ec',
                                    '6c:3b:e5:b8:ec:cc',
                                    '6c:3b:e5:b8:3d:16',
                                    '6c:3b:e5:b8:4d:58',
                                    '00:21:28:46:81:0f',
                                    '00:21:28:46:81:40',
                                    '00:21:28:46:81:52',
                                    '74:86:7a:d0:da:1e',
                                    '74:86:7a:d0:db:cc',
                                    '74:86:7a:d0:db:fc',
                                    '74:86:7a:d1:98:2c',
                                    '74:86:7a:d1:9d:ae',
                                    '80:c1:6e:64:58:ec',
                                    '80:c1:6e:6b:df:f6',
                                    '80:c1:6e:6b:ff:16',
                                    '80:c1:6e:70:a9:e2',
                                    '80:c1:6e:70:d6:48',
                                    '80:c1:6e:74:8c:48',
                                    '80:c1:6e:74:a9:ba',
                                    '80:c1:6e:74:c9:52',
                                    '80:c1:6e:74:eb:90',
                                    '80:c1:6e:74:eb:42',
                                    '80:c1:6e:74:1c:1c',
                                    '80:c1:6e:74:3c:46',
                                    '80:c1:6e:74:07:6e',
                                    '80:c1:6e:74:47:0c',
                                    '80:c1:6e:74:5a:7c',
                                    'b4:b5:2f:68:4c:2e',
                                    '00:c0:b7:79:84:66',
                                    '00:c0:b7:79:84:6f',
                                    '00:c0:b7:79:84:72',
                                    '00:c0:b7:79:84:88',
                                    '00:c0:b7:79:84:60',
                                    '00:c0:b7:79:84:61',
                                    '00:c0:b7:79:85:0c',
                                    '00:c0:b7:79:85:0d',
                                    '00:c0:b7:79:85:17',
                                    '00:c0:b7:79:85:36',
                                    '00:c0:b7:79:85:3a',
                                    '00:c0:b7:79:88:66',
                                    '00:c0:b7:79:88:0f',
                                    '00:c0:b7:79:88:a3',
                                    '00:c0:b7:79:be:86',
                                    '00:c0:b7:79:be:af',
                                    '00:c0:b7:79:c0:ab',
                                    '00:c0:b7:79:c0:b0',
                                    '00:c0:b7:79:c0:b3',
                                    '00:c0:b7:79:c0:c8',
                                    '00:c0:b7:94:0d:9f',
                                    '00:c0:b7:cf:64:7f',
                                    '00:c0:b7:cf:64:ca',
                                    '00:c0:b7:cf:65:d6',
                                    '00:c0:b7:2b:68:20',
                                    '00:c0:b7:2b:69:8c',
                                    '00:c0:b7:2b:6e:5b',
                                    '00:c0:b7:2c:64:cc',
                                    '00:c0:b7:2c:64:42',
                                    '00:c0:b7:2c:63:69',
                                    '00:c0:b7:2c:63:9b',
                                    '00:c0:b7:2c:63:de',
                                    '00:c0:b7:2c:63:26',
                                    '00:c0:b7:2d:26:75',
                                    '00:c0:b7:2d:26:78',
                                    '00:c0:b7:2e:86:6c',
                                    '00:c0:b7:51:eb:a4',
                                    '00:14:4f:79:25:3c',
                                    '00:03:ba:cd:6c:79',
                                    '00:03:ba:cd:6c:8d',
                                    '00:03:ba:cd:6c:2a',
                                    '00:03:ba:cd:6d:cc',
                                    '00:03:ba:cd:6d:e1',
                                    '00:03:ba:cd:6e:17',
                                    '00:03:ba:cd:6e:34',
                                    '00:03:ba:cd:6f:e1',
                                    '00:03:ba:cd:70:74',
                                    '00:03:ba:cd:70:e5',
                                    '00:03:ba:cd:71:87',
                                    '00:03:ba:cd:71:9b',
                                    '00:03:ba:cd:71:d3',
                                    '00:03:ba:cd:72:9c',
                                    '00:03:ba:cd:72:f6',
                                    '00:03:ba:cd:75:83',
                                    '00:03:ba:cd:7a:ad',
                                    '00:03:ba:cd:7b:af',
                                    '00:03:ba:cd:7b:b6',
                                    '00:03:ba:cd:7b:ba',
                                    '00:03:ba:cd:7b:d3',
                                    '00:03:ba:cd:7b:e9',
                                    '00:03:ba:cd:7b:5a',
                                    '00:03:ba:cd:7b:5e',
                                    '80:c1:6e:70:d6:fe',
                                    '80:c1:6e:70:e6:ea',
                                    '80:c1:6e:74:6a:2e',
                                    '80:c1:6e:74:6c:72',
                                    '80:c1:6e:74:7c:82',
                                    '80:c1:6e:74:7c:a0',
                                    '80:c1:6e:74:8a:36',
                                    '80:c1:6e:74:17:76',
                                    '80:c1:6e:74:07:20',
                                    '80:c1:6e:74:57:82',
                                    '00:14:4f:3a:48:95',
                                    '00:14:4f:3a:51:f8',
                                    '00:14:4f:3a:46:56',
                                    '00:14:4f:3a:4b:3b',
                                    '00:14:4f:3a:4c:70',
                                    '00:14:4f:3a:52:55',
                                    '00:03:ba:cd:71:ff',
                                    '00:03:ba:cd:7b:f2',
                                    '00:21:28:46:80:e2',
                                    'e8:39:35:ec:15:64',
                                    'e8:39:35:ec:1b:c8',
                                    'e8:39:35:ec:1c:c0',
                                    'e8:39:35:ec:1d:76',
                                    'e8:39:35:ec:1d:82',
                                    'e8:39:35:ec:1d:30',
                                    'e8:39:35:ec:1e:94',
                                    '1c:c1:de:e9:cc:fa',
                                    '00:a0:b8:26:81:b8',
                                    '00:a0:b8:26:81:c0',
                                    '00:a0:b8:26:25:f2',
                                    '00:a0:b8:26:25:3e',
                                    '00:14:4f:3a:52:16',
                                    '00:1a:6d:09:8f:41',
                                    '00:05:1e:04:15:eb',
                                    '00:05:1e:04:e9:3a',
                                    '00:40:8c:84:b1:c0',
                                    '00:1a:6d:09:8f:42',
                                    '00:14:4f:79:2c:c4',
                                    '00:03:ba:cd:6d:7b',
                                    '00:03:ba:cd:6d:83',
                                    '00:03:ba:cd:72:e8',
                                    '00:03:ba:cd:7b:c2',
                                    '00:03:ba:cd:7b:d8',
                                    '80:c1:6e:62:a3:8c',
                                    '80:c1:6e:62:a3:d0',
                                    'd4:85:64:45:c3:6e',
                                    'd4:85:64:45:c3:04',
                                    '1c:c1:de:e9:cc:96',
                                    '1c:c1:de:e9:cc:e8',
                                    '1c:c1:de:e9:dc:18',
                                    '1c:c1:de:f1:eb:16',
                                    '3c:4a:92:e6:8d:ac',
                                    '3c:4a:92:e6:bd:66',
                                    '3c:4a:92:e7:e4:fe',
                                    '3c:4a:92:e7:e4:5a',
                                    '3c:4a:92:e7:05:30',
                                    '3c:4a:92:e7:37:90',
                                    '00:14:4f:3a:42:6d',
                                    '00:14:4f:3a:48:5e',
                                    '00:14:4f:3a:52:41',
                                    '00:03:ba:cd:74:44',
                                    '00:14:4f:3a:48:24',
                                    '00:03:ba:cd:71:e3',
                                    '00:03:ba:cd:72:ec',
                                    '00:03:ba:cd:7b:6e',
                                    '00:03:ba:cd:7b:73',
                                    '00:03:ba:cd:7b:9e',
                                    '00:21:28:46:81:47',
                                    '00:21:28:46:81:4e',
                                    '80:c1:6e:64:2d:b4',
                                    '00:14:4f:3a:46:93',
                                    '00:14:4f:3a:46:5a',
                                    '00:14:4f:3a:47:9f',
                                    '00:14:4f:3a:47:ad',
                                    '00:14:4f:3a:47:e7',
                                    '00:14:4f:3a:47:44',
                                    '00:14:4f:3a:48:c7',
                                    '00:14:4f:3a:48:25',
                                    '00:14:4f:3a:48:58',
                                    '00:14:4f:3a:51:68',
                                    '00:14:4f:3a:51:e2',
                                    '00:14:4f:3a:51:e4',
                                    '00:14:4f:3a:51:e9',
                                    '00:14:4f:3a:51:f3',
                                    '00:14:4f:3a:51:5d',
                                    '00:14:4f:3a:52:26',
                                    '00:03:ba:cd:7e:41',
                                    '00:14:4f:3a:46:53',
                                    '00:14:4f:3a:47:d1',
                                    '3c:4a:92:e7:f4:10',
                                    '6c:3b:e5:b1:0c:ce',
                                    '6c:3b:e5:b1:0c:32',
                                    '6c:3b:e5:b1:1c:66',
                                    '6c:3b:e5:b1:1c:f0',
                                    '6c:3b:e5:b1:1c:62',
                                    '6c:3b:e5:b1:2c:b0',
                                    '6c:3b:e5:b1:3c:20',
                                    '6c:3b:e5:b2:73:ee',
                                    '6c:3b:e5:b2:b1:36',
                                    '6c:3b:e5:b2:c1:e4',
                                    '6c:3b:e5:b2:c1:2a',
                                    '80:c1:6e:64:6e:ce',
                                    '80:c1:6e:70:a6:fc',
                                    '80:c1:6e:70:b6:1e',
                                    '80:c1:6e:70:b6:06',
                                    '80:c1:6e:70:c6:54',
                                    '80:c1:6e:70:c9:c6',
                                    '80:c1:6e:74:7c:4e',
                                    '80:c1:6e:74:dd:2e',
                                    '10:60:4b:b0:da:e2',
                                    '10:60:4b:b0:db:0c',
                                    '10:60:4b:b0:eb:7c',
                                    '10:60:4b:b0:eb:c4',
                                    '10:60:4b:b1:c0:58',
                                    '00:21:28:46:81:48',
                                    '6c:3b:e5:b2:66:fe',
                                    '6c:3b:e5:b2:66:58',
                                    '6c:3b:e5:b2:76:70',
                                    '6c:3b:e5:b2:76:f6',
                                    '6c:3b:e5:b2:86:c8',
                                    '6c:3b:e5:b2:86:ee',
                                    '6c:3b:e5:b2:37:76',
                                    '6c:3b:e5:b2:37:84',
                                    '6c:3b:e5:b2:56:e6',
                                    '6c:3b:e5:b2:56:fc',
                                    '6c:3b:e5:b4:a8:ca',
                                    '74:86:7a:d0:da:d8',
                                    '74:86:7a:d0:dc:04',
                                    '74:86:7a:d0:dc:40',
                                    '74:86:7a:d0:dc:08',
                                    '74:86:7a:d0:dd:06',
                                    '80:c1:6e:64:bf:86',
                                    '80:c1:6e:64:1d:7c',
                                    '80:c1:6e:74:7c:88',
                                    '80:c1:6e:74:e9:9c',
                                    '80:c1:6e:74:1c:1e',
                                    '80:c1:6e:62:2b:18',
                                    '80:c1:6e:62:3b:f0',
                                    '10:60:4b:a1:47:b0',
                                    '10:60:4b:a1:57:c2',
                                    '3c:4a:92:e6:bd:dc',
                                    '3c:4a:92:e7:15:b2',
                                    '3c:4a:92:e7:d4:ee',
                                    '3c:4a:92:e7:e4:84',
                                    '3c:4a:92:e7:e4:a8',
                                    '3c:4a:92:e7:e4:b0',
                                    '3c:4a:92:e7:e4:de',
                                    '3c:4a:92:e7:f4:64',
                                    '3c:4a:92:e7:f4:8a',
                                    '3c:4a:92:e7:f4:56',
                                    '3c:4a:92:e7:05:d4',
                                    '3c:4a:92:e7:37:5c',
                                    '3c:4a:92:e7:62:fc',
                                    '6c:3b:e5:b4:68:c6',
                                    '6c:3b:e5:b4:68:d0',
                                    '6c:3b:e5:b4:68:ee',
                                    '6c:3b:e5:b4:78:8e',
                                    '6c:3b:e5:b4:78:b6',
                                    '6c:3b:e5:b4:78:28',
                                    '6c:3b:e5:b4:98:44',
                                    '6c:3b:e5:b4:a8:80',
                                    '6c:3b:e5:b4:a8:cc',
                                    'd8:9d:67:5c:0e:2e',
                                    'd4:85:64:4b:9f:90',
                                    '1c:c1:de:e9:dc:64',
                                    '1c:c1:de:e9:2c:6e',
                                    '1c:c1:de:e9:4c:32',
                                    '1c:c1:de:ea:89:04',
                                    '80:c1:6e:64:af:90',
                                    '80:c1:6e:64:bf:e0',
                                    '80:c1:6e:64:fc:48',
                                    '80:c1:6e:6d:00:80',
                                    '80:c1:6e:70:c8:e2',
                                    '80:c1:6e:74:0c:d0',
                                    '80:c1:6e:74:eb:fc',
                                    '80:c1:6e:62:a3:a6',
                                    '80:c1:6e:62:a3:e2',
                                    '80:c1:6e:62:a3:2a',
                                    '1c:c1:de:e9:cc:9a',
                                    '1c:c1:de:e9:cc:e4',
                                    '1c:c1:de:e9:dc:4e',
                                    '00:14:4f:3a:48:18',
                                    '00:03:ba:cd:6c:34',
                                    '3c:4a:92:e7:12:da',
                                    '3c:4a:92:e7:12:ec',
                                    '00:14:4f:3a:51:ba',
                                    '00:14:4f:3a:51:d5',
                                    '74:86:7a:d4:4e:5c',
                                    '74:86:7a:d7:a6:9c',
                                    '74:86:7a:d7:a6:da',
                                    '74:86:7a:d7:a7:84',
                                    '74:86:7a:d7:a7:4c',
                                    '74:86:7a:d7:ac:dc',
                                    '74:86:7a:d7:ac:ec',
                                    '74:86:7a:d7:ad:2e',
                                    '74:86:7a:d7:ad:42',
                                    '74:86:7a:d7:ad:4a',
                                    '74:86:7a:d7:ad:50',
                                    '74:86:7a:d7:b2:a4',
                                    '74:86:7a:d7:b2:fc',
                                    '74:86:7a:d7:b3:9a',
                                    '74:86:7a:d7:b5:2a',
                                    '00:14:4f:3a:46:4c',
                                    '00:14:4f:3a:51:b9',
                                    '00:14:4f:3a:48:fe',
                                    '00:14:4f:3a:52:01',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1153',
                        IFNAME           => 'ge-7/0/6.0',
                        IFDESCR          => 'ge-7/0/6.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:59',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(455383955) 52 days, 16:57:19.55',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1310523499',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2511869766',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:14:4f:81:2f:8a',
                                    '00:14:4f:81:32:18',
                                    '00:14:4f:81:32:03',
                                    '00:14:4f:8e:54:30',
                                    '00:14:4f:94:66:97',
                                    '00:14:4f:9a:38:a0',
                                    '00:14:4f:9a:38:36',
                                    '00:14:4f:9a:3b:be',
                                    '00:14:4f:d6:ba:b5',
                                    '00:14:4f:94:5b:01',
                                    '00:14:4f:8c:d0:4d',
                                    '00:14:4f:94:5c:89',
                                    '00:14:4f:9a:39:02',
                                    '6c:3b:e5:a7:b3:fa',
                                    '00:14:4f:8d:40:1d',
                                    '00:14:4f:94:66:69',
                                    '00:14:4f:94:66:6c',
                                    '00:14:4f:94:66:6f',
                                    '00:14:4f:94:66:72',
                                    '00:14:4f:94:66:75',
                                    '00:14:4f:94:66:81',
                                    '00:14:4f:94:66:91',
                                    '00:14:4f:94:67:25',
                                    '00:14:4f:d6:b8:9f',
                                    '00:14:4f:d6:ba:7d',
                                    '00:03:ba:cd:6c:a4',
                                    '00:03:ba:cd:7b:a8',
                                    '00:21:28:10:12:b9',
                                    '00:21:28:46:80:d5',
                                    '00:c0:b7:79:85:25',
                                    '00:c0:b7:79:be:4a',
                                    '00:c0:b7:79:c0:ba',
                                    '00:c0:b7:c7:d4:a0',
                                    '00:c0:b7:c7:d4:d8',
                                    '00:c0:b7:2d:26:6e',
                                    '00:c0:b7:2d:26:99',
                                    '00:c0:b7:2e:86:81',
                                    '00:c0:b7:2f:77:ef',
                                    '00:c0:b7:2f:78:c7',
                                    '00:c0:b7:2f:a9:df',
                                    '00:c0:b7:2f:cc:00',
                                    '00:c0:b7:30:a5:36',
                                    '00:14:4f:9a:38:2e',
                                    '00:14:4f:81:30:1c',
                                    '00:14:4f:d6:bd:29',
                                    '00:14:4f:e6:41:46',
                                    '00:14:4f:f7:ba:2d',
                                    '00:14:4f:f7:e0:61',
                                    '00:1b:24:3d:f7:06',
                                    '00:a0:b8:2a:0c:dc',
                                    '00:a0:b8:2a:af:92',
                                    '00:a0:b8:2a:af:a2',
                                    '00:a0:b8:2a:cb:36',
                                    '00:a0:b8:2a:e2:9c',
                                    '00:a0:b8:2a:e2:a8',
                                    '00:a0:b8:2a:23:02',
                                    '00:a0:b8:2a:23:18',
                                    '00:1c:0f:48:1c:41',
                                    '00:1b:24:6d:f8:2b',
                                    '00:1b:24:3d:f7:1c',
                                    '00:14:4f:81:2d:b6',
                                    '00:14:4f:9a:38:df',
                                    '00:14:4f:9a:38:ec',
                                    '00:14:4f:9a:3f:68',
                                    '00:14:4f:9a:3a:bf',
                                    '00:14:4f:94:66:94',
                                    '00:14:4f:94:66:5d',
                                    '00:14:4f:9a:3b:36',
                                    '00:14:4f:94:67:04',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1154',
                        IFNAME           => 'ge-7/0/7.0',
                        IFDESCR          => 'ge-7/0/7.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:5a',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20726) 0:03:27.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '289552805',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '525991501',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFNUMBER => 'GigabitEthernet 0/48',
                                IFDESCR  => undef,
                                SYSNAME  => 'sw-s50-5-tmk',
                                SYSDESCR => 'Dell Force10 Real Time Operating System Software. Dell Force10 Operating System Version: 1.0. Dell Force10 Application Software Version: 8.4.2.6. Copyright (c) 1999-2011 Dell Inc. All Rights Reserved.Build Time: Tue Nov 15 09:20:27 2011',
                                SYSMAC   => '00:01:e8:d6:a8:e8',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1155',
                        IFNAME           => 'vlan.25',
                        IFDESCR          => 'vlan.25',
                        IFALIAS          => 'Cloud',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.25.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20742) 0:03:27.42',
                        IFINOCTETS       => '43950084',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3463585458',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1156',
                        IFNAME           => 'vlan.43',
                        IFDESCR          => 'vlan.43',
                        IFALIAS          => 'mphotos-mgmt',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.43.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20946) 0:03:29.46',
                        IFINOCTETS       => '10559424',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '33682558',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1157',
                        IFNAME           => 'vlan.104',
                        IFDESCR          => 'vlan.104',
                        IFALIAS          => 'Sorry-page-mgmt',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.104.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20913) 0:03:29.13',
                        IFINOCTETS       => '10572160',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '10175677',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1158',
                        IFNAME           => 'vlan.105',
                        IFDESCR          => 'vlan.105',
                        IFALIAS          => 'Sorrypage',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.105.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20913) 0:03:29.13',
                        IFINOCTETS       => '3605280',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1726193150',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1159',
                        IFNAME           => 'vlan.204',
                        IFDESCR          => 'vlan.204',
                        IFALIAS          => 'Staging-mgmt',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.204.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20916) 0:03:29.16',
                        IFINOCTETS       => '12395504',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '11665989',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1160',
                        IFNAME           => 'vlan.423',
                        IFDESCR          => 'vlan.423',
                        IFALIAS          => 'Proxy-mgmt',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.23.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20888) 0:03:28.88',
                        IFINOCTETS       => '20765184',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '16855276',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1161',
                        IFNAME           => 'vlan.441',
                        IFDESCR          => 'vlan.441',
                        IFALIAS          => 'Scriptsbilling-mgmt',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.21.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20894) 0:03:28.94',
                        IFINOCTETS       => '50599036',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '33073978',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1162',
                        IFNAME           => 'vlan.442',
                        IFDESCR          => 'vlan.442',
                        IFALIAS          => 'Dns-manage',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.22.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20848) 0:03:28.48',
                        IFINOCTETS       => '9143698',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '334973',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1163',
                        IFNAME           => 'vlan.212',
                        IFDESCR          => 'vlan.212',
                        IFALIAS          => 'Scribe-router',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.212.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(615190754) 71 days, 4:51:47.54',
                        IFINOCTETS       => '758494',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3385285606',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1164',
                        IFNAME           => 'vlan.453',
                        IFDESCR          => 'vlan.453',
                        IFALIAS          => 'Main-mgmt',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.3.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20852) 0:03:28.52',
                        IFINOCTETS       => '379454292',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '906460766',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1165',
                        IFNAME           => 'vlan.454',
                        IFDESCR          => 'vlan.454',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.4.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20927) 0:03:29.27',
                        IFINOCTETS       => '335018484',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '545335152',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1166',
                        IFNAME           => 'vlan.455',
                        IFDESCR          => 'vlan.455',
                        IFALIAS          => 'Dbs-management',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.5.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20814) 0:03:28.14',
                        IFINOCTETS       => '501694593',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1721777690',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1167',
                        IFNAME           => 'vlan.456',
                        IFDESCR          => 'vlan.456',
                        IFALIAS          => 'Scripts-mgmt',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.6.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20894) 0:03:28.94',
                        IFINOCTETS       => '245104104',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '230619437',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1168',
                        IFNAME           => 'vlan.61',
                        IFDESCR          => 'vlan.61',
                        IFALIAS          => 'Logs',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.61.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20852) 0:03:28.52',
                        IFINOCTETS       => '4016228',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1004888929',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1169',
                        IFNAME           => 'vlan.459',
                        IFDESCR          => 'vlan.459',
                        IFALIAS          => 'Apc-power',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.9.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20737) 0:03:27.37',
                        IFINOCTETS       => '563776782',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1022857594',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1170',
                        IFNAME           => 'vlan.460',
                        IFDESCR          => 'vlan.460',
                        IFALIAS          => 'Images-manage',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.10.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20848) 0:03:28.48',
                        IFINOCTETS       => '18482048',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '55865969',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1171',
                        IFNAME           => 'vlan.461',
                        IFDESCR          => 'vlan.461',
                        IFALIAS          => 'Cpp-mgmt',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.11.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20742) 0:03:27.42',
                        IFINOCTETS       => '112157852',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '362904997',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1172',
                        IFNAME           => 'vlan.462',
                        IFDESCR          => 'vlan.462',
                        IFALIAS          => 'Cache-manage',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.12.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20742) 0:03:27.42',
                        IFINOCTETS       => '68752068',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '88964289',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1173',
                        IFNAME           => 'vlan.464',
                        IFDESCR          => 'vlan.464',
                        IFALIAS          => 'PhotoCache-manage',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.14.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20888) 0:03:28.88',
                        IFINOCTETS       => '308548856',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '757924216',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1174',
                        IFNAME           => 'vlan.465',
                        IFDESCR          => 'vlan.465',
                        IFALIAS          => 'Dbh-manage',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.15.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20814) 0:03:28.14',
                        IFINOCTETS       => '267239550',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '481817298',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1175',
                        IFNAME           => 'vlan.466',
                        IFDESCR          => 'vlan.466',
                        IFALIAS          => 'Video-mgmt',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.16.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20916) 0:03:29.16',
                        IFINOCTETS       => '17725992',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '54223624',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1176',
                        IFNAME           => 'vlan.467',
                        IFDESCR          => 'vlan.467',
                        IFALIAS          => 'CppBig-management',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.17.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20814) 0:03:28.14',
                        IFINOCTETS       => '450378108',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '430161475',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1177',
                        IFNAME           => 'vlan.468',
                        IFDESCR          => 'vlan.468',
                        IFALIAS          => 'WwwBda-manage',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.18.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20927) 0:03:29.27',
                        IFINOCTETS       => '61265926',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '60236198',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1178',
                        IFNAME           => 'vlan.469',
                        IFDESCR          => 'vlan.469',
                        IFALIAS          => 'WwwBma-manage',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.19.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20933) 0:03:29.33',
                        IFINOCTETS       => '426489014',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '640915447',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1179',
                        IFNAME           => 'vlan.471',
                        IFDESCR          => 'vlan.471',
                        IFALIAS          => 'WwwWap-manage',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.81.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20937) 0:03:29.37',
                        IFINOCTETS       => '69890328',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '59567432',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1180',
                        IFNAME           => 'vlan.472',
                        IFDESCR          => 'vlan.472',
                        IFALIAS          => 'WwwBiling-mgmt',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.83.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20927) 0:03:29.27',
                        IFINOCTETS       => '50054336',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '48618893',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1181',
                        IFNAME           => 'vlan.473',
                        IFDESCR          => 'vlan.473',
                        IFALIAS          => 'WwwStaff-mgmt',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.24.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20933) 0:03:29.33',
                        IFINOCTETS       => '10641728',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '17655027',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1182',
                        IFNAME           => 'vlan.487',
                        IFDESCR          => 'vlan.487',
                        IFALIAS          => 'Unreg-mgmt',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.87.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20916) 0:03:29.16',
                        IFINOCTETS       => '158667968',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '153608435',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1183',
                        IFNAME           => 'vlan.489',
                        IFDESCR          => 'vlan.489',
                        IFALIAS          => 'Splunk-mgmt',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.89.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20913) 0:03:29.13',
                        IFINOCTETS       => '3955572',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '696273',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1184',
                        IFNAME           => 'vlan.492',
                        IFDESCR          => 'vlan.492',
                        IFALIAS          => 'Partner-mgmt',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.42.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20856) 0:03:28.56',
                        IFINOCTETS       => '10099008',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '6422829',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1185',
                        IFNAME           => 'vlan.497',
                        IFDESCR          => 'vlan.497',
                        IFALIAS          => 'Scriptsbma-manage',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.97.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20913) 0:03:29.13',
                        IFINOCTETS       => '12102842',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '13875866',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1186',
                        IFNAME           => 'vlan.62',
                        IFDESCR          => 'vlan.62',
                        IFALIAS          => 'Logs-mgmt',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.62.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(17935596) 2 days, 1:49:15.96',
                        IFINOCTETS       => '9098062',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '12563663',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1187',
                        IFNAME           => 'ge-7/0/8.0',
                        IFDESCR          => 'ge-7/0/8.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:5b',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(740661416) 85 days, 17:23:34.16',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '130452625',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '115770290',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CDP        => 1,
                            CONNECTION => {
                                IFNUMBER => 'GigabitEthernet 0/48',
                                IFDESCR  => undef,
                                SYSNAME  => 'sw-s50-7-tmk',
                                SYSDESCR => 'Force10 Networks Real Time Operating System Software. Force10 Operating System Version: 1.0. Force10 Application Software Version: 8.3.2.0. Copyright (c) 1999-2010 by Force10 Networks, Inc. Build Time: Wed Jul 7 18:35:25 PDT 2010',
                                SYSMAC   => '00:01:e8:d6:da:86',
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1188',
                        IFNAME           => 'ge-6/0/3.0',
                        IFDESCR          => 'ge-6/0/3.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:42',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(27593) 0:04:35.93',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '620',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1189',
                        IFNAME           => 'ge-6/0/4.0',
                        IFDESCR          => 'ge-6/0/4.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:42',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(27612) 0:04:36.12',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '620',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '21270142',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1190',
                        IFNAME           => 'ge-7/0/47.0',
                        IFDESCR          => 'ge-7/0/47.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.15.100.253',
                        MAC              => '78:19:f7:05:fa:c2',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20726) 0:03:27.26',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1550160',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1086138',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1191',
                        IFNAME           => 'vlan.95',
                        IFDESCR          => 'vlan.95',
                        IFALIAS          => 'mphotos',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.95.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20937) 0:03:29.37',
                        IFINOCTETS       => '7984908',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1537764683',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1192',
                        IFNAME           => 'vlan.205',
                        IFDESCR          => 'vlan.205',
                        IFALIAS          => 'Staging',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.205.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20916) 0:03:29.16',
                        IFINOCTETS       => '15005962',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1525058552',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1193',
                        IFNAME           => 'vlan.488',
                        IFDESCR          => 'vlan.488',
                        IFALIAS          => 'Unreg',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.88.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20916) 0:03:29.16',
                        IFINOCTETS       => '58898437',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3235112286',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1194',
                        IFNAME           => 'vlan.490',
                        IFDESCR          => 'vlan.490',
                        IFALIAS          => 'Splunk',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.90.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20913) 0:03:29.13',
                        IFINOCTETS       => '1112064',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3970833940',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1195',
                        IFNAME           => 'vlan.503',
                        IFDESCR          => 'vlan.503',
                        IFALIAS          => 'Www',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.53.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20927) 0:03:29.27',
                        IFINOCTETS       => '602664233',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1325561218',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1196',
                        IFNAME           => 'vlan.504',
                        IFDESCR          => 'vlan.504',
                        IFALIAS          => 'Dbs',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.54.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20814) 0:03:28.14',
                        IFINOCTETS       => '176642736',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2335926762',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1197',
                        IFNAME           => 'vlan.508',
                        IFDESCR          => 'vlan.508',
                        IFALIAS          => 'Images',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.58.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20848) 0:03:28.48',
                        IFINOCTETS       => '20877632',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3272148862',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1198',
                        IFNAME           => 'vlan.510',
                        IFDESCR          => 'vlan.510',
                        IFALIAS          => 'Cache',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.60.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20741) 0:03:27.41',
                        IFINOCTETS       => '468346374',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4051534346',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1199',
                        IFNAME           => 'vlan.513',
                        IFDESCR          => 'vlan.513',
                        IFALIAS          => 'PhotoCache',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.63.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20888) 0:03:28.88',
                        IFINOCTETS       => '123633875',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3361831130',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1200',
                        IFNAME           => 'vlan.514',
                        IFDESCR          => 'vlan.514',
                        IFALIAS          => 'Dbh',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.64.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20814) 0:03:28.14',
                        IFINOCTETS       => '105413096',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1594317498',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1201',
                        IFNAME           => 'vlan.515',
                        IFDESCR          => 'vlan.515',
                        IFALIAS          => 'Cpp-big',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.65.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20742) 0:03:27.42',
                        IFINOCTETS       => '232493661',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '8920880',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1202',
                        IFNAME           => 'vlan.516',
                        IFDESCR          => 'vlan.516',
                        IFALIAS          => 'Vide0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.66.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20916) 0:03:29.16',
                        IFINOCTETS       => '7100480',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1544196754',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1203',
                        IFNAME           => 'vlan.528',
                        IFDESCR          => 'vlan.528',
                        IFALIAS          => 'WwwBda',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.78.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20927) 0:03:29.27',
                        IFINOCTETS       => '1659345974',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1907467604',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1204',
                        IFNAME           => 'vlan.529',
                        IFDESCR          => 'vlan.529',
                        IFALIAS          => 'WwwBma',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.79.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20932) 0:03:29.32',
                        IFINOCTETS       => '185547721',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '82554520',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1205',
                        IFNAME           => 'vlan.532',
                        IFDESCR          => 'vlan.532',
                        IFALIAS          => 'WwwBilling',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.84.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20932) 0:03:29.32',
                        IFINOCTETS       => '210733878',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2581285992',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1206',
                        IFNAME           => 'vlan.533',
                        IFDESCR          => 'vlan.533',
                        IFALIAS          => 'WwwStaff',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.33.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20933) 0:03:29.33',
                        IFINOCTETS       => '8081024',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '160671622',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1207',
                        IFNAME           => 'vlan.543',
                        IFDESCR          => 'vlan.543',
                        IFALIAS          => 'PartnerNet',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.93.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20888) 0:03:28.88',
                        IFINOCTETS       => '3430796',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2516556464',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1208',
                        IFNAME           => 'vlan.546',
                        IFDESCR          => 'vlan.546',
                        IFALIAS          => 'Proxy',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.96.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20888) 0:03:28.88',
                        IFINOCTETS       => '7575499',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1945226198',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1209',
                        IFNAME           => 'ge-7/0/12.0',
                        IFDESCR          => 'ge-7/0/12.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:5f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(740656306) 85 days, 17:22:43.06',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:10:f3:29:8a:fc',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1210',
                        IFNAME           => 'ge-7/0/13.0',
                        IFDESCR          => 'ge-7/0/13.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.172.1',
                        MAC              => '78:19:f7:05:fa:a0',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(473084606) 54 days, 18:07:26.06',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1568781915',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '731653128',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1211',
                        IFNAME           => 'ge-7/0/14.0',
                        IFDESCR          => 'ge-7/0/14.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:61',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20646) 0:03:26.46',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '7027860',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '25031810',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:0d:5d:00:00:01',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1212',
                        IFNAME           => 'vlan.485',
                        IFDESCR          => 'vlan.485',
                        IFALIAS          => 'Bphotos-mgmt',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.85.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20741) 0:03:27.41',
                        IFINOCTETS       => '289419058',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '367620037',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1213',
                        IFNAME           => 'vlan.502',
                        IFDESCR          => 'vlan.502',
                        IFALIAS          => 'Main-servers',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.52.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20852) 0:03:28.52',
                        IFINOCTETS       => '349787295',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '334422005',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1214',
                        IFNAME           => 'vlan.505',
                        IFDESCR          => 'vlan.505',
                        IFALIAS          => 'Scripts',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.55.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20894) 0:03:28.94',
                        IFINOCTETS       => '105888491',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3706447934',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1215',
                        IFNAME           => 'vlan.480',
                        IFDESCR          => 'vlan.480',
                        IFALIAS          => 'Bphotos',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.86.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20743) 0:03:27.43',
                        IFINOCTETS       => '138061287',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '361443439',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1216',
                        IFNAME           => 'ae27.0',
                        IFDESCR          => 'ae27.0',
                        IFTYPE           => '161',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1e',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(638821206) 73 days, 22:30:12.06',
                        IFINOCTETS       => '25805326',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '31469940',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    'c8:1f:66:ce:75:7f',
                                    'c8:1f:66:ce:75:cb',
                                    'c8:1f:66:ce:99:c5',
                                    'c8:1f:66:ce:a0:b6',
                                    'c8:1f:66:ce:41:a0',
                                    'c8:1f:66:d0:66:b1',
                                    'c8:1f:66:d0:68:c0',
                                    'c8:1f:66:d0:74:cc',
                                    'c8:1f:66:d0:8b:01',
                                    'c8:1f:66:d0:9a:44',
                                    'c8:1f:66:d0:15:91',
                                    'c8:1f:66:d0:2b:5f',
                                    'c8:1f:66:d0:4a:5e',
                                    'c8:1f:66:d1:97:7a',
                                    'c8:1f:66:d1:9b:92',
                                    'c8:1f:66:d2:17:b1',
                                    'c8:1f:66:d2:1f:6c',
                                    '88:e0:f3:b0:68:01',
                                    '74:86:7a:ed:84:30',
                                    '74:86:7a:dd:b1:56',
                                    '74:86:7a:dd:b4:da',
                                    '74:86:7a:dd:e1:92',
                                    '74:86:7a:dd:e1:94',
                                    '74:86:7a:dd:e2:8a',
                                    '74:86:7a:dd:e8:d6',
                                    'c8:1f:66:d0:66:cd',
                                    'c8:1f:66:d0:75:d1',
                                    'c8:1f:66:d0:75:e9',
                                    'c8:1f:66:d0:7b:66',
                                    'c8:1f:66:d0:7b:62',
                                    'c8:1f:66:d0:2c:d5',
                                    'c8:1f:66:d0:2d:0b',
                                    'c8:1f:66:d0:2d:03',
                                    'c8:1f:66:d0:33:c3',
                                    'c8:1f:66:d0:3b:14',
                                    'c8:1f:66:d0:3e:3b',
                                    'c8:1f:66:d0:41:6a',
                                    'c8:1f:66:d0:41:62',
                                    'c8:1f:66:d0:4c:83',
                                    'c8:1f:66:d0:53:86',
                                    'c8:1f:66:d0:53:26',
                                    'c8:1f:66:d0:53:2e',
                                    'c8:1f:66:d0:59:d0',
                                ],
                            }
                        }
                    },
                    {
                        IFNUMBER         => '1217',
                        IFNAME           => 'vlan.75',
                        IFDESCR          => 'vlan.75',
                        IFALIAS          => 'Shell',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.75.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(675293527) 78 days, 3:48:55.27',
                        IFINOCTETS       => '556768',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '749568178',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1218',
                        IFNAME           => 'pime.32769',
                        IFDESCR          => 'pime.32769',
                        IFTYPE           => '131',
                        IFSPEED          => '4294967295',
                        IFMTU            => '2147483647',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(773971864) 89 days, 13:55:18.64',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1219',
                        IFNAME           => 'vlan.603',
                        IFDESCR          => 'vlan.603',
                        IFALIAS          => 'Noreply-srv',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.202.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20856) 0:03:28.56',
                        IFINOCTETS       => '451456964',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '384101493',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1220',
                        IFNAME           => 'vlan.608',
                        IFDESCR          => 'vlan.608',
                        IFALIAS          => 'Scriptsbma',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.208.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20911) 0:03:29.11',
                        IFINOCTETS       => '14028952',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3652695771',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1221',
                        IFNAME           => 'ae26.0',
                        IFDESCR          => 'ae26.0',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(286) 0:00:02.86',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1222',
                        IFNAME           => 'ge-6/0/17.0',
                        IFDESCR          => 'ge-6/0/17.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1d',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11620) 0:01:56.20',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1223',
                        IFNAME           => 'vlan.520',
                        IFDESCR          => 'vlan.520',
                        IFALIAS          => 'Plyserve3',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.70.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20888) 0:03:28.88',
                        IFINOCTETS       => '243264',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '98177132',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1224',
                        IFNAME           => 'vlan.523',
                        IFDESCR          => 'vlan.523',
                        IFALIAS          => 'Polyserve4',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.73.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20888) 0:03:28.88',
                        IFINOCTETS       => '243072',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '78110444',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1225',
                        IFNAME           => 'vlan.509',
                        IFDESCR          => 'vlan.509',
                        IFALIAS          => 'Cpp',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.68.254',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20742) 0:03:27.42',
                        IFINOCTETS       => '177338226',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '774042328',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1226',
                        IFNAME           => 'vlan.531',
                        IFDESCR          => 'vlan.531',
                        IFALIAS          => 'WwwWap',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.82.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20933) 0:03:29.33',
                        IFINOCTETS       => '31795506',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2922963221',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1227',
                        IFNAME           => 'vlan.527',
                        IFDESCR          => 'vlan.527',
                        IFALIAS          => 'Bilinfo',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.77.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20741) 0:03:27.41',
                        IFINOCTETS       => '15859048',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '222409315',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1228',
                        IFNAME           => 'vlan.526',
                        IFDESCR          => 'vlan.526',
                        IFALIAS          => 'Public',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.76.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20894) 0:03:28.94',
                        IFINOCTETS       => '1655560',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3807647321',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1229',
                        IFNAME           => 'vlan.542',
                        IFDESCR          => 'vlan.542',
                        IFALIAS          => 'ScriptsBilling',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.92.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20894) 0:03:28.94',
                        IFINOCTETS       => '22023425',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2608527965',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1230',
                        IFNAME           => 'vlan.600',
                        IFDESCR          => 'vlan.600',
                        IFALIAS          => 'Nap-intraroute',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.0.20',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20852) 0:03:28.52',
                        IFINOCTETS       => '110302006',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1999956632',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1231',
                        IFNAME           => 'ge-6/0/0',
                        IFDESCR          => 'ge-6/0/0',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:23',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11554) 0:01:55.54',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1232',
                        IFNAME           => 'ge-6/0/1',
                        IFDESCR          => 'ge-6/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:24',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11555) 0:01:55.55',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1233',
                        IFNAME           => 'ge-6/0/3',
                        IFDESCR          => 'ge-6/0/3',
                        IFALIAS          => 'To fw-srx1400-tmk node1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:42',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(27593) 0:04:35.93',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '990564736',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1819324912',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1234',
                        IFNAME           => 'ge-6/0/4',
                        IFDESCR          => 'ge-6/0/4',
                        IFALIAS          => 'To fw-srx1400-tmk node1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:42',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(27612) 0:04:36.12',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '990564736',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1400426194',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1235',
                        IFNAME           => 'ge-6/0/2',
                        IFDESCR          => 'ge-6/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:25',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11566) 0:01:55.66',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1236',
                        IFNAME           => 'ge-6/0/5',
                        IFDESCR          => 'ge-6/0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:28',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11567) 0:01:55.67',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1237',
                        IFNAME           => 'ge-6/0/6',
                        IFDESCR          => 'ge-6/0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:29',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11585) 0:01:55.85',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1238',
                        IFNAME           => 'ge-6/0/7',
                        IFDESCR          => 'ge-6/0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:2a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11585) 0:01:55.85',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1239',
                        IFNAME           => 'ge-6/0/8',
                        IFDESCR          => 'ge-6/0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:2b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11586) 0:01:55.86',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1240',
                        IFNAME           => 'ge-6/0/9',
                        IFDESCR          => 'ge-6/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:2c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11587) 0:01:55.87',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1241',
                        IFNAME           => 'ge-6/0/10',
                        IFDESCR          => 'ge-6/0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:2d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11594) 0:01:55.94',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1242',
                        IFNAME           => 'ge-6/0/11',
                        IFDESCR          => 'ge-6/0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:2e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11594) 0:01:55.94',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1243',
                        IFNAME           => 'ge-6/0/12',
                        IFDESCR          => 'ge-6/0/12',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:2f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11594) 0:01:55.94',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1244',
                        IFNAME           => 'ge-6/0/13',
                        IFDESCR          => 'ge-6/0/13',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:30',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11604) 0:01:56.04',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1245',
                        IFNAME           => 'ge-6/0/14',
                        IFDESCR          => 'ge-6/0/14',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:31',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11604) 0:01:56.04',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1246',
                        IFNAME           => 'ge-6/0/15',
                        IFDESCR          => 'ge-6/0/15',
                        IFALIAS          => 'ae25 members',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(11604) 0:01:56.04',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1247',
                        IFNAME           => 'ge-6/0/16',
                        IFDESCR          => 'ge-6/0/16',
                        IFALIAS          => 'ae25 members',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(11614) 0:01:56.14',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1248',
                        IFNAME           => 'ge-6/0/17',
                        IFDESCR          => 'ge-6/0/17',
                        IFALIAS          => 'ae26 members',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(11614) 0:01:56.14',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1249',
                        IFNAME           => 'ge-6/0/18',
                        IFDESCR          => 'ge-6/0/18',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:35',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11624) 0:01:56.24',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1250',
                        IFNAME           => 'ge-6/0/19',
                        IFDESCR          => 'ge-6/0/19',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:36',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11625) 0:01:56.25',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1251',
                        IFNAME           => 'ge-6/0/20',
                        IFDESCR          => 'ge-6/0/20',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:37',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11634) 0:01:56.34',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1252',
                        IFNAME           => 'ge-6/0/21',
                        IFDESCR          => 'ge-6/0/21',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:38',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11634) 0:01:56.34',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1253',
                        IFNAME           => 'ge-6/0/22',
                        IFDESCR          => 'ge-6/0/22',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:39',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11645) 0:01:56.45',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1254',
                        IFNAME           => 'ge-6/0/23',
                        IFDESCR          => 'ge-6/0/23',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:3a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11645) 0:01:56.45',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1255',
                        IFNAME           => 'ge-6/0/24',
                        IFDESCR          => 'ge-6/0/24',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:3b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11645) 0:01:56.45',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1256',
                        IFNAME           => 'ge-6/0/25',
                        IFDESCR          => 'ge-6/0/25',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:3c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11655) 0:01:56.55',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1257',
                        IFNAME           => 'ge-6/0/26',
                        IFDESCR          => 'ge-6/0/26',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:3d',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11655) 0:01:56.55',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1258',
                        IFNAME           => 'ge-6/0/27',
                        IFDESCR          => 'ge-6/0/27',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:3e',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11655) 0:01:56.55',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1259',
                        IFNAME           => 'ge-6/0/28',
                        IFDESCR          => 'ge-6/0/28',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:3f',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11655) 0:01:56.55',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1260',
                        IFNAME           => 'ge-6/0/29',
                        IFDESCR          => 'ge-6/0/29',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:40',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11655) 0:01:56.55',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1261',
                        IFNAME           => 'ge-6/0/30',
                        IFDESCR          => 'ge-6/0/30',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:41',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11657) 0:01:56.57',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1262',
                        IFNAME           => 'ge-6/0/31',
                        IFDESCR          => 'ge-6/0/31',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:42',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11665) 0:01:56.65',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1263',
                        IFNAME           => 'ge-6/0/32',
                        IFDESCR          => 'ge-6/0/32',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:43',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11665) 0:01:56.65',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1264',
                        IFNAME           => 'ge-6/0/33',
                        IFDESCR          => 'ge-6/0/33',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:44',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11666) 0:01:56.66',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1265',
                        IFNAME           => 'ge-6/0/34',
                        IFDESCR          => 'ge-6/0/34',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:45',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11676) 0:01:56.76',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1266',
                        IFNAME           => 'ge-6/0/35',
                        IFDESCR          => 'ge-6/0/35',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:46',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11676) 0:01:56.76',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1267',
                        IFNAME           => 'ge-6/0/36',
                        IFDESCR          => 'ge-6/0/36',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:47',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(506036284) 58 days, 13:39:22.84',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1268',
                        IFNAME           => 'ge-6/0/37',
                        IFDESCR          => 'ge-6/0/37',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:48',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11676) 0:01:56.76',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1269',
                        IFNAME           => 'ge-6/0/38',
                        IFDESCR          => 'ge-6/0/38',
                        IFALIAS          => 'To Pci-asv-new-appliance',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:49',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(27592) 0:04:35.92',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '527569750',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '865292033',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1270',
                        IFNAME           => 'ge-6/0/39',
                        IFDESCR          => 'ge-6/0/39',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fb:4a',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11696) 0:01:56.96',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1271',
                        IFNAME           => 'ge-6/0/40',
                        IFDESCR          => 'ge-6/0/40',
                        IFALIAS          => 'Link toPrague',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:8b',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '2',
                        IFLASTCHANGE     => '(164054469) 18 days, 23:42:24.69',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '810536578',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2065355950',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1272',
                        IFNAME           => 'ge-6/0/40.0',
                        IFDESCR          => 'ge-6/0/40.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.15.15.2',
                        MAC              => '78:19:f7:05:fa:8b',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(164054469) 18 days, 23:42:24.69',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '427172110',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '378643573',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1273',
                        IFNAME           => 'vlan.8',
                        IFDESCR          => 'vlan.8',
                        IFALIAS          => 'BackupX-manage',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.8.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20741) 0:03:27.41',
                        IFINOCTETS       => '19488118',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '242161340',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1274',
                        IFNAME           => 'vlan.7',
                        IFDESCR          => 'vlan.7',
                        IFALIAS          => 'BackupX',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.7.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(20741) 0:03:27.41',
                        IFINOCTETS       => '6100406',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1649450892',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1275',
                        IFNAME           => 'ge-7/0/17.0',
                        IFDESCR          => 'ge-7/0/17.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1d',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11214) 0:01:52.14',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1276',
                        IFNAME           => 'ae25.0',
                        IFDESCR          => 'ae25.0',
                        IFTYPE           => '161',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1c',
                        IFSTATUS         => '2',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(286) 0:00:02.86',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1277',
                        IFNAME           => 'ge-6/0/15.0',
                        IFDESCR          => 'ge-6/0/15.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1c',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11605) 0:01:56.05',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1278',
                        IFNAME           => 'ge-6/0/16.0',
                        IFDESCR          => 'ge-6/0/16.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1c',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11615) 0:01:56.15',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1279',
                        IFNAME           => 'ge-7/0/15.0',
                        IFDESCR          => 'ge-7/0/15.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1c',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11201) 0:01:52.01',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1280',
                        IFNAME           => 'ge-7/0/16.0',
                        IFDESCR          => 'ge-7/0/16.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1c',
                        IFSTATUS         => '7',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(11213) 0:01:52.13',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1281',
                        IFNAME           => 'ge-6/0/42',
                        IFDESCR          => 'ge-6/0/42',
                        IFALIAS          => 'Link to Prague',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:8d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(289594003) 33 days, 12:25:40.03',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '1403384324',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2498415502',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1282',
                        IFNAME           => 'ge-6/0/42.0',
                        IFDESCR          => 'ge-6/0/42.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.15.15.14',
                        MAC              => '78:19:f7:05:fa:8d',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(289594003) 33 days, 12:25:40.03',
                        IFPORTDUPLEX     => '3',
                        IFINOCTETS       => '3086240939',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2127724837',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1283',
                        IFNAME           => 'vlan.209',
                        IFDESCR          => 'vlan.209',
                        IFALIAS          => 'Impala-mgmt',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.209.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(578010883) 66 days, 21:35:08.83',
                        IFINOCTETS       => '14919938',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '18674660',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1284',
                        IFNAME           => 'vlan.26',
                        IFDESCR          => 'vlan.26',
                        IFALIAS          => 'Social-mgmt',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.26.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(693259292) 80 days, 5:43:12.92',
                        IFINOCTETS       => '9640756',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '12515482',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1285',
                        IFNAME           => 'vlan.27',
                        IFDESCR          => 'vlan.27',
                        IFALIAS          => 'Social',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        IP               => '10.20.27.1',
                        MAC              => '78:19:f7:05:fa:01',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(693259292) 80 days, 5:43:12.92',
                        IFINOCTETS       => '10278005',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1430267746',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '1286',
                        IFNAME           => 'ae28.0',
                        IFDESCR          => 'ae28.0',
                        IFTYPE           => '161',
                        IFSPEED          => '4294967295',
                        IFMTU            => '1514',
                        MAC              => '78:19:f7:05:fa:1f',
                        IFSTATUS         => '1',
                        IFINTERNALSTATUS => '1',
                        IFLASTCHANGE     => '(751001845) 86 days, 22:06:58.45',
                        IFINOCTETS       => '310211898',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1622414',
                        IFOUTERRORS      => '0',
                        CONNECTIONS      => {
                            CONNECTION => {
                                MAC => [
                                    '00:23:e9:17:7e:06',
                                    '00:23:e9:17:7e:03',
                                    '00:23:e9:17:7e:04',
                                    '00:23:e9:17:7e:10',
                                    '00:23:e9:17:7e:08',
                                    '00:23:e9:17:7e:0a',
                                    '00:23:e9:17:7e:0b',
                                    '00:23:e9:17:7e:0c',
                                    '00:23:e9:17:7e:0d',
                                    '00:23:e9:17:7e:0f',
                                    '00:23:e9:17:7e:07',
                                    '00:23:e9:17:7e:11',
                                    '00:23:e9:17:7e:12',
                                    '00:23:e9:17:7e:15',
                                    '00:23:e9:17:7e:17',
                                    '00:23:e9:17:7e:16',
                                    '00:23:e9:17:7e:18',
                                    '00:23:e9:17:7e:02',
                                    '00:23:e9:17:7e:1a',
                                    '00:23:e9:17:7e:1c',
                                    '00:23:e9:17:7e:1d',
                                    '00:23:e9:17:7e:1f',
                                    '00:23:e9:17:7e:1e',
                                    '00:23:e9:17:7e:19',
                                    '00:23:e9:17:7e:1b',
                                    '00:23:e9:17:7e:05',
                                    '00:23:e9:17:7e:0e',
                                ],
                            }
                        }
                    },
                ]
            },
        },
    ],
    'juniper/srx3400.01.walk' => [
        {
            TYPE         => 'NETWORKING',
            MANUFACTURER => 'Juniper',
            MODEL        => 'SRX3400',
            DESCRIPTION  => 'Routeur Dauphine Juniper SRX3400',

            SNMPHOSTNAME => 'Dauphine-routeur',
            SERIAL       => 'AA2009AA0007',
            MAC          => '00:21:59:86:a8:00',
        },
        {
            INFO => {
                ID           => undef,
                TYPE         => 'NETWORKING',
                MANUFACTURER => 'Juniper',
                MODEL        => 'SRX3400',
                COMMENTS     => 'Routeur Dauphine Juniper SRX3400',
                NAME         => 'Dauphine-routeur',
                SERIAL       => 'AA2009AA0007',
                MAC          => '00:21:59:86:a8:00',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFNAME           => 'fxp0',
                        IFDESCR          => 'fxp0',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:92:fb:7f',
                        IFLASTCHANGE     => '(15) 0:00:00.15',
                        IFINOCTETS       => '2950589543',
                        IFINERRORS       => '31',
                        IFOUTOCTETS      => '2919894214',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '4',
                        IFNAME           => 'lsi',
                        IFDESCR          => 'lsi',
                        IFTYPE           => '150',
                        IFSPEED          => '0',
                        IFMTU            => '1496',
                        IFLASTCHANGE     => '(22) 0:00:00.22',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5',
                        IFNAME           => 'dsc',
                        IFDESCR          => 'dsc',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(11) 0:00:00.11',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '6',
                        IFNAME           => 'lo0',
                        IFDESCR          => 'lo0',
                        IFTYPE           => '24',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(20) 0:00:00.20',
                        IFINOCTETS       => '321074',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '321074',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '7',
                        IFNAME           => 'tap',
                        IFDESCR          => 'tap',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(26) 0:00:00.26',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '8',
                        IFNAME           => 'gre',
                        IFDESCR          => 'gre',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(16) 0:00:00.16',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '9',
                        IFNAME           => 'ipip',
                        IFDESCR          => 'ipip',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(19) 0:00:00.19',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10',
                        IFNAME           => 'pime',
                        IFDESCR          => 'pime',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(24) 0:00:00.24',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '11',
                        IFNAME           => 'pimd',
                        IFDESCR          => 'pimd',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(23) 0:00:00.23',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '12',
                        IFNAME           => 'mtun',
                        IFDESCR          => 'mtun',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(23) 0:00:00.23',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '13',
                        IFNAME           => 'fxp0.0',
                        IFDESCR          => 'fxp0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:21:59:92:fb:7f',
                        IFLASTCHANGE     => '(15) 0:00:00.15',
                        IFINOCTETS       => '2950589543',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2919895216',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '17',
                        IFNAME           => 'em0',
                        IFDESCR          => 'em0',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '02:00:00:00:00:04',
                        IFLASTCHANGE     => '(12) 0:00:00.12',
                        IFINOCTETS       => '313098609',
                        IFINERRORS       => '147',
                        IFOUTOCTETS      => '177440238',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '18',
                        IFNAME           => 'em0.0',
                        IFDESCR          => 'em0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '02:00:00:00:00:04',
                        IFLASTCHANGE     => '(12) 0:00:00.12',
                        IFINOCTETS       => '313098731',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1033363945',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '21',
                        IFNAME           => 'lo0.16384',
                        IFDESCR          => 'lo0.16384',
                        IFTYPE           => '24',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(21) 0:00:00.21',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '22',
                        IFNAME           => 'lo0.16385',
                        IFDESCR          => 'lo0.16385',
                        IFTYPE           => '24',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(21) 0:00:00.21',
                        IFINOCTETS       => '321074',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '321074',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '23',
                        IFNAME           => 'em1',
                        IFDESCR          => 'em1',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '02:00:01:00:00:04',
                        IFLASTCHANGE     => '(14) 0:00:00.14',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '24',
                        IFNAME           => 'em1.0',
                        IFDESCR          => 'em1.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '02:00:01:00:00:04',
                        IFLASTCHANGE     => '(14) 0:00:00.14',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '501',
                        IFNAME           => 'irb',
                        IFDESCR          => 'irb',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a8:20',
                        IFLASTCHANGE     => '(19) 0:00:00.19',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '502',
                        IFNAME           => 'ppd0',
                        IFDESCR          => 'ppd0',
                        IFTYPE           => '131',
                        IFSPEED          => '800000000',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(24) 0:00:00.24',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '503',
                        IFNAME           => 'ppe0',
                        IFDESCR          => 'ppe0',
                        IFTYPE           => '131',
                        IFSPEED          => '800000000',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(25) 0:00:00.25',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '504',
                        IFNAME           => 'st0',
                        IFDESCR          => 'st0',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '9192',
                        IFLASTCHANGE     => '(25) 0:00:00.25',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '505',
                        IFNAME           => 'ge-0/0/0',
                        IFDESCR          => 'ge-0/0/0',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '00:21:59:86:a4:00',
                        IFLASTCHANGE     => '(10578) 0:01:45.78',
                        IFINOCTETS       => '3769901473',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '383176232',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '506',
                        IFNAME           => 'ge-0/0/1',
                        IFDESCR          => 'ge-0/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '00:21:59:86:a4:01',
                        IFLASTCHANGE     => '(136375937) 15 days, 18:49:19.37',
                        IFINOCTETS       => '3122491056',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '693634267',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '507',
                        IFNAME           => 'ge-0/0/2',
                        IFDESCR          => 'ge-0/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a4:02',
                        IFLASTCHANGE     => '(10248) 0:01:42.48',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '508',
                        IFNAME           => 'ge-0/0/3',
                        IFDESCR          => 'ge-0/0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a4:03',
                        IFLASTCHANGE     => '(10250) 0:01:42.50',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '509',
                        IFNAME           => 'ge-0/0/4',
                        IFDESCR          => 'ge-0/0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a4:04',
                        IFLASTCHANGE     => '(10251) 0:01:42.51',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '510',
                        IFNAME           => 'ge-0/0/5',
                        IFDESCR          => 'ge-0/0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a4:05',
                        IFLASTCHANGE     => '(10254) 0:01:42.54',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '511',
                        IFNAME           => 'ge-0/0/6',
                        IFDESCR          => 'ge-0/0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a4:06',
                        IFLASTCHANGE     => '(10255) 0:01:42.55',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '512',
                        IFNAME           => 'ge-0/0/7',
                        IFDESCR          => 'ge-0/0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a4:07',
                        IFLASTCHANGE     => '(10257) 0:01:42.57',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '513',
                        IFNAME           => 'ge-0/0/8',
                        IFDESCR          => 'ge-0/0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a4:08',
                        IFLASTCHANGE     => '(10263) 0:01:42.63',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '514',
                        IFNAME           => 'ge-0/0/9',
                        IFDESCR          => 'ge-0/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a4:09',
                        IFLASTCHANGE     => '(10267) 0:01:42.67',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '515',
                        IFNAME           => 'ge-0/0/10',
                        IFDESCR          => 'ge-0/0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a4:0a',
                        IFLASTCHANGE     => '(10270) 0:01:42.70',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '516',
                        IFNAME           => 'ge-0/0/11',
                        IFDESCR          => 'ge-0/0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a4:0b',
                        IFLASTCHANGE     => '(10273) 0:01:42.73',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '518',
                        IFNAME           => 'ge-0/0/0.2',
                        IFDESCR          => 'ge-0/0/0.2',
                        IFTYPE           => '135',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:21:59:86:a4:00',
                        IFLASTCHANGE     => '(10578) 0:01:45.78',
                        IFINOCTETS       => '2022954353',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3916025718',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '520',
                        IFNAME           => 'ge-0/0/0.20',
                        IFDESCR          => 'ge-0/0/0.20',
                        IFTYPE           => '135',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:21:59:86:a4:00',
                        IFLASTCHANGE     => '(10578) 0:01:45.78',
                        IFINOCTETS       => '739787034',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3659632488',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '521',
                        IFNAME           => 'ge-0/0/0.41',
                        IFDESCR          => 'ge-0/0/0.41',
                        IFTYPE           => '135',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:21:59:86:a4:00',
                        IFLASTCHANGE     => '(10578) 0:01:45.78',
                        IFINOCTETS       => '3895378981',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1432181463',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '522',
                        IFNAME           => 'ge-0/0/0.44',
                        IFDESCR          => 'ge-0/0/0.44',
                        IFTYPE           => '135',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:21:59:86:a4:00',
                        IFLASTCHANGE     => '(10578) 0:01:45.78',
                        IFINOCTETS       => '840826462',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3838236184',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '523',
                        IFNAME           => 'ge-0/0/0.32767',
                        IFDESCR          => 'ge-0/0/0.32767',
                        IFTYPE           => '135',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '00:21:59:86:a4:00',
                        IFLASTCHANGE     => '(10578) 0:01:45.78',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '524',
                        IFNAME           => 'ge-0/0/0.21',
                        IFDESCR          => 'ge-0/0/0.21',
                        IFTYPE           => '135',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:21:59:86:a4:00',
                        IFLASTCHANGE     => '(10578) 0:01:45.78',
                        IFINOCTETS       => '621294388',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '536207076',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '525',
                        IFNAME           => 'ge-0/0/7.0',
                        IFDESCR          => 'ge-0/0/7.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:21:59:86:a4:07',
                        IFLASTCHANGE     => '(10259) 0:01:42.59',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '526',
                        IFNAME           => 'mt-6/0/0',
                        IFDESCR          => 'mt-6/0/0',
                        IFTYPE           => '131',
                        IFSPEED          => '800000000',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(21982) 0:03:39.82',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '532',
                        IFNAME           => 'ge-0/0/1.955',
                        IFDESCR          => 'ge-0/0/1.955',
                        IFTYPE           => '135',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:21:59:86:a4:01',
                        IFLASTCHANGE     => '(136375937) 15 days, 18:49:19.37',
                        IFINOCTETS       => '3450815532',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '706083052',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '533',
                        IFNAME           => 'ge-0/0/1.32767',
                        IFDESCR          => 'ge-0/0/1.32767',
                        IFTYPE           => '135',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '00:21:59:86:a4:01',
                        IFLASTCHANGE     => '(136375937) 15 days, 18:49:19.37',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        },
    ],
    'juniper/srx3400.02.walk' => [
        {
            TYPE         => 'NETWORKING',
            MANUFACTURER => 'Juniper',
            MODEL        => 'SRX3400',
            DESCRIPTION  => 'Routeur Dauphine Juniper SRX3400',

            SNMPHOSTNAME => 'Dauphine-routeur',
            SERIAL       => 'AA2009AA0007',
            MAC          => '00:21:59:86:a8:00',
        },
        {
            INFO => {
                ID           => undef,
                TYPE         => 'NETWORKING',
                MANUFACTURER => 'Juniper',
                MODEL        => 'SRX3400',
                COMMENTS     => 'Routeur Dauphine Juniper SRX3400',
                NAME         => 'Dauphine-routeur',
                SERIAL       => 'AA2009AA0007',
                MAC          => '00:21:59:86:a8:00',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFNAME           => 'fxp0',
                        IFDESCR          => 'fxp0',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:92:fb:7f',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '1173134983',
                        IFINERRORS       => '1',
                        IFOUTOCTETS      => '3910542950',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '4',
                        IFNAME           => 'lsi',
                        IFDESCR          => 'lsi',
                        IFTYPE           => '150',
                        IFSPEED          => '0',
                        IFMTU            => '1496',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5',
                        IFNAME           => 'dsc',
                        IFDESCR          => 'dsc',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '6',
                        IFNAME           => 'lo0',
                        IFDESCR          => 'lo0',
                        IFTYPE           => '24',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '928670',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '928670',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '7',
                        IFNAME           => 'tap',
                        IFDESCR          => 'tap',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '8',
                        IFNAME           => 'gre',
                        IFDESCR          => 'gre',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '9',
                        IFNAME           => 'ipip',
                        IFDESCR          => 'ipip',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10',
                        IFNAME           => 'pime',
                        IFDESCR          => 'pime',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '11',
                        IFNAME           => 'pimd',
                        IFDESCR          => 'pimd',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '12',
                        IFNAME           => 'mtun',
                        IFDESCR          => 'mtun',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '13',
                        IFNAME           => 'fxp0.0',
                        IFDESCR          => 'fxp0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:21:59:92:fb:7f',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '1173135843',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3910544176',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '17',
                        IFNAME           => 'em0',
                        IFDESCR          => 'em0',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '02:00:00:00:00:04',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '1940315607',
                        IFINERRORS       => '205',
                        IFOUTOCTETS      => '3803610000',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '18',
                        IFNAME           => 'em0.0',
                        IFDESCR          => 'em0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '02:00:00:00:00:04',
                        IFLASTCHANGE     => '(6) 0:00:00.06',
                        IFINOCTETS       => '1940315607',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '2360872742',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '21',
                        IFNAME           => 'lo0.16384',
                        IFDESCR          => 'lo0.16384',
                        IFTYPE           => '24',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(9) 0:00:00.09',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '22',
                        IFNAME           => 'lo0.16385',
                        IFDESCR          => 'lo0.16385',
                        IFTYPE           => '24',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(10) 0:00:00.10',
                        IFINOCTETS       => '928670',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '928670',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '23',
                        IFNAME           => 'em1',
                        IFDESCR          => 'em1',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '02:00:01:00:00:04',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '24',
                        IFNAME           => 'em1.0',
                        IFDESCR          => 'em1.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '02:00:01:00:00:04',
                        IFLASTCHANGE     => '(7) 0:00:00.07',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '501',
                        IFNAME           => 'irb',
                        IFDESCR          => 'irb',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a8:20',
                        IFLASTCHANGE     => '(8) 0:00:00.08',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '502',
                        IFNAME           => 'ppd0',
                        IFDESCR          => 'ppd0',
                        IFTYPE           => '131',
                        IFSPEED          => '800000000',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(11) 0:00:00.11',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '503',
                        IFNAME           => 'ppe0',
                        IFDESCR          => 'ppe0',
                        IFTYPE           => '131',
                        IFSPEED          => '800000000',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(11) 0:00:00.11',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '504',
                        IFNAME           => 'st0',
                        IFDESCR          => 'st0',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '9192',
                        IFLASTCHANGE     => '(12) 0:00:00.12',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '505',
                        IFNAME           => 'ge-0/0/0',
                        IFDESCR          => 'ge-0/0/0',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '00:21:59:86:a4:00',
                        IFLASTCHANGE     => '(10781) 0:01:47.81',
                        IFINOCTETS       => '570030832',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4148697728',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '506',
                        IFNAME           => 'ge-0/0/1',
                        IFDESCR          => 'ge-0/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '00:21:59:86:a4:01',
                        IFLASTCHANGE     => '(10881) 0:01:48.81',
                        IFINOCTETS       => '2935950780',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1019830367',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '507',
                        IFNAME           => 'ge-0/0/2',
                        IFDESCR          => 'ge-0/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a4:02',
                        IFLASTCHANGE     => '(10362) 0:01:43.62',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '508',
                        IFNAME           => 'ge-0/0/3',
                        IFDESCR          => 'ge-0/0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a4:03',
                        IFLASTCHANGE     => '(10364) 0:01:43.64',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '509',
                        IFNAME           => 'ge-0/0/4',
                        IFDESCR          => 'ge-0/0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a4:04',
                        IFLASTCHANGE     => '(10366) 0:01:43.66',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '510',
                        IFNAME           => 'ge-0/0/5',
                        IFDESCR          => 'ge-0/0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a4:05',
                        IFLASTCHANGE     => '(10368) 0:01:43.68',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '511',
                        IFNAME           => 'ge-0/0/6',
                        IFDESCR          => 'ge-0/0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a4:06',
                        IFLASTCHANGE     => '(10370) 0:01:43.70',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '512',
                        IFNAME           => 'ge-0/0/7',
                        IFDESCR          => 'ge-0/0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a4:07',
                        IFLASTCHANGE     => '(10372) 0:01:43.72',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '513',
                        IFNAME           => 'ge-0/0/8',
                        IFDESCR          => 'ge-0/0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a4:08',
                        IFLASTCHANGE     => '(10378) 0:01:43.78',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '514',
                        IFNAME           => 'ge-0/0/9',
                        IFDESCR          => 'ge-0/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a4:09',
                        IFLASTCHANGE     => '(10379) 0:01:43.79',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '515',
                        IFNAME           => 'ge-0/0/10',
                        IFDESCR          => 'ge-0/0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a4:0a',
                        IFLASTCHANGE     => '(10381) 0:01:43.81',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '516',
                        IFNAME           => 'ge-0/0/11',
                        IFDESCR          => 'ge-0/0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a4:0b',
                        IFLASTCHANGE     => '(10386) 0:01:43.86',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '518',
                        IFNAME           => 'ge-0/0/0.2',
                        IFDESCR          => 'ge-0/0/0.2',
                        IFTYPE           => '135',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:21:59:86:a4:00',
                        IFLASTCHANGE     => '(10781) 0:01:47.81',
                        IFINOCTETS       => '743707225',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '429778159',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '520',
                        IFNAME           => 'ge-0/0/0.20',
                        IFDESCR          => 'ge-0/0/0.20',
                        IFTYPE           => '135',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:21:59:86:a4:00',
                        IFLASTCHANGE     => '(10781) 0:01:47.81',
                        IFINOCTETS       => '1341385832',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1099149648',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '521',
                        IFNAME           => 'ge-0/0/0.41',
                        IFDESCR          => 'ge-0/0/0.41',
                        IFTYPE           => '135',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:21:59:86:a4:00',
                        IFLASTCHANGE     => '(10781) 0:01:47.81',
                        IFINOCTETS       => '1632523693',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1229649853',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '522',
                        IFNAME           => 'ge-0/0/0.44',
                        IFDESCR          => 'ge-0/0/0.44',
                        IFTYPE           => '135',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:21:59:86:a4:00',
                        IFLASTCHANGE     => '(10781) 0:01:47.81',
                        IFINOCTETS       => '1258993550',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1699247232',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '523',
                        IFNAME           => 'ge-0/0/0.32767',
                        IFDESCR          => 'ge-0/0/0.32767',
                        IFTYPE           => '135',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '00:21:59:86:a4:00',
                        IFLASTCHANGE     => '(10781) 0:01:47.81',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '525',
                        IFNAME           => 'ge-0/0/7.0',
                        IFDESCR          => 'ge-0/0/7.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:21:59:86:a4:07',
                        IFLASTCHANGE     => '(10374) 0:01:43.74',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '526',
                        IFNAME           => 'mt-6/0/0',
                        IFDESCR          => 'mt-6/0/0',
                        IFTYPE           => '131',
                        IFSPEED          => '800000000',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(21981) 0:03:39.81',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '532',
                        IFNAME           => 'ge-0/0/1.955',
                        IFDESCR          => 'ge-0/0/1.955',
                        IFTYPE           => '135',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:21:59:86:a4:01',
                        IFLASTCHANGE     => '(10881) 0:01:48.81',
                        IFINOCTETS       => '3724507636',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1049327709',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '533',
                        IFNAME           => 'ge-0/0/1.32767',
                        IFDESCR          => 'ge-0/0/1.32767',
                        IFTYPE           => '135',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '00:21:59:86:a4:01',
                        IFLASTCHANGE     => '(10881) 0:01:48.81',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        },
    ],
    'juniper/srx3400.03.walk' => [
        {
            TYPE         => 'NETWORKING',
            MANUFACTURER => 'Juniper',
            MODEL        => 'SRX3400',
            DESCRIPTION  => 'Routeur Dauphine Juniper SRX3400',

            SNMPHOSTNAME => 'Dauphine-routeur',
            SERIAL       => 'AA2009AA0007',
            MAC          => '00:21:59:86:a8:00',
        },
        {
            INFO => {
                ID           => undef,
                TYPE         => 'NETWORKING',
                MANUFACTURER => 'Juniper',
                MODEL        => 'SRX3400',
                COMMENTS     => 'Routeur Dauphine Juniper SRX3400',
                NAME         => 'Dauphine-routeur',
                SERIAL       => 'AA2009AA0007',
                MAC          => '00:21:59:86:a8:00',
            },
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFNAME           => 'fxp0',
                        IFDESCR          => 'fxp0',
                        IFTYPE           => '6',
                        IFSPEED          => '100000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:92:fb:7f',
                        IFLASTCHANGE     => '(15) 0:00:00.15',
                        IFINOCTETS       => '2952940484',
                        IFINERRORS       => '31',
                        IFOUTOCTETS      => '3037780714',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '4',
                        IFNAME           => 'lsi',
                        IFDESCR          => 'lsi',
                        IFTYPE           => '150',
                        IFSPEED          => '0',
                        IFMTU            => '1496',
                        IFLASTCHANGE     => '(22) 0:00:00.22',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '5',
                        IFNAME           => 'dsc',
                        IFDESCR          => 'dsc',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(11) 0:00:00.11',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '6',
                        IFNAME           => 'lo0',
                        IFDESCR          => 'lo0',
                        IFTYPE           => '24',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(20) 0:00:00.20',
                        IFINOCTETS       => '321074',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '321074',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '7',
                        IFNAME           => 'tap',
                        IFDESCR          => 'tap',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(26) 0:00:00.26',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '8',
                        IFNAME           => 'gre',
                        IFDESCR          => 'gre',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(16) 0:00:00.16',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '9',
                        IFNAME           => 'ipip',
                        IFDESCR          => 'ipip',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(19) 0:00:00.19',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '10',
                        IFNAME           => 'pime',
                        IFDESCR          => 'pime',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(24) 0:00:00.24',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '11',
                        IFNAME           => 'pimd',
                        IFDESCR          => 'pimd',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(23) 0:00:00.23',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '12',
                        IFNAME           => 'mtun',
                        IFDESCR          => 'mtun',
                        IFTYPE           => '131',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(23) 0:00:00.23',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '13',
                        IFNAME           => 'fxp0.0',
                        IFDESCR          => 'fxp0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '100000000',
                        IFMTU            => '1500',
                        MAC              => '00:21:59:92:fb:7f',
                        IFLASTCHANGE     => '(15) 0:00:00.15',
                        IFINOCTETS       => '2952940484',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3037780714',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '17',
                        IFNAME           => 'em0',
                        IFDESCR          => 'em0',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '02:00:00:00:00:04',
                        IFLASTCHANGE     => '(12) 0:00:00.12',
                        IFINOCTETS       => '669663345',
                        IFINERRORS       => '147',
                        IFOUTOCTETS      => '228891812',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '18',
                        IFNAME           => 'em0.0',
                        IFDESCR          => 'em0.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '02:00:00:00:00:04',
                        IFLASTCHANGE     => '(12) 0:00:00.12',
                        IFINOCTETS       => '669663467',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1078329431',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '21',
                        IFNAME           => 'lo0.16384',
                        IFDESCR          => 'lo0.16384',
                        IFTYPE           => '24',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(21) 0:00:00.21',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '22',
                        IFNAME           => 'lo0.16385',
                        IFDESCR          => 'lo0.16385',
                        IFTYPE           => '24',
                        IFSPEED          => '0',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(21) 0:00:00.21',
                        IFINOCTETS       => '321074',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '321074',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '23',
                        IFNAME           => 'em1',
                        IFDESCR          => 'em1',
                        IFTYPE           => '6',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '02:00:01:00:00:04',
                        IFLASTCHANGE     => '(14) 0:00:00.14',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '24',
                        IFNAME           => 'em1.0',
                        IFDESCR          => 'em1.0',
                        IFTYPE           => '53',
                        IFSPEED          => '0',
                        IFMTU            => '1500',
                        MAC              => '02:00:01:00:00:04',
                        IFLASTCHANGE     => '(14) 0:00:00.14',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '501',
                        IFNAME           => 'irb',
                        IFDESCR          => 'irb',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a8:20',
                        IFLASTCHANGE     => '(19) 0:00:00.19',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '502',
                        IFNAME           => 'ppd0',
                        IFDESCR          => 'ppd0',
                        IFTYPE           => '131',
                        IFSPEED          => '800000000',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(24) 0:00:00.24',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '503',
                        IFNAME           => 'ppe0',
                        IFDESCR          => 'ppe0',
                        IFTYPE           => '131',
                        IFSPEED          => '800000000',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(25) 0:00:00.25',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '504',
                        IFNAME           => 'st0',
                        IFDESCR          => 'st0',
                        IFTYPE           => '1',
                        IFSPEED          => '0',
                        IFMTU            => '9192',
                        IFLASTCHANGE     => '(25) 0:00:00.25',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '505',
                        IFNAME           => 'ge-0/0/0',
                        IFDESCR          => 'ge-0/0/0',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '00:21:59:86:a4:00',
                        IFLASTCHANGE     => '(10578) 0:01:45.78',
                        IFINOCTETS       => '4282189426',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1325024476',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '506',
                        IFNAME           => 'ge-0/0/1',
                        IFDESCR          => 'ge-0/0/1',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '00:21:59:86:a4:01',
                        IFLASTCHANGE     => '(136375937) 15 days, 18:49:19.37',
                        IFINOCTETS       => '3432322590',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '148633513',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '507',
                        IFNAME           => 'ge-0/0/2',
                        IFDESCR          => 'ge-0/0/2',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a4:02',
                        IFLASTCHANGE     => '(10248) 0:01:42.48',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '508',
                        IFNAME           => 'ge-0/0/3',
                        IFDESCR          => 'ge-0/0/3',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a4:03',
                        IFLASTCHANGE     => '(10250) 0:01:42.50',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '509',
                        IFNAME           => 'ge-0/0/4',
                        IFDESCR          => 'ge-0/0/4',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a4:04',
                        IFLASTCHANGE     => '(10251) 0:01:42.51',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '510',
                        IFNAME           => 'ge-0/0/5',
                        IFDESCR          => 'ge-0/0/5',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a4:05',
                        IFLASTCHANGE     => '(10254) 0:01:42.54',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '511',
                        IFNAME           => 'ge-0/0/6',
                        IFDESCR          => 'ge-0/0/6',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a4:06',
                        IFLASTCHANGE     => '(10255) 0:01:42.55',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '512',
                        IFNAME           => 'ge-0/0/7',
                        IFDESCR          => 'ge-0/0/7',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a4:07',
                        IFLASTCHANGE     => '(10257) 0:01:42.57',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '513',
                        IFNAME           => 'ge-0/0/8',
                        IFDESCR          => 'ge-0/0/8',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a4:08',
                        IFLASTCHANGE     => '(10263) 0:01:42.63',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '514',
                        IFNAME           => 'ge-0/0/9',
                        IFDESCR          => 'ge-0/0/9',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a4:09',
                        IFLASTCHANGE     => '(10267) 0:01:42.67',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '515',
                        IFNAME           => 'ge-0/0/10',
                        IFDESCR          => 'ge-0/0/10',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a4:0a',
                        IFLASTCHANGE     => '(10270) 0:01:42.70',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '516',
                        IFNAME           => 'ge-0/0/11',
                        IFDESCR          => 'ge-0/0/11',
                        IFTYPE           => '6',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1514',
                        MAC              => '00:21:59:86:a4:0b',
                        IFLASTCHANGE     => '(10273) 0:01:42.73',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '518',
                        IFNAME           => 'ge-0/0/0.2',
                        IFDESCR          => 'ge-0/0/0.2',
                        IFTYPE           => '135',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:21:59:86:a4:00',
                        IFLASTCHANGE     => '(10578) 0:01:45.78',
                        IFINOCTETS       => '3701298241',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '1648159356',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '520',
                        IFNAME           => 'ge-0/0/0.20',
                        IFDESCR          => 'ge-0/0/0.20',
                        IFTYPE           => '135',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:21:59:86:a4:00',
                        IFLASTCHANGE     => '(10578) 0:01:45.78',
                        IFINOCTETS       => '930021599',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4181873025',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '521',
                        IFNAME           => 'ge-0/0/0.41',
                        IFDESCR          => 'ge-0/0/0.41',
                        IFTYPE           => '135',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:21:59:86:a4:00',
                        IFLASTCHANGE     => '(10578) 0:01:45.78',
                        IFINOCTETS       => '2550787146',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '4130402370',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '522',
                        IFNAME           => 'ge-0/0/0.44',
                        IFDESCR          => 'ge-0/0/0.44',
                        IFTYPE           => '135',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:21:59:86:a4:00',
                        IFLASTCHANGE     => '(10578) 0:01:45.78',
                        IFINOCTETS       => '844254462',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '3846514844',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '523',
                        IFNAME           => 'ge-0/0/0.32767',
                        IFDESCR          => 'ge-0/0/0.32767',
                        IFTYPE           => '135',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '00:21:59:86:a4:00',
                        IFLASTCHANGE     => '(10578) 0:01:45.78',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '524',
                        IFNAME           => 'ge-0/0/0.21',
                        IFDESCR          => 'ge-0/0/0.21',
                        IFTYPE           => '135',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:21:59:86:a4:00',
                        IFLASTCHANGE     => '(10578) 0:01:45.78',
                        IFINOCTETS       => '621866926',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '536701402',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '525',
                        IFNAME           => 'ge-0/0/7.0',
                        IFDESCR          => 'ge-0/0/7.0',
                        IFTYPE           => '53',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:21:59:86:a4:07',
                        IFLASTCHANGE     => '(10259) 0:01:42.59',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '526',
                        IFNAME           => 'mt-6/0/0',
                        IFDESCR          => 'mt-6/0/0',
                        IFTYPE           => '131',
                        IFSPEED          => '800000000',
                        IFMTU            => '2147483647',
                        IFLASTCHANGE     => '(21982) 0:03:39.82',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '532',
                        IFNAME           => 'ge-0/0/1.955',
                        IFDESCR          => 'ge-0/0/1.955',
                        IFTYPE           => '135',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1500',
                        MAC              => '00:21:59:86:a4:01',
                        IFLASTCHANGE     => '(136375937) 15 days, 18:49:19.37',
                        IFINOCTETS       => '3760647450',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '161082278',
                        IFOUTERRORS      => '0',
                    },
                    {
                        IFNUMBER         => '533',
                        IFNAME           => 'ge-0/0/1.32767',
                        IFDESCR          => 'ge-0/0/1.32767',
                        IFTYPE           => '135',
                        IFSPEED          => '1000000000',
                        IFMTU            => '1518',
                        MAC              => '00:21:59:86:a4:01',
                        IFLASTCHANGE     => '(136375937) 15 days, 18:49:19.37',
                        IFINOCTETS       => '0',
                        IFINERRORS       => '0',
                        IFOUTOCTETS      => '0',
                        IFOUTERRORS      => '0',
                    },
                ]
            },
        },
    ],
);

plan skip_all => 'SNMP walks database required'
    if !$ENV{SNMPWALK_DATABASE};
plan tests => 2 * scalar keys %tests;

foreach my $test (sort keys %tests) {
    my $snmp  = FusionInventory::Agent::SNMP::Mock->new(
        file => "$ENV{SNMPWALK_DATABASE}/$test"
    );

    my %discovery = getDeviceInfo(
        snmp    => $snmp,
        datadir => './share'
    );
    cmp_deeply(
        \%discovery,
        $tests{$test}->[0],
        "$test: discovery"
    );

    my $inventory = getDeviceFullInfo(
        snmp    => $snmp,
        datadir => './share'
    );
    cmp_deeply(
        $inventory,
        $tests{$test}->[1],
        "$test: inventory"
    );
}
